/*******************************************************************************
    PRODIGAL (PROkaryotic DynamIc Programming Genefinding ALgorithm)
    Copyright (C) 2007-2010 University of Tennessee / UT-Battelle

    Code Author:  Doug Hyatt

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*******************************************************************************/

#include "training.h"

/* Reads a training file to use for gene prediction */

int read_training_file(char *fn, struct _training *tinf) {
  size_t rv;
  FILE *fh;
  fh = fopen(fn, "rb");
  if(fh == NULL) return 1;
  rv = fread(tinf, sizeof(struct _training), 1, fh);
  fclose(fh);
  if(rv != 1) return -1;
  return 0;
}

/* Writes a training file to use for a later run of gene prediction */

int write_training_file(char *fn, struct _training *tinf) {
  size_t rv;
  FILE *fh;
  fh = fopen(fn, "wb");
  if(fh == NULL) return -1;
  rv = fwrite(tinf, sizeof(struct _training), 1, fh);
  fclose(fh);
  if(rv != 1) return -1;
  return 0;
}

/*******************************************************************************
  The following functions initialize training data for the model genomes that
  we chose as our "bins" for metagenomic data.  Rather than put this info in
  binary files, we decided to hard code it here so that it would be part of
  the executable (making the Prodigal binary much larger but self-contained).
*******************************************************************************/
void initialize_metagenome_0(struct _training *tptr) {
  struct _training tinf = {
    0.240, 4, 4.350, { 2.312, 0.472, 0.215 }, { 0.614, -0.096, -2.495 }, 1, 
    { -1.015, -1.533, -0.875, 1.107, 0.340, -4.000, -0.041, -4.000, 0.084, 1.139, 1.471, -4.000, 1.178, 0.641, 0.027, 2.182, 2.101, 0.615, -0.174, 1.863, 0.720, 2.830, 2.655, 2.917, 2.298, 2.224, 2.917, 2.735 }, 
    {{ -0.043, -0.719, -0.291, 0.249},{ 0.222, -0.361, -0.475, -0.035},{ 0.262, -0.079, -0.828, -0.103},{ 0.241, 0.133, -0.669, -0.179},{ 0.247, -0.043, -0.489, -0.157},{ 0.253, -0.088, -0.652, -0.118},{ 0.239, -0.247, -0.349, -0.115},{ 0.331, -0.302, -0.337, -0.248},{ 0.154, -0.184, -0.385, -0.013},{ 0.243, -0.545, -0.475, -0.024},{ 0.163, -0.236, 0.183, -0.192},{ 0.136, 0.197, -0.489, -0.097},{ 0.179, -0.135, -0.669, -0.003},{ 0.258, -0.145, -0.503, -0.136},{ 0.074, -0.236, -0.226, 0.052},{ 0.161, -0.423, -0.385, 0.034},{ 0.091, -0.164, -0.302, 0.034},{ 0.044, -0.070, -0.410, 0.079},{ 0.024, -0.236, 0.270, -0.057},{ 0.059, 0.204, -0.503, -0.008},{ -0.077, -0.009, -0.325, 0.152},{ 0.174, -0.116, -0.560, -0.021},{ 0.138, -0.017, -0.410, -0.038},{ 0.115, -0.070, -0.605, 0.042},{ 0.226, -0.079, -0.215, -0.185},{ 0.044, 0.133, -0.205, -0.032},{ 0.079, -0.280, -0.226, 0.057},{ 0.084, -0.349, -0.125, 0.042},{ 0.194, -0.088, -0.247, -0.127},{ 0.205, -0.314, -0.503, -0.019},{ 0.067, -0.079, -0.361, 0.049},{ 0.212, -0.116, -0.349, -0.115} }, 
    {{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}} }, 
    0.000, { 0.650, 1.187, 0.690, -5.000, 0.157, 1.340, -1.094, -0.330, 0.553, 1.254, 0.972, 0.531, -0.276, 0.439, -0.278, 0.568, -0.329, -0.022, -1.505, -5.000, -1.106, -0.351, -0.578, -2.498, -1.299, -0.036, -1.212, -1.371, 0.133, -1.074, -2.268, -1.333, -0.053, 0.877, -0.114, -0.115, -0.120, -0.002, -1.129, -2.625, -0.540, 0.485, -1.189, -2.667, -0.754, -1.184, -1.769, -1.394, 0.809, 1.249, 0.147, 0.532, 0.528, 1.262, 1.076, -0.558, 0.877, 1.047, 0.670, 0.254, 0.649, 0.930, 0.052, 0.137, 1.313, 1.403, 1.192, -5.000, 1.296, 1.078, -1.201, 0.639, 1.052, 1.217, 1.158, 0.817, 0.700, 1.119, 0.736, 1.200, -0.105, -0.549, -1.888, -5.000, -0.930, 0.525, -0.372, -2.017, -5.000, 0.544, -0.686, -1.212, 0.003, -0.547, -2.751, -1.041, 1.273, 0.596, 0.857, 1.446, 1.186, 0.380, 0.462, 0.914, 0.843, 0.963, 0.315, -1.950, 1.343, 0.626, 0.444, 0.279, 0.917, 1.543, 0.693, 1.007, 1.280, 1.459, 1.098, 0.626, 1.247, 1.314, 1.384, 0.948, 1.114, 1.270, 0.221, 0.645, 0.869, 1.336, 0.461, -5.000, 0.779, 1.424, -0.675, 0.481, 0.571, 0.661, 0.914, 0.422, 0.238, 0.879, 0.032, 0.701, -0.271, 0.202, -1.370, -5.000, -0.433, 1.000, -5.000, 0.458, -0.705, 0.375, -0.169, -0.411, 0.307, -0.118, -2.241, -1.270, 0.019, 0.469, -1.020, -0.924, 0.464, 0.726, 0.230, -1.240, -0.524, 0.780, -0.119, -1.110, -0.830, -1.344, -0.416, -1.075, 0.657, 1.193, -0.621, 0.358, 1.060, 1.566, 0.654, -0.013, 1.076, 1.408, 0.851, 0.952, 0.619, 0.431, -0.976, -0.591, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.015, 1.200, 0.903, -5.000, 0.094, 1.519, -2.775, -1.240, -0.054, 1.181, 0.909, 0.159, 0.165, 0.933, 0.114, 1.124, -1.048, -0.081, -0.261, -5.000, -1.530, -0.886, -5.000, -2.374, -2.736, -0.200, 1.319, 0.033, 0.342, -0.191, -1.065, -1.153, -0.471, 1.137, 0.493, 0.392, -1.326, 0.626, -0.200, -1.184, -1.658, -0.261, -1.360, -3.498, -0.604, -0.018, -5.000, -1.071, 0.746, 1.476, 0.531, 0.758, 0.243, 1.261, 1.160, -1.051, 0.570, 1.273, 1.087, 0.480, 0.269, 0.934, -0.961, -0.261, 1.153, 1.573, 1.413, -5.000, 1.530, 1.537, -5.000, 1.121, 1.044, 1.317, 1.289, 0.913, 0.867, 0.918, 0.780, 1.283, 0.358, 0.666, 1.394, -5.000, 0.321, 0.857, -5.000, -5.000, -1.011, 1.832, 0.716, 0.315, 1.366, -0.472, 0.370, -0.299, 1.266, 1.671, 1.060, 0.529, -0.105, 1.291, 1.186, 0.838, 0.655, 1.220, 0.780, -5.000, 1.334, 0.780, -5.000, 0.130, 1.184, 1.602, 1.454, 1.122, 1.325, 1.686, 1.514, 0.400, 1.519, 1.578, 0.823, 1.122, 1.088, 1.342, 0.547, 0.911, 0.087, 0.248, -1.141, -5.000, -1.647, -0.686, 0.087, -1.617, -2.355, 0.270, -0.983, -2.594, -1.758, -0.829, -5.000, -1.353, -2.756, -0.158, -0.169, -5.000, -1.511, -5.000, -5.000, -5.000, -5.000, 0.780, -5.000, -0.862, -0.113, -5.000, -5.000, -1.392, -0.606, 0.868, -5.000, -1.676, -0.647, 0.493, -5.000, -5.000, -5.000, -5.000, -0.893, -0.273, -5.000, -1.488, -0.760, -1.212, -0.897, 0.391, -0.158, -0.234, -1.065, 1.032, 1.186, -0.977, 0.310, 0.655, -5.000, 0.544, -0.296, -0.438, -0.225, -1.371, -0.528, 0.301, 0.347, -5.000, -0.918, 0.682, -2.137, -1.641, -0.850, -0.595, -0.158, -0.412, -1.837, -0.597, -1.101, -0.257, -1.121, -0.032, -0.747, -5.000, -3.254, -0.102, -5.000, -3.549, -5.000, -0.647, -0.578, -3.693, 0.136, -0.636, -0.563, -1.326, -1.167, -0.195, -0.945, -1.935, -1.952, -0.318, -2.062, -2.634, -2.359, -0.136, -1.647, -4.156, -1.908, -1.882, -5.000, -1.448, -0.563, 0.629, -0.806, -0.721, -0.845, 0.748, 0.000, -1.938, 0.097, 0.201, 0.127, -0.193, -0.741, -0.422, -0.812, -1.123, 0.054, 0.895, 0.402, -5.000, 0.284, 1.303, -1.398, -0.197, 0.450, 0.949, 0.314, 0.087, -0.049, 0.750, 0.371, 0.491, 0.217, -0.711, -1.184, -5.000, -1.635, 0.985, 0.270, -1.657, -0.290, -5.000, -0.018, 1.556, 0.386, -0.128, -1.739, -0.680, 0.274, 1.004, 0.437, 0.184, -0.874, 0.493, -0.067, -1.299, -1.052, -0.067, 1.235, -2.621, -0.347, 0.394, -1.627, -0.780, 0.514, 1.243, -0.062, 0.450, 0.460, 1.071, 0.444, -0.044, 0.335, 1.146, 0.790, 0.135, 0.481, 0.143, 0.047, 0.305, 0.698, 1.037, 1.275, -5.000, 1.202, 1.198, 1.581, 0.043, 1.007, 0.625, 0.243, 0.218, 0.568, 0.705, 0.410, 0.934, 0.276, 0.315, 0.439, -5.000, -1.587, 0.007, -0.200, -0.403, 0.375, 1.281, -0.318, -0.067, 1.368, -0.398, -0.954, 0.624, 0.883, 1.626, 0.465, 0.838, 0.432, 0.493, -5.000, 0.270, 0.375, -0.067, 0.193, -0.954, 0.729, 1.397, -5.000, -0.067, 0.837, 1.287, 1.363, 1.135, 1.003, 1.503, 1.096, 0.965, 0.953, 1.107, 0.825, 0.151, 1.033, 0.986, -0.172, 0.501, 0.761, 1.125, 0.839, -5.000, 0.639, 1.105, -0.563, -0.635, 0.735, 0.619, -0.454, 0.523, 0.566, 0.857, 0.426, 0.847, 0.593, 0.507, -1.704, -5.000, -1.256, 1.368, 0.270, -0.200, -1.417, 0.270, 0.270, -0.008, 1.304, -0.141, -0.318, -0.656, 0.543, 0.903, 0.344, 0.422, 0.221, -5.000, 1.229, -0.626, 0.425, 0.315, 0.007, -1.732, 0.919, 0.655, -1.256, 0.245, 0.696, 1.294, 0.741, 0.611, 0.609, 1.117, 1.562, -1.051, 0.942, 0.722, -0.592, 0.265, 0.589, 0.704, -0.020, 0.340, 0.182, 0.908, 0.549, -5.000, 0.093, 0.528, -1.136, -1.180, -0.030, 0.002, 0.166, -0.212, -0.872, -0.015, -0.049, 0.292, -0.411, 0.582, -0.062, -5.000, -2.140, -0.136, -5.000, -2.869, -0.742, -1.429, -0.067, -0.231, 0.718, -0.211, -0.954, -0.729, -0.025, 0.335, 0.141, -0.596, -0.699, 0.521, -5.000, -1.314, -0.842, -0.273, -0.606, -1.697, 0.048, 0.052, -0.585, -0.567, 0.351, 0.981, 0.540, 0.576, 0.238, 0.985, 0.438, -0.950, 0.553, 0.867, 0.040, 0.104, 0.510, 0.557, 0.097, -0.045, -0.040, 0.379, 0.062, -5.000, 0.031, 0.948, -1.149, -1.203, -0.100, 0.188, 0.376, -0.267, -1.070, -0.227, -1.314, -0.333, -1.312, -1.033, -1.641, -5.000, -1.758, -0.067, -5.000, -2.474, -2.280, -0.225, -0.448, -1.533, -0.771, -1.462, -1.820, -0.933, -0.420, 0.433, -0.579, 0.095, -1.045, -0.742, -0.398, -1.784, -2.041, -1.309, -1.541, -2.724, -1.906, -1.394, -2.448, -1.411, -0.066, 0.523, -0.316, 0.348, -0.141, 0.637, 0.863, -1.037, 0.454, 0.590, 0.696, -0.287, -0.266, 0.256, -0.954, -0.410, 0.653, 1.197, 0.801, -5.000, 0.941, 1.083, -0.954, 0.120, 0.685, 0.790, 0.630, 0.695, -0.170, 0.336, -0.253, 0.456, -1.258, -0.739, -1.550, -5.000, -0.862, 0.493, 0.375, -3.105, -0.883, 0.529, 0.033, -0.067, -0.010, -1.041, -1.965, -1.474, 0.205, -0.200, 0.557, -0.200, -0.318, -0.893, -5.000, -1.647, 0.136, 0.898, 0.174, -0.318, -0.227, 0.156, -0.924, -1.363, 0.563, 1.235, -0.037, 0.656, 0.704, 1.152, 0.730, -0.020, 0.746, 1.041, 0.992, 0.123, 0.441, 0.614, -0.715, 0.115, 0.296, 0.676, -0.264, -5.000, 0.550, 0.937, 0.037, -0.521, 0.127, 0.499, 0.569, 0.046, -0.644, 0.201, -0.873, 0.005, -0.631, -0.698, -1.646, -5.000, 0.682, 1.186, -0.043, -2.232, -1.453, 0.156, -0.743, -1.100, -0.095, -0.593, -2.061, -0.951, -0.502, -0.954, -1.120, -1.651, 0.087, -0.200, 0.087, -2.248, -0.292, -0.318, 0.116, -0.456, -0.991, -2.365, -2.153, -1.663, -0.258, 0.433, -1.537, -0.889, -0.067, 0.645, 0.187, -1.258, -0.080, -0.374, -0.222, -0.489, -0.141, -0.627, -2.035, -1.656, 0.439, 0.949, 0.416, -5.000, 0.615, 1.295, -0.423, -0.296, 0.384, 0.515, 0.425, 0.336, -0.160, 0.589, -0.507, 0.485, -0.160, 0.489, -0.505, -5.000, -0.487, 1.088, -1.505, -1.503, -2.062, 0.395, 1.447, 0.194, 0.574, -0.468, -1.704, -0.217, 0.328, 0.848, -0.541, -0.413, 0.096, 0.705, 0.239, -0.620, -0.242, 1.100, -0.004, -0.957, -0.063, -0.345, -0.341, -0.311, 0.576, 1.112, -0.008, 0.406, 0.850, 1.024, 0.982, -0.133, 0.907, 1.248, 0.621, -0.010, 0.681, 0.830, -0.258, -0.000, -0.159, 0.221, -0.646, -5.000, -0.601, 0.481, -0.456, -1.151, -1.115, 0.670, 0.224, -1.239, -1.384, -1.016, -2.136, -0.815, -1.505, -1.295, -1.679, -5.000, -2.870, -0.488, -5.000, -3.048, -5.000, -5.000, -0.200, 0.111, -1.339, -1.571, -2.862, -2.292, -1.335, -0.190, -0.751, -1.779, -2.359, 0.018, -5.000, -1.663, -1.522, -5.000, -0.872, -2.398, -1.625, -2.493, -3.328, -1.060, 0.136, 1.006, -0.427, -0.038, 0.018, 1.103, 0.898, -0.512, 0.728, 0.956, 1.186, 0.444, 0.081, 0.752, -0.359, -0.741, 0.828, 0.603, -0.512, -5.000, 0.810, 0.759, -0.423, -0.179, 0.935, 0.780, 0.462, 0.145, -0.545, -0.288, -0.609, 0.479, -0.776, -1.758, -2.532, -5.000, -5.000, 0.493, -1.647, -1.256, -1.732, 0.655, -5.000, -0.067, -1.079, -1.169, -2.731, -1.109, -0.760, -5.000, -3.091, -0.924, 0.397, 0.716, -5.000, 0.675, 0.339, 0.780, -5.000, -5.000, -1.340, 0.007, 0.087, -0.472, 0.236, 1.070, -0.464, -0.433, 0.759, 0.942, 0.111, -0.529, 0.905, 0.467, 0.647, 0.527, 0.358, 0.109, -0.930, -0.516, -0.408, -0.322, -1.739, -5.000, -0.555, 1.437, -5.000, -1.177, -1.417, -0.606, -0.136, -1.256, -2.218, -1.982, -1.482, 0.033, -1.984, -1.481, -3.215, -5.000, -0.686, -0.136, -5.000, -2.110, -5.000, -5.000, -5.000, -0.067, -1.390, -1.533, -1.810, -2.108, -1.560, 0.581, -2.007, -2.301, -0.318, 0.963, -0.136, -5.000, -2.587, -1.256, -0.711, 0.033, -2.124, -2.465, -2.171, -2.751, -0.637, 0.174, -2.002, -0.884, -0.078, 0.748, 1.004, -2.026, 0.146, -0.511, -0.038, -0.036, -1.527, -0.378, -2.392, -1.880, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -1.834, 0.690, -2.006, -5.000, -0.509, -1.011, -0.136, -3.036, -0.675, -0.126, -0.974, -1.879, -1.819, -0.254, -1.201, -0.106, -2.198, -5.000, -5.000, -5.000, -2.552, -0.200, -5.000, -5.000, -0.318, -5.000, 0.780, -5.000, -0.920, -5.000, -5.000, -1.922, -1.971, -1.453, -5.000, -1.560, -2.746, -5.000, -5.000, -5.000, -2.821, -5.000, -1.676, -2.268, -2.209, -0.893, -5.000, -4.149, -0.858, -0.043, -1.285, -2.275, -0.772, -0.398, -0.662, -1.002, -1.569, -1.141, -0.760, -1.509, -1.462, -2.006, -1.488, -1.936, 0.668, 1.132, 1.129, -5.000, 0.722, 1.014, 0.087, 0.375, 0.963, 0.881, 0.935, -0.038, 0.106, 0.809, -0.606, 1.142, -0.711, -0.606, 0.339, -5.000, -1.065, -0.541, -1.758, -1.091, -5.000, -1.091, -0.067, 0.493, 0.416, -0.914, -5.000, -0.589, 0.087, 0.270, -5.000, -0.519, -1.982, 1.186, 1.186, -0.030, -5.000, 0.493, -0.067, -1.165, 0.007, -0.200, 1.032, -0.783, 0.139, 1.121, 0.780, 0.251, 0.526, 1.474, 1.394, -0.269, 0.605, 1.344, 0.626, 0.720, 0.616, 0.834, 0.226, 0.485, -1.723, -1.647, -5.000, -5.000, -5.000, -5.000, 0.493, -5.000, -5.000, -5.000, -0.760, -5.000, -1.732, 0.033, -0.829, -0.862, -2.033, -0.318, -0.394, -5.000, -5.000, -5.000, -5.000, -1.340, -5.000, -5.000, -5.000, -5.000, -0.354, 0.493, -0.318, 0.237, -0.549, -5.000, 0.780, -1.065, -1.417, -5.000, -5.000, -5.000, -0.423, -5.000, -0.760, -0.200, -5.000, -5.000, -5.000, 0.007, -1.201, -1.488, -5.000, -5.000, -5.000, -0.318, 0.493, -0.423, -5.000, 0.493, -5.000, -5.000, -0.633, -0.200, -0.893, -1.905, -2.017, -1.328, -1.446, -5.000, -2.204, -1.091, -0.261, -3.481, -1.810, -1.555, -0.606, -1.816, -2.546, -2.515, -2.053, -2.168, -2.534, -0.724, -1.704, -5.000, -3.492, -1.859, -5.000, -4.461, -2.264, -5.000, -5.000, -5.000, -0.993, -2.478, -0.829, -1.831, -3.029, -1.022, -0.934, -2.288, -4.248, -5.000, -5.000, -2.269, -2.726, -5.000, -5.000, -2.418, -2.987, -1.905, -5.000, -3.427, -2.146, -1.923, -2.190, -2.920, -0.559, -0.606, -1.117, -2.357, -1.632, -1.288, -0.463, -2.164, -2.057, -2.583, -5.000, -2.375, -1.629, -0.153, -2.280, -5.000, -0.760, 0.992, -0.829, -2.653, -0.504, 0.304, 0.493, -1.299, -1.366, -1.637, -1.732, -0.862, -2.522, -0.686, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -2.411, -5.000, -5.000, -1.474, -1.992, -1.256, -1.587, -0.225, -2.232, -5.000, -5.000, -1.676, -1.488, -5.000, -0.686, -0.914, -3.510, -0.067, -1.141, 0.502, -0.472, 0.270, -2.326, -0.572, -0.862, 0.493, 0.087, -0.472, -1.834, 0.675, -0.075, -0.686, -1.100, -1.392, -0.893, -2.949, 0.052, 1.240, 0.700, -5.000, 0.744, 0.413, -0.200, 0.230, -0.158, 0.716, 0.924, 0.240, -0.107, -0.390, 1.441, 1.340, -1.511, -5.000, 1.186, -5.000, -5.000, 0.780, 0.087, -5.000, -5.000, -0.067, -0.200, -5.000, 0.462, -0.200, 0.270, 0.007, -5.000, -5.000, 0.493, -5.000, 0.000, 0.270, 0.000, -5.000, 0.270, 0.087, -5.000, 0.493, -0.318, 0.329, -5.000, -5.000, 0.310, 0.809, 0.898, 0.007, 0.780, 1.304, 1.697, -0.760, 0.087, 1.368, 0.963, 0.205, 0.145, -0.378, -0.647, -0.724, 0.138, 0.375, -0.290, -5.000, 0.626, -5.000, 1.474, -0.067, 0.375, -0.519, 0.626, -0.261, 1.456, -0.563, -1.212, 0.580, -0.496, -5.000, 0.339, -5.000, -5.000, -5.000, -5.000, 0.963, 0.898, -5.000, -5.000, -0.200, -0.273, -5.000, -5.000, -0.200, -0.606, -5.000, -0.519, -5.000, 0.375, 0.000, 0.780, -5.000, 0.270, -5.000, 0.187, 0.493, -1.784, -5.000, -0.954, 0.033, 0.284, 0.306, -0.563, 0.709, -1.522, 0.493, 1.186, -0.423, 0.055, 0.205, 1.186, -1.212, 0.270, 0.353, 0.156, -0.578, 0.485, 0.039, -1.745, -5.000, -0.054, 0.156, -5.000, -2.053, -0.253, -5.000, -0.954, -1.732, -1.256, -0.456, -1.453, -0.498, -1.104, 0.493, -0.519, -5.000, -0.606, -5.000, -5.000, -5.000, -0.423, 0.000, -5.000, 0.087, -0.362, -5.000, -5.000, -2.621, -1.096, 0.087, -0.954, -5.000, -0.030, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.862, -5.000, -0.423, -2.587, -0.496, 0.234, -1.117, 1.278, 0.450, -0.633, -0.829, -0.705, -0.519, -0.686, -0.829, -1.389, -0.014, -1.212, -0.862, -0.458, 0.078, 0.701, -0.107, -5.000, 0.750, 1.586, -0.018, -0.484, 0.375, 1.237, 1.336, 0.791, -0.902, 0.220, -1.195, -0.051, -1.360, -1.005, -1.172, -5.000, -1.602, 0.780, -5.000, -1.503, -2.765, -0.261, 0.174, -1.256, -0.824, -1.314, -3.101, -2.000, -0.806, 0.060, -0.276, -0.442, -1.138, -0.549, -0.893, -1.987, -1.173, -1.488, -5.000, -5.000, -1.715, -2.248, -2.198, -2.653, 0.072, 0.773, -0.432, -0.013, 0.660, 1.445, 0.382, -0.772, 0.416, 1.474, 1.143, 0.354, 0.090, 0.157, -1.138, -0.058, 0.163, 0.373, 0.324, -5.000, 0.361, -0.058, -0.954, -2.072, -0.184, 0.339, -0.087, -0.802, -0.904, -1.621, -1.567, -0.425, -2.398, -0.718, -2.458, -5.000, -1.797, 0.145, -5.000, -2.874, -1.587, -5.000, -5.000, -0.519, -1.518, -2.096, -2.343, -2.694, -1.505, -1.657, -0.456, -2.215, -1.971, -1.011, -0.200, -1.732, -1.039, -0.318, -5.000, -2.198, -2.404, -1.065, -1.299, -1.745, -0.174, 0.537, -0.969, -0.084, 0.384, 0.603, 0.359, -1.435, 0.304, 0.983, 0.690, -0.383, -0.469, -0.519, -1.247, -1.234, -1.223, -1.283, -2.907, -5.000, -0.506, 1.294, -0.519, -3.394, -2.221, -5.000, -0.095, -1.535, -2.055, -2.240, -2.106, -1.744, -2.258, -2.236, -2.594, -5.000, -1.256, -0.241, -0.760, -1.704, -1.732, -1.065, -5.000, -0.862, -2.234, -1.639, -2.522, -3.134, -1.987, -1.500, -5.000, -2.398, -0.549, -5.000, -5.000, -1.758, -5.000, -5.000, -5.000, -5.000, -1.873, -5.000, -2.937, -2.900, -1.507, -0.997, -2.713, -0.649, -0.507, -1.039, -5.000, -1.407, -0.329, 0.023, -0.423, -0.954, -2.064, -1.741, -2.267, -2.486, -1.399, -0.425, -0.756, -5.000, -1.058, 0.728, -1.340, -2.298, -1.606, -0.622, -0.976, -1.194, -2.516, -1.516, -2.067, -1.342, -1.679, -1.014, -0.619, -5.000, -1.220, -0.200, -0.578, -1.952, -2.765, -5.000, -5.000, -1.834, -1.476, -1.808, -3.754, -1.402, -1.228, -0.233, -1.593, -1.684, -1.838, -1.471, -0.909, -2.780, -0.839, -1.234, -5.000, -2.181, -1.514, -0.310, -1.899, -2.327, -1.224, -0.256, -1.605, -1.998, -0.875, 0.813, -0.670, -1.776, -0.768, -0.466, -1.233, -1.645, -1.497, -1.496, -2.200, -2.090, 0.152, 0.764, 0.349, -5.000, -0.294, 0.829, -1.905, -0.576, -0.404, 0.412, 0.934, -0.342, -0.800, -0.306, -1.111, 0.181, -1.449, -1.576, -1.335, -5.000, -2.886, -0.660, -5.000, -2.623, -1.662, -0.647, -1.299, -1.690, -0.800, -1.676, -1.707, -1.883, -0.850, -0.256, -0.413, -1.045, -2.221, -1.288, -2.575, -3.034, -2.215, -1.221, -1.245, -2.760, -1.750, -2.721, -2.632, -2.173, 0.214, 0.601, -0.481, -0.112, -0.625, 0.690, -1.104, -3.384, -0.031, 1.013, 0.866, -0.614, -0.352, 0.521, -0.328, -0.485, 0.777, 1.026, 0.359, -5.000, 1.404, 0.424, -0.829, 0.121, 0.827, 1.052, 1.186, 0.516, 0.800, 0.199, 0.355, 0.698, -0.829, -0.572, -2.215, -5.000, -0.423, 0.270, 0.174, -0.954, -1.704, 1.474, 0.700, -1.488, -0.077, -1.379, -5.000, -1.344, 0.826, 1.237, 0.321, -0.067, 0.626, -5.000, -5.000, -0.954, -5.000, 0.963, 0.898, -0.472, -1.894, -5.000, -0.686, -0.354, 0.421, 1.271, 0.055, 0.472, 0.072, 0.823, 0.221, -0.482, 0.693, 1.580, 0.716, 0.542, 0.509, 0.680, 0.773, 0.350, -0.319, 0.566, -0.568, -5.000, 0.312, 0.988, -5.000, -1.086, -0.277, 0.809, 0.356, 0.225, -1.564, -0.993, -1.072, 0.452, -0.855, -0.273, -0.184, -5.000, -0.893, 0.339, -0.136, -1.607, -0.354, -5.000, -0.200, -5.000, -0.782, -1.522, -1.533, -1.433, -0.463, -1.894, -1.285, -1.830, -1.011, -5.000, -0.200, -1.091, -2.002, -0.067, -0.914, -1.048, -1.905, -0.463, -2.556, -0.688, -0.031, 0.358, -1.551, -0.677, -0.217, 1.186, 0.270, -0.716, 0.319, 0.802, 0.823, 0.422, -0.159, -0.210, -1.779, -1.074, -0.213, 0.472, -0.084, -5.000, -0.414, 1.619, -5.000, -0.950, -1.384, -0.296, -0.030, 0.619, -0.314, -1.117, -1.305, -0.346, -0.942, -0.328, -0.987, -5.000, -1.223, -0.519, -5.000, -3.286, -5.000, -5.000, -0.372, -0.829, -0.558, -1.398, -2.675, -1.081, -0.637, -0.013, 0.387, -1.130, -1.986, -0.954, -0.235, -2.303, -1.828, -0.136, -1.676, -0.615, -0.283, -1.505, -1.387, -1.390, -0.810, 0.147, -1.054, -0.996, -2.040, 1.518, -1.127, -2.140, -0.834, 0.318, 0.187, -1.530, -1.086, -0.826, -0.798, -1.343, -0.592, 0.483, -0.243, -5.000, -1.834, 1.591, -0.686, -2.387, -1.035, 0.409, 0.503, -1.428, -1.521, 0.318, -0.254, 0.111, -2.075, -0.346, -0.893, -5.000, -3.510, -1.617, -0.200, -5.000, -5.000, -0.829, -5.000, -0.954, -1.069, -5.000, -1.387, -2.614, -1.695, -1.834, -0.626, -2.606, -2.681, -5.000, -5.000, -2.844, -5.000, -5.000, -0.736, -4.230, -3.956, -2.908, -5.000, -2.185, -1.105, 0.852, -1.083, -1.188, -1.005, 0.116, -5.000, -2.981, -0.800, -0.989, -0.225, -1.676, -1.310, -0.067, -1.313, -1.358, 0.428, 0.972, 0.845, -5.000, 0.270, -1.091, -5.000, -0.496, 0.230, 0.557, 0.413, -0.829, -0.087, 0.963, 0.375, 0.847, -1.299, -5.000, -0.686, -5.000, -5.000, -5.000, 0.580, -5.000, -5.000, -5.000, 0.626, -5.000, 0.571, -0.067, -0.158, -1.299, -0.372, 0.087, 0.375, -1.299, -5.000, 0.087, 0.780, -0.067, -0.067, 0.675, 0.493, -1.488, -1.117, 0.270, -5.000, -0.241, -0.080, 0.878, 0.304, -1.086, 0.805, 0.780, 0.493, -0.290, -0.107, 1.046, 0.432, -0.261, 0.114, -0.122, 1.348, -0.783, -0.570, 0.111, 0.567, -5.000, -0.519, -5.000, 0.000, -5.000, -1.676, -5.000, -0.893, 0.270, -0.318, 0.339, -0.200, 0.304, -1.992, -0.686, -1.065, -5.000, -0.200, -5.000, -5.000, 0.270, -5.000, -5.000, -5.000, -5.000, 0.353, -5.000, -5.000, -0.030, -1.732, 0.493, 0.375, -0.724, -5.000, -5.000, -0.067, -5.000, -1.212, -5.000, -1.091, -5.000, -1.772, -5.000, -5.000, -0.372, -0.844, 0.270, -0.261, 0.468, -0.287, -5.000, -5.000, 0.033, 0.493, -0.829, 0.270, 0.716, 1.390, -0.647, -0.113, -1.576, -2.226, -1.027, -1.539, -5.000, -2.503, -0.666, -5.000, -1.270, -1.307, -1.165, -0.456, -1.982, -2.173, -0.806, -2.119, -1.760, -2.009, -1.587, -5.000, -5.000, -2.756, -1.039, -5.000, -3.712, -2.013, -5.000, -5.000, -0.983, -1.095, -5.000, -1.011, -1.613, -3.208, -1.189, -0.760, -1.820, -4.021, -1.091, -0.200, -3.864, -2.173, -0.829, -5.000, -5.000, -2.417, -1.299, -5.000, -2.438, -1.652, -0.445, -2.770, -2.794, -2.355, -0.701, -0.102, -2.805, -1.488, -0.161, -0.280, -2.091, -1.835, -1.976, -1.478, -2.103, -0.831, 0.834, -0.022, -5.000, -0.973, 0.780, -0.346, -2.892, -1.101, -0.008, 0.332, -1.036, -1.735, -1.281, -0.578, -0.674, -1.488, -0.760, -1.039, -5.000, -1.411, -0.893, -5.000, -2.775, -0.606, 0.493, -5.000, -0.067, -1.160, -5.000, -1.555, -1.608, -1.506, -0.606, 0.197, -2.077, -1.831, -1.212, -0.893, -5.000, -2.289, -5.000, -2.438, -4.189, -2.643, -0.158, -1.326, -2.009, -0.339, 0.655, -2.369, -1.640, -2.128, -1.299, 0.493, -2.736, -1.668, -0.760, -0.686, -1.647, -1.627, -0.969, -2.155, -2.359, 0.199, 1.052, 0.669, -5.000, 0.406, 0.432, -0.067, -1.676, 0.675, -0.398, 0.087, -0.724, -0.836, 0.550, -0.448, -0.013, -1.141, 1.186, -5.000, -5.000, -5.000, 0.780, 0.000, -5.000, 0.493, 0.270, -5.000, -5.000, 1.315, 0.493, 0.270, -1.065, -5.000, 1.591, 0.375, -0.893, -5.000, 0.000, -5.000, -0.200, -1.065, 0.780, -5.000, -5.000, -0.067, 0.270, -5.000, -5.000, 0.331, 1.440, 0.299, -1.030, -0.686, 1.091, -5.000, -1.453, -0.893, 0.881, 0.033, -1.453, 0.270, -0.277, -0.318, -0.760, -0.998, -0.080, -0.739, -5.000, -0.463, 0.145, -5.000, -1.928, -0.555, -0.122, -5.000, -1.488, -0.767, 1.273, -0.660, -0.128, -2.053, -0.519, -0.241, -5.000, -5.000, -5.000, -5.000, -5.000, 0.087, 0.493, 1.879, -5.000, -0.008, -0.760, -0.829, 0.211, -1.275, -1.065, -0.954, -5.000, -1.234, 0.780, -5.000, -5.000, 0.214, -0.318, -5.000, -0.647, -1.928, 0.270, -1.704, -0.456, -1.247, -0.989, -0.067, -1.165, -0.318, -5.000, 0.780, -5.000, -0.067, -0.519, 0.205, 1.112, -1.288, -0.372, -0.488, -0.491, -1.688, -0.530, -0.103, -5.000, -2.282, -0.760, -1.453, -3.699, -1.108, -1.360, -1.784, -2.685, -2.510, -1.587, -1.360, -1.289, -2.996, 0.087, -5.000, -5.000, -2.128, -5.000, -0.686, -5.000, -1.360, -0.067, 0.493, -5.000, -1.488, -0.175, -5.000, -1.667, -2.721, -0.563, -2.892, -3.084, -5.000, -0.261, -5.000, -3.670, -5.000, -1.091, -5.000, -5.000, -3.339, -2.215, -1.256, -1.765, -2.349, -1.497, -2.264, -3.011, -3.370, -0.472, -5.000, -2.866, -2.345, -2.908, -1.011, -1.764, -2.118, -0.269, -1.847, -2.587, -0.225, 0.761, -0.058, -5.000, -0.843, 0.806, -1.471, -2.086, -0.659, 0.615, 0.824, -0.697, -0.875, -0.493, -1.404, -0.503, -1.349, -0.839, -3.770, -5.000, -2.207, -0.989, -5.000, -2.506, -1.627, 0.452, 0.591, -2.248, -0.702, -1.251, -1.091, -2.046, -1.313, -0.365, -0.633, -0.258, -3.295, -0.541, -0.983, -2.716, -2.787, -0.914, -1.181, -2.413, -0.906, -1.242, -2.534, -2.985, -0.693, 0.205, -0.188, -1.422, -1.714, 0.145, 0.270, -2.475, -0.933, 0.313, -0.736, -2.005, -1.224, 0.085, -2.769, -1.674, 0.293, 0.365, -0.612, -5.000, 0.043, -0.158, -0.606, -1.693, 0.474, 0.683, -1.245, -0.932, -1.209, 0.074, -1.294, -0.969, -1.353, -0.423, -2.598, -5.000, -0.686, -1.065, 0.270, -5.000, -5.000, -5.000, -5.000, -0.519, -0.755, -1.488, 0.193, -2.146, -1.602, -1.212, -5.000, -1.810, -1.379, -5.000, 0.780, -5.000, -5.000, 0.780, 1.186, -5.000, -1.313, -5.000, -5.000, -1.514, -0.734, 0.523, -1.039, -0.676, -1.100, -0.606, -0.563, -1.453, 0.197, -0.736, 0.849, -1.571, -0.977, -1.267, -2.675, -1.537, -2.031, -0.782, -2.495, -5.000, -3.048, -5.000, -5.000, -1.874, -1.558, 1.285, -2.110, -2.384, -1.942, -5.000, -1.769, -1.718, -3.077, -2.503, -2.524, -5.000, -5.000, 0.174, -5.000, -5.000, -0.423, -5.000, -5.000, -1.256, -2.650, -1.189, -2.398, -2.330, -1.269, -0.423, -1.566, -1.587, -0.200, -0.606, -5.000, -1.189, -5.000, -5.000, 0.493, -1.039, -5.000, -5.000, -5.000, -2.746, -2.069, -2.018, -2.286, -2.069, -1.055, -5.000, -0.686, -3.196, -0.711, -0.633, 0.591, -1.285, -0.493, -1.758, -3.000, -1.919, -0.877, 0.146, -0.846, -5.000, -0.426, 0.335, -2.264, -2.233, -0.540, 0.285, -0.566, -1.555, -1.707, -1.192, -1.880, -1.035, -1.070, -0.639, -1.753, -5.000, -2.242, -0.080, -0.606, -3.183, -2.295, -1.834, 0.751, -0.004, -0.962, -1.317, -2.925, -2.229, -1.507, 0.800, -2.284, -2.071, -3.146, -0.893, -1.704, -5.000, -2.883, -1.471, -2.452, -3.105, -2.300, -2.743, -5.000, -1.084, -0.688, -0.568, -1.991, -1.153, -2.471, -1.718, -0.404, -0.888, -1.382, -1.232, -0.519, -2.273, -1.393, -1.698, -2.394, -1.677, 0.459, 1.167, 0.634, -5.000, 0.290, 1.284, -0.708, -0.762, 0.456, 1.093, 1.016, 0.341, -0.299, 0.546, -0.446, 0.541, -0.544, -0.244, -1.322, -5.000, -2.978, -0.036, -1.745, -3.007, -1.212, -1.555, -0.122, -0.806, 0.200, -1.198, -1.841, -1.403, -0.335, 0.108, 0.072, -0.002, -1.438, 0.033, -2.053, -2.161, -0.648, 0.060, -1.107, -2.762, -0.965, -0.377, -1.840, -1.173, 0.606, 1.257, -0.052, 0.572, 0.177, 1.117, 0.664, -0.623, 0.702, 1.055, 0.561, 0.159, 0.649, 1.081, 0.109, 0.075, 1.363, 1.446, 1.110, -5.000, 1.329, 1.441, -1.555, 0.597, 1.410, 1.503, 1.016, 1.036, 0.670, 0.962, 0.855, 1.238, -0.227, -0.191, -1.180, -5.000, -0.857, 0.637, -1.784, -1.854, -1.256, 1.467, -0.241, 0.205, 0.399, -0.519, -2.257, -1.303, 1.089, 0.533, 0.664, 0.392, 0.596, 0.914, 0.780, -0.881, 0.596, 1.186, 0.567, -5.000, 0.780, -0.189, -1.340, -0.401, 1.121, 1.465, 0.902, 1.130, 1.126, 1.445, 1.553, 0.786, 1.350, 1.521, 1.065, 1.070, 1.206, 1.163, -0.087, 0.559, -0.010, 0.852, -0.519, -5.000, -0.257, 1.630, -0.362, -0.453, 0.341, 0.871, 1.066, 0.387, -0.979, 0.135, -0.555, -0.058, -0.769, 0.595, -1.541, -5.000, -1.587, 0.685, -0.496, -1.769, -1.632, 0.941, -0.067, -0.296, 0.008, -1.157, -2.594, -1.104, -0.376, -0.978, -1.576, -1.770, -2.398, -0.572, -0.924, -3.026, -2.490, -0.633, -1.417, -2.632, -0.532, -1.498, -1.996, -2.022, -0.181, 0.636, -1.154, -0.259, 0.112, 1.325, 0.479, -0.641, 0.442, 1.063, 0.600, -0.000, 0.040, 0.009, -0.678, -0.937, 0.350, 1.057, 0.099, -5.000, 0.210, 1.221, -0.969, -0.766, -0.059, 0.392, 0.205, 0.037, -0.688, -0.210, -0.893, 0.322, -0.154, 0.788, -1.161, -5.000, -1.364, 1.105, -2.587, -2.772, 0.402, 0.845, -0.346, -2.164, 0.566, 0.654, -2.400, -0.738, -0.316, 1.120, -0.742, 0.082, -1.277, 0.040, -0.443, -2.212, -1.786, 0.047, -0.705, -1.568, -0.560, -1.193, -2.077, -1.777, -0.118, 1.013, -0.528, -0.274, 0.271, 1.436, 0.397, -0.446, 0.886, 1.419, 1.101, 0.427, 0.322, 0.580, -1.064, -0.350, -0.094, 1.081, 0.653, -5.000, -0.138, 1.335, -2.716, -1.096, 0.360, 1.136, 1.095, 0.237, 0.128, 0.937, 0.164, 0.862, -0.732, 0.136, -1.245, -5.000, -2.232, 0.270, -0.456, -3.118, -2.643, 0.205, 0.493, -0.606, 0.593, -0.980, -2.626, -1.461, -0.059, 0.683, 0.016, -1.071, -1.402, 0.493, -5.000, -1.340, -2.186, -0.107, -0.407, -3.640, -1.382, -1.145, -1.272, -2.427, 0.460, 1.252, -0.278, 0.314, 0.138, 1.313, 0.874, -0.671, 0.648, 1.261, 0.892, 0.004, 0.596, 0.872, -0.259, 0.024, 1.275, 1.631, 1.412, -5.000, 1.174, 1.037, 0.963, 0.544, 1.182, 1.142, 0.724, 0.860, 0.942, 0.774, 1.026, 1.257, 0.748, 1.110, -0.500, -5.000, -0.340, 0.214, -1.117, -1.095, -5.000, 0.868, 0.270, -5.000, 1.215, -0.498, -1.488, -0.013, 0.072, 0.963, 0.907, 0.270, 0.332, 0.726, 1.186, 0.375, 0.811, 1.319, 0.898, 0.145, 0.828, 0.780, 0.849, -0.169, 1.122, 1.557, 1.466, 0.946, 1.068, 1.635, 1.580, 0.697, 1.271, 1.416, 1.289, 0.874, 1.131, 1.335, 0.329, 0.841, 0.567, 1.246, 1.224, -5.000, 0.187, 1.381, 0.963, -1.435, -0.067, 0.983, -0.067, 0.024, -0.886, -0.318, 0.058, 1.137, 0.263, 0.876, 0.060, -5.000, -5.000, 0.087, -5.000, -1.417, 0.780, 1.474, 0.087, 0.493, 0.933, -1.453, -0.423, -0.145, 1.112, 0.963, 0.811, -0.478, 0.452, 0.898, -0.067, 0.375, 0.087, -0.318, 0.493, 0.087, -0.746, -0.318, -5.000, -1.299, 0.482, 1.145, 1.346, 0.682, 0.952, 1.291, 1.068, -1.676, 1.648, 0.768, 1.068, 1.595, 0.685, 0.690, 0.737, 0.350, -0.979, 0.099, -1.226, -5.000, -1.275, -0.067, -1.100, -1.848, -0.606, 0.079, -0.893, -0.403, -1.445, -0.160, -1.314, -0.181, -1.563, -0.620, -0.061, -5.000, -1.667, 0.475, -5.000, -2.275, -0.760, 0.116, -0.974, -2.355, -0.244, -0.729, -2.515, -0.661, -1.563, -0.299, -1.505, -2.125, -2.596, -1.522, -1.256, -2.821, -2.244, -5.000, -5.000, -0.574, -1.685, -0.655, -1.704, -1.769, -1.028, 0.360, -0.030, -0.855, -0.878, 0.524, -0.504, -1.595, -0.543, 0.190, -0.285, -0.248, -0.228, -0.247, -0.485, -1.037, 0.653, 1.322, 1.138, -5.000, 0.749, 1.390, -0.304, -0.219, 0.814, 1.226, 0.775, 0.613, 0.088, 1.152, 0.568, 0.864, 0.059, 0.427, 0.458, -5.000, -1.065, 1.026, -2.215, -2.411, -1.299, -1.076, -0.686, -0.660, 0.819, -1.539, 0.653, -0.615, 0.243, 1.357, 0.736, -0.196, -0.843, 1.511, -5.000, -0.303, -1.136, 0.468, -0.606, -1.725, -0.031, 1.232, -1.256, -0.179, 0.734, 1.374, 0.316, 0.839, 0.538, 1.180, 0.748, 0.203, 0.777, 1.168, 0.886, 0.234, 0.800, 1.049, 0.142, 0.385, 1.085, 1.449, 1.436, -5.000, 1.065, 1.534, -0.030, 0.488, 0.942, 1.103, 0.743, 0.705, 0.673, 1.111, 0.736, 0.989, 0.265, 1.409, 0.299, -5.000, -1.165, 1.440, -5.000, 0.339, -0.241, 0.567, -0.030, 0.857, 1.494, 0.598, -0.500, -0.118, 0.675, 1.329, 1.248, 0.241, 0.254, 0.898, 0.000, -0.549, 0.427, -0.354, -1.065, -1.810, 0.235, 0.780, -0.113, -0.724, 1.213, 1.679, 1.470, 0.938, 1.220, 1.511, 1.100, 0.411, 1.196, 1.396, 0.980, 0.721, 1.080, 1.208, 0.457, 0.464, 0.949, 1.098, 0.813, -5.000, 1.210, 1.070, -0.200, -0.148, 0.413, 0.048, 0.005, -0.035, 0.126, 0.946, 0.306, 0.797, 0.658, 0.780, -0.409, -5.000, 0.716, 1.186, -0.067, -1.950, 0.493, 0.493, 0.700, 1.434, 0.834, 0.611, 0.007, 0.165, 0.687, 1.454, 0.729, 0.055, -0.472, 0.339, 0.780, -0.893, 0.615, 0.432, -1.065, -0.372, 0.455, -0.200, -0.686, -0.055, 0.701, 1.327, 1.001, 0.629, 0.475, 1.102, 1.063, -0.067, 0.805, 0.872, 0.393, 0.496, 0.773, 0.537, 0.074, 0.028, 0.230, 1.013, 0.659, -5.000, 0.087, 1.038, -0.372, -0.826, -0.455, 0.532, -0.026, -0.400, -0.723, -0.040, -0.004, 0.385, 0.024, 1.200, -0.506, -5.000, -1.847, 0.818, -0.760, -2.113, 1.132, -0.519, -1.117, 0.918, 0.560, -1.017, -2.164, 0.121, -0.292, 0.690, 0.422, -1.272, -0.869, 0.841, -0.067, -1.413, -0.668, -0.018, -1.676, -1.888, -1.153, -0.502, -1.632, -1.149, -0.019, 0.715, 0.276, 0.234, 0.056, 0.919, 0.732, -0.522, 0.049, 0.451, -0.350, -0.726, 0.172, 0.676, -0.336, -0.366, 0.555, 1.264, 0.853, -5.000, 0.426, 1.338, -0.416, -0.689, 0.491, 0.884, 0.903, 0.173, -0.107, 0.751, -0.274, 0.433, -0.273, 0.225, -0.241, -5.000, -1.887, 0.683, -0.969, -2.154, -0.456, 1.002, 0.549, -1.031, 0.156, 0.224, -2.077, -0.674, -0.130, 0.631, 0.496, 0.176, -1.268, -0.086, -0.606, -2.225, -1.359, -0.258, -1.050, -2.596, -0.835, -0.648, -1.843, -1.194, 0.539, 1.359, 0.314, 0.349, 0.314, 1.066, 0.960, -0.499, 0.812, 1.384, 0.929, 0.130, 0.464, 0.768, -0.653, -0.122, 0.700, 1.405, 0.746, -5.000, 0.738, 1.316, -1.320, -0.289, 0.782, 1.054, 0.634, 0.389, 0.151, 0.840, -0.103, 0.476, -0.473, 0.251, -1.427, -5.000, -0.859, 0.586, -1.704, -1.841, -0.760, 0.214, -0.954, -1.011, 0.570, -0.215, -1.560, -1.624, 0.136, 0.344, 0.327, -0.229, -0.423, 0.889, -0.067, -0.686, -1.920, 0.544, 0.493, -2.685, -0.343, -0.090, -1.453, -1.435, 0.848, 1.514, 0.724, 0.535, 0.938, 1.270, 0.780, -0.183, 1.008, 1.260, 0.871, 0.213, 0.753, 0.899, -0.380, -0.063, -0.147, 0.770, -0.521, -5.000, -0.106, 0.742, -5.000, -1.527, -0.244, 0.776, 0.314, -0.126, -0.862, -0.382, -1.323, -0.679, -1.207, 0.430, -1.995, -5.000, -1.665, -0.261, -5.000, -1.710, -0.802, -0.200, -0.241, -1.657, -0.001, -0.556, -2.080, -1.658, -0.346, -0.580, -1.859, -1.704, -1.617, -0.736, 1.361, -5.000, -0.995, -1.011, -1.117, -1.108, -1.703, -1.617, -2.232, -2.503, -0.203, 0.366, -1.843, -1.338, -0.660, 0.549, -0.650, -0.656, 0.068, -0.017, -0.812, -0.224, -1.089, -0.386, -2.307, -1.425, -0.010, 0.693, 0.130, -5.000, 0.014, 1.051, -1.350, -0.936, 0.019, 0.732, 0.385, 0.186, -0.626, 0.216, -0.444, -0.023, -0.426, 0.513, -0.520, -5.000, -0.803, 0.764, -1.086, -1.963, -0.740, 0.795, 0.397, -0.624, 0.265, 0.165, -1.780, -1.055, -0.275, 0.839, -0.568, -0.923, -1.249, -0.379, -0.376, -1.989, -1.611, -0.028, -1.192, -2.165, -0.908, -0.651, -2.378, -0.925, -0.288, 0.565, -0.567, -0.570, -0.193, 0.347, -0.163, -1.353, 0.122, 0.493, 0.326, -0.993, -0.240, -0.251, -0.988, -0.844 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_1(struct _training *tptr) {
  struct _training tinf = {
    0.315, 4, 4.350, { 2.101, 0.614, 0.285 }, { 0.871, -0.598, -2.566 }, 1, 
    { -0.235, -0.845, -0.206, 1.127, -0.028, -0.021, 0.054, -4.000, -4.000, 0.094, 1.566, -4.000, 1.771, 0.246, -4.000, 1.711, 1.600, -4.000, -4.000, 0.608, 2.272, 1.866, 2.827, -4.000, -4.000, 1.866, -4.000, 2.377 }, 
    {{ 0.080, -0.376, -0.574, 0.232},{ 0.152, -0.606, -0.148, 0.102},{ 0.141, -0.032, -0.590, 0.065},{ 0.245, -0.148, -0.513, -0.030},{ 0.138, -0.098, -0.032, -0.095},{ 0.162, -0.314, -0.622, 0.148},{ 0.222, -0.158, -0.574, 0.018},{ 0.330, -0.290, -0.499, -0.099},{ 0.186, -0.158, -0.638, 0.076},{ 0.276, -0.470, -0.470, 0.026},{ 0.193, -0.032, -0.255, -0.099},{ 0.248, -0.314, -0.233, -0.064},{ 0.203, -0.338, -0.278, 0.018},{ 0.213, -0.376, -0.389, 0.054},{ 0.124, -0.244, -0.402, 0.113},{ 0.173, -0.200, -0.558, 0.087},{ 0.087, -0.200, -0.278, 0.098},{ 0.124, -0.118, -0.415, 0.072},{ 0.199, -0.148, -0.351, -0.022},{ 0.173, -0.069, -0.200, -0.077},{ 0.065, -0.148, -0.179, 0.069},{ 0.219, -0.158, -0.402, -0.026},{ 0.080, 0.143, -0.376, -0.010},{ 0.145, -0.338, -0.290, 0.087},{ 0.127, -0.127, -0.442, 0.080},{ 0.196, -0.158, -0.200, -0.069},{ 0.186, -0.023, -0.351, -0.060},{ 0.254, -0.148, -0.442, -0.064},{ 0.145, -0.211, -0.255, 0.034},{ 0.138, -0.179, -0.233, 0.022},{ 0.057, -0.005, -0.179, 0.018},{ 0.120, -0.098, -0.168, -0.014} }, 
    {{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}} }, 
    0.000, { 0.616, 1.085, 0.735, -5.000, 0.065, 0.772, -0.224, -0.569, -0.056, 0.696, 0.257, -0.021, -0.588, 0.524, 0.372, 0.567, 0.366, 0.523, -0.477, -5.000, -1.527, 0.497, -2.640, -0.914, -0.149, 0.240, 0.215, -0.535, 0.141, -0.243, -0.804, -0.727, 0.248, 0.579, 0.110, 0.390, -0.749, 0.295, -0.149, -1.173, 0.026, 0.749, -0.144, -0.839, 0.151, -0.286, -0.735, -0.138, 0.682, 0.840, 0.002, 0.496, 0.329, 1.070, 0.540, -0.732, 0.584, 1.235, 0.902, 0.449, 0.562, 0.860, 0.300, 0.210, 1.019, 1.250, 1.014, -5.000, 0.795, 1.155, 0.999, -0.273, 0.861, 1.171, 1.105, 0.579, -0.040, 1.039, 0.746, 1.020, 0.320, 0.258, -0.476, -5.000, -1.235, 0.251, -0.299, -1.120, -1.142, 0.320, -0.724, -1.413, 0.603, 0.348, -1.116, -0.490, 1.108, 1.227, 0.983, 0.929, 0.796, 1.032, 1.001, -0.225, 0.546, 0.860, 0.749, -0.271, 1.134, 0.814, -0.349, 0.426, 0.877, 1.228, 0.522, 0.961, 1.057, 1.320, 1.047, 0.158, 0.999, 1.415, 1.149, 0.871, 1.020, 1.132, 0.634, 0.651, 0.687, 1.174, 0.603, -5.000, 0.521, 1.034, -0.328, -0.346, 0.491, 1.008, 0.857, 0.489, -0.867, 0.453, -0.038, 0.702, 0.264, 0.404, -0.662, -5.000, -0.525, 0.670, -0.299, -1.122, 0.199, 0.721, 0.277, 0.072, 0.558, 0.342, -0.686, -0.022, 0.626, 0.711, -0.182, 0.369, -0.010, 0.452, 0.054, -1.211, 0.633, 1.055, 0.178, -0.769, 0.696, 0.186, -0.772, 0.479, 0.430, 0.769, -1.000, 0.307, 0.909, 1.225, 0.546, -0.527, 0.793, 1.208, 1.114, 0.144, 0.278, 0.550, -0.543, -0.407, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.256, 0.629, 0.377, -5.000, -0.236, 0.405, -0.411, -1.182, -0.065, 0.572, 0.224, -0.083, -1.239, 0.282, -0.167, 0.319, -0.576, -1.074, -1.013, -5.000, -2.011, -0.044, -1.472, -1.896, -1.561, -0.177, -1.208, -1.541, -0.639, -0.460, -1.960, -1.205, -0.810, 0.085, -0.577, -0.771, -1.588, 0.420, -0.018, -3.753, -0.703, 0.102, -1.478, -2.018, -0.297, -0.524, -2.708, -0.830, 0.364, 0.071, -0.695, -0.392, -0.152, 0.758, 0.272, -2.628, 0.456, 1.127, 0.539, 0.027, 0.045, 0.158, -0.396, -0.380, 0.790, 1.221, 0.906, -5.000, 0.987, 0.966, 0.251, 0.047, 0.930, 0.893, 0.918, 0.619, 0.174, 0.948, 0.778, 0.565, 0.036, 0.517, -1.451, -5.000, 0.590, 0.775, 0.218, -1.318, 0.190, 0.456, -0.132, -0.257, 0.455, 0.443, -0.900, -0.313, 0.746, 0.999, 0.624, 0.708, 0.950, 1.113, 0.762, -0.591, 0.663, 1.024, 0.905, -0.086, 0.697, 0.867, -0.538, -0.138, 0.372, 0.720, 0.098, 0.893, 0.878, 1.252, 0.725, -0.585, 1.063, 1.145, 0.936, 0.410, 0.528, 0.557, -0.486, 0.336, -0.669, 0.296, -0.758, -5.000, -1.286, -0.044, -1.332, -3.045, -1.244, -0.189, -0.641, -0.325, -2.502, -1.426, -1.256, -0.893, -0.897, -0.228, -0.817, -5.000, -2.470, 0.032, -0.582, -2.803, -0.949, -0.053, -0.501, -0.442, -1.011, -0.452, -1.472, -1.070, -0.149, 0.207, -0.425, -0.378, -0.183, 0.862, -1.002, -1.172, -0.545, -0.086, -0.891, -1.723, -0.963, -0.442, -1.152, -0.825, -0.487, -0.486, -0.786, -0.018, -0.093, 0.935, 0.145, -3.190, 0.116, 0.474, -0.121, -0.529, -0.571, -0.754, -1.677, -0.991, -0.537, 0.051, -0.323, -5.000, -1.562, -0.750, -2.317, -2.199, -0.782, -0.168, -0.559, -0.461, -1.986, -0.907, -0.809, -0.917, -0.507, -0.668, -0.709, -5.000, -3.584, -1.816, -2.147, -2.155, -1.280, -1.030, -2.416, -1.910, -0.748, -0.625, -0.332, -1.049, -0.542, 0.240, -1.584, -1.186, -2.087, -1.054, -1.798, -3.510, -0.906, -0.814, -2.426, -3.966, -0.945, -0.788, -1.431, -0.856, -0.658, -0.553, -1.733, -0.980, -1.198, -0.429, -1.120, -2.705, -0.570, -0.358, -0.456, -1.167, -1.126, -0.682, -1.688, -1.189, 0.267, 0.763, 0.380, -5.000, 0.123, 0.935, -0.875, -0.800, 0.324, 0.722, 0.316, 0.203, -0.442, 0.501, 0.153, 0.311, 0.171, 0.104, -0.356, -5.000, -0.953, 1.210, 0.198, -1.248, 0.079, 0.925, 0.579, -0.792, 0.107, 0.080, -0.437, -0.853, 0.544, 0.872, 0.197, 0.450, 0.051, 0.379, -0.325, -1.040, -0.232, 0.496, 0.047, -1.501, 0.024, -0.028, -0.935, -0.222, 0.259, 0.834, -0.286, 0.588, 0.360, 0.993, 0.518, -0.276, 0.572, 0.833, 0.539, 0.248, 0.130, 0.424, 0.239, 0.113, 0.959, 1.160, 1.190, -5.000, 0.724, 0.788, 0.671, -0.007, 0.994, 0.893, 0.732, 0.285, 0.215, 0.856, 0.411, 0.520, 0.169, 0.145, -0.660, -5.000, -0.814, 1.153, -0.037, -0.990, 0.372, 0.641, 0.656, 0.214, 0.919, 0.645, -1.398, -0.248, 0.579, 1.179, 0.866, 0.812, 0.529, 0.462, 0.682, -1.541, 0.688, 0.561, 0.307, -1.102, 0.171, -0.430, -1.110, -0.379, 0.952, 1.290, 0.721, 1.233, 0.843, 0.988, 0.455, -0.260, 0.969, 1.067, 1.074, 0.496, 0.605, 0.628, 0.463, 0.310, 0.563, 0.836, 0.793, -5.000, 0.453, 0.682, 0.018, -0.877, 0.491, 0.576, 0.232, 0.103, -0.569, 0.394, 0.013, 0.341, -0.107, 0.531, -0.448, -5.000, -0.705, 1.060, 0.379, -1.398, -0.129, 1.052, 0.405, 0.030, 0.644, 0.853, -0.772, -0.403, 0.515, 0.968, 0.398, 0.361, -0.027, 0.919, 0.460, -0.990, 0.204, 0.401, -0.063, -1.200, 0.086, 0.194, -1.095, 0.199, 0.614, 0.824, 0.020, 0.438, 0.665, 1.173, 0.921, -0.283, 0.987, 1.135, 0.688, 0.386, 0.580, 0.773, -0.191, -0.092, 0.346, 0.776, 0.300, -5.000, -0.895, 0.201, -1.383, -1.056, 0.102, 0.164, 0.251, -0.053, -1.145, 0.293, 0.514, 0.312, -0.243, 0.442, -0.248, -5.000, -1.816, -0.211, -0.529, -2.787, -0.240, -0.253, -0.396, -1.173, 0.686, 0.180, -0.234, -0.230, 0.362, 0.899, 0.464, 0.035, -0.421, 0.687, 0.039, -1.780, 0.422, -0.057, -0.200, -0.891, 0.606, 0.620, -0.483, 0.355, 0.178, 0.666, -0.263, 0.286, 0.249, 0.957, 0.292, -1.119, 0.482, 0.714, 0.474, -0.193, 0.177, 0.612, 0.156, -0.471, -0.616, -0.026, -0.564, -5.000, -0.684, 0.089, -1.139, -1.567, -0.528, -0.191, -0.222, -0.628, -1.349, -0.769, -1.211, -0.828, -0.969, -0.174, -0.938, -5.000, -1.629, -0.166, -1.160, -1.824, -0.883, -0.129, -0.262, -1.295, -1.275, -0.883, -2.121, -1.808, -0.475, -0.256, -0.663, -0.572, -1.389, -0.712, -1.924, -2.430, -1.623, -0.886, -1.094, -1.492, -0.759, -1.087, -1.040, -1.189, -0.592, -0.119, -1.444, -0.382, -0.564, -0.318, -2.617, -1.413, -0.705, 0.156, -0.592, -0.438, -0.895, -0.567, -1.307, -0.779, 0.545, 1.056, 0.791, -5.000, 0.487, 0.714, 0.504, -0.272, 0.569, 0.905, 0.741, 0.490, -0.573, 0.391, 0.190, 0.490, 0.018, -0.070, -0.840, -5.000, -0.330, 1.030, 0.069, -1.105, -0.572, 0.330, -0.337, -0.858, 0.094, 0.055, -1.767, -0.774, 0.535, 0.976, 0.251, 0.627, 0.136, 0.784, 0.229, -1.450, -0.086, 0.298, 0.356, -0.930, 0.283, -0.470, -1.071, -0.163, 0.533, 0.953, -0.000, 0.731, 0.389, 0.847, -0.347, -0.926, 0.255, 0.897, 0.700, 0.402, -0.288, 0.259, -0.106, 0.063, 0.489, 1.014, 0.446, -5.000, -0.030, 0.568, 0.163, -0.970, 0.247, 1.010, 0.408, 0.135, -0.920, 0.131, -0.392, 0.057, -0.816, -0.114, -1.371, -5.000, -1.249, 0.302, -0.491, -1.401, 0.407, 0.223, 0.270, -0.614, -0.486, 0.158, -1.950, -0.915, 0.455, 0.537, -0.149, -0.157, -0.730, 0.097, -0.265, -1.990, 0.418, 0.601, -0.274, -1.656, 0.253, -0.314, -1.304, -0.280, 0.477, 1.032, -0.639, 0.318, 0.559, 0.871, -0.019, -0.614, 0.323, 0.231, -0.015, -0.658, -0.278, -0.236, -1.601, -0.705, 0.578, 0.977, 0.502, -5.000, -0.176, 0.588, -0.613, -0.611, 0.487, 0.619, 0.513, 0.439, -0.773, 0.362, 0.569, 0.444, 0.303, 0.834, 0.021, -5.000, -0.880, 0.715, 0.142, -1.052, 0.048, 0.616, 0.467, -0.422, 0.452, 0.313, -0.325, -0.170, 0.497, 0.775, -0.074, 0.512, 0.315, 0.370, 0.111, -0.647, 0.543, 0.575, -0.330, -0.479, 0.809, 0.370, -0.356, 0.377, 0.517, 0.881, -0.171, 0.404, 0.576, 0.886, 0.175, -0.527, 0.512, 0.828, 0.447, -0.179, 0.167, 0.534, -0.317, -0.122, 0.258, 0.950, 0.402, -5.000, -0.078, 0.356, -0.538, -0.960, -0.636, 0.059, -0.502, -0.455, -1.523, -0.577, -1.019, -0.162, -0.041, 0.445, -0.983, -5.000, -1.961, 0.465, -0.802, -1.092, -0.952, -0.453, -0.943, -0.761, -0.406, -0.701, -1.811, -1.323, 0.146, 0.466, 0.181, 0.042, -0.525, 0.387, 0.156, -1.829, -0.483, 0.762, -0.473, -1.416, -0.293, -0.761, -1.759, -0.729, 0.821, 1.148, 0.167, 0.539, 0.282, 1.040, 0.891, -1.047, 0.744, 1.209, 0.853, 0.449, 0.530, 0.662, 0.249, 0.090, 1.064, 1.314, 0.807, -5.000, 1.333, 1.167, 0.644, -0.260, 0.713, 0.695, 0.885, 0.133, -0.538, 0.662, 0.069, 0.599, -0.323, -0.401, -1.190, -5.000, -0.086, 0.539, 0.356, -0.758, -0.442, 0.202, -0.538, -5.000, 0.469, -0.495, -1.566, -1.465, 0.722, 0.734, 0.315, -0.260, 0.656, -0.625, 0.762, -1.110, 0.207, 0.804, -0.408, -0.538, 0.509, 0.169, -0.057, -0.349, 0.795, 1.308, 0.474, 0.752, 0.788, 1.061, 0.535, -0.242, 0.762, 0.847, 0.936, 0.337, 0.700, 0.545, -0.373, 0.287, 0.096, 0.769, -0.170, -5.000, 0.489, 0.191, -0.501, -0.764, -0.092, 0.801, -0.183, -0.380, -2.171, -0.254, -1.245, -0.261, -0.485, -0.538, -2.003, -5.000, -1.318, 0.394, -5.000, -1.465, -0.874, 0.174, -0.742, -0.779, -0.710, -0.848, -1.446, -1.035, -0.247, 0.074, -1.426, -0.850, -0.373, 0.656, -0.244, -2.091, -0.327, 0.048, -1.417, -2.104, -0.686, -1.398, -1.853, -1.173, 0.041, 0.441, -1.464, -0.168, 0.161, 0.801, 0.587, -0.817, 0.097, 0.887, 0.600, -0.995, -0.506, -0.810, -1.329, -1.356, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -1.003, -0.078, -0.770, -5.000, -1.248, 0.338, -2.559, -2.367, -1.857, -0.442, -1.871, -1.642, -1.946, -1.249, -0.625, -1.008, -0.853, -1.436, -1.044, -5.000, -1.889, -5.000, -5.000, -5.000, -0.645, -0.973, -5.000, -5.000, -1.398, -2.571, -0.958, -2.559, -1.383, -0.280, -0.755, -2.559, -2.479, 0.474, -0.373, -5.000, -1.877, -1.507, -1.495, -2.662, -1.129, -1.215, -2.322, -2.183, -0.665, -0.271, -1.709, -1.211, -1.843, -0.097, 0.207, -2.553, -1.295, -0.086, -0.101, -0.794, -0.966, -0.498, -1.009, -1.201, 0.807, 1.131, 0.985, -5.000, 1.062, 1.210, 0.156, -0.126, 0.960, 1.287, 0.975, 0.807, 0.055, 0.579, 0.682, 0.588, 0.121, 0.041, -1.002, -5.000, -0.417, 1.414, -0.912, -1.019, 0.331, 0.320, 0.334, -1.297, 0.386, -0.092, -0.857, -0.476, 0.559, 0.738, 0.887, 0.149, 0.715, 0.804, 0.069, -5.000, 0.644, -5.000, 0.356, -1.398, 0.550, 0.302, -0.408, -0.601, 0.674, 1.079, 0.460, 0.812, 0.719, 1.392, 0.964, -0.310, 0.721, 1.153, 0.807, 0.257, 0.807, 0.741, 0.076, 0.414, -0.157, 0.584, -0.055, -5.000, -0.173, 0.579, -0.086, -2.101, -1.889, -0.425, -2.234, -0.114, -3.096, -2.200, -1.084, -0.598, -0.496, -0.260, -1.454, -5.000, -0.848, -0.012, -0.491, -2.640, -1.231, 0.474, 0.762, -1.011, -1.184, 0.069, -5.000, -0.779, 0.240, 0.569, 0.048, -0.049, -0.062, 0.608, 0.069, -1.135, 0.090, -5.000, -1.275, -1.231, -0.299, -0.912, -5.000, -2.110, -0.853, -0.028, -2.275, -0.205, -0.177, 0.640, 0.320, -2.416, 0.117, -1.030, 0.356, 0.296, -0.135, -0.462, -2.329, -0.679, -1.188, -0.408, -0.962, -5.000, -1.634, -1.168, -3.252, -2.449, -1.184, -0.442, -0.657, -0.964, -1.765, -1.364, -2.072, -1.409, -1.386, -0.953, -1.458, -5.000, -3.056, -1.309, -2.745, -3.057, -1.837, -1.666, -1.541, -1.963, -0.937, -2.038, -0.742, -1.273, -0.826, -0.671, -1.869, -1.646, -2.267, -1.200, -0.973, -2.446, -1.843, -5.000, -1.877, -3.413, -1.262, -0.538, -2.314, -1.460, -1.185, -0.804, -1.888, -1.501, -1.501, -0.842, -1.162, -2.507, -1.216, -0.674, -1.060, -1.284, -1.297, -1.109, -2.050, -1.519, -0.054, 0.530, 0.047, -5.000, -0.181, 1.027, -0.990, -0.895, -0.234, 0.489, 0.051, -0.051, -1.088, 0.087, -0.563, -0.224, -0.134, 0.443, -0.973, -5.000, -2.509, 0.962, -0.705, -2.606, -1.297, 0.525, -0.779, -0.953, 0.122, -0.459, -0.953, -1.881, 0.254, 0.394, -0.673, 0.391, -0.213, 0.554, -0.779, -0.606, -0.577, 1.034, -0.679, -1.877, -0.625, -0.232, -1.046, -1.105, 0.455, 1.182, -0.510, 0.660, 0.508, 1.138, 0.708, -0.671, -0.801, 0.608, 0.207, -0.262, 0.079, -0.173, -0.965, 0.228, 0.646, 1.084, 0.453, -5.000, 0.901, 0.539, 0.310, -0.057, 0.804, 1.241, 0.585, 0.421, -0.408, 0.742, -0.456, 0.297, -0.020, 0.682, -1.541, -5.000, -1.636, 0.944, 1.254, -1.044, -0.121, 0.831, 0.069, 0.251, 0.366, 0.156, -1.160, -0.596, 0.710, 0.624, 0.561, 0.334, 0.177, 0.587, 0.762, -5.000, 0.014, -0.442, 0.356, -1.318, 0.092, -0.260, -0.742, -1.889, 1.098, 1.232, 0.575, 1.240, 0.804, 1.167, 0.608, 0.043, 0.561, 0.905, 0.608, 0.675, 0.672, 0.721, 0.009, 0.339, -0.284, 0.514, -0.205, -5.000, 0.406, 0.090, -0.491, -1.135, -0.398, -0.114, 0.028, -0.155, -1.514, 0.298, 0.055, 0.069, -0.545, -0.121, -0.958, -5.000, -1.030, 0.251, 0.069, -5.000, 0.156, 0.356, -0.491, -1.275, 0.156, 0.561, -0.086, -0.551, 0.483, 0.251, -0.825, 0.138, 0.186, 0.251, -5.000, -5.000, 0.234, 0.302, 0.186, -5.000, 0.302, 0.036, -5.000, -0.194, 0.278, 0.340, -0.378, 0.574, 0.375, 1.072, 0.212, 0.365, 0.824, 1.224, 0.762, 0.138, 0.959, 0.773, 0.497, 0.069, -0.351, -0.144, -0.838, -5.000, -1.687, -1.133, -1.905, -1.482, -0.986, -0.546, -0.949, -1.113, -1.608, -0.487, -0.681, -0.541, -0.755, 0.179, -1.030, -5.000, -0.769, -0.522, -1.877, -2.656, -2.129, -0.538, -5.000, -1.737, 0.017, -0.114, -1.417, -0.798, 0.099, 0.831, -0.031, -0.943, -0.486, -0.219, -0.250, -5.000, 0.452, -0.973, -1.231, -1.135, 0.380, 0.517, -0.049, -0.554, -0.170, 0.113, -0.497, -0.061, 0.100, 0.488, -0.163, -1.112, -0.446, 0.769, 0.080, -0.657, -0.412, 0.430, -0.681, -0.650, -0.057, 0.688, -0.127, -5.000, 0.199, 0.924, -0.092, -0.661, 0.090, 1.020, 0.719, 0.204, -1.133, 0.056, -1.013, -0.159, 0.286, 1.039, -0.109, -5.000, -1.104, 1.042, 0.376, -0.883, 0.428, 1.147, 0.924, -0.534, -0.184, -0.136, -1.424, -0.919, -0.113, 0.450, 0.463, 0.474, -0.679, 0.280, -0.044, -1.869, -0.946, 0.004, -1.332, -2.344, 0.197, -0.995, -1.541, -0.071, 0.523, 0.801, -0.184, -0.248, 0.308, 0.643, -1.426, -0.788, -0.198, 0.724, 0.816, -0.547, 0.126, -0.458, -1.261, -0.195, 0.401, 0.964, -0.005, -5.000, 0.457, 0.770, -0.031, -0.922, 0.543, 0.709, 0.587, -0.068, -1.000, -0.118, -0.645, -0.167, -0.109, 0.174, -1.447, -5.000, -0.404, 1.121, 0.022, -1.288, -0.732, -0.408, -1.338, -1.178, -0.399, -0.232, -1.805, -1.447, -0.092, 0.195, 0.216, 0.214, -0.665, 0.251, -0.250, -1.359, -0.163, -0.491, 0.133, -1.979, 0.290, -0.064, -2.457, -0.570, 0.576, 1.043, 0.262, 0.766, 0.762, 1.055, 0.550, -0.126, 0.022, 0.588, 0.398, 0.088, 0.216, 0.462, -0.940, -0.090, -0.300, 0.327, -0.749, -5.000, -0.343, -0.230, -0.848, -1.347, -0.730, -0.127, -0.294, -0.766, -2.442, -1.859, -1.405, -1.131, -1.648, -0.744, -1.565, -5.000, -1.231, -0.525, -1.246, -2.699, -1.046, -0.273, -0.538, -2.522, -1.670, -1.143, -2.696, -1.876, -0.713, -1.127, -1.110, -1.651, -0.912, -5.000, -0.848, -5.000, -0.912, -1.723, -1.695, -5.000, -0.864, -2.976, -2.288, -3.734, -0.237, 0.156, -1.509, -0.558, -0.839, 0.069, -1.196, -1.398, -0.864, 0.011, -1.044, -1.180, -0.922, -1.361, -2.741, -1.636, -0.572, 0.013, -0.833, -5.000, -1.073, -0.277, -1.636, -1.848, -0.535, -0.468, -0.097, -1.016, -2.027, -0.247, -0.927, -0.203, -0.698, 0.019, -1.120, -5.000, -1.790, 0.138, -1.517, -1.506, -0.818, -0.442, -0.238, -0.812, -0.665, -0.638, -1.857, -1.252, -0.680, -0.173, -1.422, -1.150, -1.808, -0.092, -1.338, -2.654, -1.035, -0.055, -1.066, -1.492, -0.540, -0.832, -1.438, -1.110, -0.600, -0.481, -1.513, -0.815, -1.098, -0.018, -1.275, -1.818, -1.479, -0.323, -0.713, -2.101, -0.966, -0.728, -1.795, -1.530, 0.385, 1.021, 0.617, -5.000, 0.232, 0.750, -0.337, -0.623, 0.167, 0.543, 0.128, -0.160, -0.957, 0.109, -0.012, 0.421, 0.091, 0.696, -0.359, -5.000, -1.517, 0.377, -1.495, -1.753, -0.140, -0.430, 0.231, -0.845, -0.017, -0.873, -0.855, -1.277, 0.050, 0.691, -0.065, 0.415, -0.547, -0.037, 0.167, -2.455, -0.273, 0.787, -0.225, -1.977, -0.234, -0.373, -1.342, -0.658, 0.740, 0.884, -0.131, 0.607, 0.119, 0.968, 0.797, -1.006, 0.364, 1.173, 0.861, 0.259, 0.364, 0.717, 0.189, -0.040, 0.689, 1.098, 0.594, -5.000, 0.935, 1.321, 0.334, 0.109, 1.047, 1.180, 0.652, 0.217, -0.181, 0.506, 0.331, 0.901, 0.385, -0.086, -0.491, -5.000, -0.325, 0.867, 0.218, -0.694, -0.538, -0.373, 0.697, -2.234, 0.826, -0.364, -1.398, -0.607, 0.920, 0.893, 0.031, 0.675, 0.603, 0.474, 0.587, -1.816, 0.602, -0.121, -0.168, -1.436, 0.831, 0.334, -5.000, -0.141, 0.736, 1.040, 0.422, 1.014, 0.719, 1.046, 0.724, 0.026, 0.910, 1.290, 0.905, 0.412, 0.769, 0.874, -0.043, 0.526, 0.307, 0.503, -0.081, -5.000, 0.168, 0.474, 0.149, -0.462, -0.303, 0.502, 0.195, -0.296, -1.651, -0.209, -0.200, 0.492, -0.315, 0.061, -1.143, -5.000, -1.318, 0.156, -0.538, -0.924, -0.097, 0.356, -0.114, -0.190, -0.152, -0.138, -1.541, -0.613, -0.073, 0.181, -0.749, -0.672, -0.943, 0.069, -0.355, -2.018, -0.097, -0.507, -0.739, -1.184, 0.420, -0.652, -1.268, -0.361, -0.369, -0.067, -1.345, -0.304, -0.073, 1.101, 0.640, -0.326, 0.246, 0.979, 0.648, -0.219, 0.138, 0.263, -1.022, -0.718, 0.822, 1.165, 0.541, -5.000, -0.413, 0.442, -0.567, -0.859, 0.220, 0.801, 0.295, 0.328, -0.894, 0.431, 0.751, 0.510, 0.279, 0.826, 0.338, -5.000, -1.110, -0.280, -0.321, -1.503, -1.626, 0.271, -1.102, -0.867, 0.578, 0.197, -0.675, 0.190, 0.325, 0.915, -0.068, 0.145, -1.097, 0.031, -0.482, -3.287, -0.264, -0.219, -0.337, -1.961, 0.311, -0.187, -1.030, -0.184, 0.098, 0.475, -0.674, 0.059, -0.503, 0.517, -0.192, -2.011, 0.110, 0.699, 0.361, -0.575, -0.290, -0.200, -0.623, -0.822, -0.589, 0.440, -0.051, -5.000, -1.209, -0.062, -2.322, -1.663, -0.836, 0.296, -0.313, -0.750, -1.674, -0.243, 0.133, 0.134, -0.224, 0.014, -0.837, -5.000, -3.338, -0.582, -5.000, -2.176, -5.000, -1.359, -0.337, -2.359, 0.144, -0.427, -2.352, -1.670, -0.754, -0.037, -0.250, -0.720, -2.110, -0.689, -0.705, -4.251, -0.923, -0.399, -1.968, -2.525, -0.847, -1.458, -1.535, -1.443, 0.163, 0.704, -0.421, 0.244, -0.735, 0.320, -0.253, -2.171, -0.515, 0.644, 0.533, -0.827, -0.668, -0.335, -1.449, -1.000, 0.450, 1.054, 0.944, -5.000, -0.086, 0.356, 0.413, 0.126, 0.600, 0.969, 0.962, 0.572, 0.133, 0.879, 0.855, 0.801, 0.285, 0.102, -0.337, -5.000, -0.260, 0.637, -5.000, -1.125, 0.292, 0.879, -5.000, -1.472, 0.263, -0.219, -0.933, -0.503, 0.275, 1.113, 0.202, -0.475, -0.355, 0.819, 0.944, -1.924, -1.507, 0.474, -5.000, -1.541, 0.030, -1.507, -1.275, -0.303, 0.507, 0.411, 0.004, 0.561, -0.592, 0.515, -0.912, -0.862, 0.519, 0.874, 0.690, -0.185, 0.386, 0.137, -0.101, 0.238, 0.212, 0.448, 0.171, -5.000, -0.219, 0.839, -0.538, -2.651, -1.304, -0.268, -0.057, -0.337, -1.417, -1.338, -0.482, -0.253, -0.223, 0.181, -0.679, -5.000, -2.267, -0.049, -5.000, -2.755, -1.524, -0.268, -0.219, -0.864, 0.430, -0.742, -5.000, -1.040, -0.035, 0.048, 0.613, -0.149, -1.666, 0.251, -0.779, -5.000, -1.231, -0.219, -5.000, -2.183, -0.129, -5.000, -1.877, -1.002, -0.438, -0.440, -1.771, 0.224, -0.299, -0.337, -5.000, -1.411, 0.106, 0.721, 0.126, -1.275, 0.282, -0.207, -1.041, -0.705, -2.245, -1.088, -1.461, -5.000, -2.514, -2.000, -2.251, -3.499, -5.000, -0.556, -2.052, -1.595, -2.664, -2.052, -1.590, -1.968, -1.909, -1.275, -1.477, -5.000, -2.750, -5.000, -1.318, -2.765, -2.822, -5.000, -5.000, -3.023, -1.421, -0.848, -5.000, -2.152, -2.011, -0.638, -1.115, -2.314, -3.975, -1.990, -5.000, -5.000, -2.784, -1.803, -5.000, -5.000, -1.377, -2.509, -1.790, -3.820, -1.641, -1.617, -1.861, -0.501, -1.975, -1.492, -5.000, -2.123, -1.092, -0.726, -1.135, -1.842, -1.735, -1.256, -1.475, -2.104, -0.020, 0.755, 0.163, -5.000, -0.457, 0.852, -0.649, -1.149, -0.160, 0.494, 0.128, -0.314, -1.433, 0.414, 0.196, 0.207, -0.035, 0.517, -0.311, -5.000, -1.574, -0.779, -0.943, -2.097, -0.814, 0.675, -0.641, -0.696, -0.207, -0.752, -1.071, -0.771, 0.065, 0.575, -0.342, -0.040, -1.440, 0.069, -1.135, -2.893, -1.509, -0.139, -1.145, -2.068, -0.247, -0.182, -1.376, -1.226, 0.057, 0.631, -1.676, 0.547, -0.345, 0.269, -1.695, -1.072, -0.554, 0.725, 0.057, -0.629, -0.138, 0.166, -1.348, -0.529, 0.679, 0.932, 0.795, -5.000, 0.251, -0.037, 0.292, -0.635, -0.017, 0.872, 0.186, 0.044, -0.015, 0.601, 0.805, 0.561, -0.155, -0.219, -1.275, -5.000, -5.000, -5.000, -0.442, -0.244, -1.398, 0.656, -0.086, 0.302, 0.514, 0.579, -0.442, -0.337, -0.037, 0.413, 0.569, -0.314, -0.560, 0.069, -1.359, -1.841, -1.261, -0.280, -0.582, -1.777, -0.345, -0.219, -0.625, -1.219, 0.729, 0.899, 0.206, 0.652, -0.386, 0.579, -0.912, -0.761, 0.006, 0.959, 0.069, -0.525, 0.872, 0.944, -0.306, 0.493, -0.643, 0.106, -0.401, -5.000, -0.848, 0.069, -1.621, -2.226, -0.615, 0.069, -0.616, -0.969, -1.611, -0.280, -0.764, -0.549, -1.237, -1.084, -1.777, -5.000, -1.184, 0.000, -5.000, -5.000, -1.853, -0.337, -5.000, -0.779, 0.135, 0.310, -0.194, -2.275, -0.530, 0.329, -1.391, -1.135, -0.694, 0.474, -1.135, -2.402, -0.106, -5.000, -5.000, -0.692, -0.423, -0.337, -0.442, -0.665, -0.180, -0.295, -0.819, -0.275, -0.588, -0.779, -1.436, -1.275, 0.209, 0.671, 0.251, -1.297, 0.272, 0.377, -0.302, -0.159, -0.884, -0.205, -1.417, -5.000, -2.597, -2.165, -2.579, -3.183, -1.946, -1.084, -1.861, -1.178, -1.760, -0.902, -0.478, -0.603, -0.808, -1.359, -1.242, -5.000, -5.000, -1.541, -1.990, -5.000, -2.299, -1.359, -5.000, -2.683, -1.041, -0.299, -1.681, -1.035, -1.594, -5.000, -0.722, -2.011, -5.000, -1.135, -1.946, -3.007, -1.119, 0.356, -5.000, -5.000, -0.629, -1.030, -1.666, -1.841, -1.155, -1.081, -1.795, -0.820, -1.591, -1.345, -3.067, -1.949, -2.553, -0.149, -1.048, -2.011, -1.690, -0.878, -1.436, -1.291, -0.157, 0.568, 0.178, -5.000, 0.057, 1.088, 0.255, -0.783, 0.244, 0.959, 0.604, 0.353, -1.100, 0.337, 0.266, 0.302, 0.671, 1.265, 0.902, -5.000, -0.545, 1.315, 0.792, -0.651, 0.672, 1.207, 0.700, 0.042, -0.124, 0.736, -0.515, -0.976, -0.316, 0.093, 0.150, 0.413, -1.588, -0.200, -0.681, -2.098, -1.967, 0.054, -1.021, -1.429, 0.275, -0.337, -1.700, -0.564, 0.646, 0.907, -0.061, 0.587, 0.097, 0.336, -0.705, -0.663, -1.101, 0.469, -0.425, -0.527, 0.102, -0.283, -1.631, -0.206, 0.041, 0.325, 0.219, -5.000, 0.104, 0.174, -0.373, -1.261, 0.324, 0.209, 0.379, -0.280, -1.047, -0.130, -0.145, -0.088, -0.236, 0.022, -1.820, -5.000, -1.145, 0.647, 0.251, -1.865, -0.833, -0.422, -0.219, -0.380, -0.749, -0.225, -1.163, -1.275, -0.101, -0.299, -0.498, -0.264, -0.769, 0.637, -0.881, -1.841, -1.318, -5.000, -0.109, -0.793, -0.190, -0.100, -1.345, -0.808, 0.517, 0.692, -0.397, 0.419, 0.014, 0.575, -0.235, -0.625, -0.337, 0.912, 0.762, 0.218, 0.084, 0.097, -1.127, -0.054, -0.610, -0.682, -1.065, -5.000, -1.002, -5.000, -1.208, -2.992, -1.568, -0.264, -0.548, -1.584, -3.030, -1.541, -1.684, -1.054, -1.115, -0.475, -1.386, -5.000, -5.000, -0.391, -5.000, -1.666, -0.770, -0.831, -0.665, -1.258, -0.779, -0.727, -1.425, -1.356, -0.844, -0.825, -1.946, -0.818, -1.557, -5.000, -0.012, -2.052, -1.084, -0.814, -1.751, -5.000, -1.160, -0.086, -5.000, -2.381, -0.973, -1.029, -1.336, -0.612, -0.769, -1.275, -1.636, -0.894, -1.885, -0.168, 0.356, -1.990, -1.349, -1.421, -3.096, -1.609, 0.031, 0.395, -0.015, -5.000, -0.980, 0.328, -1.132, -1.505, 0.235, 0.490, 0.329, 0.168, -1.287, -0.422, 0.079, 0.169, -0.132, 0.577, -0.385, -5.000, -2.683, 0.394, -0.654, -2.160, -0.451, 0.143, -0.291, -0.492, -0.322, 0.271, -0.682, -0.885, -0.044, 0.561, -0.776, -0.213, -1.471, -0.395, -1.135, -3.289, -1.174, -0.066, -1.487, -2.011, -0.200, -0.260, -1.788, -1.225, 0.108, 0.689, -0.524, 0.117, -0.760, 0.052, -0.940, -2.365, -0.111, 0.349, 0.061, -1.074, -0.810, -0.456, -0.892, -1.075, 0.477, 1.080, 0.477, -5.000, 0.308, 0.716, -0.691, -0.507, 0.404, 0.775, 0.437, 0.441, -0.647, 0.399, 0.054, 0.495, 0.139, 0.707, -0.111, -5.000, -1.476, 0.195, -1.477, -1.525, -0.470, -0.028, 0.059, -0.348, 0.400, -0.030, -0.819, -0.817, 0.233, 0.617, -0.184, 0.443, -0.795, 0.029, -0.483, -1.972, -0.547, 0.206, -0.316, -1.388, -0.091, 0.083, -0.767, -0.675, 0.684, 0.930, -0.060, 0.616, 0.353, 1.050, 0.438, -0.859, 0.637, 1.142, 1.019, 0.223, 0.543, 0.847, 0.420, 0.228, 0.755, 1.164, 0.830, -5.000, 0.173, 0.796, -0.086, -0.883, 0.440, 1.002, 0.739, 0.396, -0.325, 0.523, 0.569, 0.992, 0.577, 0.603, -0.426, -5.000, -0.611, 0.676, -0.966, -0.914, -0.257, 0.302, -0.705, -1.251, 0.832, 0.389, -1.009, -0.360, 0.375, 1.024, 0.244, 0.379, 0.038, 0.981, 0.221, -1.838, -0.224, 0.693, -0.026, -1.348, 0.769, 0.320, -1.172, -0.393, 0.849, 1.122, 0.517, 1.179, 0.950, 1.225, 0.906, -0.313, 0.952, 1.322, 1.089, 0.486, 0.875, 0.993, 0.452, 0.756, -0.037, 0.591, -0.842, -5.000, -0.442, 0.485, -0.804, -1.106, -0.260, 0.189, -0.467, -0.326, -1.114, -0.214, -0.535, 0.032, -0.554, 0.004, -1.612, -5.000, -1.198, 0.278, -1.790, -3.140, -1.974, -0.263, -0.714, -1.640, -0.099, -0.312, -1.367, -1.063, -0.405, 0.001, -1.035, -1.047, -2.140, 0.403, -1.110, -1.853, -0.622, 0.263, -1.054, -2.636, 0.059, -1.253, -0.897, -1.343, -0.564, -0.083, -1.396, -0.359, -0.511, 0.813, 0.256, -0.885, -0.173, 0.606, 0.325, -0.901, -0.443, -0.113, -1.569, -0.954, 0.410, 0.742, 0.435, -5.000, -0.144, 0.509, -0.691, -1.129, 0.287, 0.471, 0.206, 0.009, -0.265, 0.310, 0.523, 0.306, 0.381, 0.820, 0.057, -5.000, -0.562, 0.587, -0.484, -0.804, -0.155, -0.031, -0.262, -1.221, 0.521, 0.396, -0.134, -0.155, 0.396, 1.042, -0.250, 0.088, -0.156, 0.496, -0.080, -1.171, 0.088, 0.251, 0.135, -0.647, 0.980, 0.119, -0.618, 0.373, 0.047, 0.774, -0.717, 0.103, 0.334, 1.134, 0.307, -0.602, 0.495, 1.216, 0.882, -0.113, 0.276, 0.710, -0.100, -0.033, -0.025, 0.888, 0.207, -5.000, -0.470, 0.743, -0.489, -1.531, 0.078, 0.942, 0.702, 0.157, -0.663, 0.435, 0.221, 0.535, -0.018, 0.194, -0.405, -5.000, -1.112, 0.566, -1.168, -1.754, -0.807, 0.548, -0.730, -0.472, 0.445, -0.196, -0.868, -1.139, -0.258, 0.669, -0.132, 0.476, -1.251, 0.700, -0.692, -1.803, -0.888, 0.394, -0.329, -2.470, -0.298, -0.272, -1.304, -0.823, 0.730, 1.138, -0.222, 0.845, 0.245, 0.986, -0.370, -1.199, 0.430, 1.192, 0.677, -0.115, 0.311, 0.601, -0.044, 0.207, 0.899, 1.351, 1.167, -5.000, 0.796, 0.918, 0.619, -0.310, 1.107, 1.011, 1.069, 0.759, 0.366, 1.008, 0.987, 0.921, 0.624, 0.351, -0.507, -5.000, -0.721, 0.656, -0.864, -0.738, 0.149, 0.929, 0.207, -0.114, 0.958, 0.430, -0.978, -0.511, 0.628, 1.133, 0.403, 0.411, 0.480, 1.042, 0.014, -1.184, 0.432, 0.439, -0.742, -1.095, 0.937, 0.251, -0.891, -0.042, 1.063, 1.387, 0.682, 1.239, 0.861, 1.302, 0.914, 0.112, 1.030, 1.186, 0.863, 0.572, 0.842, 0.796, 0.015, 0.748, 0.236, 0.861, 0.329, -5.000, 0.356, 0.697, -1.030, -1.051, -0.502, 0.436, -0.227, -0.056, -1.659, -0.086, -0.132, -0.129, 0.142, 0.447, -0.795, -5.000, -1.901, 0.545, -0.132, -1.307, -0.244, 0.268, -0.825, -0.767, 0.859, 0.430, -0.692, -0.742, 0.442, 0.708, 0.126, 0.511, -0.173, 0.394, 0.102, -0.321, -0.092, -0.219, -1.135, -1.656, 0.652, -0.943, -1.541, -0.656, -0.052, -0.113, -1.234, 0.340, -0.248, 1.032, 0.408, -0.554, 0.802, 0.807, 0.453, -0.174, 0.380, -0.074, -0.903, -1.323, -0.879, -0.115, -0.970, -5.000, -1.342, -0.480, -1.472, -1.858, -0.496, -0.139, -0.848, -0.531, -1.339, -0.160, -1.343, -0.729, -0.815, -0.875, -1.135, -5.000, -2.619, -0.809, -2.477, -1.982, -1.121, -1.016, -0.973, -1.601, -1.022, -0.254, -0.544, -1.125, -1.207, -0.158, -1.235, -1.135, -1.439, -0.933, -1.968, -2.174, -1.321, -1.651, -5.000, -1.163, -0.308, -0.606, -2.976, -1.073, -0.980, -0.290, -0.852, -0.470, -1.093, -0.389, -1.082, -1.914, -0.722, 0.087, -1.030, -1.414, -1.219, -0.772, -1.394, -0.990, 0.502, 0.990, 0.644, -5.000, 0.190, 0.953, -0.314, -0.642, 0.475, 0.953, 0.684, 0.336, -0.426, 0.689, 0.184, 0.464, 0.351, 0.421, -0.028, -5.000, -0.848, 0.867, -1.011, -1.057, 0.537, 0.879, 0.191, -0.147, 0.817, 0.420, -0.532, -0.589, 0.312, 0.897, 0.069, 0.726, -0.653, 0.682, -0.805, -1.822, -0.317, 0.693, -0.183, -0.857, -0.027, 0.098, -1.240, -0.110, 0.351, 1.024, -0.433, 0.893, 0.305, 0.862, 0.051, -0.580, 0.620, 0.993, 0.978, 0.149, 0.523, 0.675, -0.079, 0.396, 1.083, 1.323, 1.312, -5.000, 0.687, 1.141, 0.955, -0.055, 0.896, 1.119, 0.969, 0.576, 0.584, 1.182, 0.715, 0.786, 0.944, 1.082, 0.656, -5.000, -0.201, 1.272, 0.474, -0.825, 0.684, 1.042, 0.632, 0.223, 1.214, 1.207, 0.233, 0.274, 0.689, 0.923, 1.039, 0.527, -0.227, 1.098, 0.010, -1.599, 0.192, 0.743, -0.027, -0.404, 0.490, 0.326, -2.052, -0.077, 1.196, 1.419, 1.180, 1.201, 0.860, 1.416, 0.902, 0.086, 1.044, 1.183, 1.027, 0.788, 0.848, 0.967, 0.302, 0.907, 0.425, 0.813, 0.964, -5.000, 0.400, 1.079, -0.006, -0.350, 0.386, 0.635, 0.143, 0.153, 0.245, 0.639, 0.587, 0.522, 0.438, 0.926, -0.052, -5.000, -0.037, 0.895, -0.337, -0.482, -0.109, 0.952, -0.442, -0.168, 1.090, 1.049, -0.912, 0.169, 0.669, 1.177, 0.350, 0.396, 0.594, 0.839, 0.561, -0.814, 0.591, 0.433, 0.394, -0.796, 0.470, 0.614, -0.086, 1.005, 0.642, 1.037, 0.251, 0.711, 0.839, 1.167, 1.046, -0.799, 0.958, 1.216, 0.676, 0.675, 0.686, 0.951, 0.629, 0.539, 0.220, 0.395, -0.160, -5.000, -1.149, 0.082, -1.759, -1.986, -0.043, 0.110, -0.341, -0.124, -1.255, 0.137, 0.501, 0.169, -0.070, 0.342, -0.286, -5.000, -1.294, -0.094, -1.021, -1.744, -0.578, -0.052, -1.184, -0.881, 0.642, 0.322, -0.609, -0.245, 0.252, 0.686, 0.018, 0.304, -0.211, -0.117, -0.737, -0.851, 0.023, 0.688, -0.848, -5.000, 0.185, 0.241, -0.799, -0.136, 0.009, 0.501, -0.703, 0.087, -0.156, 0.613, -0.130, -1.275, -0.096, 0.531, 0.456, -0.656, -0.378, 0.302, -0.291, -0.545, 0.198, 0.758, 0.294, -5.000, 0.251, 0.981, -0.058, -0.825, 0.317, 0.957, 0.573, 0.312, -0.652, 0.531, 0.113, 0.350, 0.655, 1.128, 0.674, -5.000, -1.145, 1.089, 0.418, -0.898, 0.656, 1.066, 0.699, 0.108, 0.182, 0.635, -0.233, -0.549, 0.134, 0.251, 0.133, 0.395, -0.999, 0.150, -0.532, -1.756, -0.989, -0.210, -1.272, -1.574, 0.260, -0.267, -1.518, -0.361, 0.535, 0.875, -0.141, 0.418, 0.223, 0.334, -0.876, -0.457, -0.161, 0.603, 0.182, -0.456, 0.279, 0.028, -0.890, 0.073, 0.679, 1.024, 0.731, -5.000, -0.048, 0.812, 0.099, -0.864, 0.521, 0.911, 0.716, 0.281, -0.520, 0.414, 0.259, 0.429, 0.312, 0.527, -0.610, -5.000, -0.940, 0.924, 0.010, -1.492, 0.055, 0.469, 0.394, -0.367, 0.264, 0.169, -0.781, -0.877, 0.451, 0.801, 0.360, 0.430, -0.224, 0.587, -0.494, -2.283, -0.203, 0.352, -0.114, -0.889, 0.633, -0.244, -0.810, -0.432, 0.680, 1.040, 0.389, 0.842, 0.677, 0.818, 0.337, -0.576, 0.609, 0.848, 0.780, 0.091, 0.475, 0.443, -0.458, 0.374, -0.008, 0.282, -0.157, -5.000, -0.522, 0.639, -0.937, -1.561, 0.049, 0.738, 0.061, -0.119, -1.663, -0.364, -0.611, -0.238, -0.508, 0.207, -0.955, -5.000, -1.330, 0.400, -0.807, -1.898, -0.086, 0.637, -0.055, -0.591, -0.056, -0.213, -1.477, -0.854, -0.203, -0.077, -0.724, -0.727, -1.065, -0.337, -0.831, -3.387, -0.086, 0.033, -0.935, -2.797, -0.122, -0.280, -1.198, -1.331, -0.148, -0.006, -1.594, -0.300, 0.100, 0.277, -0.464, -1.092, -0.335, 0.053, -0.505, -1.350, -0.442, -0.481, -2.049, -1.074, 0.141, 0.585, 0.316, -5.000, -0.456, 0.606, -0.764, -1.400, 0.447, 0.505, 0.320, 0.054, -1.046, 0.087, 0.379, 0.004, 0.226, 0.756, -0.076, -5.000, -1.423, 0.662, 0.044, -1.331, -0.159, 0.272, 0.249, -0.461, 0.206, 0.115, -0.395, -0.537, 0.242, 0.926, -0.236, 0.058, -0.318, 0.193, -0.629, -1.972, 0.067, 0.450, -0.628, -1.856, 0.242, 0.249, -0.907, -0.253, 0.080, 0.659, -0.370, -0.221, -0.089, 0.296, -0.585, -1.346, 0.025, 0.255, -0.134, -0.985, -0.369, -0.291, -0.989, -0.559 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_2(struct _training *tptr) {
  struct _training tinf = {
    0.285, 4, 4.350, { 2.312, 0.409, 0.279 }, { 1.124, -1.900, -2.793 }, 1, 
    { -1.171, -0.102, -0.685, -0.141, -0.491, 1.102, -0.111, -4.000, -4.000, -0.288, 0.409, -4.000, 1.291, 0.853, 0.678, 2.434, 1.911, 0.754, -4.000, 1.908, 2.314, 3.268, 3.035, -4.000, 2.565, -4.000, 2.894, 3.312 }, 
    {{ 0.216, -0.720, -0.962, 0.190},{ 0.278, -1.323, -0.546, 0.131},{ 0.305, -0.114, -0.587, -0.147},{ 0.332, 0.042, -0.674, -0.243},{ 0.371, -0.239, -0.932, -0.131},{ 0.288, -0.546, -0.566, 0.006},{ 0.238, -0.154, -0.253, -0.131},{ 0.342, -0.168, -0.674, -0.163},{ 0.295, -0.451, -0.697, 0.002},{ 0.249, -0.239, -0.253, -0.116},{ 0.256, -0.331, -0.381, -0.055},{ 0.288, -0.451, -0.608, -0.008},{ 0.315, -0.364, -0.629, -0.065},{ 0.256, -0.507, -0.546, 0.033},{ 0.220, -0.608, -0.526, 0.094},{ 0.194, -0.268, -0.415, 0.015},{ 0.155, -0.364, -0.299, 0.055},{ 0.163, -0.587, -0.299, 0.098},{ 0.163, -0.224, -0.299, 0.006},{ 0.175, -0.398, -0.433, 0.077},{ 0.201, -0.224, -0.451, 0.002},{ 0.178, -0.168, -0.331, -0.022},{ 0.143, -0.154, -0.347, 0.020},{ 0.139, -0.210, -0.629, 0.106},{ 0.123, -0.076, -0.299, 0.002},{ 0.047, -0.076, -0.210, 0.055},{ 0.077, -0.154, -0.364, 0.094},{ 0.147, -0.210, -0.381, 0.042},{ 0.167, -0.181, -0.253, -0.027},{ 0.171, -0.331, -0.168, -0.012},{ 0.060, -0.064, -0.299, 0.064},{ 0.123, -0.064, -0.381, 0.020} }, 
    {{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}} }, 
    0.000, { 0.445, 0.986, 0.533, -5.000, -0.154, 0.870, -0.034, -0.784, -0.035, 0.619, 0.371, -0.181, -0.265, 0.315, -0.121, 0.375, -0.304, 0.366, -0.472, -5.000, -1.199, 0.325, -1.063, -1.992, -1.064, -0.225, -0.847, -0.668, 0.154, -0.696, -1.297, -0.832, 0.273, 0.913, 0.170, 0.196, 0.161, 0.542, 0.361, -1.919, -0.037, 0.901, -0.080, 0.029, 0.077, 0.529, 0.351, -0.584, 0.630, 1.075, -0.070, 0.497, 0.367, 1.117, 0.925, -1.477, 0.584, 0.923, 0.603, 0.281, 0.690, 0.834, 0.487, 0.199, 1.154, 1.423, 1.232, -5.000, 0.851, 1.081, 0.455, 0.199, 0.959, 1.274, 1.217, 0.751, 0.635, 0.944, 0.862, 1.145, 0.252, 0.898, -0.027, -5.000, -0.401, 0.280, -1.655, -1.103, -1.305, 0.117, -0.227, -0.238, 0.520, -0.182, -1.086, -0.140, 0.944, 1.072, 0.126, 0.957, 0.780, 1.050, 0.666, -1.498, 0.925, 1.309, 1.012, 0.678, 1.055, 1.029, 0.784, 0.070, 1.075, 1.485, 0.770, 0.966, 1.032, 1.356, 1.430, -0.570, 1.093, 1.212, 1.051, 1.110, 1.170, 1.117, 0.791, 0.752, 0.764, 1.248, 0.618, -5.000, 0.173, 1.199, -0.011, -0.667, 0.810, 1.291, 1.111, 1.011, -0.447, 0.733, 0.125, 0.577, 0.248, 0.863, 0.099, -5.000, -0.443, 0.553, -0.274, -1.226, 0.113, 0.558, 0.753, 0.436, 0.344, -0.020, -0.681, -0.182, 0.390, 0.535, -0.604, -0.060, 0.300, 0.902, 0.297, -1.462, 0.443, 1.032, 0.483, 0.059, -0.065, 0.243, -0.133, -0.171, 0.567, 1.013, -0.760, 0.219, 0.828, 1.279, 1.265, -0.821, 0.678, 0.764, 0.318, 0.359, 0.720, 0.531, -0.388, -0.099, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.072, 0.841, 0.302, -5.000, -0.610, 0.650, -0.400, -1.212, -0.177, 0.548, 0.250, -0.469, -0.155, 0.349, 0.133, 0.637, -1.180, 0.433, -1.015, -5.000, -1.212, -0.217, -0.486, -3.543, -1.429, -0.410, -0.526, -0.922, -0.613, -0.615, -2.280, -0.934, -0.236, 0.152, -0.282, -1.030, -0.841, 0.207, 0.489, -2.209, -0.942, -0.427, -1.076, -1.844, -0.749, -0.269, -0.937, -1.825, 0.291, 0.914, -0.003, -0.284, -0.581, 0.801, 0.805, -1.535, 0.112, 0.735, 0.283, -0.003, 0.210, 0.458, -0.149, -0.728, 0.656, 0.917, 1.016, -5.000, 0.503, 0.861, 0.743, -0.342, 1.051, 1.199, 1.169, 0.785, 0.469, 1.020, 0.661, 0.987, -0.054, 0.936, -0.061, -5.000, -0.441, 1.030, 0.455, -5.000, -0.867, 0.886, 0.696, 0.295, 0.948, 0.622, -1.035, 0.088, 0.788, 0.743, 0.026, 0.803, 0.681, 1.131, 1.371, -1.337, 1.077, 1.389, 0.542, 0.524, 0.970, 1.043, -0.279, -0.120, 0.749, 1.362, 0.899, 1.043, 0.803, 1.478, 1.502, -0.095, 0.965, 0.988, 1.008, 0.753, 0.805, 0.597, 0.500, 0.278, -0.000, 0.386, -0.761, -5.000, -0.479, 0.147, -1.103, -1.728, -0.607, 0.219, -0.653, -0.846, -0.608, -0.217, -0.756, -0.422, -0.654, 0.647, -0.415, -5.000, -1.445, 0.261, -5.000, -1.598, -5.000, 0.232, -1.021, -0.853, -0.030, 0.323, -0.427, -0.606, -0.304, 0.455, -0.714, 0.094, -0.461, -0.992, -0.931, -2.921, -2.009, 0.420, -5.000, -5.000, -1.265, -1.417, -1.378, -0.931, -0.175, 1.007, -1.134, -0.352, -0.429, 0.756, 0.656, -2.312, 0.248, 0.346, -0.210, 0.076, 0.390, 0.470, -0.917, -0.157, -0.463, 0.406, -0.587, -5.000, -1.956, -0.419, -1.579, -1.979, -0.812, -0.413, -0.811, -0.953, -1.115, -0.774, -1.256, -0.891, -0.949, 0.062, -0.518, -5.000, -2.451, -0.486, -1.856, -3.271, -2.987, -0.992, -5.000, -3.618, -0.617, -0.706, -2.270, -1.108, -0.902, 0.310, -1.203, -0.823, -1.831, -0.283, -0.975, -2.740, -1.301, -0.343, -0.808, -1.504, -1.531, -1.011, -1.103, -1.384, -0.856, 0.134, -1.735, -1.080, -1.189, 0.137, 0.125, -3.942, -0.755, -0.204, -0.698, -1.433, -0.572, -0.263, -1.134, -0.941, 0.224, 0.811, 0.411, -5.000, -0.207, 1.103, -0.064, -0.684, 0.015, 0.590, 0.373, -0.051, -0.123, 0.533, 0.075, 0.306, -0.304, 0.441, -0.364, -5.000, -1.586, 1.034, -0.187, -1.860, -0.610, -0.043, 0.050, -0.466, -0.289, -0.238, -1.397, -0.551, 0.326, 0.871, 0.518, 0.252, -0.089, 0.463, 0.050, -2.720, 0.261, 0.358, -0.328, -0.724, 0.105, -0.004, -0.356, -0.570, 0.720, 1.224, 0.337, 0.783, 0.393, 0.992, 0.637, -1.294, 0.604, 0.700, 0.455, 0.329, 0.674, 0.658, 0.382, 0.469, 0.858, 1.180, 1.053, -5.000, 0.467, 1.109, -0.213, -0.382, 0.621, 0.692, 0.696, 0.358, 0.403, 0.809, 0.349, 0.688, 0.211, 0.990, 0.305, -5.000, -0.486, 0.883, 0.596, -1.029, -0.494, 0.485, -0.151, -0.436, 0.647, 0.248, -0.917, -0.056, 0.793, 0.506, 0.347, 0.620, 0.266, 0.905, 0.174, -1.723, 0.542, 0.854, 0.622, 0.273, 0.232, 0.500, -0.392, -0.542, 1.036, 1.442, 0.703, 1.094, 0.758, 1.208, 0.932, -1.179, 1.004, 0.856, 0.658, 0.526, 0.854, 0.853, 0.490, 0.601, 0.557, 0.601, 0.780, -5.000, -0.076, 0.843, 0.324, -0.696, 0.575, 0.619, -0.168, 0.016, -0.094, 0.445, 0.034, 0.213, -0.025, 0.806, 0.232, -5.000, -0.968, 0.830, -0.105, -1.085, 0.350, 0.642, 0.289, -0.094, 0.306, 0.412, -0.637, -0.179, 0.633, 0.883, 0.603, 0.392, 0.313, 1.002, 0.473, -2.328, 0.985, 0.537, -0.615, 0.144, 0.554, 0.137, -1.154, 0.101, 0.772, 1.242, 0.166, 0.595, 0.487, 1.321, 0.916, -0.707, 0.784, 0.710, 0.137, 0.285, 0.519, 0.510, 0.346, -0.046, 0.113, 0.773, 0.508, -5.000, -0.176, 0.603, -0.897, -0.836, -0.013, -0.123, -0.219, -0.267, -0.459, -0.222, -0.469, 0.048, -0.540, 0.460, -0.105, -5.000, -1.965, -1.796, -1.397, -1.565, -0.889, -5.000, -0.774, -1.505, 0.319, -0.399, -0.983, -0.507, 0.109, 0.642, 0.179, -0.157, 0.040, 0.668, 0.200, -2.069, 0.244, 0.373, -0.333, -0.160, -0.201, 0.572, 0.660, -0.576, 0.152, 0.853, -0.136, 0.204, 0.061, 1.106, 0.779, -1.257, 0.295, 0.417, 0.537, -0.114, 0.262, 0.465, 0.365, -0.379, -0.170, 0.562, 0.171, -5.000, -0.144, 0.242, -0.383, -1.077, -0.212, 0.132, 0.038, -0.341, -0.566, -0.464, -0.696, -0.179, -1.053, -0.167, -1.091, -5.000, -1.028, -0.025, -0.630, -1.593, -1.675, -0.774, -0.206, -0.985, -0.674, -1.082, -1.999, -1.185, -0.480, 0.237, -0.072, 0.038, -0.721, -0.591, -0.318, -2.197, -0.822, -0.009, -0.660, -1.748, -0.930, -0.712, -0.692, -0.953, 0.062, 0.586, -0.336, 0.050, 0.024, 0.599, -0.015, -1.351, -0.235, 0.253, 0.114, -0.105, -0.137, 0.003, -0.702, -0.115, 0.489, 1.007, 0.720, -5.000, 0.382, 0.736, 0.310, -0.635, 0.680, 0.344, 0.714, 0.320, -0.055, 0.214, 0.028, 0.506, -0.438, 0.504, -0.115, -5.000, -0.312, 0.783, 0.565, -1.149, -0.724, -0.305, -0.644, -0.452, -0.162, -0.453, -1.689, -0.541, -0.815, 0.022, -0.206, -0.076, -0.238, -0.213, -0.601, -0.906, -0.372, -0.068, -0.557, -0.644, -0.141, -0.222, -0.992, -1.294, 0.677, 1.167, 0.224, 0.685, 0.367, 0.784, 0.853, -0.754, 0.296, 0.265, 0.155, 0.313, 0.410, 0.213, -0.044, 0.170, 0.120, 0.710, 0.244, -5.000, 0.032, 0.857, -0.196, -0.589, 0.386, 0.695, 0.111, 0.291, -0.319, -0.296, -0.658, -0.164, -0.692, 0.276, -0.519, -5.000, -1.663, 0.160, -1.129, -1.291, -0.489, 0.085, 0.100, -0.243, -0.354, -0.512, -1.501, -0.575, -0.271, -0.232, -0.699, -0.411, -0.299, 0.682, -0.333, -0.798, 0.137, 0.621, -0.019, -0.228, -0.594, -1.060, -0.970, -0.596, 0.023, 0.505, -0.898, -0.470, 0.312, 0.957, 0.422, -1.859, -0.003, 0.352, -0.073, -0.279, -0.182, -0.110, -1.247, -0.736, 0.331, 0.870, 0.420, -5.000, 0.224, 0.425, -0.798, -0.680, 0.149, 0.342, -0.228, 0.182, -0.518, -0.088, -0.465, 0.049, -0.248, 0.619, -0.154, -5.000, -0.816, -0.091, -0.821, -1.145, -0.192, -0.739, -0.783, -0.467, -0.091, -0.332, -1.103, -0.245, 0.526, 0.878, -0.262, 0.108, 0.442, 0.758, -0.078, -1.404, 0.484, 0.428, 0.050, 0.167, 0.147, 0.519, -0.113, -0.028, 0.561, 1.080, -0.107, 0.263, 0.526, 0.891, 0.673, -1.249, 0.450, 0.574, 0.418, -0.197, 0.574, 0.597, 0.097, 0.096, -0.471, 0.388, -0.659, -5.000, -0.305, 0.113, -1.675, -1.971, -0.920, -0.072, -0.760, -1.114, -1.157, -1.130, -1.183, -0.494, -1.571, -0.557, -1.796, -5.000, -1.777, -0.826, -2.050, -3.764, -2.442, -1.831, -1.103, -2.095, -0.741, -1.920, -3.088, -1.811, -0.348, 0.356, -1.031, -0.721, -0.499, -0.110, -0.196, -2.489, -0.698, 0.185, -1.353, -0.690, -0.854, -0.938, -0.895, -1.577, 0.068, 0.907, -0.912, -0.248, 0.229, 0.279, 0.882, -1.815, 0.489, 0.800, 0.682, 0.163, 0.481, 0.552, -0.046, -0.252, 0.681, 1.067, 0.510, -5.000, -0.006, 0.691, 0.167, -0.333, 0.564, 0.906, 0.776, 0.413, 0.137, -0.076, 0.145, 0.555, -0.365, 0.244, -1.032, -5.000, -0.520, 0.137, -1.655, -1.848, -5.000, -0.187, -2.009, -1.378, 0.082, -1.211, -1.837, -1.145, 0.556, 0.618, -0.992, -0.076, 0.538, 0.951, 0.176, -2.184, 0.483, 1.291, -0.174, 0.820, 0.396, 0.980, 0.074, -0.931, 0.716, 1.333, 0.296, 0.502, 0.610, 1.289, 1.104, -1.110, 0.775, 0.934, 0.780, 0.708, 0.675, 0.611, 0.321, -0.083, -0.083, 0.448, -0.571, -5.000, -0.441, 0.502, -5.000, -2.929, 0.205, 0.582, 0.301, 0.564, -0.955, -0.183, -0.478, -0.416, -1.119, -0.269, -1.609, -5.000, -1.756, -0.084, -5.000, -2.103, -0.615, -0.224, -1.129, -1.120, -1.059, -1.814, -2.030, -0.944, -0.631, -0.875, -1.451, -2.670, -0.247, -1.593, -0.427, -1.728, 0.114, -1.067, -1.417, -1.728, -1.314, -1.144, -1.655, -1.834, -0.055, 0.204, -1.617, -0.871, -0.127, 0.812, 0.941, -1.243, 0.148, 0.384, -0.565, -0.121, -0.208, -0.200, -1.242, -1.195, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -1.107, -0.283, -0.862, -5.000, -1.380, -0.575, -0.992, -2.086, -1.316, -0.791, -1.350, -2.084, -1.258, -0.123, -0.716, -0.534, -1.889, -1.436, -1.549, -5.000, -0.992, -1.593, -1.337, -2.754, -5.000, -1.454, -5.000, -5.000, -1.832, -1.805, -5.000, -1.920, -1.837, -0.238, -1.848, -1.118, -2.196, -1.714, -1.526, -2.135, -3.196, -5.000, -2.050, -5.000, -1.866, -5.000, -5.000, -4.036, -0.446, -0.322, -2.100, -1.272, -1.383, -0.931, -0.833, -2.231, -1.301, -0.530, -1.685, -0.410, -0.963, -0.644, -1.397, -1.393, 0.261, 0.633, 0.170, -5.000, -0.402, 0.861, -1.103, -0.439, 0.886, 0.830, 1.018, 0.465, 0.626, 0.167, 0.210, 0.444, -0.427, -0.684, -0.601, -5.000, -0.798, 0.107, -0.238, -1.714, -0.867, -0.392, 0.360, -1.337, -0.292, -0.798, -2.110, -0.510, 0.283, 0.414, 0.291, -5.000, -0.299, 0.843, 0.637, -0.557, -0.238, 0.337, -5.000, -0.526, 0.122, 0.050, -0.174, -1.473, 0.385, 0.873, 0.365, 0.333, 0.394, 1.048, 0.689, -1.309, 0.900, 0.956, 0.589, 0.428, 0.127, 0.317, -0.565, -0.217, -0.798, -0.105, -0.287, -5.000, -1.076, 0.589, -5.000, -5.000, -0.046, 0.266, -0.684, -1.337, -5.000, 0.232, -0.299, -0.494, -1.872, -0.174, -1.442, -5.000, -5.000, -0.410, -5.000, -1.908, -5.000, -0.105, -0.356, -0.615, -1.049, -0.287, -5.000, -1.134, -0.304, -0.299, -1.429, -1.337, -0.644, -0.644, -0.798, -2.348, -1.154, -0.867, -0.601, -0.557, -1.943, -5.000, -5.000, -1.931, -0.698, -0.220, -2.030, -0.414, 0.074, 0.861, 0.283, -5.000, -0.140, -0.931, -5.000, -0.015, -0.931, -0.174, -0.292, -1.407, -1.236, -1.195, -2.027, -5.000, -2.077, -0.572, -5.000, -2.822, -2.371, -1.316, -2.378, -1.822, -1.333, -1.728, -1.965, -1.674, -1.498, -0.251, -2.193, -5.000, -3.086, -0.947, -5.000, -2.328, -2.236, -1.655, -5.000, -2.157, -1.350, -1.027, -2.744, -1.817, -1.839, -1.316, -2.148, -1.720, -3.825, -5.000, -2.393, -3.815, -5.000, -5.000, -5.000, -2.733, -3.011, -0.931, -5.000, -2.502, -1.759, -0.634, -3.869, -1.647, -1.958, -1.217, -1.742, -2.944, -1.652, -0.983, -1.350, -1.709, -1.823, -1.103, -1.772, -2.063, -0.807, -0.087, -0.708, -5.000, -1.305, -0.056, -5.000, -2.831, -0.579, 0.172, -0.238, -1.485, -1.667, -0.644, -0.850, -0.625, -1.670, -0.427, -0.931, -5.000, -5.000, 0.455, -5.000, -5.000, -0.972, -0.174, -0.004, -1.049, -1.337, -1.454, -1.624, -5.000, -1.761, -1.378, -5.000, -1.227, -1.397, -5.000, -5.000, -5.000, -2.868, -5.000, -5.000, -2.348, -2.045, -1.655, -2.393, -2.595, -0.595, 0.684, -1.179, -0.120, -1.417, 0.050, 0.743, -1.560, -0.674, -0.774, -0.833, -1.593, -0.885, -0.644, -0.399, -1.583, -0.062, 0.790, 0.186, -5.000, -0.575, 0.696, -1.103, -2.325, 0.195, 0.472, 0.552, 0.215, -0.193, -0.226, -0.019, 0.002, -0.364, 0.589, -0.557, -5.000, -0.867, -0.557, -0.557, -2.166, -5.000, -0.318, 1.148, -0.526, -0.096, -1.417, -2.219, -0.956, -1.030, 0.137, -0.867, -0.196, -0.290, 0.800, 0.455, -5.000, -0.174, 0.455, -1.154, -1.337, -0.931, -0.931, -1.076, -1.280, 0.616, 0.925, -0.774, 0.455, 0.363, 0.769, 0.743, -0.962, 0.455, 0.803, -0.140, -0.022, 0.304, 0.327, -0.196, -0.368, -0.094, 0.029, -0.582, -5.000, 0.261, -5.000, -0.030, -0.992, 0.036, 0.283, -0.293, -0.875, -0.749, 0.266, -0.389, -0.220, -0.500, -0.821, -0.410, -5.000, -1.103, 0.743, -5.000, -1.714, -0.684, -1.154, -1.250, -5.000, -0.671, -0.105, -1.076, -1.028, -0.122, 0.050, -1.560, -0.534, -1.203, 0.050, -0.557, -2.348, 0.315, -0.461, 0.009, -1.624, -0.867, -0.238, -0.269, -0.739, 0.362, 1.148, -1.685, -0.475, 0.365, 0.925, -0.105, -0.004, 0.263, -0.383, -0.238, -0.774, 0.345, 0.167, -0.664, -0.840, -0.639, 0.176, -0.364, -5.000, -1.174, -0.575, -5.000, -1.685, -1.809, -0.269, -1.261, -0.960, -1.564, -1.203, -1.426, -0.804, -1.191, -0.867, -2.030, -5.000, -2.658, -0.867, -5.000, -5.000, -5.000, -5.000, -1.454, -2.202, -0.470, -1.920, -2.030, -0.838, -1.154, 0.886, -0.601, -2.463, -1.217, -0.798, -0.410, -5.000, 0.050, -1.294, -1.103, -0.798, -0.962, -0.105, 0.050, -2.110, -0.398, 0.416, -0.708, -1.587, -0.128, -0.076, 0.743, -2.954, -0.390, 0.092, -0.076, -0.313, 0.055, 0.050, 0.059, -0.597, -0.089, 0.741, 0.086, -5.000, 0.303, 1.079, -0.120, -0.886, -0.307, 0.542, -0.062, -0.045, -0.802, -0.167, -0.946, -0.134, -1.457, -0.233, -1.350, -5.000, -1.195, 0.582, 0.107, -1.193, -1.057, -0.134, -0.777, -1.357, -0.768, -1.078, -1.985, -1.228, -0.338, 0.397, -0.052, 0.669, -0.881, 0.096, 0.526, -1.912, -0.681, 0.301, -1.021, -1.138, -0.080, -0.228, -1.280, -0.886, -0.107, 0.646, -0.744, -0.133, -0.324, 1.191, 0.900, -1.914, -0.018, 0.603, 0.342, 0.082, 0.179, 0.383, -0.382, -0.110, -0.155, 0.396, -0.588, -5.000, -0.251, 0.509, -0.041, -0.793, 0.007, -0.076, 0.204, -0.222, -0.902, -0.601, -1.272, -0.652, -1.428, -0.313, -1.912, -5.000, -0.690, 0.337, -0.174, -2.764, -0.968, -2.528, -0.736, -1.695, -0.822, -1.445, -2.240, -1.703, -1.950, -5.000, -1.337, -2.286, -0.692, -0.151, -0.867, -5.000, -2.286, -0.510, -0.557, -0.128, -1.624, -0.541, -1.146, -2.707, 0.309, 0.861, -0.612, 0.170, 0.373, 0.689, 0.671, -2.286, 0.624, 0.153, 0.350, 0.024, -0.211, -0.478, -0.826, -0.689, -0.862, -1.209, -1.522, -5.000, -0.392, 0.337, -2.030, -1.663, -0.082, 0.060, -0.488, 0.050, -1.495, -1.404, -2.653, -1.637, -1.987, -1.624, -2.565, -5.000, -0.698, -0.030, -5.000, -2.946, -0.610, -0.116, -1.154, -0.415, -1.157, -1.516, -1.609, -1.886, -2.680, -2.877, -2.605, -1.837, -1.323, -5.000, -5.000, -1.835, -1.391, -0.952, -1.987, -0.977, -2.240, -5.000, -2.642, -2.815, -1.126, -0.661, -2.226, -1.526, -0.972, -0.015, -0.931, -1.617, -0.829, -0.597, -0.701, -1.238, -1.669, -2.044, -3.300, -1.756, -0.862, -0.092, -0.765, -5.000, -0.292, 0.010, -1.617, -1.577, -0.562, -0.700, -1.265, -0.620, -1.426, -0.984, -1.573, -0.698, -1.202, -0.373, -1.194, -5.000, -1.246, -0.715, -1.142, -2.647, -1.714, -1.582, -1.491, -2.553, -0.497, -1.324, -2.946, -1.450, -0.696, -0.269, -1.158, -1.128, -0.867, -0.289, -1.954, -3.779, -0.568, -0.061, -0.975, -0.593, -1.598, -1.203, -1.533, -1.595, -0.583, 0.313, -1.378, -0.614, -0.232, 0.398, -0.120, -1.863, -0.574, -0.267, -0.259, -1.117, -0.487, -0.713, -1.102, -1.117, 0.000, 0.835, 0.032, -5.000, -0.352, 0.354, -0.392, -0.626, -0.241, 0.521, 0.117, -0.542, -0.545, -0.042, -0.272, 0.425, -0.687, 0.030, -1.533, -5.000, -2.991, -0.259, -5.000, -3.114, -5.000, -0.850, -5.000, -1.928, -0.192, -1.709, -1.586, -1.159, -0.057, 0.604, -0.190, 0.134, -0.776, -0.477, 0.494, -2.296, -0.301, 0.202, -0.577, -0.521, -0.258, 0.137, -0.148, -0.964, 0.208, 0.832, -0.603, 0.222, -0.235, 0.415, 0.897, -3.114, 0.409, 0.648, 1.009, 0.256, 0.467, 0.710, 0.472, 0.153, 0.835, 1.254, 0.611, -5.000, 0.007, 0.760, -1.491, -0.510, 0.580, 0.876, 1.148, 0.631, 0.424, 0.563, 0.377, 0.787, -0.419, 0.193, -0.488, -5.000, 0.150, 0.637, -0.238, -2.348, -1.103, -0.356, -0.644, -5.000, 0.179, -1.268, -2.061, -0.750, 0.476, 0.277, -0.136, -0.356, -0.019, 0.780, 1.015, -5.000, -0.356, 0.830, 0.273, 0.232, 0.442, 0.637, -0.630, -0.296, 0.745, 1.222, 0.251, 0.984, 0.883, 1.280, 1.117, -0.651, 1.090, 1.020, -0.072, 1.053, 0.759, 0.767, 0.125, 0.144, 0.142, 0.606, -0.513, -5.000, 0.160, 1.126, -1.920, -1.316, 0.196, 0.584, 0.254, 0.355, -0.747, 0.232, -0.125, 0.042, -1.105, -0.126, -1.265, -5.000, -1.283, 0.035, -0.798, -2.702, -2.333, -0.397, -0.105, -0.840, -0.253, -0.500, -1.303, -0.535, -0.779, -0.711, -1.097, -0.858, -0.321, 0.375, -0.500, -1.780, -0.310, 0.279, -2.184, -0.844, -0.909, -0.312, -1.617, -0.527, -0.328, 0.293, -1.648, -0.612, -0.147, 1.065, 0.743, -1.624, 0.269, 0.012, -0.013, -0.232, 0.162, 0.188, -0.632, -0.801, 0.122, 0.921, 0.198, -5.000, -0.608, 0.289, -1.203, -1.051, 0.215, 0.319, -0.224, 0.303, -0.268, -0.174, -0.188, -0.136, -0.466, 0.618, -0.305, -5.000, -1.805, -1.593, -0.427, -1.521, -5.000, -1.417, -5.000, -2.009, 0.034, -0.947, -1.436, -0.838, -0.301, 0.654, -1.006, -0.238, -0.461, 0.574, -0.130, -2.228, -0.503, 0.865, -1.337, -0.163, -0.872, 0.396, -0.363, -0.684, -0.403, 0.687, -1.197, -0.426, -0.480, 1.038, 0.966, -3.156, -0.242, 0.612, 0.695, -0.344, -0.113, 0.298, -0.537, -0.686, -0.588, 0.522, -0.026, -5.000, -1.005, 0.640, -1.987, -1.965, -0.494, 0.585, 0.190, -0.602, -0.559, 0.255, -0.198, 0.415, -1.273, 0.325, -0.692, -5.000, -2.318, -0.238, -1.770, -3.539, -2.385, -0.048, -0.526, -1.526, -0.863, -0.771, -1.196, -0.954, -0.992, 0.455, -0.483, -0.336, -1.609, -1.085, -0.084, -3.056, -0.873, -0.335, -1.203, -1.651, -0.953, 0.191, -2.172, -1.670, -0.067, 0.963, -0.293, 0.091, -0.741, 0.327, 0.613, -2.021, 0.060, 0.778, 0.856, 0.216, 0.244, 0.547, 0.274, -0.296, 0.366, 1.102, 0.581, -5.000, -0.347, 0.961, -0.196, -0.880, 0.760, 1.148, 0.907, 0.755, 0.320, 0.315, 0.836, 0.823, -0.689, 0.565, -0.664, -5.000, -1.250, 0.050, -5.000, -1.309, -5.000, 0.083, 0.232, -0.427, 0.281, -0.340, -2.166, -0.590, 0.381, 0.637, -0.105, 0.337, -0.724, 0.589, 0.167, -5.000, -0.125, 0.780, 0.337, -1.067, -0.257, 0.765, -5.000, -1.848, 0.632, 1.367, 0.455, 0.613, 0.347, 1.078, 1.331, -0.805, 0.804, 1.051, 0.414, 0.594, 0.519, 0.455, 0.283, -0.190, -0.082, 0.682, 0.028, -5.000, 0.003, 1.088, -5.000, -1.822, -0.030, 0.719, -0.269, -0.299, -0.627, -0.030, -0.076, -0.305, -0.867, 0.498, -1.503, -5.000, -2.286, 0.483, -5.000, -1.350, -1.560, 0.560, -5.000, -0.461, 0.206, 0.659, -0.812, -0.429, -0.664, 0.155, 0.111, 0.137, -0.956, -1.103, -0.030, -2.348, -0.410, -0.140, -5.000, -1.129, -0.615, -0.761, -0.187, -0.289, 0.446, 1.127, -1.287, 0.479, -0.299, 1.063, -0.174, -0.919, 0.925, 0.853, 0.337, 0.283, 0.849, 0.597, -0.221, -0.156, -2.145, -1.417, -1.750, -5.000, -2.009, -1.350, -5.000, -2.579, -2.100, -0.880, -2.009, -2.428, -2.404, -0.780, -2.995, -2.441, -2.702, -1.624, -2.019, -5.000, -5.000, -5.000, -5.000, -2.898, -5.000, -1.920, -5.000, -2.489, -1.618, -1.685, -5.000, -3.294, -2.272, -5.000, -2.784, -1.330, -3.318, -5.000, -2.236, -3.297, -5.000, -2.030, -1.655, -5.000, -2.356, -1.609, -2.138, -3.300, -2.389, -1.076, -1.878, -2.259, -2.174, -1.371, -1.006, -2.657, -1.909, -1.312, -1.243, -1.746, -1.840, -1.063, -2.589, -2.328, -0.119, 0.874, 0.047, -5.000, -0.858, 1.036, -0.181, -1.962, -0.100, 0.599, 0.487, -0.494, -0.500, 0.162, 0.114, 0.324, -0.938, 0.557, -0.526, -5.000, -2.476, 0.455, -0.931, -5.000, -2.407, -0.324, -1.337, -0.893, -0.503, 0.009, -0.210, -0.999, -0.427, 0.195, -0.062, -0.429, -1.260, -0.568, 0.150, -3.712, -0.600, 0.251, -1.491, -1.219, -0.952, -0.470, -0.571, -1.378, -0.055, 0.990, -1.277, 0.262, -0.231, 0.678, 1.148, -1.140, 0.333, 0.912, 0.455, 0.128, 0.199, 0.765, 0.253, -0.444, 0.538, 1.256, 0.909, -5.000, -0.992, 0.778, -0.105, -1.160, 0.710, 1.039, 0.966, 0.411, 0.318, 0.672, 0.209, 0.428, -0.200, 0.800, -0.356, -5.000, -5.000, -5.000, -5.000, -5.000, -1.250, 0.689, 0.050, 0.107, 0.275, -0.500, -0.494, -0.569, 0.188, 0.455, -0.557, -0.724, -0.423, -0.151, 0.107, -1.770, -0.387, 0.851, -0.004, -0.815, 0.149, 0.288, -0.575, -1.065, 0.782, 1.413, 0.994, 0.905, 0.896, 1.159, 0.976, -0.923, 0.907, 1.297, 0.589, 0.869, 1.100, 1.132, 0.254, 0.309, 0.193, 0.312, 0.083, -5.000, -0.420, 1.148, -0.867, -1.103, -0.119, 0.433, -0.724, -1.179, -0.765, -0.206, -0.414, -0.429, -1.756, 0.214, -0.724, -5.000, -0.356, 0.000, -5.000, -1.943, -0.586, 0.078, -0.410, -0.586, -0.238, -0.284, 0.050, -1.238, -0.366, 0.609, -0.867, -2.050, -0.910, 0.925, -0.557, -1.350, 0.514, 0.455, 0.047, -1.491, -0.105, -0.105, -1.250, -0.761, 0.206, 0.994, 0.022, -1.124, -0.187, -0.724, -5.000, -5.000, -0.068, 0.301, 0.199, -0.623, 0.870, 0.147, -0.238, -0.408, -0.405, 0.554, -0.179, -5.000, -2.071, -0.117, -2.184, -1.962, -0.213, -0.051, -1.265, -0.767, -0.752, -0.299, -0.757, -0.166, -1.161, 0.589, -0.356, -5.000, -2.702, -5.000, -5.000, -5.000, -1.796, -0.299, -5.000, -2.050, -0.335, -0.867, -5.000, -1.378, -0.983, 0.218, -0.644, -0.931, -0.598, 0.473, 0.137, -5.000, -0.741, 0.325, -0.931, -1.154, -0.761, 0.708, 0.145, -1.404, -0.578, 0.378, -1.473, -0.782, -0.859, 0.443, 0.637, -2.673, -0.122, 0.417, 0.589, -0.369, 0.177, 0.396, -0.030, -0.735, -0.302, 0.798, 0.116, -5.000, -0.696, 0.577, -0.582, -1.335, -0.179, 0.628, -0.100, -0.404, -1.093, -0.108, -0.359, -0.025, -1.643, -0.129, -0.815, -5.000, -3.068, -0.259, -1.685, -2.901, -1.723, -0.623, -0.087, -0.962, -1.085, -1.265, -1.765, -1.672, -0.453, 0.132, 0.098, -0.353, -0.623, 0.044, 0.520, -2.286, -0.729, -0.171, -0.736, -0.927, -0.524, 0.321, -0.566, -1.709, -0.080, 0.778, -0.578, 0.073, -0.296, 0.510, 0.483, -2.012, 0.133, 0.701, 0.511, 0.221, 0.050, 0.406, -0.377, -0.531, 0.218, 0.878, 0.424, -5.000, -0.014, 1.013, -5.000, -1.422, 0.643, 0.798, 0.476, 0.310, -0.827, -0.157, -0.343, 0.064, -1.693, 0.504, -0.680, -5.000, -1.943, 0.455, 0.050, -2.449, -1.685, 0.155, -0.992, -0.931, -0.387, -0.105, -1.345, -1.777, -0.392, -0.392, -0.644, -0.671, -0.510, 0.232, 0.137, -5.000, -0.972, 0.455, 0.009, -0.238, -0.807, 0.160, -1.280, -1.685, 0.550, 1.268, 0.444, 0.597, 0.537, 0.979, 1.187, -0.633, 1.010, 1.020, 0.301, 0.663, 0.661, 0.792, -0.304, -0.084, -0.113, 0.749, -0.466, -5.000, -1.067, 0.589, 0.114, -1.444, 0.141, 0.727, 0.086, 0.062, -0.966, 0.038, -0.383, -0.323, -0.854, 0.560, -1.624, -5.000, -5.000, 0.119, -0.128, -1.848, -0.893, 0.315, -1.272, -0.077, -0.310, 0.050, -1.473, -0.840, -0.656, -0.461, -0.521, -0.943, -1.030, 0.512, -0.287, -2.071, -0.671, 0.853, -0.279, -0.910, -0.780, -0.318, -0.980, -1.181, -0.095, 0.706, -1.545, -0.341, -0.601, 0.611, -0.140, -3.511, -0.572, 0.463, -0.183, -0.608, 0.109, 0.069, -0.557, -0.684, -0.526, 0.059, -1.099, -5.000, -1.203, -0.012, -0.383, -1.753, -0.644, -0.500, -0.589, -1.060, -1.542, -1.257, -1.213, -0.700, -1.017, -0.861, -1.343, -5.000, -1.901, -0.461, -2.050, -2.844, -2.658, -2.090, -1.491, -2.253, -1.012, -1.645, -2.037, -1.971, -1.137, -0.440, -1.428, -1.339, -1.328, -0.787, -1.002, -2.901, -0.858, -0.333, -1.404, -0.778, -1.481, -0.989, -1.361, -1.653, -0.782, -0.229, -1.415, -1.159, -1.063, 0.067, 0.031, -2.308, -0.068, 0.093, 0.031, -0.781, -0.634, -0.234, -0.980, -0.806, 0.382, 1.108, 0.485, -5.000, -0.163, 0.619, -0.088, -0.568, 0.306, 0.679, 0.541, -0.119, -0.132, 0.319, -0.117, 0.343, -0.841, 0.182, -1.359, -5.000, -1.727, -0.244, -1.265, -2.041, -1.648, -1.536, -0.595, -1.364, 0.149, -0.914, -1.786, -0.799, 0.303, 0.816, 0.290, 0.275, -0.268, -0.077, 0.304, -2.295, -0.032, 0.700, 0.040, -0.203, -0.209, 0.269, 0.006, -0.833, 0.557, 1.059, -0.167, 0.506, 0.220, 0.953, 1.061, -1.565, 0.616, 0.969, 0.820, 0.479, 0.602, 0.850, 0.476, 0.210, 1.219, 1.426, 1.220, -5.000, 0.866, 1.042, 0.504, 0.324, 1.253, 1.262, 1.238, 0.827, 0.766, 1.000, 0.824, 1.185, 0.348, 0.940, -0.295, -5.000, -0.180, 0.649, -0.019, -0.419, -0.290, -0.461, 0.137, 0.035, 0.967, 0.116, -1.004, 0.050, 0.933, 0.828, -0.015, 0.508, 0.782, 0.983, 0.861, -0.637, 0.803, 1.272, 0.969, 0.542, 0.939, 1.020, 0.585, -0.064, 1.034, 1.408, 0.740, 1.147, 1.143, 1.457, 1.531, -0.539, 1.093, 1.300, 1.045, 0.991, 1.119, 1.114, 0.638, 0.737, 0.194, 0.779, -0.511, -5.000, -0.593, 0.634, -1.259, -1.473, 0.495, 0.601, 0.708, 0.482, -0.635, 0.034, -1.049, -0.294, -0.394, -0.101, -1.275, -5.000, -1.109, 0.098, -2.463, -1.596, -0.780, -0.105, 0.250, -0.117, 0.079, -0.987, -1.848, -0.798, -0.650, -0.064, -0.992, -1.085, -1.064, 0.039, -1.482, -2.562, -0.406, 0.372, -0.410, -1.250, -0.614, -0.594, -1.272, -1.271, -0.233, 0.280, -1.286, -0.636, 0.018, 0.952, 0.656, -1.774, 0.101, 0.184, 0.142, -0.282, -0.093, -0.229, -0.909, -0.858, 0.318, 0.840, 0.152, -5.000, -0.094, 0.520, -0.988, -0.914, 0.438, 0.393, 0.053, 0.127, -0.421, -0.095, -0.495, 0.058, -0.121, 0.704, -0.434, -5.000, -1.422, -0.660, -2.541, -1.620, -1.120, -0.157, -0.844, -1.147, 0.150, -0.301, -1.217, -0.133, 0.074, 1.032, -0.144, 0.031, -0.205, 0.546, 0.500, -2.369, 0.060, 0.823, -0.030, -0.060, -0.101, 0.589, 0.217, -0.464, 0.037, 0.895, -0.773, -0.279, 0.147, 1.222, 1.142, -1.593, 0.576, 1.096, 1.057, 0.589, 0.247, 0.700, -0.160, -0.304, 0.021, 0.593, 0.423, -5.000, -0.118, 0.702, -0.039, -0.943, 0.346, 0.647, 0.428, -0.045, 0.145, 0.495, -0.170, 0.537, -1.128, 0.657, -0.628, -5.000, -2.009, 0.417, -1.609, -2.723, -2.009, -0.644, -0.833, -0.891, -0.028, -0.535, -2.219, -0.781, -0.204, 0.343, -0.097, -0.184, -0.530, -0.392, 0.107, -1.655, -0.399, 0.137, -0.956, -0.971, -0.375, -0.050, -1.096, -1.555, 0.522, 1.014, 0.154, 0.498, 0.226, 0.664, 0.935, -1.917, 0.588, 0.954, 0.932, 0.365, 0.697, 0.822, 0.462, 0.288, 1.035, 1.356, 1.296, -5.000, 0.568, 1.123, 0.520, 0.129, 1.366, 1.414, 1.245, 0.978, 0.903, 1.047, 0.932, 1.270, 0.184, 0.971, 0.401, -5.000, -0.619, 0.535, -0.196, -1.500, 0.199, 0.912, 0.455, 0.294, 1.044, 0.821, -0.461, 0.411, 0.524, 1.020, 0.487, 0.861, 0.455, 1.133, 0.925, -1.250, 0.840, 1.262, 0.774, -0.140, 0.678, 1.071, 0.483, 0.021, 1.095, 1.469, 1.058, 1.184, 0.974, 1.445, 1.501, -0.465, 1.105, 1.324, 0.756, 0.831, 0.998, 1.038, 0.673, 0.675, 0.989, 1.254, 0.972, -5.000, 0.803, 1.295, 0.009, -0.378, 0.560, 1.278, -0.157, 0.479, 0.083, 0.777, 1.041, 0.820, 0.368, 1.135, -0.140, -5.000, -0.833, 1.360, 0.568, -1.848, -0.056, 1.005, 0.167, 0.204, 1.201, 1.133, 0.365, 0.536, 1.009, 1.088, 0.131, 0.981, 0.383, 1.235, 0.812, -1.593, 0.199, 1.241, 0.743, 0.743, 0.899, 0.689, 0.520, 0.743, 1.062, 1.468, -0.170, 1.022, 0.634, 1.563, 1.485, -0.833, 1.190, 1.410, 0.576, 1.161, 1.236, 1.260, 0.715, 0.462, -1.402, -0.325, -1.564, -5.000, -1.979, -0.724, -2.502, -3.047, -0.798, -0.596, -2.371, -1.217, -1.633, -1.353, -1.675, -1.252, -1.498, -0.500, -1.928, -5.000, -2.314, -1.323, -2.449, -3.477, -1.454, -0.436, -1.655, -1.860, -0.539, -0.815, -1.277, -1.393, -1.918, -0.692, -1.328, -1.049, -2.094, -2.286, -1.191, -3.321, -2.463, -1.085, -1.640, -2.095, -2.473, -1.154, -2.270, -2.658, -1.948, -1.095, -1.528, -1.311, -1.574, -0.660, -1.678, -2.203, -1.701, -0.899, -0.587, -1.012, -1.178, -1.032, -1.576, -1.644, 0.626, 1.060, 0.792, -5.000, 0.163, 1.250, 0.160, -0.633, 0.520, 0.904, 0.601, 0.176, 0.216, 0.813, 0.324, 0.481, -0.400, 1.037, 0.414, -5.000, -1.491, 0.843, -1.714, -2.421, -1.238, 0.330, -0.263, -0.429, 0.165, 0.077, -0.992, -0.633, 0.275, 0.743, 0.283, 0.013, -0.188, 0.085, 0.225, -2.123, 0.025, 0.455, -0.105, -0.431, -0.295, 0.036, -0.412, -1.274, 0.630, 1.241, 0.321, 0.849, 0.558, 0.918, 0.835, -1.665, 0.757, 0.957, 0.641, 0.510, 0.763, 0.958, 0.582, 0.193, 0.904, 1.314, 1.140, -5.000, 0.406, 1.193, 0.421, -0.584, 0.881, 1.039, 0.884, 0.567, 0.474, 0.890, 0.578, 0.735, 0.113, 1.070, 0.412, -5.000, -0.284, 1.210, 0.589, -0.625, -1.227, 0.730, 0.050, -0.174, 0.665, 0.518, -0.689, -0.242, 0.929, 0.876, 0.643, 0.760, -0.141, 1.081, 0.162, -1.526, 0.767, 1.092, 0.618, -0.180, 0.129, 0.674, -0.251, -1.034, 1.094, 1.454, 1.080, 1.089, 0.699, 1.293, 1.088, -1.369, 0.908, 1.185, 0.766, 0.672, 0.875, 0.944, 0.386, 0.481, 0.545, 0.833, 0.927, -5.000, 0.485, 0.962, 0.114, -0.630, 0.641, 0.764, -0.313, 0.088, 0.225, 0.623, 0.122, 0.256, -0.437, 0.890, 0.602, -5.000, -0.287, 1.030, -1.103, -1.479, 0.420, 0.487, -0.125, -0.347, 0.357, 0.764, -0.657, -0.202, 0.899, 1.102, 0.583, -0.044, 0.527, 0.805, -0.174, -1.179, 0.693, 0.890, 0.266, 0.147, 0.585, 0.602, -0.183, 0.200, 0.908, 1.327, 0.751, 0.569, 0.706, 1.285, 1.331, -0.798, 0.509, 0.874, 0.474, 0.219, 0.721, 0.698, 0.228, -0.021, 0.351, 1.004, 0.689, -5.000, 0.020, 0.539, -2.090, -1.376, 0.101, -0.023, -0.468, -0.204, -0.453, 0.160, -0.084, 0.260, -0.399, 0.830, -0.392, -5.000, -2.348, -0.084, -1.685, -2.404, -1.337, 0.003, -1.076, -1.085, 0.331, -0.454, -0.798, -0.716, 0.132, 0.701, 0.442, -0.292, 0.040, 0.989, 0.455, -2.548, -0.078, 0.553, 0.291, -0.324, -0.206, 0.931, 0.497, -0.862, 0.234, 0.799, -0.080, 0.185, 0.077, 1.107, 0.946, -1.203, 0.217, 0.641, 0.387, -0.306, 0.358, 0.721, 0.318, -0.305, 0.543, 1.197, 0.696, -5.000, 0.096, 1.124, 0.274, -0.616, 0.471, 0.857, 0.620, 0.160, -0.226, 0.388, -0.210, 0.307, -0.546, 0.548, -0.455, -5.000, -1.376, 0.743, 0.059, -1.472, -0.557, -0.212, -0.047, -0.175, 0.106, -0.226, -1.239, -0.746, 0.244, 0.765, 0.755, 0.272, -0.089, 0.359, -0.050, -1.556, 0.098, 0.450, -0.069, -0.150, 0.031, 0.400, -0.054, -0.861, 0.579, 1.134, 0.131, 0.488, 0.370, 1.123, 0.909, -1.001, 0.699, 1.040, 0.796, 0.581, 0.640, 0.943, 0.366, 0.248, 0.744, 1.208, 0.917, -5.000, 0.397, 1.090, 0.133, -0.601, 0.750, 1.078, 0.869, 0.477, 0.134, 0.496, 0.148, 0.522, -0.188, 0.611, -0.378, -5.000, -0.290, 0.712, -0.256, -1.254, -0.068, 0.301, -0.137, -0.137, 0.381, -0.163, -1.624, -0.727, 0.059, 0.589, -0.276, 0.050, -0.023, 0.699, 0.436, -2.733, 0.494, 1.112, 0.283, -0.310, -0.185, 0.434, -0.756, -0.794, 0.834, 1.272, 0.627, 0.719, 0.645, 1.127, 1.300, -0.906, 0.875, 1.108, 0.782, 0.743, 0.665, 0.680, -0.134, 0.275, 0.128, 0.760, 0.247, -5.000, 0.061, 1.154, 0.062, -0.714, 0.550, 1.026, 0.662, 0.652, -0.703, 0.291, -0.319, -0.145, -0.530, 0.629, -1.127, -5.000, -1.073, 0.441, -0.318, -1.616, -0.420, 0.720, 0.495, 0.080, 0.018, -0.284, -1.023, -0.782, -0.537, -0.504, -1.140, -1.088, -0.008, 0.493, 0.015, -1.886, 0.335, 0.875, -0.151, -0.531, -0.742, -0.544, -0.876, -1.117, 0.135, 0.659, -0.845, -0.457, 0.006, 1.189, 0.705, -1.309, 0.228, 0.700, 0.135, -0.349, -0.090, -0.030, -0.851, -0.686, 0.062, 0.773, 0.033, -5.000, -0.427, 0.357, -0.427, -1.338, 0.083, 0.227, -0.331, -0.239, -0.792, -0.300, -0.610, -0.106, -0.328, 0.551, -0.309, -5.000, -1.320, -0.614, -1.965, -1.509, -1.710, -0.541, -1.049, -1.467, -0.028, -0.596, -1.469, -0.521, -0.073, 0.776, -0.545, -0.268, -0.405, 0.756, 0.304, -2.050, -0.246, 0.661, 0.012, -0.314, -0.675, 0.097, -0.718, -0.871, -0.075, 0.794, -0.593, -0.398, -0.063, 0.776, 0.711, -1.687, 0.226, 0.682, 0.519, -0.234, -0.093, 0.075, -0.381, -0.520 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_3(struct _training *tptr) {
  struct _training tinf = {
    0.400, 4, 4.350, { 1.474, 0.436, 1.090 }, { 1.234, -0.943, -2.547 }, 0, 
    { 0.010, -1.191, -0.406, -0.066, -0.449, 1.161, -0.663, -4.000, -4.000, 0.595, 2.048, -4.000, 0.191, -0.303, 0.165, -0.105, -1.485, 0.662, -4.000, -0.596, 1.543, 1.596, 1.854, -4.000, 1.404, -4.000, 3.301, 3.412 }, 
    {{ 0.243, -0.171, -0.171, -0.068},{ -0.050, -0.705, 0.090, 0.280},{ 0.204, -0.124, -0.409, 0.072},{ 0.297, -0.350, -0.338, 0.042},{ 0.239, -0.220, -0.191, -0.022},{ 0.136, -0.152, -0.397, 0.154},{ 0.276, -0.511, -0.272, 0.102},{ 0.145, -0.200, -0.106, 0.031},{ 0.159, -0.316, -0.071, 0.052},{ 0.234, -0.373, -0.106, 0.010},{ 0.154, -0.262, -0.162, 0.082},{ 0.140, -0.498, -0.191, 0.204},{ 0.026, -0.350, -0.115, 0.217},{ 0.168, -0.200, -0.062, -0.022},{ 0.186, -0.210, -0.305, 0.092},{ 0.209, -0.171, -0.251, 0.021},{ 0.131, -0.152, -0.071, -0.000},{ 0.131, -0.262, -0.088, 0.067},{ 0.047, -0.133, -0.053, 0.067},{ 0.042, 0.013, -0.191, 0.062},{ 0.092, -0.283, -0.115, 0.131},{ 0.126, 0.044, -0.079, -0.121},{ 0.126, -0.262, -0.053, 0.052},{ 0.112, -0.210, -0.053, 0.042},{ 0.026, -0.003, -0.251, 0.117},{ 0.082, -0.053, -0.020, -0.039},{ 0.072, -0.152, -0.181, 0.121},{ 0.021, -0.143, -0.012, 0.072},{ 0.021, -0.036, -0.097, 0.062},{ 0.067, -0.305, -0.028, 0.117},{ 0.010, 0.075, 0.037, -0.091},{ 0.131, -0.106, -0.012, -0.068} }, 
    {{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 0.650, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 0.846, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { 0.747, -4.000, -4.000, 0.685, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 1.402, -4.000, -4.000, 0.679, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 0.987, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 1.109, -4.000, -4.000, 1.384, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 1.636, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 1.218, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { 1.226, -4.000, -4.000, 0.853, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 1.520, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 2.613, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 0.917, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}} }, 
    -0.289, { 0.463, 0.846, 0.425, -5.000, -0.650, -0.548, -0.744, -0.504, -0.644, -0.481, -0.607, -0.809, -0.443, -0.074, -0.412, 0.225, 0.475, 0.496, 0.139, -5.000, -1.139, -0.356, -0.861, -1.371, -0.788, 0.066, -0.069, -0.275, 0.274, 0.045, -0.348, -0.217, 0.069, 0.730, -0.054, 0.515, -0.404, 0.542, 0.464, -0.972, -0.020, 0.691, 0.041, 0.053, 0.016, 0.396, 0.827, -0.370, 0.466, 0.948, -0.058, 0.457, 0.179, 0.689, 0.579, -0.796, 0.523, 0.835, 0.633, 0.003, 0.759, 0.360, 0.061, 0.250, 0.530, 1.070, 0.720, -5.000, 0.200, 0.616, -0.213, -0.505, 0.556, 0.935, 0.907, 0.480, 1.006, 1.067, 1.183, 1.118, 1.181, 1.167, 1.029, -5.000, 0.303, 0.728, 0.284, 0.014, 0.548, 0.909, 0.706, 0.343, 1.152, 1.129, 0.701, 0.829, 1.131, 1.141, 0.858, 1.146, 0.246, 0.881, 0.932, -0.809, 0.927, 1.231, 0.806, 0.220, 0.596, 0.844, 0.850, 0.378, 0.733, 1.320, 0.501, 1.058, 0.992, 0.899, 1.095, 0.062, 0.890, 1.171, 0.643, 0.450, 1.159, 0.706, -0.003, 0.845, 0.639, 1.197, 0.701, -5.000, -0.776, -0.094, -0.736, -0.985, -0.010, 0.804, 0.131, 0.110, -0.787, 0.374, 0.384, 0.644, 0.800, 0.790, 0.492, -5.000, -1.404, -0.022, 0.032, -1.251, 0.208, 0.439, 0.178, -0.057, 0.953, 0.935, 0.759, 0.700, 0.678, 0.702, -0.073, 0.273, -0.013, -0.239, 0.571, -1.092, 0.678, 0.914, 0.668, -0.292, 0.720, 0.296, 0.644, 0.147, 0.138, 0.750, -1.282, -0.175, 0.453, 0.515, 0.502, -0.874, -0.172, 0.123, -0.492, -0.433, 0.643, 0.033, -0.464, 0.089, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.916, -0.441, -0.740, -5.000, -1.119, -1.285, -2.611, -1.607, -1.474, -0.918, -1.345, -1.229, -0.586, -0.629, -0.759, -0.424, -0.879, -0.741, -0.933, -5.000, -2.425, -0.432, -1.578, -1.610, -0.625, -0.644, -0.857, -1.110, -0.911, -0.589, -0.670, -0.520, -0.759, -0.162, -1.214, -0.710, -1.290, -0.343, -0.644, -2.159, -0.882, -0.007, -0.864, -0.803, -1.468, -0.374, -0.297, -1.229, -0.692, 0.288, -1.623, -0.520, -0.935, -0.504, -1.121, -1.918, -0.470, -0.086, -0.451, -0.627, 0.181, -0.557, -1.165, -0.542, -0.260, 0.043, -0.109, -5.000, -0.973, 0.126, -1.722, -1.692, -0.645, -0.368, -0.295, -0.819, -0.038, -0.132, 0.144, 0.473, 0.287, 0.325, -0.075, -5.000, -1.045, 0.377, -0.940, -1.533, 0.171, 0.256, -0.061, -0.398, 0.259, 0.448, -0.839, -0.154, -0.229, 0.408, -1.094, -0.199, -1.387, -0.018, -0.899, -1.549, -0.091, 0.137, -0.134, -0.574, -0.479, 0.698, -0.694, -0.847, -0.315, 0.615, -1.155, -0.181, -0.488, 0.281, -0.710, -1.133, -0.380, 0.210, -0.465, -0.110, -0.369, -0.808, -1.203, -0.606, -0.644, 0.085, -0.407, -5.000, -1.610, -0.391, -1.340, -1.015, -1.226, -0.306, -0.982, -0.610, -1.537, -0.386, -0.600, -1.178, -0.493, 0.005, -1.142, -5.000, -1.319, -1.121, -0.772, -2.386, -1.267, -0.243, -1.274, -0.733, -0.113, 0.195, -0.435, -0.549, -0.876, -0.272, -0.608, -1.205, -0.653, -0.410, -0.310, -2.625, -0.528, -0.661, -0.786, -0.925, -0.232, -0.134, -0.801, -0.992, -1.231, -0.228, -1.395, -1.287, -1.142, 0.027, 0.563, -2.131, -1.453, -0.860, -1.626, -1.110, -0.174, -1.001, -1.517, -0.847, -0.817, 0.018, -1.320, -5.000, -1.551, -1.506, -2.744, -1.946, -1.373, -0.568, -1.354, -1.282, -1.428, -1.102, -1.810, -1.272, -0.227, -0.457, -0.592, -5.000, -1.480, -1.057, -1.214, -1.701, -2.021, -1.467, -1.369, -1.015, -0.574, -0.294, -0.186, -0.515, -0.421, -0.231, -1.279, -0.395, -1.093, -1.509, -0.278, -1.540, -0.577, 0.384, -0.741, -0.765, -0.726, 0.083, -1.002, -0.244, -0.959, -0.468, -1.596, -1.299, -0.883, -0.383, -1.309, -1.704, -0.217, -0.354, -1.225, -0.823, -0.276, -0.977, -1.302, -0.809, 0.106, 0.721, 0.097, -5.000, -1.108, -1.231, -1.243, -0.968, -0.861, -0.457, -0.615, -1.193, -0.938, -0.154, -0.799, -0.495, -0.709, 0.191, -0.360, -5.000, -1.766, -0.604, -1.427, -1.231, -0.102, -0.933, -0.666, -0.850, -0.297, -1.063, -1.434, -0.837, -0.159, 0.409, -0.815, -0.013, -0.840, 0.097, -0.334, -2.108, -0.440, 0.219, -0.600, -0.697, -0.858, -0.560, -0.203, -1.209, 0.066, 0.749, -1.364, 0.205, -0.563, 0.006, -0.680, -1.778, -0.017, 0.259, 0.019, -0.309, -0.092, -0.486, -0.450, -0.419, 0.323, 1.024, 0.841, -5.000, -0.633, 0.399, -0.858, -0.523, -0.093, 0.521, -0.105, -0.295, 0.588, 0.773, 0.582, 0.494, 0.266, 0.776, 0.673, -5.000, -1.380, 0.228, -0.334, -0.904, -0.302, 0.026, -0.216, -0.485, -0.076, 0.299, -0.332, -0.111, -0.024, 0.408, -0.637, -0.089, -1.293, -0.024, -0.680, -2.108, -0.396, -0.149, 0.110, -1.039, -1.072, 0.141, -0.178, -1.597, 0.481, 0.948, -0.174, 0.633, 0.183, 0.156, 0.053, -0.673, -0.191, 0.517, -0.136, 0.208, 0.364, -0.122, -1.091, -0.229, 0.090, 0.721, 0.484, -5.000, -0.636, 0.083, -0.589, -1.065, -0.444, 0.238, -0.493, -0.785, -0.682, -0.011, -0.259, -0.296, -0.172, 0.183, -0.741, -5.000, -1.166, -1.039, -0.450, -1.503, -0.501, -0.482, -1.252, -0.489, -0.374, -0.293, -0.145, -0.667, -0.099, 0.172, -0.566, -0.533, -1.358, -0.698, -0.588, -1.267, -0.054, -0.494, -0.122, -0.840, -0.802, -0.202, -0.082, -0.049, 0.128, 0.558, -1.237, -0.342, -0.221, 0.520, -0.004, -1.414, -0.024, -0.018, -1.040, -1.387, 0.062, -0.612, -1.562, -0.570, -0.016, 0.705, -0.292, -5.000, -1.407, -0.338, -2.112, -0.706, -0.624, -0.035, -0.935, -0.624, -0.599, 0.393, -0.661, -0.124, -0.328, -0.062, -0.927, -5.000, -1.069, -2.257, -0.726, -1.190, -1.080, -0.713, -1.244, -0.468, -0.400, -0.103, -0.826, -0.703, -0.562, 0.154, -1.099, -0.634, -1.211, -0.410, -0.553, -1.439, -0.930, -0.591, -0.964, -0.727, -0.702, -0.207, -0.034, -0.505, -0.291, 0.190, -1.172, -0.326, -0.756, 0.124, -0.628, -1.912, -0.404, -0.116, -0.694, -0.577, -0.425, -0.505, -0.344, -0.673, -0.387, 0.466, 0.220, -5.000, -0.607, -0.309, -1.339, -0.978, -0.759, -0.682, -0.927, -1.161, -1.182, -0.481, -0.663, -0.330, -0.307, -0.381, -0.393, -5.000, -0.991, -0.313, -0.465, -1.153, -0.466, -0.443, -1.244, -0.668, -0.390, -0.664, -0.967, -0.781, 0.009, -0.001, -0.277, -0.086, -0.971, 0.110, 0.040, -0.545, -1.244, -0.202, -0.165, -0.874, -0.312, -0.946, -0.379, -0.678, 0.119, 0.401, -0.911, -0.499, -0.332, -0.010, -0.917, -0.689, -0.594, -0.090, -0.728, -1.059, 0.015, -0.156, -0.444, -0.246, 0.053, 0.889, 0.516, -5.000, -0.217, -0.012, -0.396, -0.831, -0.245, 0.173, 0.164, -0.495, 0.273, 0.459, 0.271, 0.290, 0.588, 0.531, 0.675, -5.000, -0.368, 0.399, 0.411, -0.959, 0.012, -0.139, 0.401, -0.302, 0.036, 0.187, -0.551, -0.359, 0.121, 0.357, -0.479, 0.407, -1.142, 0.159, -0.145, -1.794, -0.323, 0.083, 0.588, -0.786, -0.287, -0.129, 0.074, -0.494, 0.331, 0.990, 0.437, 1.013, 0.425, 0.442, -0.320, -0.736, 0.029, 0.456, 0.633, 0.078, 0.523, -0.243, -0.580, 0.144, 0.383, 0.808, 0.590, -5.000, -0.570, -0.294, -0.730, -0.728, -0.429, -0.193, -0.511, -0.684, -0.859, 0.198, -1.180, 0.111, 0.163, 0.786, 0.028, -5.000, -1.014, -0.226, -1.143, -0.871, -0.163, -0.122, -0.397, -1.078, -0.145, -0.405, -0.734, -0.425, 0.689, -0.171, -0.213, 0.066, -0.057, 0.458, 0.124, -1.564, 0.682, 0.389, 0.047, -0.085, 0.584, -0.044, -0.490, 0.280, -0.070, 0.670, -0.921, -0.135, -0.115, 0.053, 0.298, -1.176, -0.330, 0.177, -0.321, -0.770, 0.292, -0.892, -1.090, -0.397, -0.054, 0.748, 0.181, -5.000, -0.850, -0.225, -1.221, -0.718, -0.822, -0.053, -0.699, -0.701, -0.470, 0.332, -0.739, 0.012, 0.479, 1.045, 0.846, -5.000, -0.666, 0.164, -0.115, -0.314, -0.288, 0.629, 0.053, -0.419, 0.252, 0.911, 0.758, 0.485, 0.613, 0.833, 0.407, 0.526, 0.594, 0.578, 0.757, -0.817, 0.650, 0.890, 0.366, 0.149, 0.874, 0.694, 0.444, 0.436, 0.342, 1.112, 0.142, 0.385, 0.229, 0.674, 0.544, -0.660, -0.055, 0.538, -0.341, -0.357, 0.493, 0.407, 0.180, 0.350, 0.502, 1.227, 1.066, -5.000, -0.471, -0.163, -0.453, -0.159, -0.358, -0.160, -0.583, -1.038, -0.850, -0.079, -0.326, 0.445, 0.538, 0.751, 0.065, -5.000, -1.015, 0.121, -0.411, -0.628, 0.229, 0.422, 0.334, 0.067, 0.229, 0.226, -1.067, 0.060, 0.496, 1.300, 0.651, 0.753, 0.011, 1.057, 0.812, -0.792, 0.590, 1.032, -0.104, 0.120, 0.001, 0.451, 0.738, -0.253, 0.909, 1.272, 0.246, 0.871, 0.533, 0.957, 0.603, -0.635, 0.814, 1.055, 0.725, 0.170, 1.045, 0.733, 0.392, 0.523, 0.523, 1.216, 1.013, -5.000, -0.155, 0.350, -0.351, -0.303, 0.327, 0.916, 0.492, 0.415, 0.693, 0.745, 0.921, 1.108, 0.938, 1.297, 0.689, -5.000, -0.081, 0.574, -0.230, -0.082, 0.377, 0.925, 0.417, 0.362, 0.670, 0.665, 0.050, 0.384, 0.918, 0.902, 0.668, 0.768, 0.103, 0.907, 1.076, -0.534, 0.516, 1.246, 0.382, 0.181, -0.256, 0.693, 0.437, -0.309, 0.791, 1.226, -0.083, 1.120, 0.718, 0.920, 0.314, 0.369, 0.575, 1.131, 0.056, 0.597, 0.648, 0.073, -0.911, 0.191, 0.354, 1.198, 0.384, -5.000, -0.408, -0.076, -0.413, -0.295, -0.283, 0.845, -0.174, -0.077, -1.034, 0.003, -0.036, 0.323, 0.556, 0.846, 0.021, -5.000, -0.788, -0.165, -0.479, -0.671, 0.312, 0.917, -0.043, -0.435, 0.664, 0.655, -0.244, 0.002, 0.517, 0.887, 0.119, 0.121, -0.035, 0.552, 0.626, -1.094, 0.692, 0.885, 0.082, 0.043, 0.632, 0.228, 0.103, -0.112, -0.041, 0.527, -1.514, -0.022, 0.265, 0.765, 0.471, -0.875, 0.432, 0.462, -0.767, -0.670, 0.718, 0.184, -0.625, 0.004, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -1.203, -0.403, -1.013, -5.000, -1.348, -1.443, -1.061, -1.287, -1.327, -1.109, -1.365, -1.918, -1.180, -0.951, -1.213, -0.790, -1.235, -0.199, -1.048, -5.000, -1.143, -0.791, -2.366, -0.858, -1.297, 0.020, -0.548, -0.068, -1.379, -0.601, -0.661, -0.887, -0.668, 0.083, -1.333, -1.228, -1.089, -0.242, -0.528, -1.389, -1.007, -0.386, -0.750, -0.784, -1.664, -0.776, -0.280, -1.629, -0.954, 0.196, -1.561, -0.441, -0.574, -0.810, -0.428, -1.591, -0.626, -0.033, -0.157, -0.903, 0.057, -1.567, -1.290, -0.672, 0.009, 0.628, 0.123, -5.000, -1.732, -0.236, -0.428, -1.147, -0.866, 0.039, 0.195, -0.518, -0.013, 0.270, -0.159, 0.752, 0.184, 0.602, -0.099, -5.000, -0.975, 0.648, -1.214, -0.843, -0.247, 0.089, -0.062, -0.236, 0.023, 0.240, -0.736, -0.269, 0.092, 0.864, 0.032, -0.368, -1.154, 0.606, -0.457, -0.955, 0.175, 0.114, -0.310, -0.093, -0.369, 0.316, -0.001, -0.654, -0.062, 0.859, -1.073, 0.361, 0.067, 0.699, 0.312, -0.754, 0.113, 0.737, -0.308, -0.769, -0.032, -0.462, -0.933, -0.203, 0.034, 0.667, 0.101, -5.000, 0.214, -0.113, -0.479, -0.759, -0.726, 0.185, -0.444, -0.823, -1.725, -0.261, -0.495, -0.362, -0.488, 0.378, -1.202, -5.000, -1.597, 0.180, -0.936, -1.658, -0.374, 0.195, -0.241, -0.735, -0.013, -0.097, -0.672, -0.738, 0.163, 0.348, -0.514, -0.532, -0.326, 0.262, 0.581, -1.379, -0.078, -0.229, -0.139, -0.936, -0.786, -1.155, 0.283, -0.547, -0.852, -0.048, -1.870, -0.759, -0.136, 0.590, -0.305, -1.708, -0.404, -0.877, -0.297, -0.675, -0.311, -0.235, -1.415, -0.846, -0.801, 0.205, -0.926, -5.000, -1.963, -1.453, -1.033, -2.005, -0.857, -1.159, -1.106, -1.673, -1.207, -0.430, -2.000, -0.649, -0.468, -0.133, -0.574, -5.000, -1.580, -1.943, -1.233, -1.693, -1.317, -0.729, -1.014, -1.149, -0.831, -0.154, -0.462, -0.858, -0.393, 0.447, -0.783, -0.845, -0.653, -0.095, -0.538, -1.345, -0.615, -0.438, -0.628, -0.855, -0.118, -0.633, -0.201, -0.600, -0.907, -0.592, -2.066, -1.264, -0.821, -0.288, -0.772, -1.762, -0.796, -0.455, -0.959, -1.383, -0.839, -1.007, -1.434, -0.900, 0.056, 0.866, 0.439, -5.000, -1.010, -0.889, -0.833, -0.434, -1.054, -0.794, -0.412, -0.946, -0.701, -0.169, -0.315, 0.072, -0.251, -0.086, -1.155, -5.000, -1.648, -0.022, -1.312, -0.698, -0.316, -0.230, 0.032, -1.172, -0.224, 0.248, -1.279, -0.784, 0.061, 1.112, 0.238, 0.267, -0.800, -0.122, -0.063, -1.333, -0.300, 0.286, -0.691, 0.016, -0.795, -0.380, 0.489, -1.530, 0.049, 0.976, -0.803, 0.382, -0.305, 0.543, 0.237, -0.797, 0.127, 0.696, 0.266, 0.083, 0.630, -0.784, -1.610, 0.022, 0.230, 1.183, 0.787, -5.000, -0.635, 0.092, -0.922, -0.410, -0.033, 0.550, 0.315, -0.220, -0.131, 0.921, 0.762, 0.811, 0.434, 0.648, 0.275, -5.000, -0.936, 0.465, -0.135, -0.488, -0.313, 0.381, -0.186, 0.201, 0.186, 0.228, -0.347, -0.072, -0.048, 0.214, -0.157, 0.207, -1.333, 0.323, -0.779, -1.961, -0.574, 0.261, 0.200, -1.305, -0.668, -0.012, -0.898, -1.082, 0.254, 1.054, 0.119, 0.682, 0.524, 0.603, 0.199, -0.864, -0.547, 0.140, -1.221, -0.868, 0.927, -0.741, -1.363, 0.299, 0.084, 0.717, 0.152, -5.000, -0.479, 0.415, -1.258, -1.324, -0.664, 0.141, -0.540, -0.590, -1.075, -0.041, 0.062, -0.138, -0.223, 0.451, -0.763, -5.000, -1.379, 0.262, -0.637, -2.396, -0.316, 0.016, -1.159, -0.772, -0.332, -0.065, -0.815, -0.459, -0.036, -0.163, -0.071, -0.396, -0.678, 0.799, 0.106, -2.231, 0.079, 0.206, 0.241, -0.583, -0.285, -0.730, 0.280, -0.392, 0.234, 0.894, -1.679, 0.330, 0.450, 1.007, 0.480, -0.040, -0.491, -0.522, -1.267, -0.661, 0.711, -0.128, -1.468, -0.045, 0.098, 0.347, -0.517, -5.000, -1.451, -1.147, -1.814, -0.726, -0.365, 0.152, -1.256, -0.798, -0.873, 0.413, -0.218, -0.021, 0.361, 0.214, -0.669, -5.000, -0.884, -1.010, -1.481, -0.932, -1.415, -1.472, -1.395, -0.136, -0.470, 0.345, -0.172, -0.440, -0.443, -0.063, -0.329, -0.300, -0.389, 0.577, 0.023, -1.477, 0.153, 0.454, -0.833, 0.070, 0.533, 0.320, 0.984, 0.264, -0.085, 0.116, -0.414, 0.016, 0.001, 0.578, -0.273, -1.386, -0.145, 0.079, -0.773, -0.452, 0.304, 0.136, 0.203, -0.179, 0.037, 1.093, 0.746, -5.000, -0.668, 0.032, -0.026, -1.233, -0.502, 0.136, -0.326, -0.514, -1.585, 0.077, -0.166, 0.056, 0.105, 0.571, 0.283, -5.000, -1.050, 0.721, 0.562, -0.908, 0.347, 0.468, -0.014, -0.060, 0.008, 0.158, -0.712, -0.776, 0.767, 1.142, 0.697, 0.666, 0.089, 0.895, 0.714, -0.644, -0.000, 0.595, -0.562, -1.001, 0.136, 0.112, -0.152, -0.056, 0.117, 0.790, -0.312, 0.119, 0.011, 0.356, -1.209, -0.788, -0.577, 0.232, -0.549, -0.142, 0.953, -0.487, -0.795, 0.153, -0.095, 1.010, 0.662, -5.000, -0.750, -0.041, -0.757, -0.799, -0.182, 0.391, 0.352, -0.324, 0.282, 0.508, 0.400, 0.552, 0.465, 0.567, 0.341, -5.000, -0.539, 0.685, 0.379, -0.308, 0.205, 0.399, 0.373, 0.043, 0.272, 0.399, -0.417, -0.261, 0.355, 0.332, 0.145, 0.357, -0.506, 0.522, 0.248, -1.197, 0.189, 0.703, -0.042, -0.506, -0.500, 0.138, 0.277, -1.255, 0.737, 1.312, 0.607, 1.192, 0.780, 0.803, 0.238, 0.114, -0.022, 0.610, 0.053, -0.452, 1.090, -0.024, -0.379, 0.532, 0.117, 0.820, 0.385, -5.000, -0.387, 0.082, -0.764, -0.149, -0.051, 0.364, -0.253, -0.321, -0.915, -0.650, -0.450, 0.420, 0.285, 0.357, 0.032, -5.000, -0.649, -0.560, -1.323, -1.047, -0.159, -0.033, -0.366, -0.554, -0.087, -0.206, -1.078, -0.542, 0.637, 0.309, -0.205, -0.006, 0.054, -0.191, -0.949, -1.663, 0.269, 0.131, -0.847, -0.250, 0.188, -0.272, -1.509, -0.968, -0.139, 0.668, -0.815, 0.032, 0.480, 0.539, 0.519, -0.629, -0.629, -0.661, -0.643, -1.221, 0.441, -0.745, -1.206, -0.802, -0.287, 0.740, -0.516, -5.000, -0.975, -0.709, -1.347, -0.598, -1.159, 0.012, -0.353, -0.817, -0.803, -0.097, -0.072, -0.178, 0.080, 0.783, 0.131, -5.000, -0.632, -0.116, -0.723, -0.640, -0.039, 0.210, -0.103, -0.125, 0.251, 0.494, 0.245, -0.069, 0.217, 0.524, -0.130, 0.034, -0.162, -0.048, 0.236, -1.414, 0.136, 0.656, 0.078, -0.150, 0.486, 0.384, 0.320, 0.218, -0.524, 0.363, -0.310, -0.362, -0.486, 0.208, -0.247, -1.165, -0.738, -0.017, -0.868, -1.056, 0.239, -0.310, -0.976, -0.268, 0.428, 1.020, 0.670, -5.000, -1.006, -0.582, -0.815, -0.279, -0.791, -0.703, -0.552, -0.825, -0.891, -0.169, -0.329, 0.453, 0.457, 0.495, 0.384, -5.000, -1.287, -0.408, -0.045, -0.824, -0.724, 0.167, 0.137, -0.085, 0.345, 0.195, -0.454, 0.013, 0.383, 1.147, 0.479, 0.750, -0.032, 0.777, 0.909, -1.023, -0.061, 0.677, 0.304, 0.330, -0.313, 0.541, 1.047, -0.264, 0.768, 1.089, 0.372, 0.986, 0.393, 0.732, 0.886, -0.741, 0.754, 0.987, 0.830, 0.136, 0.962, 0.556, 0.150, 0.585, 0.540, 1.248, 0.917, -5.000, 0.020, 0.002, -0.037, -0.374, -0.374, 0.715, 0.428, 0.266, 0.571, 0.779, 1.041, 1.336, 1.233, 1.236, 1.023, -5.000, -0.131, 0.635, -0.037, 0.231, 0.223, 0.836, 0.098, -0.221, 0.989, 0.921, 0.260, 0.656, 0.796, 0.566, 0.534, 0.841, -0.067, 0.032, 0.746, -0.706, 0.272, 0.701, 0.249, -0.140, 0.114, 0.828, 0.316, -0.243, 0.721, 1.250, 0.711, 1.240, 0.920, 0.929, 1.066, 0.209, 0.722, 1.253, 0.684, 0.437, 1.084, 0.470, -0.026, 0.774, 0.362, 1.090, 0.338, -5.000, -1.284, -0.128, -1.297, -0.965, -0.754, 0.353, -0.803, -0.294, -1.072, 0.023, 0.137, 0.211, 0.359, 0.565, -0.318, -5.000, -1.805, -0.054, -0.635, -1.094, -1.109, 0.137, 0.063, -0.284, 0.407, 0.565, -0.118, 0.212, 0.123, 0.257, -0.234, -0.230, -0.671, -0.288, 0.317, -1.661, 0.468, 0.699, -0.057, -0.072, 0.424, 0.110, 0.459, -0.280, -0.828, 0.040, -1.084, -0.738, -0.611, 0.523, 0.206, -0.952, -0.422, -0.127, -1.032, -0.676, 0.343, -0.354, -0.479, -0.062, 0.536, 1.142, 0.444, -5.000, -1.765, -0.360, -0.381, -1.158, -0.136, 0.348, -0.041, -0.214, -0.110, 0.228, -0.495, 0.465, 0.824, 1.043, 0.829, -5.000, -1.348, -1.030, -0.538, -0.891, -0.750, -0.495, -0.344, -0.974, 0.277, 0.716, 0.618, 0.218, 0.247, 0.523, -0.315, -0.092, -0.400, -0.200, -0.689, -1.651, 0.119, 0.981, 0.106, 0.205, 0.469, 0.437, 0.163, -0.024, -0.121, 0.874, -0.745, 0.232, 0.049, 0.768, 0.467, -0.688, 0.224, 0.966, 0.296, 0.480, 0.760, 0.311, -0.287, 0.342, -0.627, 0.381, -0.061, -5.000, -1.718, -0.925, -1.425, -1.474, -1.053, -0.684, -1.133, -1.119, -1.496, -0.377, -0.407, -0.123, 0.185, 0.725, 0.632, -5.000, -0.871, 0.032, -0.928, -1.207, -0.102, 0.496, -0.241, -0.425, -0.001, 0.397, -0.174, -0.012, -0.196, 0.889, -0.071, 0.347, -1.004, -0.413, 0.002, -1.200, -0.637, -0.398, -1.379, -0.195, -0.798, -0.414, -0.536, -1.000, -0.421, 0.580, -1.532, -0.901, -0.311, 0.164, -0.191, -1.669, -0.462, 0.368, -0.195, -0.122, 0.423, -0.574, -0.876, 0.083, -0.139, 0.703, 0.287, -5.000, -0.403, -0.428, 0.311, -0.349, -0.289, 0.298, -0.102, -0.112, 0.665, 0.422, 0.640, 0.938, 1.105, 1.228, 1.177, -5.000, -0.312, 0.530, 0.366, -0.088, -0.256, 0.273, -0.383, 0.101, 0.522, 0.699, 0.208, 0.567, 0.466, 0.460, 0.026, 0.306, -0.644, 0.502, 0.261, -2.228, -0.297, 0.169, -0.432, -0.006, 0.057, 0.295, -0.459, -0.635, -0.047, 0.738, 0.251, 0.886, 0.303, 0.777, 0.554, -0.550, 0.155, 0.965, 0.056, 0.141, 0.703, -0.057, -0.670, 0.223, 0.373, 1.157, 0.553, -5.000, -0.438, 0.505, 0.137, -0.403, -0.067, 0.673, -0.075, 0.053, -0.903, 0.303, 0.415, 0.228, 0.409, 0.980, 0.509, -5.000, -0.876, -0.313, -0.543, -0.819, -0.585, 0.620, -0.085, 0.162, 0.639, 0.818, 0.295, 0.257, 0.483, 0.900, 0.159, 0.649, -0.439, 0.063, 0.455, -0.908, 0.239, 0.812, 0.232, -0.546, 0.259, 0.032, 0.232, 0.008, -0.823, 0.618, -0.858, -0.086, 0.221, 0.648, 0.868, -0.710, -0.531, -0.015, -0.422, -0.868, 1.039, -0.081, -0.864, 0.440, -0.934, -0.496, -1.455, -5.000, -2.100, -1.923, -2.184, -1.938, -1.457, -1.434, -1.629, -1.890, -1.621, -1.326, -2.088, -1.505, -1.258, -0.644, -1.926, -5.000, -2.100, -1.377, -3.597, -1.581, -5.000, -1.319, -1.732, -1.347, -0.643, -0.200, -0.542, -1.201, -0.747, -0.741, -1.319, -1.198, -2.019, -0.943, -0.968, -2.034, -0.868, -0.801, -0.367, -0.479, -0.661, -0.554, -0.833, -1.312, -1.704, -0.815, -1.857, -1.301, -1.393, -1.244, -1.142, -2.066, -1.147, -0.624, -1.109, -1.572, -0.858, -1.267, -1.648, -1.345, 0.251, 1.034, 0.641, -5.000, -1.096, 0.177, -0.809, -0.570, -0.294, 0.241, -0.196, -0.397, -0.674, 0.205, -0.184, 0.279, 0.128, 0.536, 0.437, -5.000, -2.858, -0.534, -0.784, -1.248, -0.228, 0.152, -0.194, -0.189, 0.211, 0.214, -0.474, -0.364, 0.264, 0.751, 0.349, 0.608, -0.706, 0.272, 0.464, -1.320, 0.055, 0.372, 0.015, -0.066, -0.418, 0.099, 0.386, -0.358, 0.348, 0.961, -0.093, 0.804, -0.052, 0.597, 0.360, -0.895, 0.062, 0.690, 0.517, 0.125, 0.886, 0.167, -0.425, 0.378, 0.383, 1.131, 1.001, -5.000, -0.356, 0.268, -0.073, -0.073, 0.560, 0.944, 0.157, 0.311, 0.316, 1.034, 0.941, 0.770, 0.844, 1.067, 1.131, -5.000, -0.401, 0.634, 0.463, -1.103, 0.430, 0.756, 0.474, 0.032, 0.650, 0.942, 0.409, 0.464, 0.469, 0.704, 0.417, 0.611, 0.088, 0.411, 0.113, -1.600, 0.188, 0.537, 0.253, -0.109, -0.250, 0.607, 0.298, -0.447, 0.506, 1.187, 0.552, 1.084, 0.745, 0.995, 1.044, -0.147, 0.494, 0.903, 0.819, 0.127, 1.315, 0.449, -0.593, 0.827, 0.114, 0.642, 0.179, -5.000, -0.226, -0.086, -0.434, -1.159, -0.217, 0.276, -0.496, -0.364, -0.945, 0.301, -0.111, -0.136, -0.133, 0.371, -0.181, -5.000, -5.000, -0.815, -0.491, -0.884, -0.238, 0.032, -0.990, -0.294, 0.223, 0.111, 0.314, -0.140, 0.273, 0.474, -0.033, -0.148, -0.204, 0.298, -0.011, -1.254, -0.041, 0.315, -0.491, -0.381, -0.073, -0.191, 0.237, -0.029, 0.242, 1.081, -0.488, 0.634, 0.362, 1.183, 0.602, -0.268, 0.237, -0.006, -0.098, -0.358, 0.984, -0.034, -1.195, 0.155, -0.364, 0.416, -0.481, -5.000, -1.358, -1.256, -1.840, -1.118, -0.689, -0.237, -0.760, -0.382, -1.074, 0.174, -0.122, -0.180, 0.232, 0.571, 0.340, -5.000, -0.839, -0.374, -1.067, -1.932, -1.375, 0.077, -0.583, -0.122, -0.043, 0.478, 0.471, -0.324, -0.023, 0.223, -0.072, 0.066, -0.295, 0.157, -0.479, -1.563, -0.723, 0.383, -0.029, -0.088, 0.659, 0.377, 0.756, 0.059, -0.432, 0.458, -0.661, -0.168, -0.083, 0.478, -0.020, -1.084, -0.071, 0.291, 0.073, -0.414, 0.324, 0.081, 0.079, 0.011, 0.018, 0.971, 0.683, -5.000, -0.643, 0.004, -0.005, -1.094, -0.716, -0.292, -0.263, -0.601, -0.732, -0.214, 0.136, 0.397, 0.326, 0.602, 0.289, -5.000, -0.460, 0.291, 0.214, -0.709, 0.274, 0.529, 0.394, 0.190, 0.331, 0.412, -0.754, -0.397, 0.653, 0.819, -0.069, 0.577, -0.457, 0.392, 0.285, -1.303, -0.071, 0.538, -0.189, -0.173, -0.214, -0.051, 0.013, -0.745, -0.017, 0.896, -0.111, 0.769, 0.114, 0.191, -0.122, -0.809, -0.146, 0.184, -0.410, -0.153, 0.994, 0.072, -0.691, 0.356, -0.623, 0.494, 0.064, -5.000, -1.221, 0.310, -0.207, -0.747, 0.037, 0.645, 0.032, 0.248, 0.167, 0.488, 0.533, 0.728, 0.677, 0.634, 0.928, -5.000, -0.892, 0.425, 0.469, -0.399, 0.119, 0.243, 0.140, -0.147, 0.221, 0.549, -0.300, 0.125, 0.736, 0.389, 0.437, 0.645, -0.401, 0.330, 0.397, -2.118, -0.051, -0.146, -0.522, -1.732, -0.065, 0.448, 0.234, -0.715, 0.229, 0.907, 0.138, 1.109, 0.618, 0.598, -0.169, -0.217, -0.153, 0.148, 0.083, -0.403, 0.944, -0.103, -0.436, 0.709, 0.265, 0.920, 0.482, -5.000, -0.490, 0.196, -0.037, -0.484, 0.388, 0.730, 0.155, 0.297, -1.401, -0.122, 0.298, 0.523, 0.646, 0.888, 0.850, -5.000, -1.589, -0.012, -0.096, -0.574, 0.366, 0.155, 0.063, 0.260, 0.571, 0.640, 0.227, 0.187, 1.148, 0.785, 0.645, 1.015, -0.150, -0.086, 0.371, -2.219, -0.079, 0.417, 0.103, -0.054, 0.699, -0.636, -1.075, -0.360, 0.398, 0.971, -0.179, 0.522, 0.395, 0.725, 0.474, -0.077, -0.432, -0.403, -0.316, -0.587, 1.050, -0.064, -0.759, 0.505, -0.142, 0.596, -0.549, -5.000, -0.873, -0.737, -1.225, -1.104, -0.611, -0.622, -0.583, -0.377, -0.967, -0.821, -1.375, -0.093, 0.378, 0.611, 0.389, -5.000, -1.213, -0.391, -0.745, -0.806, -1.130, -0.812, -0.189, -0.392, 0.119, -0.060, 0.099, -0.396, 0.581, 0.882, -0.124, 0.324, -0.008, -0.038, -0.279, -1.773, 0.361, 0.400, 0.072, 0.126, 0.407, 0.002, -0.141, -0.157, -0.504, 0.272, -1.082, -0.047, -0.329, -0.152, -0.112, -1.249, -0.439, -0.401, -0.496, -0.701, -0.062, -0.508, -0.926, -0.621, 0.370, 0.837, 0.109, -5.000, -0.684, -1.000, -1.069, -0.951, -0.452, -0.315, -0.583, -0.932, -0.446, -0.461, -0.558, 0.203, 0.520, 0.161, 0.168, -5.000, -1.060, -0.927, -0.665, -0.713, -0.431, -0.710, -0.106, -0.474, 0.233, -0.057, -0.924, -0.181, 0.235, 0.609, -0.157, 0.571, -0.484, -0.058, 0.300, -0.894, 0.188, 0.668, 0.479, 0.174, -0.360, 0.400, 0.696, -0.372, 0.055, 0.516, -0.187, 0.066, 0.160, 0.245, 0.311, -1.039, 0.357, 0.738, 0.474, -0.137, 0.554, 0.058, -0.741, 0.017, 0.495, 0.926, 0.327, -5.000, -0.448, 0.063, -1.172, -0.759, 0.362, 0.763, 0.315, 0.204, 0.505, 0.795, 0.917, 1.210, 1.098, 0.848, 0.403, -5.000, -0.167, 0.070, -0.137, -0.269, -0.386, 0.225, 0.032, 0.125, 0.939, 0.654, -0.232, 0.684, 0.873, 0.936, 0.448, 0.710, 0.283, 0.989, 0.972, -0.602, 0.962, 0.912, 0.730, 0.451, 0.539, 1.115, 0.821, -0.027, 0.774, 1.105, 0.534, 1.168, 0.909, 1.182, 1.158, 0.103, 1.116, 1.255, 0.894, 0.554, 1.225, 1.002, 0.360, 0.919, -0.385, 0.267, -1.048, -5.000, -2.048, -1.247, -1.615, -1.904, -0.880, -0.287, -1.214, -0.980, -1.732, -0.846, -1.010, -0.425, -0.122, -0.048, -1.239, -5.000, -2.048, -1.229, -2.325, -1.742, -0.992, -0.304, -1.078, -0.940, -0.103, 0.199, -0.624, -0.367, -0.357, -0.006, -0.949, -0.819, -0.783, -0.136, -0.240, -2.348, 0.464, 0.425, -0.033, -0.196, 0.291, 0.013, 0.339, -0.626, -0.874, -0.092, -1.403, -0.508, -0.559, 0.278, -0.042, -1.513, -0.472, -0.155, -0.637, -0.728, -0.306, -0.406, -1.254, -0.637, 0.208, 0.785, -0.250, -5.000, -0.830, -0.850, -0.586, -1.125, -0.053, 0.682, -0.263, -0.329, -0.343, -0.110, -0.289, -0.621, 0.523, 0.843, 0.444, -5.000, -1.126, -0.252, -0.174, -0.512, -0.141, 0.147, -0.220, -0.150, 0.443, 0.861, 0.592, 0.421, 0.932, 1.131, 0.618, 0.622, 0.803, 1.009, 0.880, -0.925, 0.764, 0.980, 0.768, 0.521, 0.797, 0.612, 0.535, 0.271, -0.545, 0.451, -0.791, -0.334, -0.073, 0.781, 0.011, -0.843, 0.091, 0.702, -0.507, -0.139, 0.290, 0.231, -0.376, -0.130, 0.078, 0.607, 0.119, -5.000, -1.144, -0.794, -1.703, -1.097, -0.378, -0.145, -0.502, -0.659, -0.547, 0.025, -0.397, 0.281, 0.723, 0.765, 0.333, -5.000, -0.838, -0.289, -1.472, -0.781, -0.038, 0.679, 0.002, 0.228, 0.424, 0.364, -0.111, 0.271, 0.372, 1.081, 0.285, 0.589, -0.602, 0.157, 0.677, -1.213, -0.399, 0.113, -0.770, -0.009, -0.736, -0.113, 0.348, -1.200, -0.169, 0.702, -1.521, -0.349, 0.374, 0.633, 0.481, -0.620, 0.225, 0.971, 0.472, -0.034, 0.722, 0.198, -0.242, 0.483, 0.211, 0.922, 0.575, -5.000, -1.175, -0.184, -0.651, -0.930, -0.394, 0.231, 0.389, 0.065, 0.427, 0.399, 0.432, 1.063, 1.040, 1.210, 0.698, -5.000, -0.346, 0.526, -0.024, -0.466, 0.038, 0.581, 0.145, 0.476, 0.642, 0.774, -0.152, 0.639, 0.612, 0.443, 0.071, 0.639, -0.103, 0.679, 0.567, -1.061, 0.298, 0.527, 0.295, -0.091, 0.349, 0.944, 0.307, -0.332, 0.591, 1.271, 0.399, 1.173, 0.577, 0.884, 0.668, -0.029, 0.501, 0.883, 0.151, 0.325, 0.938, 0.453, -0.254, 0.552, 0.354, 1.135, 0.312, -5.000, -0.328, 0.417, -0.499, -0.675, -0.114, 0.779, 0.069, 0.089, -2.849, 0.349, 0.426, 0.210, 0.474, 0.667, -0.241, -5.000, -0.904, 0.214, -0.374, -1.089, 0.422, 0.659, -0.316, -0.122, 0.618, 0.928, 0.649, 0.175, 0.501, 0.484, -0.102, 0.236, -0.002, -0.146, 0.725, -1.104, 0.391, 0.502, -0.059, -0.368, 0.538, 0.263, 0.566, 0.498, -0.850, 0.428, -1.168, 0.093, 0.343, 0.624, 0.847, -0.884, -0.118, -0.438, -0.892, -0.491, 0.567, -0.528, -0.888, -0.383, -1.064, -0.611, -1.954, -5.000, -1.661, -1.669, -1.831, -2.704, -1.814, -0.502, -2.179, -2.471, -1.152, -0.615, -1.845, -0.588, -0.598, -0.008, -0.815, -5.000, -1.575, -0.990, -2.081, -1.856, -1.561, -0.606, -1.237, -0.938, -0.221, 0.093, -0.422, -0.204, -0.902, -0.096, -1.163, -0.498, -1.142, -1.050, -0.726, -2.051, -0.334, 0.094, -0.866, -0.853, 0.010, -0.011, 0.039, -0.225, -1.388, -0.456, -1.808, -1.244, -1.044, -0.368, -1.054, -1.885, -1.132, -0.346, -1.518, -1.787, -0.370, -0.684, -1.211, -0.793, 0.251, 0.751, 0.252, -5.000, -0.766, -0.158, -0.153, -0.583, -0.252, 0.021, 0.041, -0.454, -0.741, 0.193, -0.515, 0.067, 0.051, 0.555, -0.059, -5.000, -1.703, -0.421, -0.218, -0.935, -0.586, 0.553, -0.136, 0.022, -0.122, 0.306, -0.643, -0.376, 0.274, 0.750, 0.186, 0.581, -0.408, 0.118, 0.368, -1.179, 0.093, 0.531, -0.231, -0.033, -0.412, -0.179, 0.498, -0.521, 0.359, 0.969, -0.587, 0.566, -0.094, 0.540, 0.032, -1.232, 0.286, 0.692, 0.645, 0.269, 0.463, 0.229, -0.257, 0.179, 0.195, 0.966, 0.902, -5.000, -0.788, -0.423, -0.726, -0.605, -0.253, 0.753, 0.456, 0.006, 0.186, 0.770, 0.461, 0.486, 0.650, 1.112, 0.391, -5.000, -0.459, 0.266, 0.575, -0.377, 0.461, 0.713, 0.408, 0.303, 0.513, 0.695, -0.035, 0.180, 0.326, 0.921, 0.464, 0.663, -0.551, 0.603, 0.601, -2.041, 0.431, 1.051, 0.638, 0.124, -0.008, 0.786, 0.290, -0.335, 0.738, 1.293, 0.765, 1.090, 0.707, 0.863, 0.850, -0.611, 0.392, 0.875, 0.281, -0.037, 0.894, 0.319, -0.602, 0.654, -0.214, 0.606, 0.125, -5.000, -0.830, -0.233, -0.717, -1.216, -0.170, 0.316, -0.253, -0.474, -0.935, 0.261, -0.489, -0.422, -0.275, 0.609, -0.890, -5.000, -1.509, -0.428, -1.043, -1.453, -0.568, 0.180, -0.071, -0.713, -0.543, 0.141, -0.580, -0.282, 0.140, 0.843, -0.159, -0.476, -0.746, -0.178, -0.754, -1.306, 0.397, 0.786, -0.356, -0.209, 0.160, 0.232, 0.309, -0.153, 0.289, 0.839, -0.705, -0.100, -0.704, 0.903, 0.176, -0.967, -0.145, 0.437, -0.892, -0.633, 0.461, -0.262, -1.015, -0.446, -0.027, 0.188, -0.282, -5.000, -1.596, -0.847, -0.912, -1.312, -0.785, -0.213, -0.577, -0.607, -1.053, -0.197, -0.528, -1.016, 0.045, 0.532, -0.084, -5.000, -2.151, -0.757, -1.434, -1.088, -0.685, -0.256, -0.612, -0.799, -0.046, -0.273, 0.049, -0.265, -0.191, 0.625, -0.807, -0.179, -0.747, 0.298, 0.234, -1.413, -0.220, 0.386, -0.058, 0.247, -0.028, 0.089, 0.700, -0.170, -0.300, 0.484, -0.971, -0.295, -0.316, 0.354, -0.093, -1.639, -0.514, 0.005, -0.796, -0.489, -0.154, -0.163, -0.400, -0.502, 0.661, 1.170, 1.086, -5.000, -0.316, 0.241, 0.273, -0.523, 0.215, 0.470, 0.318, -0.110, -0.281, 0.572, 0.337, 0.701, 0.918, 0.988, 0.695, -5.000, -0.734, 0.991, 0.896, -0.232, 1.028, 1.133, 0.838, 0.868, 0.729, 0.861, 0.103, -0.238, 1.117, 1.328, 0.789, 1.064, 0.218, 1.003, 0.740, -0.385, 0.671, 1.219, 0.350, 0.330, 0.313, 0.709, 0.597, 0.257, 0.480, 1.218, -0.113, 0.524, 0.295, 0.554, -0.282, -0.612, 0.418, 0.532, 0.542, -0.023, 1.184, 0.270, -0.526, 0.482, -0.105, 0.560, 0.437, -5.000, -1.074, -0.023, -0.568, -1.573, -0.410, 0.013, 0.032, -0.394, -0.068, 0.138, -0.026, 0.237, 0.545, 0.299, 0.232, -5.000, -0.716, 0.233, 0.054, -0.664, 0.066, 0.285, 0.070, -0.245, -0.014, 0.110, -0.930, -0.717, 0.473, 0.386, -0.021, 0.518, -0.513, 0.101, 0.250, -1.887, -0.030, 0.372, -0.196, -1.135, -0.371, -0.072, 0.006, -0.697, 0.091, 0.806, -0.235, 0.617, 0.057, 0.137, -0.048, -0.661, -0.303, 0.168, -0.034, -0.140, 0.492, -0.210, -0.778, 0.049, -0.363, 0.437, -0.141, -5.000, -0.748, -0.141, -0.280, -1.426, -0.346, 0.055, -0.270, -0.306, -0.909, -0.923, -0.705, -0.483, -0.126, -0.186, -0.660, -5.000, -1.331, -0.328, -0.842, -1.098, -0.638, -0.410, -0.893, -1.038, -0.536, -0.261, -0.608, -0.964, 0.060, 0.276, -0.747, -0.737, -0.707, -0.294, -0.503, -1.526, -0.557, -0.230, -0.699, -0.728, -0.333, -0.918, -1.034, -0.869, -0.661, -0.039, -2.235, -0.846, -0.354, -0.007, -0.911, -1.645, -0.709, -0.666, -1.295, -1.112, -0.379, -0.835, -1.636, -0.970, 0.026, 0.496, -0.159, -5.000, -1.104, -0.364, -1.154, -1.339, -1.020, -0.142, -0.862, -0.405, -0.676, -0.098, -0.640, 0.146, 0.553, 0.797, 0.680, -5.000, -0.944, -0.130, -0.650, -0.579, -0.914, -0.278, 0.011, -0.037, 0.294, 0.393, 0.369, 0.159, 0.733, 1.234, 0.377, 0.532, 0.386, 0.595, 0.585, -0.803, 0.666, 1.010, 0.370, -0.021, 0.677, 0.706, 0.566, 0.476, -0.237, 0.617, -0.664, -0.261, -0.069, 0.379, -0.040, -1.198, -0.240, 0.018, -0.835, -0.878, -0.006, -0.309, -0.651, -0.356 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_4(struct _training *tptr) {
  struct _training tinf = {
    0.317, 4, 4.350, { 2.217, 0.462, 0.321 }, { 1.016, -0.950, -2.907 }, 0, 
    { 0.085, -0.778, -2.781, 0.145, -0.035, 0.515, -0.049, -4.000, -4.000, 0.311, 0.538, -4.000, -1.175, -0.560, -4.000, -0.151, -0.426, -4.000, -4.000, -4.000, 1.201, -4.000, 0.815, -4.000, 1.326, 2.019, -4.000, 1.837 }, 
    {{ 0.235, -0.031, -0.393, -0.106},{ 0.073, -0.897, 0.012, 0.177},{ 0.055, -0.373, -0.458, 0.230},{ 0.115, -0.313, -0.106, 0.049},{ 0.275, -0.373, -0.187, -0.098},{ 0.055, -0.239, -0.333, 0.160},{ 0.049, 0.066, -0.204, 0.004},{ 0.171, -0.373, -0.106, 0.004},{ 0.085, -0.222, -0.373, 0.138},{ 0.121, -0.090, -0.187, -0.009},{ 0.166, -0.257, -0.187, 0.004},{ 0.177, -0.222, -0.239, -0.002},{ 0.132, -0.016, -0.222, -0.042},{ 0.230, -0.222, -0.458, 0.004},{ 0.049, -0.239, -0.170, 0.115},{ 0.160, -0.187, -0.187, -0.015},{ 0.177, -0.045, -0.106, -0.135},{ 0.103, -0.106, -0.170, 0.011},{ 0.198, -0.106, -0.045, -0.165},{ 0.193, -0.204, -0.187, -0.049},{ 0.097, -0.222, -0.294, 0.103},{ 0.097, -0.122, -0.154, 0.017},{ 0.109, -0.075, -0.294, 0.036},{ 0.166, -0.187, -0.154, -0.036},{ 0.166, -0.075, -0.122, -0.098},{ 0.085, -0.031, -0.154, -0.009},{ 0.073, -0.090, 0.053, -0.063},{ 0.067, 0.026, -0.122, -0.029},{ 0.079, -0.122, -0.187, 0.049},{ 0.085, -0.170, -0.154, 0.049},{ 0.042, 0.053, 0.053, -0.098},{ -0.009, -0.002, -0.154, 0.073} }, 
    {{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 0.509, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 0.856, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 0.369, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}} }, 
    -0.414, { 0.453, 1.023, 0.589, -5.000, 0.130, 0.324, 0.066, -0.789, 0.057, 0.527, -0.211, -0.387, -0.396, 0.194, -0.116, 0.454, 0.092, 0.567, 0.195, -5.000, -1.403, -0.378, -1.220, -1.599, -1.387, -0.142, 0.255, -0.949, -0.097, -0.185, -0.627, -0.525, 0.122, 0.533, -0.183, -0.006, -0.610, 0.620, 0.519, -1.387, 0.069, 0.602, -0.221, -0.101, -0.143, -0.029, 0.290, -0.713, 0.714, 1.023, 0.081, 0.688, 0.389, 0.957, 1.058, -0.760, 0.495, 1.012, 0.882, 0.087, 0.729, 0.649, 0.310, 0.117, 0.839, 1.179, 0.889, -5.000, 0.838, 0.666, 0.558, -0.538, 0.651, 1.037, 0.969, 0.564, 0.786, 0.906, 0.803, 0.888, 0.653, 0.971, 0.408, -5.000, 0.012, 0.737, 0.620, -0.726, -1.375, 0.284, -0.479, -0.884, 0.789, 0.667, 0.268, 0.582, 0.992, 0.438, -0.213, 0.262, 0.290, 0.880, 0.320, -0.815, 0.582, -0.122, 0.166, -5.000, 0.554, 0.880, 0.266, -0.335, 1.135, 1.441, 0.851, 1.256, 1.081, 1.053, 1.280, 0.489, 1.039, 1.260, 1.180, 0.777, 1.156, 1.075, 0.856, 0.884, 0.603, 1.197, 0.586, -5.000, 0.654, 1.191, 0.215, -0.658, 0.106, 1.248, 0.223, 0.297, -0.751, 0.637, -0.074, 0.734, 0.270, 0.592, -0.241, -5.000, -0.724, -0.272, 0.240, -1.784, 0.150, 0.447, -0.048, -0.221, 0.581, 0.422, -0.300, 0.069, 0.534, 0.526, -0.159, 0.154, -0.276, 0.353, 0.761, -1.324, 0.866, 1.027, 0.509, 0.086, 0.847, 0.508, 0.529, -0.399, 0.480, 0.822, -1.001, -0.048, 0.814, 1.046, 1.345, -0.613, 0.402, 1.042, 0.799, -0.086, 0.520, 0.417, -0.524, 0.075, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.247, 0.567, -0.122, -5.000, -0.018, 0.454, -0.766, -0.952, 0.062, 0.635, 0.078, -0.138, -0.139, 0.130, -0.080, 0.415, -1.391, 0.086, -0.670, -5.000, -1.072, 0.358, -1.120, -1.871, -1.577, 0.693, -0.122, -0.949, -0.544, 0.139, -1.172, -0.559, -0.244, -0.373, -0.389, -0.043, -0.981, 1.053, 0.543, -1.369, -0.161, 0.348, -0.555, -0.839, -0.151, -0.068, 0.126, -1.233, -0.314, 0.368, -1.254, 0.088, -0.274, 1.036, 1.026, -0.766, -0.203, 0.950, 0.922, -0.538, 0.444, 0.614, -0.644, -0.383, 0.191, 0.834, 0.179, -5.000, -0.255, 1.007, -0.702, -0.897, 0.578, 1.076, 0.522, 0.241, 0.545, 0.620, 0.478, 0.739, 0.063, 0.789, -0.181, -5.000, -0.231, 0.679, 0.587, -1.335, 0.051, 0.725, -5.000, -0.022, 0.552, 0.278, -0.191, -0.032, 0.502, 0.571, 0.012, -0.543, -0.417, 1.098, 1.131, -0.702, 0.592, 1.536, 0.215, 1.131, 0.119, 1.036, 0.000, 0.438, 0.278, 0.941, 0.166, 0.788, 0.508, 0.975, 0.502, 0.222, 0.461, 1.214, 0.866, 0.548, 0.010, 0.106, -0.207, 0.165, -0.046, 0.249, -0.479, -5.000, -0.122, -1.066, -0.122, -1.029, -0.316, -0.479, 0.089, -1.066, -5.000, -0.527, 0.215, -0.185, -0.824, -0.373, 0.053, -5.000, -1.672, 0.342, -5.000, -5.000, -1.120, 0.320, -5.000, 0.032, 0.235, -0.779, -1.395, 0.020, -0.168, 0.377, -0.884, -0.839, -0.255, -5.000, 0.725, -0.661, 0.600, 0.032, -0.527, -5.000, -0.073, 0.843, -0.373, -0.191, -0.749, 0.215, -1.138, -0.174, -1.120, 0.438, 0.438, -0.122, -0.224, -0.741, -0.191, 0.661, 0.132, -0.296, -0.741, 0.150, -0.949, -0.028, -1.126, -5.000, -1.731, -1.707, -5.000, -2.373, -1.429, -0.450, -0.989, -1.120, -2.456, -1.120, -2.771, -0.765, -0.805, -0.643, -0.806, -5.000, -0.865, -1.080, -0.445, -1.873, -2.885, -0.574, -1.657, -1.577, -0.331, -0.514, -0.479, -0.825, -0.586, 0.072, -1.048, -1.257, -0.966, -1.029, -0.304, -2.183, -1.778, -0.122, -1.126, -2.483, -0.771, -1.543, -1.201, -1.466, -1.186, -0.468, -1.501, -1.332, -0.881, -0.827, -0.354, -2.318, -1.009, -0.695, -0.605, -1.441, -0.957, -0.827, -1.119, -1.127, 0.069, 0.982, 0.369, -5.000, 0.059, 0.593, -0.458, -0.877, 0.001, 0.108, -0.284, -0.639, -0.490, 0.246, -0.130, 0.120, -0.316, 0.771, -0.096, -5.000, -2.820, 0.419, -5.000, -1.634, 0.438, -0.191, -0.884, -0.815, 0.081, -0.338, -0.841, -0.796, 0.118, 0.794, -0.561, 0.571, -0.637, 0.763, -0.063, -2.493, -0.282, -0.004, -0.629, -0.589, -0.450, -0.741, -0.269, -0.610, 0.296, 1.077, -0.760, 0.734, 0.088, 0.915, 0.502, -0.462, 0.352, 0.599, 0.467, 0.081, 0.144, 0.275, -0.361, 0.143, 0.620, 1.310, 0.998, -5.000, 0.872, 1.031, -0.032, -0.592, 0.257, 0.836, 0.275, 0.180, 0.372, 0.766, 0.640, 0.727, 0.525, 1.001, 0.373, -5.000, -0.309, 0.971, -0.574, -0.855, -0.917, 0.089, -0.191, -1.354, 0.664, 0.134, 0.032, -0.407, -0.173, 0.620, 0.049, 0.260, -1.120, 0.880, 0.571, -1.038, 0.215, 0.525, -1.267, -0.296, -0.649, -0.255, 0.182, -0.815, 0.815, 1.204, 0.645, 1.198, 0.637, 0.790, 0.834, -0.242, 0.799, 0.908, 0.602, 0.401, 0.645, 0.604, 0.304, 0.457, 0.338, 0.663, 0.436, -5.000, 0.420, 0.249, -0.917, -0.988, -0.122, 0.267, -0.163, -0.333, -0.614, 0.287, -0.283, 0.046, -0.144, -0.012, -0.160, -5.000, 0.005, -0.688, 0.725, -1.211, -0.335, -0.101, -0.037, -0.633, 0.028, -0.206, -0.756, -1.091, 0.040, 1.131, -0.599, -0.170, -0.940, 0.403, 0.166, -0.855, 0.251, -0.136, -0.676, -0.699, 0.087, 0.578, -0.448, -0.860, 0.298, 0.489, -0.470, -0.268, 0.150, 0.363, 1.131, -0.381, 0.136, 0.447, 0.119, -0.213, 0.017, 0.106, -0.446, -0.282, 0.029, 0.797, 0.243, -5.000, -0.806, -0.307, -0.537, -1.475, -0.779, -0.132, -0.607, -0.930, -0.776, 0.144, -0.413, -0.363, 0.057, 0.226, -1.228, -5.000, -2.303, -2.381, -0.574, -1.336, -1.333, -0.316, -1.220, -1.434, 0.148, -0.150, -0.471, -0.977, -0.595, 0.244, -0.927, -1.267, -1.038, -0.122, -0.518, -1.285, -0.303, -0.014, -0.080, -1.003, -0.000, 0.141, 0.013, -0.568, -0.098, 0.680, 0.056, 0.138, -0.132, 0.474, 0.206, -1.259, -0.213, 0.093, 0.053, -0.231, -0.368, 0.018, 0.171, -0.438, -0.257, 0.560, -0.029, -5.000, -0.216, 0.299, -0.213, -1.309, -0.640, 0.138, -0.595, -0.851, -0.830, -0.341, -0.627, -0.276, 0.050, 0.654, -0.090, -5.000, -0.048, 0.408, 0.032, -0.815, -0.622, 0.386, -0.741, -0.174, -0.483, -0.983, -1.112, -1.115, -0.243, 0.056, -0.342, -0.156, -0.953, -0.122, -0.427, -3.043, -1.143, -0.638, -0.935, -1.191, -0.606, -1.204, -0.779, -1.363, -0.081, 0.633, -1.157, -0.122, -0.048, 0.014, 0.215, -0.783, -0.263, 0.341, -0.013, -0.454, 0.028, -0.267, -0.389, -0.299, 0.217, 1.065, 0.476, -5.000, 0.521, 0.552, 0.215, -0.440, 0.320, 0.601, -0.010, 0.012, 0.442, 0.802, -0.082, 0.250, 0.335, 0.557, -0.675, -5.000, 0.039, 0.486, 0.543, -1.126, -0.624, 0.104, 0.407, -0.145, -0.027, -0.698, -1.132, -0.461, -0.306, -0.122, -0.518, -1.577, -0.527, 0.320, 0.032, -1.244, -1.038, 1.131, 0.298, -5.000, -0.316, -1.267, -5.000, -1.204, 0.712, 1.060, 0.115, 0.896, 0.454, 0.586, 0.608, -0.497, 0.409, 0.446, 0.597, 0.083, 0.611, 0.321, -0.249, 0.192, 0.360, 0.829, 0.361, -5.000, 0.311, 0.666, 0.284, -0.450, -0.232, 0.391, -0.099, -0.454, -1.136, -0.057, -0.949, -0.040, -0.191, 0.281, -0.335, -5.000, 0.132, -0.004, 0.645, -0.920, 0.066, -0.028, -0.949, -1.085, -0.327, -1.124, -1.862, -1.005, 0.146, -0.245, -0.525, -0.840, -0.301, 0.089, 0.592, -1.278, 0.116, 0.466, -0.799, -1.520, -0.493, -2.219, -0.897, -1.861, 0.188, 0.751, -0.772, 0.227, 0.532, 0.179, 0.880, -0.715, 0.047, 0.417, -0.140, -0.090, 0.078, -0.404, -0.409, -0.290, 0.289, 0.764, 0.139, -5.000, -0.194, 0.379, -0.249, -0.871, -0.079, 0.639, -0.001, -0.333, -0.181, 0.210, -0.172, 0.141, 0.399, 0.994, 0.192, -5.000, 0.136, 0.288, -0.293, -0.558, -0.342, 0.525, 0.125, -0.154, 0.037, 0.279, -0.326, -0.145, 0.572, 0.464, 0.007, 0.024, 0.614, 0.866, 0.919, -0.892, 0.392, 0.598, 0.387, -0.230, 0.738, 0.360, 0.284, -0.050, 0.575, 0.983, -0.024, 0.207, 0.503, 0.724, 0.921, -0.389, 0.488, 0.827, 0.661, 0.047, 0.449, 0.564, 0.353, 0.149, 0.278, 0.758, 0.552, -5.000, -0.061, 0.130, 0.198, -0.957, -0.031, 0.448, -0.321, -0.723, -0.808, -0.332, -0.447, -0.071, -0.264, 0.443, -0.183, -5.000, -1.344, -0.691, -0.445, -1.180, -0.901, -0.618, 0.150, -0.741, -0.371, -0.178, -1.057, -0.797, 0.145, 0.610, 0.014, -0.274, -0.752, 0.847, 0.823, -1.277, -0.126, 0.455, -0.244, -0.377, -0.772, -0.504, -0.502, -1.401, 0.747, 1.100, 0.094, 0.422, 0.470, 0.818, 1.169, -0.191, 0.677, 1.207, 0.964, 0.074, 0.587, 0.542, 0.398, 0.106, 0.695, 1.189, 0.878, -5.000, 0.475, 0.886, 0.600, -0.623, 0.606, 0.821, 0.290, 0.023, 0.215, 0.160, 0.339, 0.642, 0.594, 0.835, -0.276, -5.000, -0.329, 0.667, -0.410, -0.553, -5.000, 0.032, 0.032, -5.000, 0.191, 0.250, -0.614, -0.227, 0.750, 0.215, -5.000, -1.009, -0.085, 0.089, 1.013, -0.917, -0.316, 0.438, 0.215, 0.000, -0.850, -0.574, -0.949, -0.022, 1.164, 1.385, 0.380, 0.851, 0.921, 1.068, 0.908, 0.306, 0.592, 1.183, 1.143, 0.334, 0.488, 0.628, 0.514, 0.353, 0.244, 1.042, 0.202, -5.000, 0.532, 0.790, 0.525, -0.402, -0.661, 0.525, 0.005, -0.479, -0.847, -0.175, -0.065, 0.098, -0.204, 0.313, -0.766, -5.000, -0.815, -0.142, -5.000, -2.366, -1.787, 0.032, -0.296, -0.009, -0.524, -0.431, -2.037, -0.441, 0.328, 0.081, -0.408, -0.606, -1.120, 0.949, 0.255, -1.434, 0.223, 0.171, 0.097, -0.730, 0.166, -2.005, -0.068, -0.995, 0.182, 0.625, -1.041, -0.363, 0.715, 0.997, 0.988, -0.724, -0.410, 0.364, 0.199, -0.815, -0.457, -0.435, -1.114, -0.770, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.499, 0.371, 0.051, -5.000, -0.110, -0.009, -0.255, -1.738, -0.696, 0.448, -0.276, -0.656, -1.025, -0.322, -0.805, -0.252, -1.482, 0.290, -0.438, -5.000, -1.877, -0.725, -5.000, -2.183, -0.884, 0.480, 1.131, -0.884, -1.453, 0.020, -0.574, -0.683, -0.376, 0.119, -0.122, -0.850, -1.285, 0.438, 0.977, -2.061, -0.624, -5.000, -5.000, -2.466, -1.123, -0.493, -1.232, -1.854, -0.496, -0.004, -0.234, -0.195, -0.300, 0.670, 0.725, -1.182, -0.468, 0.461, 0.489, -0.464, -0.201, -0.280, -1.020, -1.076, 0.175, 0.988, 0.108, -5.000, 0.392, 0.620, -5.000, -1.110, 0.234, 0.655, 0.487, 0.044, 0.298, 0.816, 0.298, 0.508, -0.513, 0.579, -0.893, -5.000, -0.048, 0.592, -0.479, -1.282, -0.884, 0.480, 1.372, -5.000, 0.061, -0.527, -1.577, -0.634, 0.108, 0.525, -5.000, -1.311, -0.927, 0.908, -5.000, -5.000, -1.038, -5.000, -0.949, -5.000, 0.438, -0.255, -0.479, 0.166, 0.307, 0.975, 0.044, 0.582, 0.809, 1.010, 0.389, -0.311, 0.017, 1.141, 0.812, -0.219, 0.396, 0.231, 0.066, 0.158, 0.195, 0.466, 0.448, -5.000, 0.320, -0.255, -5.000, -5.000, -0.479, 0.608, 0.215, -1.252, -1.434, -0.661, -0.073, -0.304, -0.339, -0.949, -0.032, -5.000, -5.000, -0.741, -5.000, -1.289, -0.884, 0.812, -0.479, -5.000, 0.525, -0.949, -5.000, -1.146, -0.048, -0.191, 0.138, -0.063, 0.215, 0.000, 0.725, 0.215, 0.571, -5.000, -5.000, -1.311, 0.284, -5.000, 0.032, -0.479, -0.688, -1.066, -0.335, 0.763, 0.284, -5.000, -5.000, -0.884, -0.661, 0.215, -5.000, -0.122, 0.571, -0.741, -0.255, -0.255, -0.733, -0.213, -1.114, -5.000, -1.532, -1.381, -2.047, -3.146, -0.551, -0.269, -1.371, -1.395, -1.518, -0.861, -1.831, -0.932, -0.510, -0.067, -0.473, -5.000, -1.326, -0.938, -0.884, -1.954, -5.000, -0.511, -1.577, -5.000, -0.566, 0.269, -1.787, -0.799, -0.708, 0.525, -0.930, -1.956, -1.807, 0.012, -0.445, -5.000, -1.379, -5.000, -2.558, -1.712, -1.138, -0.791, -0.316, -2.156, -0.824, -0.346, -1.277, -1.126, -1.214, -0.558, -0.741, -1.739, -1.136, -0.474, -0.171, -1.649, -1.156, -1.202, -1.259, -1.389, -0.695, 0.306, -0.159, -5.000, -0.877, 0.397, -0.255, -0.984, -0.712, -0.227, -0.741, 0.205, -1.208, -0.417, -0.649, -0.496, -1.333, -5.000, -5.000, -5.000, -5.000, -0.479, -5.000, -5.000, -5.000, 0.725, -5.000, -5.000, -0.574, -0.316, -0.884, -1.626, -0.500, 0.284, -1.267, -0.085, -2.156, -5.000, -0.741, -1.038, -0.599, -0.191, 0.389, -0.884, -1.202, -1.172, -0.122, -2.201, -0.032, 0.869, 0.671, 1.026, -1.094, -0.122, -5.000, -5.000, -0.191, 0.634, 0.725, -0.479, -1.731, -0.574, -1.029, -0.979, -0.240, 1.093, 0.423, -5.000, 0.377, 1.070, -5.000, -0.741, -0.527, 0.193, -0.445, -0.122, -0.056, 0.352, 0.502, 0.115, -0.949, 0.571, -1.577, -5.000, -1.434, 0.502, -5.000, -1.220, -0.574, -5.000, 0.725, -5.000, 0.193, 0.175, -5.000, -0.661, -1.244, -5.000, -0.574, -5.000, -0.427, 0.525, 0.000, -5.000, -0.191, -5.000, -0.122, -5.000, -1.220, 0.438, -0.373, -5.000, 0.448, 0.789, 0.474, 0.384, 0.584, 0.812, -0.048, -0.286, 0.255, 0.255, -0.527, 0.543, 0.306, 0.531, -0.276, 0.049, 0.015, 0.415, -0.110, -5.000, -0.741, 0.502, 0.725, -1.267, -0.640, 0.377, -0.596, 0.162, -1.577, -0.715, -0.255, -0.345, -0.316, -5.000, 0.571, -5.000, 1.131, -5.000, -5.000, -5.000, 0.812, -5.000, 0.215, -5.000, 0.654, 0.320, -5.000, -0.453, -0.301, -0.255, -0.373, -1.066, -5.000, 0.725, -5.000, -1.267, -0.949, -0.661, -0.479, -0.511, 0.671, -0.122, 0.284, -0.766, -0.503, 0.032, -0.741, -0.661, 0.358, 0.032, 0.725, -5.000, 0.138, 0.032, -5.000, -0.022, 0.393, 0.869, -0.157, -1.220, -0.326, 0.438, -0.884, -5.000, -2.439, -0.027, -5.000, -2.839, -1.172, -0.104, -1.354, -1.103, -1.787, -1.702, -0.661, -0.316, -0.373, -5.000, 0.150, -5.000, -0.479, -5.000, -5.000, -5.000, -5.000, 0.215, -5.000, -0.122, -0.815, 0.502, -0.574, -1.865, 0.184, -5.000, -0.427, -0.884, -1.311, -0.373, 0.869, -5.000, -0.122, 0.438, 0.725, -0.702, 0.119, -5.000, 0.089, -1.146, -0.299, 0.384, -1.220, -0.059, -0.122, 0.252, -0.255, -0.969, -0.039, 0.138, 0.592, -0.255, -0.684, -0.276, -1.188, -1.138, -0.153, 0.822, 0.015, -5.000, 0.133, 0.720, -0.815, -1.735, 0.028, 0.573, -0.014, -0.286, -0.854, -0.057, -0.598, -0.263, 0.034, 0.834, 0.054, -5.000, -0.020, 0.869, -0.048, -0.610, 0.007, 0.598, 0.763, -0.290, -0.551, -0.134, -0.859, -0.531, 0.205, 0.551, 0.338, 0.366, -0.973, 0.664, -0.779, -1.098, -0.820, -0.511, -0.985, -0.997, 0.053, -1.042, -0.585, -0.793, -0.379, 0.802, -1.133, -0.025, -0.159, 0.300, -0.022, -0.760, 0.092, 0.347, 0.277, -0.155, 0.215, -0.189, -1.624, -0.112, -0.264, 0.687, -0.479, -5.000, -0.399, 0.238, -0.427, -0.640, -0.226, 0.420, 0.264, -0.354, -0.670, -0.602, -0.620, -0.355, -0.069, 0.352, -0.144, -5.000, -0.354, 0.147, 0.320, -1.041, -1.490, 0.014, -0.779, -5.000, -0.373, -0.352, -1.430, -0.716, -1.745, -1.120, -5.000, -2.127, -1.052, -0.427, 0.119, -2.253, -0.897, -5.000, -5.000, -2.068, -0.884, -0.604, -5.000, -2.410, 0.540, 1.009, 0.032, 0.592, 0.488, 0.560, 0.119, 0.058, 0.009, 0.295, -0.122, -0.138, 0.394, -0.042, -0.505, -0.120, -0.493, 0.526, -0.378, -5.000, -0.507, -0.373, -0.255, -1.921, -0.299, 0.206, -0.215, -0.624, -1.498, -0.741, -1.687, -0.636, -0.587, -0.500, -0.803, -5.000, -2.108, -0.741, -0.122, -1.172, -0.354, -1.354, -0.032, -0.417, -0.781, -1.278, -1.711, -1.574, -0.529, -1.252, -0.965, -1.262, -0.427, -5.000, -1.577, -2.335, -0.994, -5.000, -1.741, -3.226, -0.766, -2.687, -2.473, -2.554, -0.183, 0.509, -1.386, -0.135, -0.479, -0.427, -5.000, -1.395, -0.326, -1.311, -0.438, -1.076, -0.427, -1.472, -1.975, -0.891, -0.582, 0.593, -0.505, -5.000, -1.104, -0.105, -0.596, -1.424, -0.653, 0.277, -0.673, -0.721, -1.767, -0.064, -0.859, -0.486, -0.589, 0.421, -1.014, -5.000, -0.690, -0.292, -0.985, -1.198, -1.228, -0.661, -0.165, -0.596, -0.570, -0.392, -0.995, -0.962, -0.522, -0.144, -0.596, -0.911, -0.617, 0.145, 0.222, -1.103, -0.801, -0.445, -0.625, -0.715, -0.272, -0.345, -0.926, -1.152, -0.447, 0.337, -1.130, -0.779, -0.605, 0.099, 0.075, -1.207, -0.817, 0.060, -0.046, -1.210, -0.463, -0.551, -0.599, -0.902, 0.177, 0.858, 0.440, -5.000, 0.110, -0.479, -0.681, -0.748, -0.314, 0.344, -0.147, -0.981, -0.861, 0.005, -0.183, 0.271, -0.305, -0.138, -0.122, -5.000, -1.539, -1.204, -0.048, -1.434, -1.368, -5.000, -0.741, -0.142, -0.461, -0.386, -1.128, -0.846, 0.023, 0.491, -0.042, 0.243, -0.877, 0.669, 0.290, -2.113, -0.444, 0.115, -0.421, -0.412, -0.722, -0.460, -0.078, -1.029, 0.637, 0.949, 0.153, 0.823, 0.137, 0.793, 1.251, -0.540, 0.468, 1.155, 1.012, 0.163, 0.669, 0.609, 0.514, 0.248, 0.709, 0.749, 0.611, -5.000, 0.201, 0.175, 0.032, -0.815, 0.710, 0.923, 0.190, 0.066, 0.114, 0.119, 0.332, 0.544, 0.156, 0.571, -0.289, -5.000, -1.244, 0.474, 0.571, -1.080, -5.000, -5.000, -5.000, -5.000, 0.264, -1.543, -0.618, -0.280, 0.783, 0.725, -0.604, 0.525, -0.618, -5.000, 1.536, -5.000, 0.725, 0.725, 0.843, 0.119, 0.438, 0.438, -0.574, -5.000, 0.908, 1.009, 0.478, 1.017, 0.467, 0.877, 1.226, 0.581, 0.648, 0.908, 0.395, -0.068, 0.962, 0.700, 0.189, 0.356, 0.128, 0.778, -0.154, -5.000, 0.238, 0.693, -5.000, -1.066, -1.110, 0.997, -0.359, -0.514, -1.929, -0.610, -0.255, 0.027, -0.305, 0.215, -1.160, -5.000, -0.901, -0.316, -5.000, -0.979, -1.702, -0.157, 0.438, -1.472, -0.335, -0.707, -1.050, -1.098, 0.101, 0.173, -0.704, -0.570, -0.356, 0.342, -0.335, -1.424, 0.595, 0.332, -0.969, -1.594, -0.011, -0.039, -0.177, -0.898, -0.627, -0.105, -1.572, -0.668, 0.114, 0.525, 0.600, -1.294, -0.581, 0.132, -0.539, -1.584, -0.352, -0.210, -1.081, -0.686, 0.419, 1.078, 0.192, -5.000, -0.361, -0.373, -0.093, -1.298, 0.103, 0.700, -0.226, -0.378, -0.453, -0.093, -0.206, -0.351, 0.253, 0.198, -0.048, -5.000, -0.715, -1.960, -1.120, -1.792, -1.267, -1.267, -5.000, -5.000, -0.203, -0.273, -1.642, -0.989, -0.045, 0.456, -0.686, -1.319, -1.045, -1.094, -0.341, -2.453, -0.412, -0.511, -0.688, -1.172, 0.236, -0.979, -0.494, -2.018, -0.389, 0.415, -1.024, -0.461, -0.153, 0.246, 0.682, -1.731, 0.036, 0.640, 0.209, -0.325, -0.371, 0.221, -0.242, -0.371, -0.801, 0.115, -0.432, -5.000, -1.046, -0.788, -1.472, -1.824, -1.043, -0.613, -0.749, -1.185, -1.332, -0.479, -0.895, 0.095, -0.323, -0.574, -1.024, -5.000, -2.114, -1.289, 0.032, -2.192, -0.604, -0.479, 0.215, -0.048, -2.210, -0.561, -0.825, -1.230, -0.344, 0.377, -0.191, 0.071, -1.896, 0.081, 0.255, -2.350, -0.944, -1.120, -1.652, -1.228, -1.177, -0.596, -0.406, -1.333, -0.303, 0.385, -0.300, 0.011, -0.745, 0.487, 0.075, -1.459, -0.466, 0.554, 0.505, -0.554, -0.146, -0.204, -0.799, -0.740, 0.249, 1.084, 0.616, -5.000, 0.260, 0.843, 1.131, -0.861, 0.582, 1.022, 1.082, 0.632, 0.661, 0.336, 0.689, 0.739, 0.605, 1.070, 0.641, -5.000, 0.455, 0.119, 0.438, -0.359, 0.032, -0.122, 1.131, 0.032, 0.422, -0.073, -0.640, 0.059, 0.525, 1.824, -0.574, -5.000, 0.389, 0.215, 1.313, -0.574, -5.000, -5.000, 1.824, -5.000, 0.358, 0.725, 0.438, -0.122, 0.488, 0.885, 0.262, 0.602, 0.363, 0.872, 0.725, -0.004, 0.761, 1.182, 1.051, 0.060, 0.725, 0.851, 0.554, 0.498, 0.589, 1.201, 0.568, -5.000, -0.479, -0.122, 0.215, 0.089, -0.316, 0.654, 0.182, 0.032, -0.979, 0.679, 0.119, 0.175, 0.432, 0.794, 0.949, -5.000, -1.472, -1.172, 1.131, -2.047, -5.000, 0.843, -5.000, -0.373, 0.580, 0.759, 0.255, -0.038, 0.430, -0.048, -0.104, 0.258, -0.022, -5.000, -5.000, -1.009, 0.835, 0.571, 0.075, -5.000, 0.649, 0.438, 0.592, -0.815, -0.096, 0.614, -0.548, 0.007, 0.215, 1.131, 1.419, -0.191, 0.293, 0.215, -0.213, -0.511, 0.288, 0.751, -1.311, 0.745, -1.805, -0.940, -1.301, -5.000, -1.941, -2.719, -1.085, -4.175, -2.245, -0.511, -5.000, -1.990, -1.824, -1.865, -1.555, -1.376, -1.687, -0.534, -1.499, -5.000, -1.724, -2.005, -1.009, -1.787, -1.354, -1.543, -1.472, -5.000, -1.099, -0.661, -1.672, -1.224, -1.814, -5.000, -2.242, -2.009, -2.303, -5.000, -2.005, -3.759, -2.583, -5.000, -0.731, -5.000, -1.791, -5.000, -2.270, -2.439, -1.698, -1.074, -1.763, -1.281, -1.649, -0.596, -0.633, -2.209, -1.702, -0.441, -0.427, -2.373, -1.417, -1.379, -1.541, -1.367, 0.160, 1.008, 0.350, -5.000, -0.180, 0.614, -0.200, -1.563, -0.195, 0.582, -0.030, -0.433, -1.045, -0.329, -0.066, 0.094, -0.150, 1.090, -0.140, -5.000, -5.000, 0.150, -5.000, -1.311, -1.434, 0.725, -5.000, -0.255, -0.217, 0.119, -0.949, -1.014, 0.083, 0.608, -0.059, 0.363, -0.934, 0.908, -0.168, -1.135, -0.391, 0.266, -0.841, -0.589, -0.170, -0.276, -0.088, -0.797, 0.158, 0.560, 0.042, 0.456, -0.909, 0.620, 1.345, -0.913, -0.328, 0.893, 0.298, -0.634, 0.172, 0.381, -0.460, -0.445, 0.528, 1.214, 0.755, -5.000, -0.688, -0.009, -0.373, 0.235, -0.417, 0.855, -0.276, 0.070, -0.093, 0.410, -0.048, 0.298, 0.512, 0.725, -0.022, -5.000, -5.000, 0.438, 0.725, -0.157, -5.000, -5.000, 0.000, -5.000, 0.352, 0.525, -5.000, -0.283, -0.093, -5.000, -0.427, -0.779, -0.815, 0.843, -5.000, -1.759, -0.453, -5.000, -0.884, -0.511, 0.182, -5.000, -1.009, -0.661, 0.652, 0.423, 0.327, 0.747, 0.304, -0.296, 1.456, -1.434, 0.166, 0.968, -0.150, -0.771, 0.895, 0.529, 0.387, 0.438, -0.665, 0.226, 0.198, -5.000, -0.296, 0.377, 0.571, -2.381, -0.691, 0.298, -0.091, -0.164, -0.850, 0.605, -0.618, -0.126, -0.802, -0.122, -0.230, -5.000, -0.213, 0.032, -5.000, -5.000, -0.255, -0.073, -5.000, -0.168, 0.320, 0.089, -0.479, -0.415, -0.277, -0.479, -1.042, -1.045, -0.801, -5.000, -0.884, -2.287, 0.134, -0.168, -5.000, -0.679, -0.267, -1.472, -0.284, -0.758, -0.457, -0.198, -0.310, -0.517, -0.104, 0.304, 1.131, -1.453, -0.331, 0.320, -0.389, -0.518, 0.519, 0.336, 0.002, 0.074, -0.713, -0.612, -0.571, -5.000, -2.026, -0.850, -1.326, -2.387, -0.863, 0.114, -1.227, -0.666, -3.509, -1.220, -1.425, -1.172, -0.890, 0.480, -0.373, -5.000, -2.466, -5.000, -5.000, -1.032, -5.000, -5.000, -5.000, -5.000, -0.082, -0.511, -1.983, -1.766, -0.567, -0.335, -1.228, -1.750, -0.865, -0.009, -0.604, -3.012, -0.712, -0.255, -0.324, -1.244, -0.053, 0.358, -0.012, -1.839, -0.475, -0.048, -0.363, -0.411, -0.675, -0.273, 0.620, -2.210, -0.231, 0.311, 0.263, -0.305, 0.024, 0.563, 0.069, -0.068, -0.299, 0.790, 0.219, -5.000, 0.224, 0.751, -0.204, -1.135, 0.098, 0.631, -0.578, -0.622, -1.000, 0.168, -0.338, 0.090, 0.181, 1.206, 0.299, -5.000, -0.100, 0.972, 0.032, -0.325, -0.076, 0.671, 0.543, -0.296, -0.198, 0.008, -0.801, -0.961, 0.547, 0.715, 0.387, 0.243, -1.311, 0.155, -0.427, -1.819, -0.392, 0.342, -0.596, -1.005, -0.153, -0.582, -1.289, -1.357, 0.101, 0.880, 0.027, 0.438, -0.088, 0.662, -0.048, -0.755, -0.115, 0.820, 0.550, 0.067, 0.608, 0.265, -0.527, 0.022, -0.640, 0.536, -0.319, -5.000, 0.150, 0.175, -0.661, -1.009, 0.186, 0.667, -0.391, -0.196, -0.496, -0.574, -1.434, 0.026, -0.004, -5.000, -0.964, -5.000, -0.681, 0.215, -0.255, -2.335, -5.000, -0.048, 1.062, -0.316, -0.206, -0.675, -0.612, -0.291, 0.016, -5.000, -5.000, -5.000, 0.032, 1.131, 0.843, -1.172, -1.395, -5.000, -0.574, -0.815, -0.304, -0.373, -0.884, -1.642, 0.364, 0.620, 0.072, 0.538, 0.429, -0.373, -0.122, -0.815, 0.025, -0.316, 0.342, -0.710, 0.522, 0.222, -0.191, -0.027, 0.372, 0.923, 0.410, -5.000, -0.296, -0.213, -0.255, -0.873, 0.189, 0.611, -0.131, -0.063, -1.626, -0.090, -0.649, 0.132, 0.062, 0.438, 0.193, -5.000, -0.633, -0.122, -0.373, -1.717, -0.555, -0.122, 0.032, -1.066, -0.420, -1.009, -0.786, -0.729, 0.470, 0.089, -0.090, -0.413, -0.059, 0.032, 0.284, -1.889, -0.177, 0.089, -0.756, -1.814, -0.532, -0.815, -1.532, -1.696, -0.028, -0.233, -0.690, -0.226, 0.262, -1.395, -5.000, -2.630, -0.549, -0.014, -0.316, -1.066, 0.234, -0.389, -0.717, -0.060, -0.732, 0.194, -0.633, -5.000, -1.190, -0.766, -0.604, -1.937, -0.536, 0.410, -0.618, -0.721, -2.149, -1.543, -0.888, -0.462, -0.380, -0.438, -0.338, -5.000, -1.464, -0.719, -1.289, -1.186, -1.731, -1.717, -2.424, -1.032, -1.034, -0.653, -2.099, -1.345, -0.251, 0.066, -0.765, -1.172, -1.229, -0.395, -0.961, -2.966, -0.588, -1.267, -0.764, -0.888, -0.485, -0.421, -1.624, -1.352, -0.105, 0.385, -1.124, -0.261, -0.365, -1.177, 0.060, -1.539, -0.821, 0.048, 0.023, -1.021, -0.898, -0.662, -0.872, -1.094, 0.525, 1.064, 0.483, -5.000, 0.242, 0.158, -0.551, -0.765, 0.295, 0.627, 0.118, -0.087, -0.303, 0.123, -0.068, 0.519, 0.262, 0.607, 0.121, -5.000, -0.807, -0.260, -1.311, -1.043, -0.363, 0.163, -0.410, -1.814, 0.141, -0.218, -0.776, -0.579, 0.160, 0.642, -0.387, 0.385, -0.717, 0.341, 0.166, -1.362, -0.063, 0.622, -0.070, 0.092, -0.168, -0.100, 0.463, -0.543, 0.501, 0.864, 0.063, 0.480, 0.475, 0.908, 1.375, -0.716, 0.475, 1.049, 0.989, -0.097, 0.656, 0.660, 0.342, 0.177, 0.698, 1.133, 0.725, -5.000, 0.259, 0.438, -0.168, -0.774, 0.576, 1.135, 0.577, 0.273, 0.531, 0.669, 0.799, 1.104, 0.529, 0.784, -0.097, -5.000, -0.792, 0.426, -0.427, -0.228, -1.508, 0.377, -5.000, -5.000, 0.779, 0.372, -0.584, 0.120, 0.381, -0.122, -0.009, -0.316, 0.117, 0.587, 0.859, -0.292, -0.060, 0.358, 0.592, -1.672, 0.656, 0.438, 0.759, -0.362, 1.049, 1.320, 0.864, 1.274, 1.193, 1.316, 1.472, 0.333, 1.093, 1.317, 1.049, 0.484, 1.145, 1.194, 0.961, 0.860, -0.031, 0.590, -0.430, -5.000, -0.181, 0.516, -5.000, -1.239, -0.403, 0.659, -0.130, -0.280, -1.712, 0.009, -0.511, -0.029, -0.326, 0.077, -1.240, -5.000, -0.549, -0.373, -0.157, -1.894, -1.120, -1.155, -1.672, -0.969, -0.114, 0.070, -1.479, -0.937, -0.043, 0.162, -0.571, -0.914, -0.382, 0.111, -0.059, -2.280, 0.468, 0.869, 0.095, -0.141, 0.546, 0.136, 0.191, -0.620, -0.654, 0.173, -1.426, -0.756, -0.247, 0.965, 0.873, -0.515, -0.562, 0.708, 0.296, -0.544, -0.873, -0.035, -0.749, -0.612, 0.365, 1.206, 0.287, -5.000, -0.346, 0.180, -0.082, -1.545, 0.086, 0.458, -0.063, -0.153, -0.162, 0.281, -0.474, 0.164, 0.518, 0.880, 0.147, -5.000, -0.046, -0.445, -1.172, -0.853, -0.850, -0.286, -1.434, -0.791, 0.408, -0.084, -0.847, 0.037, 0.429, 0.845, -0.205, -0.242, 0.153, 0.810, 0.742, -1.474, -0.094, 0.498, 0.375, 0.023, 0.705, 0.682, 0.215, -0.341, -0.223, 0.776, -0.529, -0.192, 0.301, 0.887, 0.701, -1.018, 0.388, 1.078, 0.402, -0.174, 0.198, 0.580, 0.055, -0.201, 0.065, 0.867, 0.257, -5.000, 0.082, 0.340, -0.850, -1.466, -0.007, 0.637, -0.119, -0.186, -0.501, 0.211, -0.284, 0.503, 0.394, 0.691, 0.234, -5.000, -0.975, 0.092, -0.779, -0.578, 0.070, -0.177, 0.725, -0.917, 0.537, 0.025, -0.497, -0.176, 0.178, 0.799, 0.183, 0.426, -0.979, 0.834, 0.725, -1.781, -0.458, 0.101, -0.509, -0.519, -0.671, 0.172, 0.364, -0.586, 0.457, 0.946, -0.337, 0.241, 0.553, 1.071, 0.949, -0.360, 0.625, 1.134, 0.955, 0.278, 0.748, 0.757, 0.177, 0.378, 0.498, 1.063, 0.646, -5.000, 0.633, 0.467, -0.815, -1.807, 0.707, 0.973, 0.701, 0.558, 0.847, 0.763, 0.490, 0.973, 0.613, 0.887, 0.258, -5.000, 0.367, 0.827, 0.304, -0.503, -0.661, 0.365, -0.527, -1.009, 0.527, 0.103, -0.224, -0.081, 0.686, -0.009, -0.022, 0.348, -0.284, 1.379, 0.725, -0.104, 0.400, -5.000, -0.345, -1.354, 0.713, 0.725, 0.377, 0.582, 0.840, 1.242, 0.829, 1.086, 0.768, 1.050, 1.192, 0.429, 0.772, 1.116, 0.895, 0.399, 0.903, 0.813, 0.442, 0.545, 0.924, 1.390, 1.107, -5.000, 1.399, 0.571, 0.438, -0.927, 0.459, 0.843, 0.908, 0.641, 0.066, 1.036, 0.410, 0.770, 0.529, 0.608, 0.339, -5.000, -1.543, 0.255, -0.574, -1.434, 0.032, 0.661, 0.215, 0.826, 1.077, 0.696, 0.293, 0.255, 0.892, 1.082, 0.650, 1.191, -0.000, 1.536, 0.812, -0.000, 0.725, 1.332, -0.191, -0.067, 0.890, 1.467, 0.926, 1.023, 0.857, 1.083, 0.150, 0.617, 0.835, 0.763, 1.506, 0.032, 0.358, 1.070, 0.725, 0.369, 1.000, 0.752, 0.658, 0.955, -0.844, -0.111, -1.442, -5.000, -1.624, -1.636, -2.558, -3.030, -1.018, 0.058, -1.937, -1.024, -0.490, -0.332, -1.417, -0.344, -0.548, -0.174, -0.992, -5.000, -0.468, -0.691, -1.333, -1.526, -2.026, -0.604, -1.172, -5.000, -0.162, 0.225, -1.354, -0.449, -0.716, -0.507, -1.113, -1.120, -1.172, 0.171, -1.626, -2.260, -1.144, -0.191, -2.118, -1.294, -0.197, -0.435, -0.724, -1.354, -1.039, 0.082, -1.331, -0.513, -0.877, -0.313, -0.999, -1.514, -0.937, -0.196, -0.339, -1.135, -0.503, -0.205, -0.676, -0.863, 0.300, 0.872, 0.670, -5.000, 0.028, 0.681, -0.410, -0.764, 0.201, 0.646, 0.378, -0.050, -0.305, 0.340, 0.091, 0.395, -0.054, 0.587, -0.191, -5.000, -0.909, -0.104, -5.000, -0.949, -0.328, -0.191, -0.122, -0.427, 0.298, 0.171, -1.172, -0.473, 0.213, 0.858, 0.459, 0.538, -0.851, 0.661, -0.427, -1.267, -0.120, 0.610, -0.479, -0.434, -0.074, 0.244, -0.283, -0.466, 0.566, 1.100, 0.128, 0.718, 0.239, 1.014, 0.778, -0.156, 0.377, 1.064, 0.989, 0.456, 0.588, 0.723, 0.047, 0.217, 0.676, 1.261, 1.090, -5.000, 0.769, 0.974, 0.886, -0.122, 0.358, 0.983, 0.303, 0.067, 0.382, 0.879, 0.284, 0.654, 0.692, 1.214, 0.266, -5.000, -0.198, 0.534, 1.419, -0.177, -1.610, 1.077, -5.000, -0.255, 0.744, 0.840, -0.022, 0.194, 0.318, 0.543, 0.269, 0.101, -1.113, 1.222, 0.266, -2.037, 0.018, 0.166, -0.640, -0.080, 0.390, 0.480, 0.725, -0.162, 1.017, 1.429, 0.973, 1.049, 0.973, 1.321, 1.469, -0.216, 0.781, 1.155, 0.987, 0.371, 1.051, 1.089, 0.527, 0.702, 0.530, 1.196, 0.844, -5.000, 0.806, 0.866, 0.774, -0.000, 0.173, 0.674, 0.447, -0.460, -0.510, 0.297, 0.290, 0.659, -0.129, 0.754, 0.600, -5.000, -1.642, 0.634, -5.000, -0.177, -0.157, 0.474, -0.373, -0.286, 0.349, 0.111, 0.101, 0.274, 0.427, 1.264, -0.006, -0.084, -0.450, 1.354, 0.964, -0.204, 0.831, 0.386, 0.404, 0.056, 0.801, 1.059, 0.540, 0.284, 0.700, 1.270, 0.304, 0.709, 0.595, 1.370, 1.529, 0.476, 0.649, 0.812, 0.320, 0.286, 0.659, 0.824, 0.074, 0.389, 0.290, 0.602, 0.134, -5.000, -1.349, -0.927, -1.340, -1.844, -0.588, 0.028, -0.397, -0.713, -1.130, -0.073, -1.099, -0.505, -0.188, 0.620, 0.255, -5.000, -1.354, -0.479, -0.741, -1.120, -5.000, -0.073, -5.000, -1.220, 0.412, -0.110, -1.588, -1.260, -0.213, 0.373, -0.524, -0.683, -0.674, 0.986, 0.531, -1.526, -0.754, -0.328, -0.435, -0.093, 0.013, 0.629, 0.445, -0.795, 0.053, 0.442, -0.316, -0.042, 0.139, 0.807, 0.752, -0.894, 0.055, 0.417, 0.332, -0.178, -0.204, 0.133, 0.040, -0.388, 0.491, 1.088, 0.800, -5.000, 0.278, 0.907, 0.358, -0.829, 0.375, 0.784, 0.078, -0.082, -0.163, 0.659, 0.262, 0.570, 0.681, 1.165, 0.626, -5.000, 0.093, 0.955, 0.851, -0.542, 0.419, 0.962, 0.464, 0.349, 0.239, 0.113, -0.328, -0.507, 0.539, 1.008, 0.286, 0.415, -0.855, 0.506, -0.245, -1.395, 0.291, 0.707, -0.060, -0.381, 0.177, -0.030, -0.446, -0.348, 0.564, 1.109, 0.053, 0.368, 0.412, 0.730, 0.710, -0.562, 0.462, 1.026, 0.908, 0.509, 0.699, 0.616, -0.092, 0.255, 0.191, 1.057, 0.438, -5.000, -0.117, 0.590, -0.078, -1.114, 0.462, 0.990, 0.574, 0.093, 0.236, 0.436, 0.135, 0.460, 0.475, 0.470, -0.255, -5.000, 0.005, 0.722, 0.392, -0.862, -0.479, 0.461, 0.175, 0.199, 0.034, -0.273, -0.558, -0.365, 0.157, -0.341, -0.734, -0.845, -1.051, 0.549, 0.142, -1.038, -0.430, -0.797, -0.267, -0.884, 0.019, -0.721, -0.754, -1.829, 0.772, 1.043, 0.649, 1.013, 0.853, 0.827, 1.016, -0.199, 0.499, 0.928, 0.769, -0.101, 0.710, 0.481, -0.010, 0.246, 0.224, 1.014, 0.525, -5.000, 0.366, 1.103, -0.219, -0.544, 0.160, 1.034, 0.285, 0.266, -1.210, 0.253, -0.097, 0.285, -0.011, 0.543, -0.293, -5.000, -1.179, 0.297, 0.377, -1.289, -0.035, 0.380, -0.199, -0.165, -0.186, -0.784, -0.645, -0.599, 0.104, 0.284, -0.552, -0.597, -0.897, 0.271, 0.351, -1.267, -0.040, 0.291, -0.564, -1.284, -0.068, -0.901, -0.725, -0.558, -0.130, 0.667, -0.772, -0.321, 0.054, 0.502, 0.171, -1.315, -0.902, -0.210, -0.293, -0.890, -0.077, -0.563, -1.215, -0.437, 0.087, 0.739, 0.249, -5.000, -0.767, 0.460, -0.595, -1.244, 0.065, 0.630, -0.092, -0.208, -0.540, 0.207, -0.384, 0.050, 0.241, 0.585, 0.387, -5.000, -0.422, 0.128, -0.273, -1.007, -1.484, -0.028, -0.211, -0.511, -0.147, -0.012, -0.392, -0.230, 0.393, 0.871, -0.275, 0.037, -0.044, 0.447, 0.704, -1.985, 0.038, 0.504, 0.068, -0.633, 0.288, 0.168, -0.117, -0.302, 0.090, 0.810, -0.342, -0.089, 0.045, 0.422, 0.414, -1.228, -0.048, 0.516, 0.207, -0.609, -0.257, 0.006, -0.332, -0.366 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_5(struct _training *tptr) {
  struct _training tinf = {
    0.534, 11, 4.350, { 1.013, 0.181, 1.806 }, { 0.892, -1.555, -2.110 }, 1, 
    { -1.716, -2.336, -1.312, -0.674, -0.916, -1.226, -0.126, -4.000, -0.620, -0.483, -1.536, -4.000, 1.101, 0.752, -1.124, 2.435, 2.415, -4.000, 1.738, 0.765, 0.905, 0.306, 3.273, 3.126, 2.574, -4.000, 3.207, 2.880 }, 
    {{ 0.036, -0.373, 0.064, 0.219},{ 0.063, -0.578, 0.012, 0.354},{ 0.345, -0.274, -0.250, 0.110},{ 0.295, -0.338, -0.101, 0.092},{ 0.285, -0.232, -0.202, 0.110},{ 0.168, -0.315, -0.103, 0.214},{ 0.262, -0.412, -0.077, 0.159},{ 0.239, -0.246, -0.167, 0.145},{ 0.181, -0.311, -0.069, 0.169},{ 0.194, -0.328, -0.050, 0.151},{ 0.094, -0.209, 0.018, 0.093},{ 0.075, -0.223, -0.031, 0.171},{ 0.128, -0.272, -0.068, 0.193},{ 0.125, -0.166, -0.068, 0.110},{ 0.105, -0.164, 0.003, 0.057},{ 0.108, -0.254, -0.000, 0.134},{ 0.095, -0.109, -0.027, 0.048},{ 0.025, -0.112, -0.044, 0.135},{ 0.060, -0.114, -0.041, 0.103},{ 0.092, -0.103, 0.002, 0.014},{ 0.100, -0.153, -0.010, 0.066},{ 0.085, -0.193, 0.003, 0.103},{ 0.119, -0.080, -0.054, 0.021},{ 0.058, -0.170, -0.020, 0.133},{ 0.099, -0.125, -0.113, 0.142},{ 0.090, -0.084, -0.064, 0.066},{ 0.025, -0.098, -0.084, 0.160},{ 0.097, -0.159, -0.070, 0.135},{ 0.067, -0.029, -0.093, 0.062},{ 0.092, -0.105, -0.022, 0.042},{ 0.045, -0.102, -0.076, 0.139},{ 0.030, -0.046, -0.072, 0.095} }, 
    {{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}} }, 
    0.000, { 0.304, 0.486, -0.035, -5.000, -0.480, -0.196, -0.618, -5.000, -0.434, 0.061, -0.105, -0.183, 0.064, 0.102, 0.349, 0.221, 0.390, 0.688, 0.383, -5.000, -0.549, 0.038, -0.863, -0.118, 0.032, 0.445, 0.346, -0.097, 0.582, 0.614, 0.871, 0.251, 0.417, 0.571, 0.116, 0.622, 0.294, 0.359, 0.261, -0.469, 0.585, 0.499, 0.171, 0.182, 0.530, 0.458, 0.330, 0.403, 0.388, 0.447, -0.085, 0.380, 0.294, 0.484, 0.556, -0.176, 0.408, 0.408, 0.707, 0.476, 0.567, 0.295, 0.527, 0.466, 0.576, 0.752, 0.105, -5.000, -0.327, 0.317, -0.612, -5.000, -0.097, 0.256, -0.478, -0.073, 0.388, 0.613, 0.489, 0.458, 0.400, 0.462, 0.680, -5.000, -0.125, 0.455, -0.032, 0.587, 0.410, 0.673, 0.730, 0.383, 0.846, 0.815, 1.036, 0.449, 0.855, 0.824, 0.303, 0.826, 0.638, 0.500, 0.707, -0.059, 0.802, 0.734, 0.195, 0.462, 0.825, 0.610, 0.608, 0.718, 0.610, 0.799, 0.434, 0.543, 0.392, 0.441, 0.829, 0.082, 0.144, 0.055, -0.003, 0.049, 0.916, 0.534, 0.879, 0.749, 0.036, 0.308, -0.347, -5.000, -0.771, -0.543, -1.263, -5.000, -0.110, 0.026, -0.381, -0.044, -0.105, 0.015, -0.100, 0.203, 0.104, 0.298, 0.050, -5.000, -0.722, -0.307, -1.040, -0.397, 0.214, 0.078, 0.081, 0.069, 0.486, 0.345, 0.724, 0.438, -0.217, -0.599, -0.920, -0.349, -0.504, -0.926, -0.941, -1.219, 0.052, -0.250, -0.694, -0.512, 0.175, -0.553, -0.404, -0.111, -0.172, -0.216, -0.672, -0.308, -0.249, -0.523, -0.598, -0.810, -0.363, -0.707, -0.823, -0.645, -0.096, -0.777, -1.048, -0.513, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.347, -0.553, -1.036, -5.000, -0.729, -1.249, -1.810, -5.000, -0.832, -0.858, -1.056, -0.980, -0.278, -0.206, -0.025, -0.415, -0.728, -0.407, -0.589, -5.000, -1.334, -0.857, -1.121, -0.972, -0.790, -0.771, -1.207, -1.044, -0.196, -0.185, -0.153, -0.204, -0.441, -0.184, -0.772, -0.633, -0.909, -0.775, -1.029, -1.166, -0.821, -0.681, -1.301, -0.974, -0.520, -0.500, -0.243, -0.271, -0.579, -0.785, -0.814, -0.789, -0.692, -0.952, -1.062, -1.140, -0.355, -0.297, 0.079, -0.401, -0.123, -0.537, 0.413, -0.336, 0.167, 0.344, -0.638, -5.000, -0.707, -0.174, -1.296, -5.000, -0.848, -0.809, -0.899, -0.905, 0.115, 0.293, 0.770, 0.267, 0.003, 0.430, 0.374, -5.000, -0.717, -0.291, -0.530, -0.058, -0.176, 0.013, -0.264, -0.577, 0.462, 0.091, 0.476, 0.092, -0.055, -0.040, -0.311, -0.148, -0.078, -0.358, -0.413, -0.929, 0.113, 0.037, -0.593, -0.331, 0.069, 0.071, 0.397, -0.111, -0.154, -0.558, -0.857, -0.454, -0.514, -0.758, -0.527, -1.240, -1.292, -1.734, -1.282, -1.439, 0.276, -0.462, 0.505, -0.097, -0.590, -0.379, -1.053, -5.000, -1.403, -1.113, -1.750, -5.000, -0.885, -0.960, -1.483, -0.911, -0.835, -0.873, -1.272, -0.916, -0.721, -0.379, -0.777, -5.000, -1.346, -1.075, -1.389, -1.159, -0.725, -0.855, -1.311, -0.923, -0.259, -0.250, -0.248, -0.279, -0.774, -0.936, -1.259, -1.052, -1.135, -1.298, -1.411, -1.766, -0.315, -0.577, -1.073, -1.273, -0.552, -0.867, -1.262, -0.644, -0.722, -1.241, -1.360, -1.483, -1.307, -1.492, -1.470, -1.673, -1.361, -1.548, -1.663, -1.397, -0.848, -1.493, -1.598, -1.308, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.313, -0.169, -1.171, -5.000, -0.986, -0.896, -1.720, -5.000, -0.844, -0.834, -1.017, -0.889, -0.427, -0.452, -0.371, -0.454, -0.413, 0.025, -0.105, -5.000, -0.822, -0.744, -1.036, -0.514, -0.481, -0.602, -0.556, -1.216, 0.076, 0.060, 0.168, -0.259, -0.358, 0.010, -0.487, -0.184, -0.403, -0.493, -0.596, -1.158, -0.531, -0.447, -0.946, -1.207, -0.332, -0.174, -0.062, -0.294, -0.328, -0.281, -0.808, -0.419, -0.576, -0.615, -0.777, -1.052, -0.828, -0.730, -0.399, -0.738, -0.187, -0.550, -0.495, -0.352, 0.126, 0.389, -0.884, -5.000, -0.887, -0.529, -1.484, -5.000, -1.107, -0.904, -1.547, -1.233, -0.303, -0.096, -0.337, -0.313, -0.147, 0.489, 0.349, -5.000, -0.920, 0.027, -0.642, -0.283, -0.277, -0.054, -0.398, -0.698, 0.194, 0.338, 0.615, -0.390, -0.293, -0.115, -0.770, -0.642, -0.371, -0.205, -0.714, -1.248, 0.045, 0.021, -0.437, -0.605, -0.059, -0.095, -0.161, -0.324, 0.028, 0.140, -0.441, -0.192, -0.281, -0.120, -0.375, -0.856, -0.802, -0.890, -1.162, -0.834, 0.227, -0.425, -0.060, -0.246, -0.623, -0.547, -0.931, -5.000, -1.121, -0.652, -1.676, -5.000, -0.984, -0.996, -1.469, -1.193, -0.908, -0.853, -0.869, -0.740, -0.399, -0.128, -0.457, -5.000, -0.997, -0.319, -1.279, -0.875, -0.321, -0.945, -1.066, -1.011, -0.263, -0.152, -0.068, -0.379, -0.181, -0.255, -1.058, -0.865, -0.710, -0.450, -0.906, -1.355, -0.090, -0.704, -1.004, -0.821, -0.041, -0.757, -0.813, -0.193, -0.210, -0.643, -1.089, -0.867, -0.772, -0.564, -0.849, -1.255, -0.687, -1.055, -0.893, -1.061, -0.234, -0.927, -1.384, -1.050, -0.406, 0.023, -1.092, -5.000, -1.539, -1.392, -2.015, -5.000, -0.935, -0.931, -1.220, -1.007, -0.820, -0.393, -0.905, -0.742, -0.204, 0.005, -0.055, -5.000, -1.129, -0.718, -1.356, -0.710, -0.669, -0.955, -0.582, -0.762, 0.222, 0.084, 0.520, -0.264, -0.142, -0.100, -0.490, -0.246, -0.666, -0.583, -0.845, -1.030, 0.055, 0.294, -0.287, -0.523, -0.219, -0.026, 0.126, -0.048, -0.329, -0.128, -0.782, -0.639, -0.672, -0.007, -0.634, -0.948, -0.702, -0.468, -0.552, -0.779, -0.229, -0.387, -0.534, -0.634, 0.024, 0.160, -0.245, -5.000, -0.567, -0.341, -0.795, -5.000, -0.504, -0.552, -0.798, -0.780, -0.432, -0.480, -0.454, -0.315, -0.153, 0.135, -0.001, -5.000, -0.631, -0.157, -0.732, -0.322, -0.474, -0.089, -0.473, -0.659, 0.099, 0.124, 0.119, -0.238, -0.219, -0.122, -0.306, -0.147, -0.611, 0.046, -0.247, -0.712, -0.318, -0.278, -0.762, -0.852, -0.171, -0.191, -0.309, -0.151, -0.037, 0.144, -0.141, 0.148, -0.234, -0.248, -0.129, -0.756, -0.180, -0.322, -0.662, -0.545, -0.044, -0.187, -0.064, -0.009, 0.221, 0.364, -0.561, -5.000, -0.370, -0.222, -0.864, -5.000, -0.463, -0.423, -1.008, -0.611, -0.203, -0.140, -0.249, -0.075, 0.090, 0.300, 0.278, -5.000, -0.576, 0.417, -0.178, 0.034, 0.104, 0.369, 0.105, -0.147, 0.245, 0.684, 0.638, -0.165, 0.237, 0.378, -0.141, 0.051, -0.097, 0.399, -0.010, -0.490, 0.189, 0.072, -0.486, -0.139, 0.209, -0.137, -0.223, 0.033, 0.038, 0.253, -0.136, 0.076, -0.134, -0.167, -0.105, -0.367, -0.516, -0.711, -0.851, -0.494, 0.252, -0.250, -0.254, 0.035, 0.256, 0.265, -0.565, -5.000, -0.352, -0.511, -1.006, -5.000, -0.445, -0.312, -0.406, -0.623, -0.292, -0.168, -0.894, -0.326, 0.249, 0.705, 0.354, -5.000, -0.447, 0.127, -0.608, -0.226, 0.289, 0.306, 0.025, -0.157, 0.467, 0.495, 0.728, 0.063, -0.416, -0.591, -0.690, -0.487, -0.480, -0.557, -1.064, -1.126, 0.074, -0.371, -0.702, -0.637, -0.147, -0.865, -0.800, -0.372, -0.028, -0.042, -0.736, -0.612, -0.584, -1.018, -0.819, -1.204, -0.626, -0.738, -0.495, -0.682, -0.068, -0.891, -1.025, -0.760, 0.061, 0.467, -0.015, -5.000, -0.500, -0.100, -0.844, -5.000, -0.099, 0.032, -0.511, -0.516, -0.198, 0.109, -0.218, -0.216, 0.120, 0.451, 0.573, -5.000, -0.656, -0.103, -0.455, -0.179, -0.056, 0.123, -0.046, -0.125, 0.391, 0.588, 0.752, 0.137, 0.016, 0.052, -0.234, -0.022, -0.475, -0.220, -0.303, -0.698, 0.152, 0.087, -0.274, -0.420, -0.143, -0.179, -0.432, -0.303, -0.051, 0.374, -0.168, -0.269, -0.382, 0.079, -0.270, -0.758, -0.480, -0.368, -0.506, -0.525, 0.007, -0.357, -0.279, -0.221, 0.235, 0.536, 0.026, -5.000, -0.421, -0.203, -0.933, -5.000, -0.606, -0.479, -0.533, -0.738, -0.285, -0.182, 0.090, -0.126, -0.023, 0.716, 0.390, -5.000, -0.628, -0.231, -0.925, -0.329, -0.507, 0.089, -0.087, -0.581, 0.376, 0.350, 0.694, -0.001, 0.660, 0.992, 0.536, 0.918, 0.486, 0.696, 0.574, -0.298, 0.705, 0.420, 0.053, 0.247, 0.562, 0.475, 0.348, 0.359, 0.575, 0.683, 0.245, 0.397, 0.510, 0.664, 0.621, -0.140, 0.474, 0.443, 0.637, 0.322, 0.556, 0.308, 0.562, 0.468, 1.060, 1.254, 0.455, -5.000, -0.234, 0.243, -0.322, -5.000, 0.049, 0.425, -0.228, 0.051, 0.368, 0.732, 0.639, 0.396, 0.484, 0.973, 0.965, -5.000, -0.207, 0.540, 0.122, 0.500, 0.523, 0.657, 0.494, 0.027, 0.937, 0.904, 1.154, 0.460, 0.842, 1.079, 0.775, 1.032, 0.546, 0.852, 0.853, 0.020, 0.659, 0.707, 0.247, 0.636, 0.651, 0.593, 0.554, 0.759, 0.723, 0.911, 0.487, 0.627, 0.554, 0.574, 0.801, 0.282, -0.012, 0.027, -0.214, 0.104, 0.799, 0.597, 0.875, 0.742, 0.373, 0.744, 0.405, -5.000, -0.248, 0.138, -0.551, -5.000, 0.223, 0.668, 0.269, 0.466, 0.047, 0.593, 0.648, 0.687, 0.683, 1.045, 0.557, -5.000, -0.238, 0.436, -0.292, 0.477, 0.384, 0.530, 0.616, 0.442, 0.808, 0.834, 0.827, 0.688, 0.526, 0.510, 0.012, 0.543, 0.388, 0.378, 0.204, -0.320, 0.607, 0.347, -0.183, -0.262, 0.408, -0.020, -0.225, 0.355, 0.344, 0.376, 0.184, 0.620, 0.360, 0.230, 0.368, -0.270, 0.476, 0.304, 0.160, 0.088, 0.541, -0.059, -0.258, 0.033, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.537, -0.521, -1.229, -5.000, -1.087, -1.202, -1.242, -5.000, -0.908, -0.752, -0.983, -0.799, -0.515, -0.498, -0.457, -0.520, -0.741, -0.324, -0.294, -5.000, -0.858, -0.579, -0.990, -0.815, -0.860, -0.853, -1.047, -1.021, -0.148, -0.322, -0.316, -0.423, -0.596, 0.036, -0.669, -0.421, -0.899, -0.510, -0.666, -0.956, -0.758, -0.586, -0.890, -0.937, -0.534, -0.390, -0.320, -0.336, -0.462, -0.765, -0.953, -1.453, -1.016, -0.778, -1.420, -1.153, 0.384, -0.047, -0.585, -0.614, -0.340, -0.440, -0.352, -0.296, 0.596, 0.819, -0.135, -5.000, -0.651, 0.049, -0.934, -5.000, -0.662, -0.647, -0.849, -0.995, 0.126, 0.471, 0.503, 0.497, 0.246, 0.798, 0.903, -5.000, -0.453, 0.281, -0.435, 0.230, 0.010, 0.238, 0.018, -0.237, 0.848, 0.608, 0.904, 0.304, 0.160, 0.428, 0.129, 0.222, -0.099, 0.135, -0.090, -0.559, 0.395, 0.396, -0.257, -0.131, 0.241, 0.322, 0.664, -0.081, -0.277, -0.231, -0.737, -0.587, -0.402, -0.141, -0.373, -0.788, -0.981, -1.611, -0.972, -1.207, 0.176, -0.161, 0.508, -0.165, -0.271, 0.029, -0.550, -5.000, -1.238, -0.636, -1.304, -5.000, -0.499, -0.698, -0.896, -0.903, -0.877, -0.612, -0.614, -0.483, -0.521, 0.130, -0.251, -5.000, -1.142, -0.598, -0.958, -0.830, -0.295, -0.497, -0.886, -0.906, -0.230, -0.016, -0.074, -0.265, -0.297, -0.191, -0.588, -0.486, -0.519, -0.591, -0.728, -1.029, -0.104, -0.367, -0.801, -0.574, -0.315, -0.543, -0.572, -0.466, -0.504, -0.124, -0.953, -0.878, -0.823, -0.846, -0.892, -1.093, -1.413, -1.217, -1.828, -1.583, -0.569, -0.909, -1.308, -0.774, 0.028, 0.336, -0.534, -5.000, -0.972, -0.729, -1.404, -5.000, -0.567, -0.205, -0.822, -0.576, -0.703, 0.059, -0.199, -0.236, -0.145, 0.672, 0.637, -5.000, -1.104, -0.837, -1.202, -0.621, -0.638, -0.407, 0.003, -0.464, 0.432, 0.524, 0.838, 0.285, 0.348, 0.767, 0.224, 0.274, -0.140, 0.207, -0.342, -0.931, 0.315, 0.351, 0.022, -0.100, 0.201, 0.257, -0.012, 0.349, -0.476, -0.690, -0.714, -0.900, -0.385, -0.252, -0.666, -1.066, -0.574, -1.083, -0.466, -0.803, -0.259, -0.527, -0.765, -0.565, 0.231, 0.515, -0.061, -5.000, -0.771, -0.138, -0.983, -5.000, -0.405, -0.217, -0.416, -0.617, -0.316, -0.133, 0.044, -0.272, -0.036, 0.558, 0.516, -5.000, -0.447, 0.089, -0.405, 0.012, -0.202, 0.193, -0.069, -0.418, 0.530, 0.573, 0.798, 0.033, 0.299, 0.676, 0.260, 0.509, -0.183, 0.434, 0.069, -0.683, 0.296, 0.282, -0.219, -0.191, 0.167, 0.362, 0.031, 0.054, 0.224, 0.651, 0.341, 0.377, -0.136, 0.334, -0.013, -0.614, -0.275, -0.171, -0.345, -0.677, 0.092, -0.009, -0.046, 0.007, 0.509, 0.889, -0.445, -5.000, -0.678, 0.008, -0.814, -5.000, -1.051, -0.543, -1.250, -0.947, -0.211, 0.073, -0.449, -0.288, 0.348, 0.897, 0.745, -5.000, -0.608, 0.467, -0.040, 0.119, 0.200, 0.417, 0.111, -0.242, 0.660, 0.788, 0.950, -0.176, 0.261, 0.395, -0.274, 0.137, -0.018, 0.246, -0.172, -0.774, 0.325, 0.240, -0.187, -0.223, 0.188, 0.246, 0.020, 0.107, 0.511, 0.818, 0.236, 0.514, 0.098, 0.192, 0.285, -0.454, -0.274, -0.410, -0.827, -0.567, 0.658, 0.238, 0.098, 0.165, 0.008, 0.316, -0.244, -5.000, -1.012, -0.181, -1.054, -5.000, -0.243, -0.324, -0.769, -0.670, -0.679, -0.058, -0.320, -0.371, 0.134, 0.525, 0.337, -5.000, -0.774, 0.380, -0.541, -0.468, 0.289, -0.119, -0.274, -0.469, 0.236, 0.464, 0.739, -0.085, 0.628, 0.865, -0.030, 0.150, 0.156, 0.644, 0.071, -0.465, 0.576, 0.277, -0.187, -0.291, 0.644, 0.368, -0.219, 0.622, 0.409, 0.604, 0.130, 0.197, -0.148, 0.451, 0.204, -0.718, 0.074, 0.182, -0.404, -0.419, 0.506, -0.100, -0.789, -0.442, -0.135, 0.427, -0.566, -5.000, -1.319, -0.491, -1.253, -5.000, -0.828, -0.556, -0.948, -0.849, -0.923, -0.284, -0.586, -0.671, 0.052, 0.722, 0.429, -5.000, -1.116, -0.381, -0.961, -0.417, -0.420, -0.399, -0.331, -0.705, 0.464, 0.563, 0.784, -0.212, 0.145, 0.711, 0.123, 0.398, -0.274, 0.383, -0.056, -0.831, 0.367, 0.450, -0.144, -0.423, 0.174, 0.491, 0.318, 0.290, -0.131, 0.242, -0.139, -0.198, -0.449, 0.361, -0.144, -0.887, -0.644, -0.216, -0.552, -0.639, -0.110, -0.113, -0.366, -0.533, 0.333, 0.753, 0.179, -5.000, -0.514, 0.220, -0.677, -5.000, -0.336, 0.130, -0.075, -0.124, -0.309, 0.039, 0.110, 0.079, 0.252, 0.955, 0.716, -5.000, -0.531, 0.501, -0.213, 0.169, 0.064, 0.670, 0.314, 0.080, 0.657, 0.870, 0.954, 0.095, 0.352, 0.594, 0.001, 0.506, 0.248, 0.842, 0.611, -0.307, 0.731, 0.607, -0.350, 0.035, 0.439, 0.368, -0.363, -0.110, 0.642, 0.962, 0.683, 0.933, 0.321, 0.570, 0.732, -0.239, -0.030, -0.031, -0.380, -0.105, 0.640, 0.151, -0.047, 0.747, 0.803, 1.102, -0.026, -5.000, -0.503, 0.280, -0.529, -5.000, -0.589, -0.098, -0.743, -0.498, -0.081, 0.427, 0.596, 0.304, 0.590, 1.001, 0.972, -5.000, -0.364, 0.802, 0.470, 0.332, 0.544, 0.823, 0.551, 0.440, 0.745, 1.083, 1.165, 0.069, 0.768, 1.048, -0.355, 0.670, 0.454, 0.907, 0.579, -0.128, 0.596, 0.400, -0.345, -0.001, 0.663, 0.302, -0.058, 0.472, 0.632, 1.001, 0.550, 0.832, 0.079, 0.446, 0.420, 0.084, -0.574, -0.674, -0.725, -0.407, 0.772, 0.078, -0.040, 0.633, 0.767, 1.058, 0.549, -5.000, -0.119, 0.836, 0.010, -5.000, 0.427, 0.745, 0.063, 0.511, 0.229, 0.780, 0.549, 0.498, 0.953, 1.245, 0.875, -5.000, -0.052, 0.989, 0.408, 0.654, 1.040, 1.066, 0.813, 0.735, 0.999, 1.217, 1.121, 0.580, 0.939, 1.051, 0.316, 0.750, 0.874, 0.895, 0.690, 0.124, 1.020, 0.751, 0.067, 0.397, 0.776, 0.293, -0.149, 0.683, 0.843, 0.996, 0.584, 0.957, 0.547, 0.800, 0.790, 0.060, 0.518, 0.340, 0.093, 0.279, 0.837, 0.277, -0.268, 0.306, -0.104, 0.425, 0.036, -5.000, -0.906, -0.088, -0.786, -5.000, -0.283, -0.145, -0.447, -0.493, -0.379, 0.031, 0.032, -0.225, 0.054, 0.625, 0.425, -5.000, -0.593, 0.178, -0.286, -0.218, 0.141, 0.335, 0.020, -0.181, 0.466, 0.652, 0.735, -0.014, -0.315, 0.362, -0.016, -0.057, -0.480, 0.170, -0.169, -0.816, 0.076, 0.002, -0.495, -0.716, -0.261, -0.067, -0.111, -0.229, 0.164, 0.546, 0.018, 0.015, -0.477, 0.090, -0.038, -0.775, -0.374, -0.330, -0.716, -0.547, -0.039, -0.490, -0.372, -0.189, 0.427, 0.669, -0.041, -5.000, -0.402, -0.474, -0.880, -5.000, -0.631, -0.409, -0.392, -0.577, -0.260, -0.144, 0.255, -0.122, 0.158, 0.616, 0.570, -5.000, -0.700, -0.196, -0.743, 0.099, -0.302, -0.113, 0.008, -0.291, 0.715, 0.404, 0.780, 0.095, 0.672, 0.864, 0.310, 0.865, 0.410, 0.531, 0.491, -0.482, 0.760, 0.661, -0.019, 0.214, 0.674, 0.633, 0.615, 0.462, 0.631, 0.746, 0.276, 0.628, 0.344, 0.535, 0.579, -0.198, 0.755, 0.653, 0.650, 0.665, 0.690, 0.461, 0.777, 0.663, 0.916, 0.956, 0.075, -5.000, -0.224, 0.098, -0.455, -5.000, -0.232, 0.014, -0.590, -0.175, 0.348, 0.575, 1.032, 0.403, 0.641, 0.898, 0.913, -5.000, -0.452, 0.440, -0.089, 0.897, 0.246, 0.612, 0.545, -0.003, 1.010, 0.805, 1.093, 0.183, 0.748, 0.868, 0.473, 1.041, 0.553, 0.552, 0.659, 0.067, 0.681, 0.701, 0.176, 0.471, 0.793, 0.778, 1.030, 0.816, 0.448, 0.646, 0.231, 0.644, 0.308, 0.295, 0.470, -0.092, 0.038, -0.218, -0.281, -0.042, 0.783, 0.477, 0.945, 0.806, 0.053, 0.429, -0.232, -5.000, -0.492, -0.255, -1.040, -5.000, -0.061, -0.040, -0.358, -0.243, -0.404, -0.046, -0.233, -0.138, 0.075, 0.623, 0.029, -5.000, -0.621, 0.286, -0.825, -0.326, 0.053, -0.040, -0.187, -0.073, 0.467, 0.478, 0.594, 0.195, 0.048, -0.008, -0.463, 0.044, 0.104, 0.063, -0.254, -0.552, 0.248, 0.006, -0.457, -0.390, 0.290, -0.241, -0.611, 0.206, -0.013, 0.147, -0.365, 0.029, -0.091, -0.156, -0.199, -0.761, -0.090, -0.237, -0.512, -0.321, 0.214, -0.316, -0.857, -0.242, 0.362, 0.361, -0.334, -5.000, -1.008, -0.497, -1.128, -5.000, -0.437, -0.627, -0.721, -0.661, -0.229, -0.064, -0.522, -0.416, 0.454, 0.842, 0.468, -5.000, -0.652, -0.605, -1.134, -0.046, -0.313, -0.485, -0.256, -0.581, 0.723, 0.396, 0.723, 0.189, 1.064, 1.139, 0.676, 0.975, 0.874, 0.876, 0.539, 0.054, 1.149, 1.120, 0.512, 0.645, 1.010, 0.862, 0.592, 0.896, 0.313, 0.671, -0.032, 0.328, 0.278, 0.451, 0.155, -0.304, 0.441, 0.421, 0.225, 0.239, 0.426, 0.292, -0.145, 0.012, 0.233, 0.345, -0.032, -5.000, -0.977, -0.630, -1.294, -5.000, -0.766, -0.399, -0.216, -0.601, -0.196, -0.123, 0.371, 0.061, -0.070, 0.699, 0.608, -5.000, -0.651, -0.231, -0.912, 0.120, -0.513, -0.389, -0.554, -0.720, 0.740, 0.413, 0.831, 0.048, 0.222, 0.778, 0.120, 0.465, -0.260, 0.346, 0.036, -0.699, -0.040, 0.088, -0.670, -0.656, 0.136, 0.462, 0.686, 0.165, 0.099, 0.105, -0.196, 0.066, -0.067, 0.087, 0.003, -0.490, -0.070, 0.027, -0.532, 0.513, 0.434, 0.175, 0.532, 0.384, 0.714, 0.924, -0.063, -5.000, -0.640, -0.153, -1.064, -5.000, -0.628, -0.507, -0.629, -0.688, 0.193, 0.469, 0.676, 0.831, 0.509, 0.983, 0.779, -5.000, -0.679, -0.068, -0.383, 0.333, -0.069, 0.278, 0.149, -0.222, 1.043, 0.685, 1.026, 0.432, 0.673, 0.714, 0.359, 0.661, 0.384, 0.388, 0.324, -0.420, 0.591, 0.502, -0.005, 0.261, 0.702, 0.613, 0.940, 0.569, 0.235, 0.334, 0.047, 0.351, -0.136, -0.027, 0.079, -0.409, -0.689, -0.762, -0.619, -0.618, 0.943, 0.412, 1.101, 0.752, 0.148, 0.595, -0.158, -5.000, -1.068, -0.094, -0.916, -5.000, -0.453, -0.084, -0.736, -0.458, -0.420, 0.129, -0.039, -0.093, 0.077, 0.737, 0.152, -5.000, -0.797, 0.164, -0.583, -0.383, 0.142, 0.118, -0.098, -0.151, 0.327, 0.656, 0.762, 0.135, 0.436, 0.617, -0.358, 0.086, 0.118, 0.161, -0.156, -0.714, 0.395, 0.189, -0.586, -0.267, 0.589, -0.344, -0.385, 0.477, -0.036, 0.145, -0.437, 0.068, -0.339, -0.159, -0.072, -0.979, -0.310, -0.339, -1.182, -0.681, 0.386, -0.397, -0.903, -0.208, -0.628, -0.485, -0.864, -5.000, -1.298, -1.300, -1.456, -5.000, -1.031, -0.961, -1.080, -1.178, -0.762, -0.661, -1.190, -0.719, -0.354, 0.235, -0.024, -5.000, -1.167, -0.790, -1.211, -0.824, -0.867, -0.926, -0.849, -1.130, 0.083, 0.144, 0.469, -0.031, -0.333, 0.054, -0.245, -0.237, -0.770, -0.283, -0.696, -1.051, -0.464, -0.365, -0.777, -0.715, -0.342, -0.295, -0.258, -0.220, -0.628, -0.948, -0.776, -0.882, -0.725, -0.660, -0.843, -1.044, -0.418, -0.951, -0.983, -0.900, -0.476, -0.796, -0.790, -0.602, 0.639, 0.844, 0.318, -5.000, -0.459, 0.324, -0.563, -5.000, -0.326, 0.026, -0.037, -0.502, -0.179, 0.073, 0.117, 0.052, 0.138, 0.814, 0.598, -5.000, -0.231, 0.163, -0.113, 0.659, -0.013, 0.298, 0.213, -0.449, 0.789, 0.800, 0.907, 0.094, 0.495, 0.803, 0.347, 0.881, -0.061, 0.563, 0.266, -0.400, 0.512, 0.480, -0.016, -0.029, 0.429, 0.665, 0.456, 0.348, 0.498, 0.883, 0.471, 0.944, 0.104, 0.517, 0.513, -0.223, 0.093, 0.196, 0.002, 0.085, 0.650, 0.271, 0.194, 0.572, 0.544, 0.835, -0.201, -5.000, -0.415, 0.309, -0.304, -5.000, -0.839, -0.271, -0.883, -0.707, 0.069, -0.024, 0.149, 0.055, 0.261, 0.825, 0.519, -5.000, -0.517, 0.292, -0.198, 0.201, 0.057, 0.279, 0.056, -0.392, 0.562, 0.652, 0.834, -0.180, 0.397, 0.446, -0.098, 0.280, 0.062, 0.417, 0.234, -0.496, 0.370, 0.401, -0.047, -0.160, 0.485, 0.423, 0.419, 0.319, 0.503, 0.740, 0.122, 0.720, 0.025, 0.388, 0.238, -0.338, -0.109, -0.160, -0.392, -0.295, 0.914, 0.435, 0.524, 0.674, 0.006, 0.236, -0.430, -5.000, -1.096, -0.555, -1.076, -5.000, -0.696, -0.480, -1.080, -0.704, -0.628, -0.227, -0.253, -0.259, -0.136, 0.339, -0.183, -5.000, -0.658, -0.787, -0.812, -0.716, -0.302, -0.512, -0.554, -0.662, -0.066, 0.440, 0.310, -0.264, 0.082, 0.230, -0.203, -0.006, -0.462, 0.097, -0.282, -0.846, 0.244, 0.023, -0.273, -0.252, 0.287, 0.113, -0.276, 0.066, 0.028, 0.061, -0.241, -0.028, -0.557, -0.116, -0.274, -0.694, -0.259, -0.165, -0.484, -0.578, 0.178, -0.167, -0.345, -0.325, -0.031, 0.494, -0.447, -5.000, -1.235, -0.823, -1.372, -5.000, -0.726, -0.676, -0.836, -0.671, -0.636, -0.365, -0.563, -0.526, 0.096, 0.484, 0.225, -5.000, -0.228, -0.498, -1.025, -0.051, -0.299, -0.332, -0.307, -0.603, 0.470, 0.406, 0.507, -0.053, 0.289, 0.497, 0.065, 0.134, -0.415, 0.164, -0.121, -0.567, 0.536, 0.429, 0.059, 0.029, 0.447, 0.549, 0.533, 0.335, -0.336, 0.247, -0.455, -0.306, -0.411, 0.181, -0.212, -0.933, -0.608, -0.325, -0.328, -0.644, -0.002, 0.021, 0.123, -0.266, 0.474, 0.696, 0.331, -5.000, -0.500, -0.102, -0.492, -5.000, -0.612, -0.194, -0.304, -0.485, -0.320, -0.186, 0.137, -0.132, 0.443, 0.912, 0.633, -5.000, -0.730, 0.376, -0.224, 0.178, -0.128, 0.376, 0.112, -0.158, 0.917, 1.084, 1.237, 0.264, 0.395, 0.497, 0.159, 0.566, 0.142, 0.613, 0.392, -0.256, 0.539, 0.493, -0.148, -0.135, 0.282, 0.249, -0.022, -0.060, 0.526, 0.860, 0.593, 0.967, 0.171, 0.490, 0.646, 0.052, 0.285, 0.327, -0.171, -0.175, 0.698, 0.410, 0.327, 0.618, 0.496, 0.754, -0.168, -5.000, -0.557, 0.044, -0.667, -5.000, -0.300, -0.205, -0.506, -0.262, 0.007, 0.041, 0.488, 0.295, 0.501, 0.663, 0.469, -5.000, -0.289, 0.517, -0.144, 0.291, 0.251, 0.383, 0.311, -0.005, 0.540, 0.795, 0.853, 0.072, 0.589, 0.587, 0.274, 0.555, 0.036, 0.476, 0.249, -0.333, 0.287, 0.186, -0.134, 0.050, 0.653, 0.180, -0.126, 0.273, 0.413, 0.650, 0.180, 0.711, 0.095, 0.144, 0.040, -0.237, -0.367, -0.409, -0.321, -0.352, 0.867, 0.293, 0.285, 0.677, 0.294, 0.314, 0.085, -5.000, -0.406, -0.067, -0.415, -5.000, -0.123, 0.222, -0.350, -0.123, 0.048, 0.043, 0.087, 0.128, 0.261, 0.123, 0.166, -5.000, -0.541, -0.118, -0.369, -0.245, 0.417, 0.268, 0.120, -0.055, 0.532, 0.615, 0.484, 0.285, 0.594, 0.491, -0.158, 0.433, 0.374, 0.187, 0.094, -0.408, 0.712, 0.201, -0.122, 0.025, 0.742, 0.165, -0.226, 0.716, 0.353, 0.512, 0.097, 0.381, 0.107, 0.034, 0.096, -0.540, -0.108, -0.233, -0.287, -0.233, 0.396, -0.142, -0.554, 0.061, 0.305, 0.645, 0.120, -5.000, -0.514, 0.090, -0.356, -5.000, -0.177, 0.022, -0.412, -0.165, -0.299, 0.025, -0.299, -0.320, 0.453, 0.936, 0.487, -5.000, -0.365, -0.067, -0.467, 0.326, 0.223, 0.225, 0.418, -0.008, 0.669, 0.787, 0.871, 0.197, 0.690, 0.759, 0.303, 0.638, 0.539, 0.515, 0.407, -0.087, 0.663, 0.425, -0.000, 0.182, 0.433, 0.431, -0.174, 0.533, 0.180, 0.522, 0.190, 0.229, 0.074, 0.377, 0.293, -0.669, 0.098, 0.094, -0.180, -0.311, 0.223, -0.094, -0.135, -0.012, 0.255, 0.369, -0.145, -5.000, -0.356, -0.312, -0.925, -5.000, -0.338, -0.440, -0.271, -0.408, -0.156, -0.112, 0.117, 0.060, 0.371, 0.512, 0.334, -5.000, -0.320, 0.010, -0.646, 0.290, -0.163, 0.105, 0.170, -0.082, 0.595, 0.577, 0.756, 0.264, 0.509, 0.563, 0.144, 0.591, 0.407, 0.238, 0.374, -0.143, 0.654, 0.489, 0.266, 0.375, 0.518, 0.610, 0.498, 0.315, 0.342, 0.415, 0.032, 0.326, 0.278, 0.384, 0.385, -0.245, 0.488, 0.477, 0.700, 0.400, 0.446, 0.273, 0.607, 0.441, 0.759, 0.786, -0.218, -5.000, -0.400, -0.139, -1.057, -5.000, -0.301, -0.328, -0.848, -0.444, 0.410, 0.454, 0.518, 0.587, 0.585, 0.664, 0.694, -5.000, -0.167, 0.210, -0.237, 0.731, 0.357, 0.379, 0.517, 0.256, 0.990, 0.730, 1.000, 0.473, 0.739, 0.596, 0.339, 0.795, 0.595, 0.258, 0.597, 0.005, 0.777, 0.694, 0.197, 0.502, 0.813, 0.656, 0.803, 0.651, 0.430, 0.358, 0.010, 0.403, 0.235, -0.040, 0.306, -0.158, -0.139, -0.464, -0.469, -0.136, 0.754, 0.452, 0.796, 0.598, 0.048, 0.380, -0.147, -5.000, -0.626, -0.283, -1.086, -5.000, -0.521, -0.119, -0.742, -0.368, -0.209, -0.000, -0.100, 0.055, 0.181, 0.426, 0.069, -5.000, -0.821, -0.217, -0.915, -0.407, -0.018, -0.209, -0.172, -0.259, 0.507, 0.499, 0.580, 0.236, 0.058, -0.006, -0.318, -0.047, 0.039, -0.108, -0.204, -0.696, 0.416, 0.102, -0.226, -0.139, 0.189, -0.013, -0.456, 0.203, 0.098, 0.150, -0.327, -0.154, -0.038, -0.176, -0.112, -0.622, -0.141, -0.204, -0.340, -0.425, 0.172, -0.190, -0.561, -0.251, 0.225, 0.185, -0.528, -5.000, -0.930, -0.872, -1.450, -5.000, -0.996, -0.796, -1.424, -0.700, -0.361, -0.084, -0.475, -0.244, 0.240, 0.624, 0.451, -5.000, -0.895, -0.629, -1.107, 0.001, -0.437, -0.758, -0.137, -0.649, 0.835, 0.866, 0.906, 0.341, 0.882, 0.993, 0.567, 0.767, 0.823, 0.816, 0.652, 0.075, 1.149, 1.264, 0.825, 0.664, 0.957, 1.043, 0.955, 0.886, 0.205, 0.262, -0.229, 0.004, 0.161, 0.257, 0.188, -0.554, 0.157, 0.303, 0.258, 0.092, 0.305, 0.069, -0.286, -0.033, 0.069, 0.184, -0.418, -5.000, -1.036, -0.977, -1.199, -5.000, -0.391, -0.436, -0.060, -0.424, -0.167, -0.150, 0.221, 0.054, -0.141, 0.437, 0.216, -5.000, -0.751, -0.419, -0.689, -0.103, -0.451, -0.510, -0.617, -1.064, 0.465, 0.264, 0.577, 0.036, 0.234, 0.706, 0.204, 0.347, -0.220, 0.232, -0.006, -0.993, -0.004, 0.026, -0.810, -0.453, 0.215, 0.389, 0.520, 0.149, -0.118, -0.254, -0.222, -0.286, -0.125, -0.225, -0.579, -0.849, -0.355, 0.038, 0.027, -0.219, 0.217, -0.054, 0.379, 0.184, 0.384, 0.494, -0.395, -5.000, -0.393, -0.205, -1.071, -5.000, -0.682, -0.422, -0.968, -0.607, 0.233, 0.241, 0.935, 0.680, 0.161, 0.463, 0.317, -5.000, -0.668, -0.269, -0.530, -0.034, -0.045, 0.206, -0.016, -0.104, 0.678, 0.697, 0.748, 0.444, 0.523, 0.500, 0.099, 0.491, 0.321, 0.200, 0.142, -0.627, 0.532, 0.387, -0.200, 0.273, 0.609, 0.488, 0.599, 0.411, 0.107, 0.161, -0.284, 0.231, -0.211, -0.318, -0.154, -0.581, -0.924, -0.996, -1.082, -0.777, 0.766, 0.142, 0.604, 0.669, 0.248, 0.515, -0.244, -5.000, -0.823, -0.376, -0.949, -5.000, -0.391, -0.146, -0.707, -0.145, -0.259, 0.318, -0.112, 0.120, 0.118, 0.689, 0.080, -5.000, -0.765, 0.169, -0.583, -0.349, 0.275, 0.302, 0.020, 0.011, 0.595, 0.840, 0.902, 0.409, 0.368, 0.470, -0.388, 0.002, 0.226, 0.148, -0.183, -0.775, 0.544, 0.224, -0.533, -0.356, 0.585, -0.017, -0.503, 0.496, 0.071, 0.044, -0.463, -0.042, -0.167, 0.145, 0.186, -0.777, 0.047, -0.162, -0.545, -0.452, 0.535, -0.150, -0.761, -0.095, -0.457, -0.284, -0.957, -5.000, -1.235, -0.974, -1.679, -5.000, -1.144, -0.941, -1.188, -0.958, -0.567, -0.449, -1.030, -0.518, -0.400, 0.246, -0.091, -5.000, -1.053, -0.914, -1.458, -0.858, -0.846, -0.892, -0.948, -1.236, 0.233, 0.229, 0.382, -0.014, -0.254, 0.063, -0.522, -0.232, -0.712, -0.216, -0.858, -1.167, -0.114, -0.038, -0.697, -0.507, -0.306, -0.063, -0.099, -0.228, -0.688, -0.777, -0.880, -0.877, -0.966, -0.742, -0.789, -0.978, -0.434, -0.677, -1.001, -0.971, -0.242, -0.924, -0.779, -0.697, -0.177, 0.030, -0.540, -5.000, -1.187, -0.916, -1.635, -5.000, -0.576, -0.652, -0.770, -0.574, -0.325, -0.574, -0.555, -0.175, -0.314, 0.063, 0.044, -5.000, -0.740, 0.149, -1.065, -0.443, -0.493, -0.318, -0.257, -0.513, 0.269, 0.507, 0.420, -0.064, -0.041, 0.164, -0.102, 0.251, -0.398, 0.040, -0.343, -0.663, 0.140, -0.056, -0.501, -0.551, 0.150, 0.126, 0.105, -0.194, 0.065, 0.085, -0.280, 0.056, -0.489, -0.241, -0.299, -0.809, -0.464, -0.430, -0.301, -0.082, 0.225, -0.245, -0.194, 0.104, -0.174, 0.151, -0.996, -5.000, -1.317, -1.016, -1.501, -5.000, -1.344, -1.244, -1.354, -1.194, -0.175, -0.580, 0.103, -0.069, 0.007, 0.373, 0.129, -5.000, -0.737, -0.076, -0.608, -0.291, -0.229, -0.221, -0.402, -0.553, 0.264, 0.349, 0.350, -0.115, -0.281, -0.258, -0.680, -0.310, -0.386, -0.546, -0.557, -1.089, 0.055, -0.212, -0.385, -0.424, 0.149, -0.059, -0.060, -0.051, 0.025, 0.062, -0.308, -0.095, -0.358, -0.479, -0.553, -0.904, -0.975, -1.050, -1.013, -0.784, 0.477, 0.012, 0.100, 0.154, -0.245, -0.124, -0.815, -5.000, -0.674, -0.675, -1.579, -5.000, -0.746, -0.723, -1.204, -0.752, -0.591, -0.418, -0.370, -0.318, -0.471, 0.008, -0.330, -5.000, -0.999, -0.349, -1.098, -0.961, -0.467, -0.779, -0.853, -1.033, -0.063, 0.146, 0.215, -0.115, -0.257, 0.083, -0.831, -0.455, -0.358, -0.118, -0.721, -1.393, 0.049, -0.328, -0.474, -0.627, 0.194, 0.013, -0.507, -0.060, -0.092, -0.470, -0.324, -0.348, -0.433, 0.003, -0.293, -0.999, -0.214, -0.387, -0.443, -0.652, 0.097, -0.238, -0.959, -0.638, -0.156, 0.019, -0.942, -5.000, -1.101, -1.233, -1.809, -5.000, -0.693, -0.876, -1.205, -0.929, -0.762, -0.425, -0.902, -0.652, 0.146, 0.273, 0.077, -5.000, -1.075, -0.587, -1.450, -0.642, -0.474, -0.821, -0.759, -0.905, 0.317, 0.209, 0.427, -0.195, -0.042, 0.211, -0.285, -0.096, -0.653, -0.158, -0.609, -0.877, 0.127, 0.325, -0.132, -0.294, 0.108, 0.428, 0.221, 0.191, -0.238, -0.043, -0.665, -0.461, -0.614, -0.050, -0.451, -1.225, -0.381, -0.473, -0.426, -0.599, -0.071, -0.204, -0.455, -0.523, 0.468, 0.654, 0.080, -5.000, -0.332, -0.036, -0.448, -5.000, -0.209, -0.034, -0.155, -0.138, -0.065, -0.138, -0.048, 0.148, 0.349, 0.858, 0.508, -5.000, -0.365, 0.368, -0.268, 0.287, 0.245, 0.751, 0.475, 0.357, 0.627, 0.957, 0.968, 0.330, 0.491, 0.606, 0.203, 0.426, 0.414, 0.634, 0.457, -0.054, 0.742, 0.543, -0.010, 0.193, 0.458, 0.452, -0.102, 0.017, 0.524, 0.725, 0.343, 0.519, 0.330, 0.452, 0.583, -0.035, 0.363, 0.334, 0.034, 0.177, 0.632, 0.260, 0.254, 0.597, 0.248, 0.379, -0.301, -5.000, -0.675, -0.541, -1.010, -5.000, -0.699, -0.824, -0.990, -0.810, -0.166, -0.204, 0.265, 0.247, 0.206, 0.477, 0.388, -5.000, -0.423, 0.175, -0.261, 0.019, 0.109, 0.088, 0.219, -0.128, 0.444, 0.637, 0.586, 0.047, 0.237, 0.247, -0.015, 0.223, -0.050, 0.131, -0.012, -0.613, 0.284, 0.015, -0.311, 0.034, 0.407, 0.052, -0.134, 0.238, 0.173, 0.248, -0.058, 0.192, -0.293, -0.222, -0.296, -0.337, -0.626, -1.029, -0.739, -0.606, 0.527, 0.028, -0.025, 0.452, 0.162, 0.279, -0.261, -5.000, -0.471, -0.433, -0.757, -5.000, -0.307, -0.440, -0.948, -0.633, -0.163, -0.033, -0.112, 0.086, 0.264, 0.594, 0.193, -5.000, -0.694, -0.067, -0.572, -0.238, 0.285, -0.083, -0.235, -0.342, 0.464, 0.367, 0.429, 0.172, 0.160, -0.020, -0.358, -0.097, -0.059, 0.005, -0.284, -0.780, 0.416, -0.180, -0.661, -0.263, 0.378, -0.111, -0.264, 0.351, 0.199, 0.162, -0.143, 0.141, -0.093, -0.002, -0.040, -0.546, -0.301, -0.451, -1.001, -0.791, 0.238, -0.452, -0.809, -0.113, 0.144, 0.422, -0.252, -5.000, -0.659, -0.060, -0.878, -5.000, -0.232, 0.050, -0.446, -0.225, -0.137, 0.293, -0.225, -0.163, 0.401, 0.784, 0.536, -5.000, -0.683, -0.180, -0.673, -0.019, 0.089, 0.185, 0.184, -0.127, 0.672, 0.886, 0.959, 0.303, 0.515, 0.648, 0.149, 0.305, 0.315, 0.454, 0.267, -0.294, 0.658, 0.518, 0.079, 0.037, 0.352, 0.379, -0.188, 0.435, 0.101, 0.361, -0.032, -0.122, -0.012, 0.233, 0.165, -0.446, -0.077, -0.001, -0.261, -0.301, 0.010, -0.270, -0.346, -0.209 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_6(struct _training *tptr) {
  struct _training tinf = {
    0.427, 11, 4.350, { 2.507, 0.163, 0.330 }, { 0.959, -1.154, -2.229 }, 1, 
    { -0.968, -1.027, -0.652, -0.275, -0.711, 0.349, -0.011, -4.000, 0.053, 0.176, -0.482, -4.000, 0.560, 0.555, 0.004, 1.918, 2.138, 0.548, 1.349, 0.145, 1.012, 1.730, 3.083, 1.339, 2.034, 0.646, 2.062, 2.231 }, 
    {{ 0.116, -0.372, 0.125, 0.009},{ -0.050, -0.595, 0.254, 0.155},{ 0.216, -0.073, -0.333, 0.022},{ 0.220, -0.196, -0.321, 0.088},{ 0.285, -0.147, -0.268, -0.055},{ 0.205, -0.109, -0.337, 0.061},{ 0.220, -0.359, -0.154, 0.081},{ 0.170, -0.150, -0.219, 0.063},{ 0.149, -0.189, -0.312, 0.155},{ 0.166, -0.230, -0.189, 0.096},{ 0.177, -0.182, -0.164, 0.042},{ 0.168, -0.211, -0.136, 0.052},{ 0.108, -0.083, -0.237, 0.098},{ 0.108, -0.103, -0.103, 0.031},{ 0.096, -0.150, -0.164, 0.110},{ 0.120, -0.116, -0.204, 0.088},{ 0.061, -0.057, -0.154, 0.081},{ 0.137, -0.175, -0.129, 0.061},{ 0.059, -0.119, -0.200, 0.147},{ 0.018, 0.090, -0.222, 0.059},{ 0.075, 0.005, -0.245, 0.077},{ 0.035, -0.023, -0.234, 0.128},{ 0.077, -0.014, -0.113, 0.009},{ -0.002, -0.001, -0.004, 0.007},{ 0.102, -0.083, -0.143, 0.050},{ 0.139, -0.041, -0.106, -0.046},{ 0.059, -0.076, -0.035, 0.020},{ 0.086, -0.147, -0.109, 0.086},{ 0.029, 0.082, -0.063, -0.048},{ 0.026, -0.080, 0.054, -0.011},{ 0.088, 0.088, -0.161, -0.050},{ 0.086, 0.062, -0.208, 0.002} }, 
    {{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}} }, 
    0.000, { 0.400, 0.930, 0.495, -5.000, -0.562, 0.412, 0.010, -5.000, -0.011, 0.515, -0.236, -0.310, -0.147, 0.348, -0.062, 0.577, -0.100, 0.589, 0.019, -5.000, -0.865, 0.312, -0.783, -0.124, 0.087, 0.452, -0.127, -0.359, 0.528, 0.506, -0.173, 0.102, -0.317, 0.517, -0.118, -0.026, -0.234, 0.343, -0.004, -1.138, 0.066, 0.425, 0.122, -0.264, 0.057, 0.688, 0.293, -0.377, 0.208, 0.799, 0.071, 0.464, 0.203, 0.569, 0.224, -0.431, 0.380, 0.632, 0.606, 0.017, 0.530, 0.495, 0.654, 0.218, 1.048, 1.402, 1.210, -5.000, 0.118, 0.811, 0.811, -5.000, 0.783, 0.957, 0.777, 0.496, 0.622, 1.132, 0.870, 1.232, 0.353, 0.983, 0.578, -5.000, -0.461, 0.443, 0.130, 0.326, 0.801, 0.808, 0.744, 0.335, 0.832, 0.982, 0.679, 0.793, 0.533, 0.952, 0.478, 0.749, 0.343, 0.762, 0.603, -0.190, 0.872, 0.894, 0.826, 0.544, 0.788, 0.848, 0.745, 0.076, 0.761, 1.087, 0.562, 0.921, 0.621, 0.876, 0.813, 0.198, 0.889, 1.142, 0.997, 0.727, 1.019, 0.760, 0.693, 0.777, 0.622, 1.186, 0.735, -5.000, -0.205, 0.572, 0.189, -5.000, 0.243, 0.568, -0.069, 0.280, -0.044, 0.388, 0.231, 0.916, 0.155, 0.765, 0.447, -5.000, -0.923, 0.309, -0.347, 0.148, 0.315, 0.642, 0.270, -0.014, 0.595, 0.670, 0.298, 0.546, 0.106, 0.554, -0.055, 0.221, -0.121, 0.352, 0.150, -0.612, 0.249, 0.378, 0.111, -0.149, 0.077, 0.531, 0.175, -0.322, 0.511, 0.884, 0.239, 0.573, 0.471, 0.671, 0.465, 0.132, 0.766, 0.804, 0.665, 0.455, 0.756, 0.541, 0.002, 0.132, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.659, 0.034, -0.639, -5.000, -1.343, -0.769, -1.263, -5.000, -1.265, -0.814, -0.701, -1.338, -0.567, -0.127, -0.521, -0.058, -0.896, -0.263, -0.567, -5.000, -0.663, -0.870, -1.074, -0.895, -0.260, -0.706, -1.016, -1.128, -0.278, -0.028, -0.667, -0.381, -0.844, -0.311, -1.594, -1.000, -1.250, -0.630, -1.112, -1.507, -1.077, -0.589, -0.597, -1.053, -1.091, -0.418, -0.675, -1.008, -0.375, 0.048, -0.017, -0.491, -0.665, -0.237, -1.035, -1.585, -0.483, -0.143, -0.419, -0.795, -0.415, -0.492, -0.303, -0.639, 0.470, 0.899, 0.679, -5.000, -0.464, 0.265, 0.007, -5.000, 0.416, 0.512, 0.125, -0.189, 0.146, 0.732, 0.674, 0.917, -0.055, 0.341, 0.293, -5.000, -0.605, 0.201, -0.331, -0.115, 0.201, 0.339, 0.028, -0.072, 0.471, 0.766, 0.224, 0.374, -0.144, 0.327, -0.026, 0.429, -0.168, 0.510, 0.237, -0.766, -0.009, 0.399, 0.143, -0.243, 0.257, 0.113, 0.309, -0.465, -0.135, 0.371, -0.144, 0.388, -0.159, 0.068, -0.342, -0.067, -0.293, 0.163, 0.026, -0.318, 0.131, -0.305, -0.253, -0.009, -0.028, 0.535, 0.059, -5.000, -0.616, -0.060, -0.370, -5.000, -0.243, -0.017, -1.030, -0.401, -0.550, -0.268, -0.607, -0.111, -0.387, 0.106, -0.221, -5.000, -1.393, -0.374, -0.796, -0.519, -0.240, 0.018, -0.391, -0.658, 0.058, 0.279, -0.114, 0.241, -0.551, 0.080, -0.601, -0.443, -0.565, 0.088, -0.722, -0.988, -0.429, -0.185, -0.722, -0.917, -0.097, -0.112, -0.511, -0.783, -0.175, 0.375, -0.377, -0.039, -0.325, 0.301, -0.117, -1.073, -0.099, 0.169, -0.065, -0.396, 0.196, 0.023, -0.239, -0.157, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.138, 0.625, 0.138, -5.000, -0.847, 0.048, -0.340, -5.000, -0.682, -0.283, -0.782, -0.548, -0.581, -0.239, -0.466, 0.353, -0.232, 0.183, -0.063, -5.000, -1.277, 0.003, -0.513, -0.098, -0.026, -0.001, -0.476, -0.854, 0.346, 0.474, -0.255, -0.187, -0.505, 0.320, -0.375, 0.161, -0.295, 0.278, -0.317, -1.168, -0.312, -0.163, -0.188, -0.676, -0.256, 0.112, -0.120, -0.545, -0.154, 0.382, -0.271, 0.190, -0.255, 0.223, -0.530, -0.557, -0.232, 0.177, -0.070, -0.312, -0.038, -0.073, -0.500, -0.220, 0.474, 0.864, 0.626, -5.000, -0.727, 0.214, -0.201, -5.000, 0.087, 0.159, -0.272, -0.632, -0.166, 0.542, 0.288, 0.701, -0.186, 0.530, 0.269, -5.000, -0.910, 0.134, -0.303, -0.167, 0.075, 0.083, -0.202, -0.487, 0.177, 0.555, -0.058, -0.014, -0.175, 0.094, -0.421, 0.018, -0.501, 0.239, -0.440, -1.198, 0.010, 0.046, -0.518, -0.232, -0.003, 0.078, -0.257, -0.690, 0.319, 0.652, 0.061, 0.674, 0.087, 0.268, -0.024, -0.276, -0.095, 0.218, 0.081, -0.145, 0.496, 0.183, -0.281, -0.008, -0.251, -0.000, -0.538, -5.000, -0.782, -0.372, -0.869, -5.000, -0.451, -0.480, -0.916, -1.149, -1.086, -0.323, -0.431, -0.384, -0.768, 0.120, -0.396, -5.000, -1.250, -0.483, -1.514, -0.873, -0.410, -0.571, -0.846, -0.799, 0.029, 0.075, -0.304, -0.180, -0.638, 0.363, -0.797, -0.642, -0.745, -0.371, -0.990, -1.341, -0.490, -0.649, -0.695, -1.102, -0.640, -0.632, -0.542, -0.858, -0.174, 0.280, -0.604, -0.551, -0.399, -0.303, -0.646, -1.054, -0.310, -0.412, -0.366, -0.258, -0.050, -0.189, -1.064, -0.638, -0.290, 0.114, -0.287, -5.000, -1.470, -0.752, -1.338, -5.000, -1.076, -0.601, -1.210, -1.250, -0.848, -0.650, -0.441, -0.315, -0.602, 0.037, -0.367, -5.000, -1.203, -0.527, -1.613, -0.673, -0.985, -0.691, -1.003, -1.040, -0.242, -0.249, -0.642, 0.105, -1.000, -0.342, -0.915, -0.959, -0.578, -0.157, -0.748, -1.369, -0.153, -0.262, 0.059, -0.846, -0.266, -0.348, -0.174, -0.797, -0.495, -0.099, -0.442, -0.352, -0.349, -0.055, -0.503, -0.974, -0.154, -0.004, -0.179, -0.749, -0.137, -0.115, -0.175, -0.317, -0.074, 0.463, -0.036, -5.000, -0.766, -0.136, -0.681, -5.000, -0.724, -0.827, -1.076, -1.028, -0.887, -0.662, -0.701, -0.187, -0.249, 0.041, -0.208, -5.000, -0.917, -0.410, -0.906, -0.421, -0.642, -0.139, -0.714, -0.850, -0.203, -0.222, -0.742, -0.591, -0.413, -0.188, -0.305, -0.719, -0.400, -0.231, -0.662, -1.379, -0.336, -0.131, -0.657, -0.799, -0.697, 0.016, -0.572, -0.964, -0.015, 0.308, -0.221, 0.148, -0.169, -0.340, -0.449, -0.731, 0.095, 0.085, -0.069, -0.092, -0.091, -0.234, -0.311, -0.317, 0.526, 0.889, 0.581, -5.000, -0.368, 0.122, 0.074, -5.000, 0.145, 0.146, -0.633, -0.449, -0.144, 0.504, 0.173, 0.643, -0.366, 0.258, 0.023, -5.000, -0.837, 0.015, 0.171, -0.154, 0.353, 0.397, 0.063, -0.306, 0.265, 0.377, 0.024, 0.155, 0.008, 0.305, 0.002, 0.271, -0.380, 0.261, -0.153, -0.589, 0.444, 0.403, -0.088, -0.235, -0.109, 0.002, -0.253, -0.315, 0.286, 0.793, 0.526, 0.826, 0.184, 0.246, -0.037, -0.268, 0.197, 0.307, 0.310, -0.218, 0.442, 0.138, -0.323, -0.031, 0.220, 0.654, 0.589, -5.000, -0.566, 0.160, -0.248, -5.000, 0.126, 0.050, -0.590, -0.554, -0.129, 0.244, -0.520, 0.161, -0.234, 0.358, 0.108, -5.000, -0.615, 0.345, -0.607, -0.414, 0.300, 0.289, -0.515, -0.516, 0.478, 0.367, -0.332, 0.060, -0.188, 0.309, -0.521, -0.412, -0.386, 0.063, -0.839, -0.882, 0.138, 0.183, -0.615, -0.465, -0.165, -0.146, -0.362, -0.786, 0.101, 0.385, -0.239, -0.118, 0.150, 0.080, -0.071, -0.487, 0.025, 0.078, -0.184, -0.251, 0.211, -0.062, -0.561, -0.348, 0.552, 1.108, 0.936, -5.000, -0.361, 0.681, 0.273, -5.000, 0.323, 0.468, -0.172, -0.070, 0.009, 0.784, 0.245, 0.765, 0.223, 0.920, 0.740, -5.000, -0.680, 0.256, -0.013, 0.484, 0.565, 0.688, 0.020, -0.000, 0.776, 0.710, 0.562, 0.716, 0.291, 0.757, 0.315, 0.286, 0.180, 0.498, 0.227, -0.653, 0.603, 0.847, 0.414, 0.044, 0.469, 0.554, 0.516, 0.013, 0.586, 1.026, 0.710, 0.750, 0.580, 0.723, 0.552, -0.307, 0.601, 0.725, 0.465, -0.013, 0.656, 0.501, 0.274, 0.173, -0.138, 0.555, -0.098, -5.000, -0.943, 0.039, -0.466, -5.000, -0.544, 0.051, -0.676, -0.567, -0.766, -0.085, -0.389, 0.107, -0.870, 0.007, -0.442, -5.000, -1.083, -0.462, -1.012, -0.556, -0.468, -0.361, -0.500, -1.328, -0.286, -0.037, -1.015, -0.228, -0.276, -0.047, -0.836, -0.508, -0.727, -0.122, -0.383, -1.461, -0.435, 0.174, -0.416, -0.757, -0.466, -0.163, -0.347, -1.011, -0.158, 0.289, -0.403, 0.057, -0.035, 0.394, -0.191, -0.481, 0.284, 0.385, 0.277, -0.019, 0.062, 0.451, 0.358, -0.123, 0.745, 1.266, 0.851, -5.000, -0.061, 0.564, 0.587, -5.000, 0.279, 0.781, 0.383, 0.367, 0.149, 0.632, 0.741, 1.049, 0.149, 0.881, 0.287, -5.000, -0.462, 0.290, -0.055, 0.109, 0.427, 0.520, 0.337, 0.060, 0.487, 0.676, 0.396, 0.563, 0.070, 0.538, 0.020, 0.718, -0.127, 0.348, 0.174, -0.617, 0.028, 0.373, 0.398, -0.210, 0.059, 0.179, -0.091, -0.499, 0.480, 0.944, 0.339, 0.614, 0.200, 0.665, 0.304, 0.125, 0.274, 0.680, 0.799, 0.476, 0.678, 0.596, 0.408, 0.395, 0.234, 0.843, 0.509, -5.000, -0.284, 0.417, -0.245, -5.000, 0.001, 0.183, -0.331, 0.419, -0.068, 0.753, -0.064, 0.566, -0.060, 0.665, 0.227, -5.000, -0.924, 0.072, -0.103, 0.039, 0.210, 0.460, 0.405, -0.114, 0.414, 0.407, -0.116, 0.355, -0.111, 0.410, -0.167, -0.036, -0.544, 0.321, -0.143, -1.138, -0.103, 0.237, -0.090, -0.574, -0.019, -0.071, -0.257, -0.776, 0.351, 0.616, 0.277, 0.466, 0.356, 0.477, 0.341, -0.203, 0.449, 0.726, 0.543, 0.188, 0.498, 0.298, -0.027, -0.227, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.797, -0.137, -1.083, -5.000, -0.913, -0.759, -1.387, -5.000, -1.070, -0.321, -1.663, -1.234, -1.239, -0.675, -1.011, -0.128, -1.059, -0.826, -0.987, -5.000, -1.304, -0.996, -1.544, -0.933, -1.518, -0.476, -1.265, -0.695, -0.715, -0.151, -0.717, -0.735, -1.881, -0.731, -1.597, -1.182, -1.588, -0.706, -1.111, -2.049, -1.165, -1.080, -1.276, -1.484, -1.815, -0.746, -1.147, -1.964, -1.095, -0.438, -0.735, -0.678, -0.687, -0.665, -0.877, -1.584, -0.875, -0.550, -0.382, -0.664, -0.890, -0.708, -0.546, -0.953, 0.230, 0.877, 0.606, -5.000, -0.504, 0.239, -0.137, -5.000, 0.440, 0.480, -0.155, 0.000, 0.140, 0.623, 0.730, 0.845, -0.163, 0.402, 0.292, -5.000, -0.232, 0.195, 0.041, 0.017, 0.179, 0.234, 0.592, -0.108, 0.501, 0.430, 0.237, 0.455, -0.728, -0.074, -0.183, -0.088, -0.355, 0.252, -0.254, -0.819, -0.349, -0.065, -0.112, -0.507, 0.168, 0.056, -0.151, -0.879, -0.238, 0.263, -0.164, 0.144, -0.277, -0.231, -0.812, -0.721, -0.317, -0.088, 0.095, -0.106, 0.136, -0.222, -0.297, -0.074, -0.040, 0.433, 0.037, -5.000, -0.282, -0.091, -0.544, -5.000, -0.611, -0.642, -1.203, -0.651, -0.618, -0.308, -0.809, -0.222, -0.824, 0.188, -0.318, -5.000, -1.100, -0.436, -1.198, -0.794, -0.531, 0.146, -0.181, -0.956, 0.115, 0.253, -0.281, -0.077, -0.366, -0.010, -1.333, -0.750, -0.932, -0.304, -0.919, -1.309, -0.205, -0.378, -0.847, -0.230, -0.819, -0.686, -1.647, -1.534, -0.402, 0.089, -0.628, -0.148, -0.333, -0.050, -0.459, -1.240, 0.195, -0.221, -0.444, -0.290, 0.163, -0.281, -0.862, -0.680, -0.082, 0.421, 0.143, -5.000, -1.291, -0.104, -0.760, -5.000, -0.430, -0.259, -0.856, -0.705, -0.400, -0.079, -0.112, 0.194, -0.791, 0.298, 0.101, -5.000, -1.204, -0.302, -1.066, -0.536, 0.128, 0.069, -0.086, -0.466, -0.038, -0.023, 0.370, 0.097, -0.353, 0.078, -0.241, -0.611, -0.115, 0.301, -0.229, -1.305, 0.292, 0.318, 0.114, -0.171, -0.154, -0.199, -0.176, -0.582, -0.121, 0.391, -0.129, -0.039, -0.091, 0.193, -0.280, -1.008, 0.040, 0.162, -0.319, -0.615, 0.113, -0.049, -0.326, -0.426, 0.341, 0.893, 0.451, -5.000, -0.547, 0.383, 0.006, -5.000, 0.009, 0.294, -0.260, -0.275, -0.626, 0.146, -0.115, 0.650, -0.705, 0.391, 0.206, -5.000, -0.118, 0.133, -0.037, -0.136, 0.096, 0.298, -0.100, -0.613, 0.128, 0.653, 0.062, 0.171, -0.211, 0.481, 0.189, 0.679, -0.189, 0.571, 0.339, -0.368, 0.069, 0.400, -0.200, -0.182, -0.073, 0.372, 0.620, -0.540, -0.111, 0.693, 0.221, 0.669, -0.010, 0.126, 0.198, -0.019, -0.105, 0.211, 0.356, 0.164, 0.337, 0.011, -0.062, 0.042, 0.633, 1.096, 0.901, -5.000, -0.399, 0.519, 0.087, -5.000, 0.072, 0.318, -0.273, -0.061, -0.041, 0.504, 0.552, 1.011, -0.278, 0.570, 0.452, -5.000, -1.423, 0.172, -0.281, 0.169, 0.326, 0.263, -0.017, -0.207, 0.458, 0.650, 0.180, 0.270, -0.192, 0.556, 0.029, 0.315, -0.370, 0.316, 0.027, -0.807, 0.043, 0.182, -0.028, -0.420, -0.014, 0.063, -0.028, -0.797, 0.448, 0.952, 0.473, 0.809, 0.155, 0.465, 0.339, -0.061, 0.129, 0.219, 0.070, 0.150, 0.467, 0.161, -0.027, 0.193, 0.170, 0.514, 0.122, -5.000, -0.402, 0.297, -0.194, -5.000, 0.303, -0.085, -0.936, -0.652, -0.559, -0.002, -0.492, 0.313, -0.569, 0.278, -0.163, -5.000, -0.798, 0.003, -0.788, -0.415, 0.129, -0.040, -0.366, -0.612, -0.022, 0.472, -0.190, 0.323, -0.567, 0.407, -0.524, -0.353, -0.702, 0.055, -0.582, -1.021, -0.271, -0.335, -0.921, -0.384, 0.013, -0.250, -0.161, -0.813, 0.044, 0.458, -0.131, 0.112, 0.271, 0.445, -0.113, -0.493, 0.122, 0.141, 0.065, -0.104, 0.251, 0.248, -0.473, -0.305, -0.318, 0.295, 0.016, -5.000, -1.466, -0.478, -1.104, -5.000, -1.020, -0.581, -1.286, -1.198, -1.157, -0.445, -0.236, -0.072, -0.880, 0.124, -0.128, -5.000, -1.578, -0.491, -1.206, -0.526, -0.721, -0.642, -1.073, -1.005, -0.019, -0.155, -0.119, 0.009, -0.977, -0.370, -0.784, -0.685, -0.806, -0.355, -0.653, -1.387, -0.258, 0.239, -0.273, -0.590, -0.544, -0.278, -0.300, -1.342, -0.685, 0.105, -0.085, -0.243, -0.404, 0.040, -0.163, -1.089, -0.017, -0.155, -0.001, -0.513, -0.189, -0.081, -0.158, -0.337, 0.200, 0.910, 0.473, -5.000, -0.601, 0.569, 0.095, -5.000, -0.360, -0.047, -0.946, -0.649, -0.456, 0.097, -0.420, 0.495, -0.334, 0.612, 0.264, -5.000, -0.747, 0.448, 0.119, -0.134, 0.300, 0.499, -0.069, -0.272, 0.485, 0.746, 0.109, 0.324, 0.124, 0.878, 0.568, 0.558, 0.094, 0.708, 0.228, -0.583, 0.286, 0.664, 0.115, 0.156, 0.256, 0.505, 0.193, -0.425, 0.235, 1.016, 0.771, 0.711, 0.210, 0.461, 0.194, -0.494, 0.050, 0.598, 0.031, -0.186, 0.497, 0.169, -0.059, 0.240, 0.642, 1.222, 1.067, -5.000, -0.297, 0.659, 0.508, -5.000, 0.338, 0.278, -0.023, -0.202, -0.041, 0.748, 0.500, 0.972, 0.022, 0.893, 0.521, -5.000, -0.752, 0.537, 0.423, -0.030, 0.639, 0.717, 0.314, -0.126, 0.576, 0.763, 0.280, 0.507, 0.190, 0.709, 0.378, 0.476, 0.178, 0.579, 0.256, -0.097, 0.377, 0.479, 0.142, -0.100, 0.219, 0.519, 0.257, -0.413, 0.702, 1.107, 0.669, 1.110, 0.373, 0.708, 0.389, 0.466, 0.118, 0.618, 0.492, 0.042, 0.736, 0.462, -0.121, 0.461, 0.243, 0.898, 0.701, -5.000, -0.532, 0.449, 0.258, -5.000, 0.527, 0.503, -0.274, -0.350, 0.223, 0.306, 0.252, 0.530, -0.344, 0.529, -0.008, -5.000, -0.713, -0.021, -0.318, -0.157, 0.338, 0.619, 0.023, -0.404, 0.361, 0.197, -0.043, 0.088, -0.329, 0.260, -0.091, -0.191, -0.277, 0.034, -0.453, -1.090, -0.177, 0.319, -0.412, -0.365, -0.459, -0.265, -0.339, -0.856, -0.098, 0.714, 0.200, 0.363, 0.656, 0.309, 0.397, -0.399, -0.120, 0.120, -0.016, -0.076, 0.003, 0.112, -0.432, -0.401, 0.110, 0.908, 0.639, -5.000, -0.581, 0.461, -0.007, -5.000, 0.183, 0.407, -0.351, -0.243, -0.295, 0.299, 0.213, 0.611, -0.290, 0.679, 0.676, -5.000, -0.521, 0.595, 0.032, 0.191, 0.407, 0.308, -0.060, -0.145, 0.357, 0.770, -0.109, 0.440, -0.215, 0.154, -0.365, -0.051, -0.195, -0.021, -0.354, -0.872, 0.328, 0.480, 0.278, -0.449, -0.266, -0.007, -0.073, -0.849, 0.080, 0.695, 0.373, 0.384, 0.152, 0.336, 0.212, -0.046, 0.217, 0.455, 0.231, -0.057, 0.193, 0.181, -0.083, -0.310, -0.155, 0.589, -0.096, -5.000, -1.004, -0.230, -0.459, -5.000, -0.796, -0.355, -0.788, -0.658, -0.915, -0.176, -0.428, 0.271, -0.897, 0.102, -0.530, -5.000, -1.300, -0.207, -1.048, -0.199, -0.539, -0.154, -0.256, -0.876, 0.163, 0.157, -0.426, 0.036, -0.501, 0.035, -0.375, -0.048, -0.625, -0.088, -0.146, -1.281, -0.167, -0.071, -0.153, -0.604, -0.237, -0.022, 0.050, -0.647, -0.249, 0.224, -0.052, 0.474, 0.266, -0.144, 0.161, -0.754, 0.161, 0.320, 0.474, 0.031, 0.095, 0.222, 0.152, -0.171, 0.871, 1.141, 0.972, -5.000, -0.152, 0.259, 0.305, -5.000, 0.253, 0.469, 0.441, 0.159, 0.187, 0.779, 0.757, 1.140, 0.081, 0.492, 0.274, -5.000, -0.857, 0.097, 0.139, 0.161, 0.293, 0.298, 0.375, 0.235, 0.700, 0.904, 0.448, 0.379, -0.016, 0.418, 0.103, 0.591, -0.111, 0.422, 0.268, -0.355, 0.276, 0.451, 0.630, 0.205, 0.435, 0.539, 0.370, -0.279, 0.142, 0.577, -0.240, 0.697, -0.195, 0.497, 0.120, -0.202, 0.192, 0.611, 0.640, 0.442, 0.546, 0.386, 0.399, 0.258, 0.195, 0.834, 0.126, -5.000, -0.623, 0.417, -0.104, -5.000, -0.225, 0.015, -0.807, -0.283, -0.645, -0.002, -0.375, 0.484, -0.442, 0.291, 0.286, -5.000, -1.575, 0.148, -0.707, -0.499, 0.142, 0.070, -0.495, -0.334, 0.332, 0.582, 0.026, 0.077, -0.660, -0.042, -0.364, -0.055, -0.691, -0.017, -0.436, -1.108, -0.133, -0.123, -0.384, -0.792, -0.368, -0.235, -0.435, -0.788, -0.245, 0.371, -0.273, 0.285, -0.067, 0.171, -0.104, -0.632, 0.047, 0.164, 0.254, 0.263, 0.338, 0.384, -0.290, -0.473, 0.097, 0.745, 0.349, -5.000, -0.875, -0.244, -0.674, -5.000, -0.830, -0.498, -0.784, -1.034, -0.436, -0.685, -0.204, 0.218, -0.312, 0.383, 0.499, -5.000, -1.011, -0.253, -0.843, 0.177, -0.026, -0.217, -0.644, -0.581, 0.231, 0.215, -0.489, 0.282, 0.103, 0.462, 0.047, 0.139, 0.120, 0.236, 0.058, -0.787, 0.570, 0.506, 0.246, 0.023, 0.469, -0.042, 0.216, -0.791, 0.010, 0.687, 0.134, 0.230, 0.235, 0.607, 0.445, -0.269, 0.557, 0.829, 0.631, 0.231, 0.125, 0.375, 0.010, -0.378, -0.345, 0.321, -0.127, -5.000, -1.413, -0.290, -0.601, -5.000, -0.606, -0.370, -0.891, -1.039, -0.988, -0.365, -0.364, 0.445, -0.760, 0.271, 0.601, -5.000, -0.805, -0.394, -1.178, -0.359, -0.297, 0.439, -0.296, -0.731, 0.165, 0.336, -0.363, -0.419, -0.604, 0.036, -0.331, 0.151, -0.757, 0.192, -0.278, -1.184, -0.069, -0.110, -0.078, -0.386, -0.189, 0.153, -0.080, -0.992, -0.486, 0.051, -0.241, 0.228, -0.485, -0.118, -0.610, -0.733, -0.042, 0.071, 0.181, -0.181, 0.049, -0.043, 0.061, -0.402, 0.579, 1.053, 0.772, -5.000, -0.508, 0.452, 0.277, -5.000, 0.401, 0.457, 0.335, 0.014, -0.004, 0.639, 0.708, 1.179, 0.044, 0.328, 0.237, -5.000, -1.220, 0.290, -0.169, 0.238, 0.417, 0.689, 0.509, 0.042, 0.637, 0.875, 0.293, 0.297, -0.061, 0.540, 0.466, 0.470, -0.156, 0.565, 0.425, -0.359, 0.400, 0.557, 0.434, -0.056, 0.525, 0.545, 0.484, -0.259, -0.151, 0.352, 0.242, 0.402, -0.316, 0.291, -0.090, -0.135, -0.035, 0.428, 0.392, 0.028, 0.342, 0.149, 0.076, 0.288, 0.313, 0.718, 0.142, -5.000, -0.878, 0.108, -0.289, -5.000, 0.070, -0.212, -0.881, -0.708, -0.057, 0.076, -0.269, 0.326, -0.589, 0.467, -0.362, -5.000, -1.196, -0.293, -0.913, -0.632, -0.072, 0.127, -0.396, -0.580, 0.190, 0.311, 0.007, 0.223, -0.434, 0.365, -0.603, -0.016, -0.389, 0.114, -0.125, -0.940, -0.307, -0.009, -0.418, -0.212, -0.103, -0.279, -0.737, -0.689, -0.066, 0.313, -0.264, 0.172, -0.454, 0.189, -0.025, -0.580, -0.008, 0.086, 0.052, -0.251, 0.536, 0.218, -0.153, -0.235, -0.972, -0.375, -0.605, -5.000, -1.656, -1.257, -1.820, -5.000, -1.039, -1.553, -1.778, -1.555, -1.466, -1.640, -0.981, -0.468, -1.153, -0.787, -0.688, -5.000, -1.861, -0.783, -1.392, -0.741, -1.205, -0.941, -1.353, -1.666, -0.717, -0.513, -0.851, -0.577, -1.142, -0.520, -0.729, -1.051, -1.131, -0.111, -0.798, -1.905, -0.739, -0.452, -0.989, -1.103, -0.706, -0.384, -0.483, -1.411, -1.007, -0.421, -0.839, -0.774, -0.982, -0.280, -1.172, -1.253, -0.441, -0.335, -0.890, -1.183, -0.583, -0.610, -0.802, -1.080, 0.238, 0.872, 0.405, -5.000, -0.552, 0.358, -0.022, -5.000, -0.228, 0.175, -0.333, -0.516, -0.510, 0.215, 0.220, 0.581, -0.353, 0.557, 0.139, -5.000, -1.106, -0.053, -0.328, -0.776, 0.049, 0.161, -0.147, -0.495, 0.357, 0.466, 0.141, 0.057, -0.395, 0.683, -0.075, 0.319, -0.271, 0.453, 0.095, -0.361, 0.195, 0.455, 0.063, -0.004, 0.203, 0.533, 0.350, -0.200, 0.030, 0.594, 0.288, 0.806, -0.151, 0.521, 0.158, -0.470, 0.192, 0.479, 0.150, 0.019, 0.512, 0.343, 0.205, 0.017, 0.738, 1.101, 0.921, -5.000, -0.322, 0.458, 0.117, -5.000, 0.267, 0.440, -0.200, -0.145, -0.165, 0.605, 0.712, 1.057, -0.059, 0.752, 0.498, -5.000, -1.013, 0.271, -0.158, 0.040, 0.282, 0.456, 0.158, -0.272, 0.387, 0.714, 0.414, 0.460, -0.109, 0.532, 0.077, 0.406, -0.543, 0.690, 0.259, -0.765, 0.195, 0.446, 0.141, -0.142, 0.315, 0.609, 0.492, -0.245, 0.230, 0.736, 0.354, 0.729, -0.208, 0.635, 0.026, -0.885, 0.162, 0.477, 0.392, 0.135, 0.668, 0.407, 0.272, 0.088, 0.304, 0.814, 0.043, -5.000, -0.729, 0.105, -0.268, -5.000, -0.149, -0.032, -0.157, -0.231, -0.408, 0.064, 0.080, 0.432, -0.422, 0.376, 0.277, -5.000, -1.131, 0.198, -0.427, -0.332, 0.126, -0.127, -0.218, -0.542, 0.164, 0.584, 0.028, 0.285, -0.039, 0.909, -0.046, 0.015, 0.007, 0.360, 0.016, -0.519, -0.045, -0.026, -0.188, -0.347, -0.052, 0.369, -0.010, -0.223, 0.247, 0.912, 0.081, 0.266, 0.041, 0.248, 0.088, -0.231, 0.201, 0.151, 0.102, 0.059, 0.363, 0.417, 0.143, -0.203, -0.171, 0.486, 0.114, -5.000, -0.951, -0.510, -0.822, -5.000, -0.867, -0.497, -0.944, -0.944, -0.903, -0.112, -0.246, 0.093, -0.460, -0.028, 0.129, -5.000, -0.090, -0.267, -0.981, -0.372, -0.782, -0.748, -0.576, -1.509, -0.013, -0.304, -0.247, -0.045, -0.429, 0.253, -0.404, -0.419, -0.829, 0.098, -0.427, -1.057, -0.123, 0.054, -0.022, -0.510, -0.362, -0.127, -0.096, -0.877, -0.585, 0.152, -0.262, -0.103, -0.658, 0.096, 0.010, -1.474, -0.074, 0.260, 0.067, -0.363, -0.043, 0.240, 0.092, -0.537, 0.032, 0.862, 0.345, -5.000, -0.897, 0.208, -0.092, -5.000, -0.223, -0.352, -0.856, -0.820, -0.884, -0.253, -0.235, 0.421, -0.581, 0.254, 0.029, -5.000, -1.490, 0.126, 0.266, -0.092, -0.086, 0.102, -0.217, -0.607, 0.144, 0.640, 0.187, -0.153, -0.263, 0.463, 0.149, 0.416, 0.018, 0.538, 0.007, -0.802, 0.317, 0.581, 0.239, -0.218, 0.234, 0.463, 0.120, -0.890, 0.130, 0.911, 0.464, 0.673, 0.320, 0.580, 0.065, -0.275, 0.450, 0.613, 0.459, 0.186, 0.482, 0.417, 0.322, -0.115, 0.594, 1.063, 0.734, -5.000, -0.369, 0.199, 0.116, -5.000, 0.096, 0.237, -0.348, -0.180, -0.486, 0.397, 0.430, 0.977, -0.149, 0.550, 0.412, -5.000, -0.946, 0.044, -0.230, -0.360, 0.288, 0.215, 0.086, -0.297, 0.387, 0.825, 0.194, 0.327, -0.073, 0.660, 0.723, 0.442, -0.124, 0.604, -0.069, -0.628, 0.427, 0.466, 0.406, -0.027, 0.343, 0.431, 0.208, -0.521, 0.297, 0.884, 0.288, 0.939, 0.049, 0.518, 0.252, -0.281, 0.257, 0.550, 0.502, 0.328, 0.592, 0.410, 0.146, -0.105, 0.224, 0.908, 0.590, -5.000, -0.644, 0.903, 0.050, -5.000, 0.378, 0.647, -0.315, -0.419, 0.040, 0.436, 0.107, 0.538, -0.014, 0.622, 0.471, -5.000, -1.096, 0.128, -0.379, -0.241, 0.094, 0.323, -0.093, -0.482, 0.339, 0.408, 0.114, 0.199, 0.036, 0.621, -0.034, 0.146, -0.276, -0.057, -0.261, -0.638, 0.195, 0.351, 0.067, -0.386, -0.115, 0.027, -0.682, -0.866, 0.346, 0.855, 0.248, 0.469, 0.210, 0.278, 0.124, 0.103, 0.271, 0.125, 0.249, 0.017, 0.176, 0.219, -0.313, -0.303, -0.422, 0.383, -0.229, -5.000, -1.367, -0.178, -0.812, -5.000, -0.988, -0.161, -1.157, -1.028, -0.971, -0.380, -0.871, -0.089, -0.882, -0.132, -0.216, -5.000, -1.665, -0.392, -1.376, -0.318, -0.714, -0.691, -1.035, -1.518, -0.090, -0.361, -1.004, -0.596, -0.798, -0.378, -0.945, -0.497, -0.984, -0.661, -0.709, -1.662, -0.511, -0.491, -0.558, -0.950, -0.951, -0.736, -1.000, -1.403, -0.529, 0.108, -0.235, -0.284, -0.489, -0.305, -0.476, -1.245, -0.216, -0.032, -0.047, -0.581, -0.332, -0.294, -0.515, -0.808, 0.224, 0.722, 0.257, -5.000, -0.695, 0.039, -0.275, -5.000, -0.439, -0.405, -0.507, -0.569, -0.544, -0.282, -0.371, 0.404, -0.162, 0.470, 0.095, -5.000, -0.916, 0.011, -0.737, -0.081, 0.047, 0.293, -0.155, -0.578, 0.550, 0.544, -0.281, 0.125, -0.392, 0.156, -0.023, 0.114, -0.354, 0.177, -0.043, -0.930, -0.151, 0.342, 0.179, -0.475, -0.015, 0.374, 0.138, -0.544, -0.067, 0.444, -0.061, 0.363, -0.016, 0.050, -0.083, -0.572, 0.118, 0.426, 0.568, 0.005, 0.374, 0.395, 0.560, -0.030, 0.939, 1.237, 1.011, -5.000, 0.057, 0.597, 0.299, -5.000, 0.624, 0.739, 0.381, 0.488, 0.532, 0.759, 0.717, 1.258, 0.333, 0.813, 0.379, -5.000, -0.374, 0.312, 0.043, 0.174, 0.787, 0.683, 0.607, 0.235, 0.723, 1.001, 0.639, 0.737, 0.271, 0.690, 0.392, 0.725, 0.022, 0.781, 0.691, -0.464, 0.564, 0.610, 0.787, 0.342, 0.676, 0.728, 0.750, 0.090, 0.504, 0.853, 0.222, 0.755, 0.220, 0.722, 0.645, -0.051, 0.365, 0.731, 0.816, 0.645, 0.757, 0.605, 0.410, 0.598, 0.266, 0.804, 0.623, -5.000, -0.798, 0.249, -0.345, -5.000, -0.128, -0.100, -0.586, -0.490, -0.630, -0.010, -0.579, 0.408, -0.201, 0.444, 0.081, -5.000, -1.207, 0.248, -0.440, -0.248, 0.156, 0.296, -0.094, -0.435, 0.492, 0.492, -0.008, 0.266, -0.264, 0.225, -0.257, 0.066, -0.387, 0.213, -0.435, -0.897, 0.049, 0.091, -0.075, -0.543, 0.037, 0.042, -0.217, -0.477, -0.013, 0.493, 0.061, 0.235, 0.117, 0.414, 0.293, -0.356, 0.201, 0.559, 0.329, 0.188, 0.463, 0.390, -0.192, -0.063, 0.155, 0.543, 0.179, -5.000, -0.985, -0.308, -0.952, -5.000, -0.743, -0.859, -1.020, -1.029, -0.577, 0.078, -0.615, 0.331, -0.244, 0.401, 0.215, -5.000, -1.048, 0.041, -0.388, 0.183, 0.334, -0.057, -0.271, -0.743, 0.491, 0.566, 0.019, 0.586, 0.217, 0.626, 0.156, -0.056, 0.097, 0.469, 0.195, -0.751, 0.745, 0.822, 0.617, 0.325, 0.393, 0.627, 0.593, -0.318, 0.223, 0.800, 0.341, 0.169, 0.547, 0.923, 0.513, -0.262, 0.846, 0.986, 0.741, 0.421, 0.464, 0.594, 0.261, -0.002, 0.092, 0.496, 0.036, -5.000, -0.804, -0.099, -0.525, -5.000, -0.533, -0.166, -0.835, -0.783, -0.639, -0.193, -0.305, 0.544, 0.092, 0.282, 0.369, -5.000, -1.186, 0.060, -0.961, -0.039, 0.109, 0.223, 0.008, -0.299, 0.438, 0.385, 0.092, 0.184, -0.265, 0.485, 0.105, 0.471, -0.029, 0.422, 0.054, -0.657, 0.435, 0.447, 0.058, -0.067, 0.623, 0.535, 0.105, -0.329, -0.005, 0.437, -0.186, 0.299, -0.041, 0.167, -0.274, -0.638, -0.007, 0.218, 0.572, 0.251, 0.617, 0.123, 0.230, -0.072, 0.486, 0.883, 0.610, -5.000, -0.482, 0.138, 0.033, -5.000, 0.485, 0.704, 0.118, -0.030, 0.068, 0.445, 0.740, 1.072, 0.040, 0.364, 0.218, -5.000, -0.659, -0.035, 0.359, 0.196, 0.372, 0.791, 0.418, 0.099, 0.662, 0.966, 0.673, 0.500, -0.240, 0.289, 0.300, 0.468, -0.216, 0.748, 0.365, -0.569, 0.416, 0.625, 0.384, 0.157, 0.576, 0.697, 0.566, -0.033, -0.028, 0.520, 0.212, 0.630, 0.055, 0.379, 0.154, -0.338, -0.162, 0.450, 0.221, 0.402, 0.663, 0.031, 0.136, 0.397, 0.198, 0.726, 0.323, -5.000, -0.765, 0.052, 0.019, -5.000, -0.114, -0.023, -0.577, -0.564, -0.558, 0.030, -0.401, 0.511, -0.123, 0.482, 0.157, -5.000, -1.180, -0.013, -0.716, -0.292, 0.176, 0.407, -0.040, -0.404, 0.339, 0.524, 0.202, 0.610, -0.298, 0.440, -0.223, -0.001, -0.553, 0.125, -0.308, -0.875, -0.110, 0.307, 0.040, -0.594, -0.051, 0.002, -0.043, -0.379, -0.006, 0.833, 0.091, 0.220, 0.003, 0.384, 0.122, -0.479, 0.223, 0.246, 0.187, -0.135, 0.565, 0.378, -0.178, 0.087, -0.397, -0.002, -0.642, -5.000, -1.688, -0.941, -1.511, -5.000, -1.137, -1.173, -1.565, -1.247, -1.253, -0.494, -0.938, -0.223, -0.929, 0.009, -0.544, -5.000, -1.974, -0.777, -1.354, -0.830, -0.487, 0.070, -1.657, -1.601, -0.098, 0.458, -0.029, -0.063, -0.677, -0.176, -0.522, -0.698, -0.898, -0.493, -0.312, -1.396, -0.218, 0.078, -0.606, -0.876, -0.622, -0.262, -0.830, -0.714, -0.426, 0.135, -0.596, -0.363, -0.595, -0.051, -0.685, -1.114, -0.182, 0.241, -0.453, -0.498, -0.187, -0.113, -0.433, -0.679, 0.127, 0.848, 0.413, -5.000, -0.675, 0.385, 0.267, -5.000, -0.265, 0.100, -0.481, -0.559, -0.393, 0.143, 0.038, 0.591, -0.037, 0.525, 0.023, -5.000, -1.179, 0.183, -0.487, -0.189, 0.261, 0.472, -0.007, -0.274, 0.424, 0.784, 0.335, 0.197, -0.094, 0.578, 0.186, 0.383, -0.260, 0.561, 0.014, -0.584, 0.192, 0.573, 0.129, -0.044, 0.363, 0.770, 0.572, -0.183, -0.033, 0.825, 0.235, 0.325, 0.109, 0.443, -0.010, -0.459, 0.380, 0.437, 0.497, 0.000, 0.595, 0.258, 0.247, 0.179, 0.444, 1.125, 0.759, -5.000, -0.415, 0.360, 0.016, -5.000, 0.132, 0.418, -0.230, -0.251, 0.360, 0.618, 0.706, 0.909, 0.084, 0.805, 0.467, -5.000, -0.923, 0.471, -0.095, -0.052, 0.497, 0.759, 0.160, 0.177, 0.449, 0.868, 0.600, 0.439, -0.030, 0.751, 0.104, 0.370, -0.189, 0.812, 0.430, -0.605, 0.343, 0.546, 0.177, -0.080, 0.429, 0.786, 0.582, -0.165, 0.289, 0.920, 0.525, 0.687, 0.076, 0.770, 0.602, -0.174, 0.289, 0.657, 0.491, 0.343, 0.791, 0.668, 0.380, 0.388, 0.285, 0.931, 0.647, -5.000, -0.418, 0.161, -0.140, -5.000, -0.016, 0.048, -0.644, -0.237, -0.025, 0.360, 0.050, 0.602, -0.075, 0.655, 0.337, -5.000, -0.664, 0.244, -0.297, -0.139, 0.361, 0.208, -0.225, -0.303, 0.302, 0.828, 0.332, 0.547, 0.182, 0.989, 0.145, 0.315, -0.063, 0.699, 0.137, -0.650, 0.201, 0.462, 0.049, -0.331, 0.291, 0.738, 0.231, -0.087, 0.387, 1.163, 0.436, 0.441, 0.300, 0.686, 0.359, -0.227, 0.431, 0.370, 0.214, 0.091, 0.644, 0.732, 0.274, 0.068, -0.070, 0.639, 0.317, -5.000, -1.002, -0.619, -0.549, -5.000, -1.138, -0.412, -0.682, -0.814, -0.909, -0.423, -0.212, 0.134, -0.121, 0.358, 0.162, -5.000, -1.142, -0.129, -0.759, -0.089, -0.765, -0.349, -0.324, -0.670, 0.393, 0.143, -0.374, 0.273, -0.120, 0.060, -0.061, -0.163, -0.434, 0.278, -0.335, -0.983, 0.048, 0.266, 0.096, -0.198, -0.113, 0.297, 0.280, -0.483, -0.209, 0.510, -0.036, 0.180, 0.071, 0.568, -0.054, -0.680, 0.061, 0.320, 0.212, -0.391, 0.229, 0.394, 0.195, -0.181, 0.321, 0.914, 0.643, -5.000, -0.440, 0.497, 0.140, -5.000, -0.405, -0.136, -0.742, -0.655, -0.660, -0.070, -0.283, 0.558, -0.178, 0.689, 0.372, -5.000, -1.078, 0.178, -0.171, -0.005, 0.204, 0.563, 0.113, -0.318, 0.528, 0.710, 0.264, 0.405, 0.008, 0.770, 0.289, 0.395, 0.030, 0.709, 0.255, -0.541, 0.529, 0.751, 0.407, 0.121, 0.387, 0.680, 0.491, -0.347, 0.371, 1.064, 0.644, 0.600, 0.335, 0.635, 0.203, -0.236, 0.830, 1.011, 0.848, 0.563, 0.581, 0.616, 0.445, 0.243, 0.328, 0.984, 0.697, -5.000, -0.879, 0.153, -0.052, -5.000, -0.192, 0.049, -0.528, -0.450, -0.148, 0.329, 0.064, 0.761, -0.365, 0.494, 0.681, -5.000, -0.959, 0.109, -0.089, -0.321, 0.321, 0.515, 0.136, -0.177, 0.230, 0.737, 0.316, 0.185, -0.190, 0.716, 0.114, 0.255, -0.124, 0.709, 0.198, -0.780, 0.417, 0.540, 0.239, 0.055, 0.225, 0.546, 0.358, -0.397, 0.179, 0.845, 0.124, 0.420, 0.144, 0.709, 0.089, -0.153, 0.232, 0.681, 0.573, 0.242, 0.332, 0.266, -0.156, 0.044, 0.161, 0.844, 0.436, -5.000, -0.552, 0.525, -0.332, -5.000, -0.008, 0.319, -0.506, -0.464, -0.263, 0.280, -0.217, 0.219, -0.185, 0.566, 0.407, -5.000, -0.920, 0.200, -0.758, -0.265, 0.245, 0.345, -0.309, -0.551, 0.262, 0.359, -0.268, 0.063, -0.028, 0.463, 0.086, 0.023, -0.262, 0.352, -0.397, -1.302, 0.046, 0.259, 0.155, -0.208, -0.019, -0.083, -0.042, -0.517, 0.091, 0.708, 0.074, 0.149, 0.346, 0.500, -0.043, -0.541, -0.265, 0.236, -0.062, -0.119, 0.100, 0.016, -0.601, -0.527, -0.028, 0.618, 0.348, -5.000, -1.028, 0.198, -0.132, -5.000, -0.235, -0.213, -0.732, -0.586, -0.506, -0.041, -0.321, 0.230, -0.452, 0.349, 0.042, -5.000, -1.242, 0.089, -0.375, -0.100, 0.017, -0.086, -0.569, -0.744, 0.143, 0.011, -0.473, 0.034, -0.358, -0.065, -0.571, -0.184, -0.295, -0.041, -0.597, -1.366, 0.155, 0.189, 0.027, -0.641, -0.441, -0.279, -0.255, -0.676, -0.174, 0.498, 0.022, -0.063, 0.117, 0.339, 0.060, -0.792, 0.198, 0.353, 0.192, -0.299, -0.108, 0.091, -0.169, -0.368 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_7(struct _training *tptr) {
  struct _training tinf = {
    0.341, 11, 4.350, { 2.629, 0.216, 0.155 }, { 0.663, -0.431, -0.997 }, 1, 
    { -2.360, -3.707, -1.479, -0.936, -4.000, -4.000, -0.318, 0.513, -4.000, -4.000, 0.513, -4.000, 0.088, -0.447, 1.736, 0.630, 1.814, 1.860, -4.000, 2.446, 2.185, 1.059, 2.695, -0.126, 3.105, 3.234, 1.206, 3.316 }, 
    {{ 0.159, -0.066, -0.412, 0.035},{ 0.298, -0.327, -0.323, -0.061},{ 0.356, 0.278, -0.835, -0.357},{ 0.301, 0.149, -0.682, -0.197},{ 0.289, 0.040, -0.632, -0.120},{ 0.279, -0.188, -0.374, -0.073},{ 0.264, -0.279, -0.437, 0.007},{ 0.242, -0.241, -0.309, -0.026},{ 0.280, -0.453, -0.332, 0.012},{ 0.284, -0.323, -0.336, -0.038},{ 0.296, -0.318, -0.398, -0.034},{ 0.275, -0.253, -0.327, -0.057},{ 0.273, -0.332, -0.327, -0.024},{ 0.276, -0.123, -0.323, -0.122},{ 0.280, -0.249, -0.355, -0.055},{ 0.345, -0.204, -0.388, -0.163},{ 0.243, -0.087, -0.274, -0.114},{ 0.231, -0.196, -0.378, -0.005},{ 0.178, 0.027, -0.341, -0.061},{ 0.190, 0.005, -0.241, -0.107},{ 0.226, -0.200, -0.341, -0.010},{ 0.190, -0.035, -0.232, -0.088},{ 0.181, 0.064, -0.374, -0.073},{ 0.214, -0.022, -0.398, -0.059},{ 0.208, -0.039, -0.318, -0.073},{ 0.195, 0.118, -0.346, -0.137},{ 0.128, -0.063, -0.318, 0.035},{ 0.113, -0.022, -0.220, -0.007},{ 0.158, 0.052, -0.341, -0.050},{ 0.128, -0.009, -0.296, 0.000},{ 0.121, 0.089, -0.301, -0.043},{ 0.188, 0.071, -0.407, -0.073} }, 
    {{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}} }, 
    0.000, { 0.364, 1.024, 0.134, -5.000, 0.043, 0.631, -0.839, -5.000, 0.222, 0.884, 0.266, 0.114, 0.707, 0.826, 0.320, 0.636, -0.196, 0.321, -0.731, -5.000, -0.313, 0.613, -1.601, -0.346, -0.242, 0.517, -0.056, -0.463, 0.488, 0.450, -0.286, 0.283, 0.407, 0.940, -0.139, 0.591, -0.137, 0.221, -0.770, -1.270, -0.149, 0.523, -0.340, -0.519, 0.037, 0.352, -0.059, -0.159, 0.296, 0.885, -0.291, 0.138, 0.268, 0.788, -0.815, -0.748, 0.341, 0.832, 0.299, 0.043, 0.380, 0.680, 0.352, 0.001, 1.082, 1.450, 0.889, -5.000, 0.863, 1.275, 0.167, -5.000, 0.870, 1.273, 1.101, 0.710, 1.206, 1.262, 0.745, 1.131, 0.373, 0.953, -0.106, -5.000, 0.313, 0.719, -1.069, 0.242, 0.591, 0.806, 0.702, 0.337, 0.749, 0.766, -0.202, 0.624, 1.215, 1.490, 0.855, 1.377, 0.723, 0.913, 0.332, -0.048, 0.851, 1.264, 1.020, 0.597, 0.905, 1.094, 0.773, 0.548, 0.948, 1.365, 0.561, 0.920, 0.877, 1.179, 0.417, 0.010, 0.929, 1.256, 1.171, 0.824, 0.840, 1.060, 0.663, 0.638, 0.051, 0.828, -0.289, -5.000, 0.095, 0.637, -0.949, -5.000, 0.421, 1.078, 0.285, 0.249, 0.157, 0.132, -0.295, 0.091, -0.109, 0.523, -0.501, -5.000, -0.002, 0.324, -1.535, -0.397, 0.064, 0.598, -0.555, -0.296, 0.380, 0.040, -0.724, -0.249, -0.040, 0.506, -0.918, -0.355, -0.568, 0.447, -1.216, -1.521, 0.059, 0.682, -0.362, -0.517, -0.638, -0.324, -1.061, -0.850, 0.131, 0.711, -0.618, -0.081, 0.181, 0.939, -0.456, -0.810, 0.376, 1.045, 0.602, 0.347, 0.183, 0.417, -0.323, -0.333, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.171, 0.653, -0.135, -5.000, -0.373, 0.463, -1.350, -5.000, 0.143, 0.820, 0.032, -0.079, 0.716, 0.714, 0.162, 0.700, -0.732, 0.102, -0.954, -5.000, -0.982, -0.113, -1.997, -0.723, -0.188, 0.289, -0.729, -0.337, 0.562, 0.629, -0.114, 0.446, 0.065, 0.762, -0.136, 0.321, -0.685, 0.117, -1.344, -1.894, -0.406, 0.553, -0.724, -1.178, -0.045, 0.477, -0.319, -0.216, -0.108, 0.544, -0.331, -0.236, -0.247, 0.412, -1.025, -1.018, 0.392, 1.043, 0.283, 0.105, 0.115, 0.572, 0.074, -0.336, 0.541, 1.166, 0.537, -5.000, 0.602, 1.017, -0.052, -5.000, 0.893, 1.166, 0.818, 0.457, 1.047, 1.056, 0.796, 1.145, -0.046, 0.615, -0.417, -5.000, 0.034, 0.676, -1.304, 0.212, 0.572, 0.929, 0.371, 0.318, 0.747, 0.670, -0.098, 0.588, 0.733, 1.234, 0.702, 0.996, 0.306, 0.998, 0.043, -0.445, 0.618, 1.114, 0.436, -0.181, 0.568, 0.930, 0.386, 0.266, 0.520, 1.080, 0.387, 0.569, 0.661, 1.259, -0.170, -0.041, 0.783, 1.223, 0.856, 0.543, 0.532, 0.929, 0.444, 0.396, -0.919, -0.219, -1.644, -5.000, -1.339, -0.500, -3.083, -5.000, -0.372, 0.502, -0.732, -0.836, -1.130, -1.094, -1.215, -0.965, -1.330, -0.154, -2.098, -5.000, -0.929, 0.060, -2.109, -1.010, -0.664, 0.780, -0.603, -1.167, -0.596, -0.288, -1.561, -0.598, -0.849, -0.577, -1.881, -1.279, -1.730, -0.392, -2.540, -2.501, -0.914, 0.498, -1.054, -1.337, -1.301, -0.652, -1.196, -1.487, -1.108, -0.651, -1.526, -1.349, -0.898, 0.042, -2.009, -1.954, -0.460, 0.511, -0.411, -0.445, -0.757, -0.144, -1.074, -1.206, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.216, 0.908, 0.169, -5.000, 0.044, 0.819, -0.987, -5.000, -0.126, 0.582, 0.113, -0.495, 0.458, 0.718, 0.098, 0.367, -0.288, 0.450, -0.805, -5.000, -0.320, 0.482, -1.096, -0.014, -0.353, 0.391, -0.279, -0.519, 0.622, 0.245, -0.528, 0.201, 0.445, 1.066, -0.047, 0.725, 0.015, 0.459, -1.076, -0.802, 0.037, 0.783, -0.010, -0.498, 0.313, 0.594, -0.021, 0.195, -0.021, 0.640, -0.344, 0.033, -0.053, 0.621, -0.811, -0.870, 0.033, 0.801, 0.255, -0.059, 0.080, 0.565, -0.146, -0.044, 0.620, 1.199, 0.750, -5.000, 0.583, 1.177, -0.068, -5.000, 0.581, 0.914, 0.338, 0.049, 0.935, 1.075, 0.474, 0.887, 0.391, 0.913, 0.248, -5.000, 0.568, 0.821, -0.780, 0.290, 0.341, 0.934, 0.005, -0.303, 0.771, 0.686, 0.019, 0.626, 1.081, 1.399, 0.812, 1.052, 0.439, 0.988, -0.717, -0.441, 0.604, 1.081, 0.502, 0.366, 0.830, 1.045, 0.551, 0.333, 0.859, 1.185, 0.632, 0.996, 0.830, 1.304, 0.159, -0.019, 0.641, 1.055, 0.468, 0.409, 0.732, 1.051, 0.489, 0.400, 0.236, 0.732, -0.035, -5.000, 0.242, 0.602, -0.760, -5.000, 0.298, 0.193, -0.381, -0.395, 0.166, 0.248, -0.179, 0.063, -0.409, 0.289, -0.676, -5.000, 0.335, 0.491, -0.359, 0.005, -0.376, 0.116, -0.688, -0.619, 0.217, -0.073, -0.846, -0.335, 0.138, 0.875, -0.614, -0.371, -0.728, 0.457, -1.151, -0.885, -0.051, 0.111, -0.580, -0.557, -0.178, 0.157, -0.998, -0.351, 0.321, 1.019, -0.190, 0.004, -0.023, 0.713, -0.492, -0.472, 0.281, 0.301, -0.150, -0.178, 0.164, 0.473, -0.284, -0.451, -0.140, 0.597, -0.127, -5.000, -0.318, -0.053, -1.266, -5.000, -0.252, 0.124, -0.433, -0.589, -0.061, 0.265, -0.344, -0.147, -0.514, 0.283, -1.060, -5.000, -0.486, -0.244, -2.271, -0.286, -0.582, -0.225, -0.468, -1.206, 0.352, -0.403, -0.751, -0.230, -0.122, 0.698, -0.975, 0.068, -0.439, 0.127, -0.981, -1.640, -0.083, 0.345, -0.540, -0.722, -0.155, 0.229, -0.331, -0.454, -0.150, 0.533, -0.523, 0.015, -0.241, 0.516, -1.295, -1.361, -0.175, 0.422, -0.229, -0.682, -0.055, 0.343, -0.323, -0.394, 0.416, 1.147, 0.309, -5.000, 0.430, 1.032, -0.755, -5.000, 0.353, 0.903, 0.169, -0.010, 0.643, 0.788, 0.130, 0.530, 0.303, 0.818, 0.048, -5.000, 0.138, 0.671, -1.360, -0.076, 0.236, 0.886, -0.080, -0.285, 0.544, 0.490, -0.264, 0.322, 0.544, 0.970, 0.037, 0.660, 0.161, 0.638, -0.247, -1.018, 0.065, 0.621, 0.109, -0.292, 0.224, 0.380, 0.122, -0.033, 0.528, 1.085, 0.110, 0.350, 0.480, 0.912, -0.835, -0.924, 0.534, 0.966, 0.486, 0.044, 0.239, 0.738, 0.281, 0.118, 0.509, 1.089, 0.440, -5.000, 0.258, 1.043, -0.468, -5.000, 0.421, 1.011, 0.329, 0.132, 0.804, 0.844, 0.447, 0.699, 0.213, 0.655, -0.210, -5.000, 0.516, 0.857, -0.985, 0.146, 0.414, 0.857, 0.133, -0.053, 0.442, 0.483, -0.370, 0.197, 0.741, 1.117, -0.032, 0.733, 0.104, 0.676, -0.562, -1.203, 0.235, 0.913, 0.413, -0.135, -0.052, 0.303, -0.195, -0.464, 0.652, 1.174, -0.003, 0.500, 0.602, 1.051, -0.516, -0.624, 0.498, 1.065, 0.656, 0.245, 0.446, 0.684, 0.059, 0.160, 0.290, 0.971, -0.052, -5.000, 0.181, 0.554, -0.928, -5.000, 0.176, 0.717, -0.385, -0.226, 0.195, 0.425, -0.418, -0.003, -0.410, 0.308, -1.122, -5.000, -0.231, 0.035, -1.556, -0.687, -0.278, 0.339, -0.873, -0.462, 0.203, 0.201, -1.666, -0.309, -0.193, 0.462, -1.235, -0.191, -0.812, -0.167, -1.723, -1.424, -0.135, 0.338, -0.922, -0.874, -0.504, -0.234, -1.197, -0.722, -0.014, 0.733, -0.740, -0.056, -0.139, 0.304, -1.165, -1.555, 0.010, 0.434, -0.260, -0.328, -0.191, 0.091, -1.061, -0.722, 0.501, 1.088, 0.156, -5.000, 0.194, 0.928, -0.609, -5.000, 0.320, 0.730, -0.061, -0.347, 0.328, 0.613, -0.263, -0.026, 0.261, 0.974, 0.076, -5.000, 0.117, 0.391, -1.536, -0.219, 0.007, 0.543, -0.541, -0.318, 0.467, 0.451, -0.449, 0.138, 0.447, 1.005, -0.271, 0.303, 0.064, 0.683, -0.704, -1.689, 0.361, 0.856, -0.175, -0.093, 0.270, 0.635, -0.307, -0.106, 0.595, 1.111, -0.086, 0.363, 0.448, 0.892, -0.757, -1.108, 0.516, 1.070, 0.331, 0.165, 0.397, 0.693, -0.024, -0.069, 0.060, 0.832, -0.327, -5.000, -0.180, 0.382, -1.198, -5.000, -0.204, 0.602, -0.172, -0.354, 0.157, 0.255, -0.580, 0.119, -0.860, 0.071, -1.084, -5.000, -0.746, -0.134, -2.204, -0.965, -0.965, 0.113, -0.690, -1.095, -0.158, -0.077, -1.116, -0.371, 0.048, 0.597, -0.622, 0.183, -0.554, -0.291, -0.999, -1.586, -0.577, 0.234, -0.706, -0.838, -0.268, -0.244, -0.638, -0.717, 0.053, 0.738, -0.593, -0.066, -0.003, 0.680, -0.933, -1.085, 0.323, 0.767, 0.233, -0.013, 0.248, 0.508, 0.135, -0.133, 0.832, 1.238, 0.606, -5.000, 0.706, 0.949, 0.101, -5.000, 0.589, 1.016, 0.708, 0.309, 0.879, 0.831, 0.001, 0.719, -0.163, 0.341, -0.738, -5.000, -0.156, 0.212, -0.941, -0.264, -0.029, 0.214, -0.173, -0.378, 0.188, -0.051, -1.053, -0.211, 0.891, 1.328, 0.323, 0.968, 0.516, 0.668, -0.231, -0.748, 0.709, 1.042, 0.846, 0.462, 0.424, 0.596, 0.104, 0.086, 0.638, 1.201, 0.273, 0.533, 0.644, 1.015, -0.120, -0.336, 0.549, 1.065, 0.857, 0.302, 0.513, 0.759, 0.229, 0.251, -0.170, 0.475, -0.550, -5.000, -0.180, 0.523, -0.998, -5.000, -0.175, 0.723, -0.419, -0.150, -0.372, -0.220, -1.069, -0.381, -0.806, -0.048, -1.048, -5.000, -0.138, -0.030, -2.550, -0.757, -0.693, 0.270, -0.959, -0.550, -0.360, -0.552, -1.371, -0.724, -0.395, 0.124, -2.311, -0.840, -0.970, -0.012, -1.147, -2.352, -0.125, 0.426, -0.538, -0.803, -1.115, -0.696, -1.606, -1.430, -0.251, 0.522, -1.250, -0.450, -0.073, 0.729, -1.152, -1.393, 0.111, 0.828, 0.172, -0.048, -0.170, -0.066, -1.009, -0.840, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.157, 0.575, -0.362, -5.000, -0.444, 0.369, -1.161, -5.000, -0.060, 0.894, -0.238, -0.181, 0.278, 0.245, -0.503, 0.360, -1.090, -0.343, -0.957, -5.000, -0.669, -0.505, -1.538, -1.014, -0.325, 0.002, -1.184, -0.754, 0.117, 0.078, -1.255, -0.253, -0.439, 0.501, -0.596, -0.180, -1.065, -0.709, -0.938, -1.741, -0.942, 0.082, -1.023, -1.267, -0.618, -0.281, -1.168, -1.147, -0.478, 0.302, -0.653, -0.318, -0.323, 0.185, -1.752, -1.103, -0.114, 0.881, 0.030, -0.277, -0.078, 0.169, -0.608, -0.701, 0.402, 1.015, 0.254, -5.000, 0.364, 0.895, -0.354, -5.000, 0.763, 1.135, 0.521, 0.089, 0.841, 0.818, 0.556, 0.986, -0.240, 0.127, -0.443, -5.000, -0.482, -0.056, -0.465, -0.560, 0.450, 0.335, -0.103, -0.082, 0.588, 0.328, -0.283, 0.307, 0.309, 0.709, 0.144, 0.328, 0.062, 0.515, -0.876, -1.259, 0.583, 0.539, 0.206, -0.156, -0.095, 0.527, -0.286, -0.393, 0.089, 0.650, -0.031, 0.050, 0.335, 0.864, -0.306, -0.432, 0.295, 0.854, 0.261, 0.237, -0.024, 0.362, -0.126, 0.032, -1.323, -0.582, -1.556, -5.000, -1.550, -1.455, -1.469, -5.000, -1.187, 0.021, -1.342, -1.062, -1.572, -0.933, -1.531, -1.239, -1.579, -0.365, -1.530, -5.000, -1.448, -1.479, -1.966, -2.192, -1.075, -1.484, -0.637, -1.114, -1.367, -1.243, -1.171, -1.279, -2.034, -1.122, -2.099, -2.032, -2.112, -0.791, -2.002, -2.939, -1.466, -0.534, -1.125, -1.688, -1.773, -0.899, -1.931, -1.913, -1.072, -1.010, -1.406, -1.189, -2.235, -0.560, -1.873, -1.414, -1.054, 0.021, -1.184, -0.729, -1.611, -0.921, -1.296, -1.932, -0.119, 0.592, -0.358, -5.000, -0.350, 0.335, -1.481, -5.000, -0.164, 0.318, -0.107, -0.554, -0.516, -0.022, -0.850, -0.334, -0.614, 0.137, -0.655, -5.000, -0.968, -0.245, -1.857, -0.508, -0.240, -0.036, -0.292, -0.509, -0.183, -0.171, -0.845, -0.506, -0.175, 0.796, -0.799, -0.297, -0.924, 0.236, -2.534, -1.631, -0.625, 0.083, -0.758, -1.589, -0.528, -0.062, -1.251, -1.217, -0.052, 0.564, -0.937, -0.415, -0.307, 0.377, -1.732, -1.732, -0.201, 0.390, -0.142, -0.470, -0.495, -0.090, -0.707, -0.678, 0.108, 0.809, -0.279, -5.000, 0.309, 0.791, -0.808, -5.000, -0.124, 0.548, -0.282, -0.613, 0.227, 0.171, -0.239, 0.158, -0.632, 0.082, -0.570, -5.000, 0.165, 0.403, -2.400, -0.224, -0.482, 0.069, -0.333, -0.543, 0.472, 0.177, -1.065, -0.030, 0.289, 1.016, -0.105, 0.285, -0.349, 0.169, -1.060, -1.410, -0.113, 0.340, -0.266, -0.561, -0.090, 0.637, 0.176, -0.277, -0.222, 0.410, -0.776, -0.132, 0.001, 0.603, -0.831, -1.196, 0.002, 0.135, 0.119, -0.073, -0.416, 0.099, -0.368, -0.481, 0.556, 1.157, 0.588, -5.000, 0.630, 0.935, -0.637, -5.000, 0.444, 0.760, 0.152, -0.327, 0.674, 1.004, 0.308, 0.403, 0.120, 0.453, 0.153, -5.000, 0.166, 0.479, -0.717, -0.003, 0.134, 0.586, 0.138, -0.189, 0.660, 0.352, -0.742, 0.193, 0.650, 1.196, -0.231, 0.787, 0.578, 0.659, -5.000, -0.717, 0.718, 0.605, -0.065, 0.123, 0.503, 1.022, -1.078, 0.275, 0.755, 1.279, 0.678, 0.701, 0.685, 1.126, 0.326, -0.322, 0.580, 0.609, 0.431, 0.123, 0.410, 0.883, -0.083, 0.370, -0.155, 0.315, -0.408, -5.000, -0.193, 0.151, -1.060, -5.000, -0.131, 0.199, -0.758, -0.918, -0.213, -0.181, -0.687, -0.298, -0.726, -0.052, -1.165, -5.000, -0.614, 0.462, -5.000, 0.016, -0.231, -0.065, -1.455, -0.810, -0.204, -0.155, -0.758, -0.343, -0.164, 0.220, -1.112, -1.167, -0.570, -0.471, -0.534, -0.572, 0.071, -0.391, -1.158, -0.924, -0.283, -0.155, -1.124, -0.652, -0.009, 0.772, -0.026, -0.319, -0.090, 0.283, -0.454, -0.521, -0.280, 0.280, -0.739, -0.344, 0.029, 0.112, -0.431, -0.488, -0.461, 0.106, -0.468, -5.000, -0.527, -0.272, -1.542, -5.000, -0.812, 0.039, -0.879, -1.396, -0.409, 0.030, -0.864, -0.423, -1.117, -0.251, -0.396, -5.000, -0.865, -0.522, -1.466, -0.691, -0.903, -0.029, -0.776, -1.211, -0.008, -0.237, -0.855, -0.464, -0.443, 0.275, -1.060, -0.733, -1.124, -0.463, -1.042, -2.336, -0.513, 0.211, -0.578, -0.893, -0.573, -0.063, -0.864, -1.044, -0.356, 0.288, -0.266, -0.179, -0.222, 0.216, -0.728, -1.582, -0.351, 0.057, -0.196, -0.920, -0.570, 0.064, -0.292, -0.586, 0.163, 1.026, 0.257, -5.000, 0.384, 0.940, -0.244, -5.000, 0.220, 0.919, 0.069, -0.165, 0.652, 0.632, -0.111, 0.471, -0.020, 0.721, -0.000, -5.000, 0.146, 0.405, -1.144, -0.313, -0.284, 0.898, -0.239, -0.398, 0.452, 0.356, -0.372, 0.203, 0.527, 0.808, -0.056, 0.541, 0.023, 0.534, -0.826, -0.788, 0.021, 0.611, -0.374, -0.312, 0.269, 0.307, 0.021, 0.053, 0.277, 0.989, -0.242, 0.145, 0.162, 0.884, -0.709, -0.867, 0.403, 0.998, 0.318, 0.020, 0.185, 0.650, 0.170, 0.128, 0.234, 0.771, 0.126, -5.000, 0.276, 0.766, -0.485, -5.000, -0.005, 0.568, -0.048, -0.177, 0.585, 0.628, 0.146, 0.373, -0.224, 0.140, -0.880, -5.000, 0.175, 0.339, -1.335, -0.342, -0.053, 0.431, -0.573, -0.677, 0.090, 0.035, -0.596, -0.194, 0.456, 0.954, 0.038, 0.815, 0.063, 0.462, -0.924, -0.199, 0.195, 0.792, -0.053, -0.092, 0.246, 0.273, -0.470, -0.236, 0.541, 1.033, 0.219, 0.476, 0.480, 0.903, -0.056, -0.323, 0.321, 0.867, 0.469, -0.055, 0.338, 0.688, -0.222, 0.119, -0.216, 0.758, -0.367, -5.000, -0.091, 0.481, -0.684, -5.000, -0.198, 0.453, -0.340, -0.325, 0.166, 0.002, -0.599, -0.132, -0.940, 0.103, -1.311, -5.000, -0.410, -0.275, -1.617, -0.909, -0.577, 0.099, -1.530, -0.999, -0.085, -0.346, -1.336, -0.617, -0.972, -0.346, -1.383, -1.090, -1.442, -0.893, -2.098, -2.438, -0.882, 0.146, -2.053, -1.036, -1.330, -0.794, -1.586, -1.613, -0.400, 0.370, -1.334, -0.545, -0.998, 0.002, -1.582, -2.058, -0.347, 0.287, -0.794, -0.623, -0.578, -0.477, -1.531, -1.144, 0.319, 1.019, -0.057, -5.000, 0.399, 0.734, -0.635, -5.000, 0.025, 0.759, -0.229, -0.428, 0.169, 0.328, -0.613, -0.068, -0.224, 0.690, -0.175, -5.000, -0.221, 0.353, -1.488, -0.349, 0.051, 0.547, -0.614, -0.627, 0.131, 0.088, -0.805, 0.070, -0.185, 0.505, -1.067, -0.257, -0.533, 0.264, -1.172, -1.576, -0.093, 0.631, -0.523, -0.427, -0.396, -0.195, -1.231, -0.778, 0.106, 0.856, -0.324, 0.005, 0.059, 0.778, -0.972, -1.224, 0.167, 0.854, 0.094, -0.150, -0.096, 0.427, -0.386, -0.294, 0.302, 1.038, 0.081, -5.000, 0.007, 0.628, -0.956, -5.000, 0.215, 0.680, 0.092, -0.043, 0.737, 0.497, 0.319, 0.661, -0.282, 0.433, -0.509, -5.000, -0.751, 0.305, -1.703, -0.412, -0.034, 0.632, -0.200, -0.463, 0.493, 0.466, -0.108, 0.340, 0.365, 0.665, -0.064, 0.604, -0.419, 0.004, -1.196, -1.368, -0.014, 0.369, -0.264, -0.576, -0.049, 0.488, -0.036, -0.121, 0.056, 0.706, -0.437, -0.169, 0.022, 0.599, -0.817, -0.874, 0.297, 0.577, 0.524, -0.204, 0.221, 0.515, 0.116, -0.107, 0.948, 1.320, 0.765, -5.000, 0.670, 1.308, -0.499, -5.000, 0.978, 1.220, 0.870, 0.696, 1.219, 1.058, 0.767, 1.121, 0.207, 0.652, -0.294, -5.000, -0.110, 0.302, -0.791, 0.090, 0.475, 0.651, 0.487, -0.054, 0.711, 0.431, -0.276, 0.413, 0.894, 1.195, 0.758, 1.255, 0.219, 0.784, -0.924, -0.495, 0.783, 0.932, 0.562, 0.452, 0.604, 0.819, 0.662, 0.456, 0.542, 1.072, 0.278, 0.587, 0.613, 0.974, -0.616, -0.234, 0.704, 1.044, 0.908, 0.469, 0.525, 0.839, 0.427, 0.404, -0.263, 0.449, -0.597, -5.000, -0.160, 0.524, -1.490, -5.000, 0.000, 0.658, -0.260, -0.361, -0.176, -0.239, -0.816, -0.184, -0.463, 0.106, -1.233, -5.000, -0.616, 0.046, -1.542, -0.460, -0.575, 0.187, -0.298, -1.330, -0.054, -0.244, -1.939, -0.633, -0.854, 0.354, -1.029, -0.709, -1.452, -0.052, -1.463, -1.253, -0.414, -0.149, -1.117, -1.057, -1.247, -0.493, -1.265, -1.117, -0.423, 0.171, -1.086, -0.449, -0.245, 0.589, -1.769, -0.898, -0.158, 0.844, 0.092, -0.356, -0.295, 0.140, -0.455, -0.849, 0.469, 0.989, 0.144, -5.000, 0.222, 0.840, -0.959, -5.000, 0.216, 0.680, -0.093, -0.582, 0.355, 0.349, -0.101, 0.068, 0.282, 0.959, 0.344, -5.000, -0.075, 0.572, -1.256, -0.055, -0.199, 0.063, -0.276, -0.704, 0.489, 0.508, -0.255, 0.244, -0.045, 0.883, -0.316, 0.238, -0.614, 0.251, -0.988, -1.553, -0.072, 0.691, -0.000, -0.516, -0.152, 0.226, -0.660, -0.811, 0.427, 1.087, 0.015, 0.134, 0.032, 0.784, -0.978, -1.248, 0.468, 0.972, 0.645, 0.215, 0.088, 0.714, -0.045, -0.374, -0.327, 0.643, -0.576, -5.000, -0.785, 0.206, -1.003, -5.000, -0.532, 0.291, -0.514, -0.477, 0.221, 0.259, -0.109, 0.433, -0.792, -0.240, -0.600, -5.000, -1.374, -0.213, -3.409, -1.111, -0.410, 0.393, -0.315, -0.955, 0.303, 0.013, -0.528, -0.507, -0.468, 0.469, -1.284, -0.258, -1.579, -0.627, -1.763, -2.015, -1.216, 0.018, -0.746, -1.708, -0.649, 0.002, -0.506, -0.971, -0.807, 0.145, -1.293, -1.121, -0.542, 0.029, -1.205, -1.558, -0.327, 0.285, -0.167, -1.114, -0.433, 0.010, -0.594, -0.877, 0.241, 0.964, -0.013, -5.000, 0.138, 0.819, -0.288, -5.000, 0.423, 0.955, 0.394, 0.230, 0.715, 0.530, 0.750, 1.031, -0.603, 0.103, -0.303, -5.000, -0.459, 0.228, -0.231, -0.468, 0.208, 0.378, 0.382, -0.572, 0.325, 0.324, -0.490, 0.038, 0.343, 0.703, -0.083, 0.373, -0.509, 0.150, -0.311, -0.939, 0.180, 0.750, -0.049, -0.742, 0.080, 0.387, -0.463, -0.214, -0.044, 0.637, -0.179, -0.130, 0.324, 0.720, -0.558, -0.604, 0.283, 0.851, 0.428, -0.039, 0.141, 0.361, 0.045, -0.141, -0.855, -0.610, -1.481, -5.000, -1.909, -0.728, -0.945, -5.000, -0.249, 0.206, -0.677, -0.637, -0.837, -0.872, -0.835, -0.587, -1.477, -0.128, -1.798, -5.000, -0.985, -0.408, -1.164, -0.854, -0.349, 0.057, -1.484, -0.519, -0.461, -0.219, -1.602, -0.880, -1.746, -0.668, -1.227, -1.733, -2.716, -0.762, -0.869, -3.100, -1.051, -0.826, -0.917, -1.058, -1.013, -1.717, -1.865, -2.265, -1.353, -1.017, -1.405, -1.634, -1.416, -0.565, -2.495, -1.530, -0.637, 0.057, -1.096, -1.345, -1.265, -0.398, -0.932, -1.316, -1.137, -0.726, -1.395, -5.000, -1.286, -0.338, -2.764, -5.000, -1.226, -0.371, -1.256, -1.443, -1.304, -1.517, -1.517, -1.186, -1.507, -1.117, -0.951, -5.000, -1.936, -0.939, -2.079, -1.763, -0.955, -0.487, -1.008, -2.037, -1.190, -0.952, -1.235, -1.441, -1.436, -0.893, -1.406, -1.377, -2.061, -1.386, -1.786, -2.768, -1.713, -0.959, -1.939, -1.827, -1.523, -1.042, -2.534, -2.295, -1.503, -0.789, -1.619, -1.205, -1.450, -0.573, -2.613, -2.444, -1.336, -0.950, -1.325, -1.759, -1.515, -0.846, -1.423, -1.709, 0.012, 0.775, -0.395, -5.000, -0.109, 0.554, -1.185, -5.000, 0.113, 0.481, -0.269, -0.272, 0.412, 0.302, 0.121, 0.568, -0.393, 0.209, -0.771, -5.000, -0.731, 0.074, -0.655, -1.121, -0.503, 0.283, -0.049, -0.680, 0.433, 0.061, -0.227, -0.223, 0.087, 0.446, -0.623, -0.032, -0.856, 0.047, -1.347, -1.580, -0.412, 0.185, -0.613, -1.160, -0.027, 0.290, -0.410, -0.491, -0.136, 0.548, -0.596, -0.430, -0.299, 0.545, -1.239, -0.993, 0.042, 0.469, 0.297, -0.389, 0.072, 0.424, -0.503, -0.439, 0.563, 1.091, 0.560, -5.000, 0.473, 1.204, -0.376, -5.000, 0.593, 0.750, -0.132, 0.109, 0.941, 0.861, 0.656, 0.918, -0.368, 0.422, -0.487, -5.000, -0.147, 0.117, -5.000, -0.967, 0.222, 0.401, -0.385, -0.056, 0.051, 0.009, -1.399, -0.480, 0.711, 1.036, 0.239, 0.796, -0.115, 0.521, -1.287, -1.746, 0.471, 0.599, -0.021, -0.080, 0.458, 0.621, 0.037, -0.284, 0.622, 1.103, 0.316, 0.387, 0.433, 1.125, -0.747, -0.762, 0.331, 0.907, 0.401, 0.117, 0.591, 0.787, 0.237, 0.114, -0.098, 0.514, -0.556, -5.000, -0.248, 0.114, -1.033, -5.000, -0.238, -0.102, -0.261, -0.916, 0.057, 0.017, -0.225, -0.104, -0.817, -0.236, -0.803, -5.000, 0.186, 0.129, -1.617, -0.288, -0.530, -0.454, -0.668, -1.367, 0.090, -0.220, -0.860, -0.502, -0.469, 0.513, -0.627, -0.611, -1.013, 0.117, -0.654, -0.957, -0.125, -0.060, -0.279, -1.000, -0.231, 0.015, -0.543, -0.701, -0.221, 0.671, -0.616, -0.563, -0.420, 0.290, -1.365, -0.597, 0.018, -0.109, -0.264, -0.224, -0.081, 0.230, -0.498, -0.888, -0.366, 0.237, -0.627, -5.000, -0.603, -0.539, -1.863, -5.000, -0.511, -0.358, -0.842, -0.999, -0.288, -0.258, -0.447, -0.113, -1.062, -0.269, -0.373, -5.000, -0.998, -0.109, -1.006, -0.776, -0.550, -0.476, -0.666, -1.059, -0.079, -0.425, -1.605, -0.641, -0.719, -0.309, -0.899, -0.469, -1.475, -0.860, -1.048, -2.457, -0.697, -0.311, -1.145, -1.305, -1.027, -0.793, -0.932, -1.225, -0.568, 0.025, -1.191, -0.741, -0.743, -0.150, -1.596, -2.228, -0.583, 0.113, -0.568, -0.894, -0.260, -0.029, -0.319, -0.806, -0.055, 0.737, -0.359, -5.000, -0.035, 0.584, -0.950, -5.000, -0.151, 0.517, -0.624, -0.447, 0.157, 0.188, -0.254, 0.293, -0.062, 0.627, 0.047, -5.000, -0.331, 0.234, -1.965, -0.694, -0.233, 0.304, -0.738, -0.409, 0.389, 0.271, -0.851, 0.028, -0.108, 0.457, -0.710, -0.063, -0.755, -0.298, -1.118, -1.933, -0.547, 0.163, -0.526, -1.026, -0.380, -0.006, -0.868, -0.754, -0.011, 0.642, -0.625, -0.584, -0.183, 0.359, -1.038, -1.292, 0.092, 0.395, 0.032, -0.598, -0.143, 0.313, -0.355, -0.484, 0.365, 0.956, 0.021, -5.000, 0.285, 0.746, -0.492, -5.000, 0.268, 0.612, 0.068, -0.020, 0.627, 0.607, 0.301, 0.728, -0.050, 0.443, -0.802, -5.000, -0.245, 0.438, -0.879, -0.412, 0.234, 0.574, -0.516, -0.098, 0.386, 0.181, -1.402, -0.402, 0.329, 0.948, 0.148, 0.067, -0.306, -0.049, -2.023, -1.047, 0.314, 0.431, 0.016, -0.746, 0.045, -0.316, -0.713, -0.625, 0.170, 0.840, -0.340, -0.159, 0.432, 0.799, -0.542, -0.927, 0.071, 0.495, 0.134, -0.183, 0.178, 0.610, -0.214, -0.090, -0.214, 0.498, -0.356, -5.000, -0.007, 0.257, -0.710, -5.000, 0.244, 0.532, -0.507, -0.412, -0.098, -0.372, -0.568, -0.084, -0.432, 0.095, -0.736, -5.000, -0.324, -0.041, -1.222, -0.791, -0.292, -0.282, -1.119, -0.596, 0.154, -0.098, -1.133, -0.682, -0.529, -0.098, -0.985, -0.897, -0.605, -0.204, -1.927, -2.345, -0.394, 0.126, -1.018, -0.843, -1.075, -0.560, -1.851, -1.466, -0.378, 0.324, -1.125, -0.665, -0.647, 0.089, -1.955, -2.210, -0.237, 0.048, -0.543, -0.747, -0.539, -0.295, -1.044, -0.962, -0.178, 0.593, -0.562, -5.000, -0.084, 0.384, -0.624, -5.000, -0.264, 0.142, -0.788, -0.606, -0.194, -0.209, -0.770, -0.204, -0.428, 0.583, -0.300, -5.000, -0.640, -0.013, -1.527, -0.896, -0.813, -0.037, -0.833, -1.136, -0.032, -0.052, -1.012, -0.380, -0.575, 0.098, -1.140, -0.741, -1.310, -0.327, -1.544, -2.660, -0.702, -0.060, -1.296, -1.126, -0.981, -0.810, -1.284, -1.487, -0.335, 0.487, -0.848, -0.705, -0.469, 0.149, -0.986, -1.811, -0.497, 0.067, -0.358, -0.713, -0.713, -0.203, -0.606, -0.845, 0.325, 0.998, 0.051, -5.000, -0.217, 0.568, -1.018, -5.000, 0.038, 0.718, 0.125, -0.163, 0.494, 0.551, -0.201, 0.413, -0.170, 0.555, -0.509, -5.000, -0.541, 0.225, -1.670, -0.384, -0.090, 0.460, -0.100, -0.326, 0.424, 0.467, -0.431, 0.376, 0.365, 0.718, -0.181, 0.471, -0.332, 0.019, -0.843, -1.237, -0.056, 0.334, -0.184, -0.573, 0.070, 0.419, 0.043, -0.163, 0.042, 0.651, -0.641, -0.241, -0.175, 0.516, -1.326, -1.039, 0.377, 0.705, 0.199, -0.040, 0.198, 0.491, 0.060, -0.221, 0.860, 1.297, 0.744, -5.000, 0.451, 1.131, -0.133, -5.000, 0.813, 1.197, 0.835, 0.608, 1.137, 1.140, 0.562, 1.077, 0.325, 0.878, -0.271, -5.000, 0.139, 0.691, -0.496, 0.384, 0.841, 1.056, 0.578, 0.404, 0.875, 0.920, -0.126, 0.654, 1.058, 1.256, 0.890, 1.284, 0.302, 0.663, 0.117, -0.533, 0.752, 1.189, 1.071, 0.515, 0.792, 0.953, 0.780, 0.581, 0.699, 1.179, 0.387, 0.682, 0.758, 1.006, 0.191, 0.083, 0.824, 1.170, 1.086, 0.667, 0.707, 0.984, 0.596, 0.510, -0.259, 0.545, -0.663, -5.000, -0.293, 0.511, -1.269, -5.000, 0.031, 0.612, -0.274, -0.212, -0.313, 0.078, -0.873, -0.279, -0.439, 0.241, -0.788, -5.000, -0.682, -0.026, -1.651, -0.399, -0.572, 0.483, -0.962, -0.756, 0.014, -0.336, -1.143, -0.543, -0.559, -0.125, -1.199, -0.236, -0.952, 0.325, -1.302, -1.480, -0.567, 0.188, -0.764, -1.172, -0.912, -0.504, -1.303, -1.202, -0.411, 0.370, -0.704, -0.413, -0.335, 0.567, -1.233, -1.062, -0.021, 0.663, -0.031, -0.168, -0.235, 0.098, -0.913, -0.857, 0.101, 0.584, -0.402, -5.000, -0.347, 0.292, -1.470, -5.000, -0.115, 0.401, -0.207, -0.469, 0.033, 0.014, -0.638, -0.493, 0.140, 0.735, 0.037, -5.000, -0.362, 0.089, -1.361, -0.392, -0.102, 0.233, -0.240, -0.542, 0.304, 0.303, -0.422, 0.098, -0.186, 0.551, -0.713, 0.060, -0.877, -0.164, -1.507, -1.666, -0.202, 0.582, -0.275, -0.682, -0.414, -0.192, -0.603, -0.796, 0.307, 0.887, -0.373, -0.001, 0.085, 0.604, -0.990, -1.044, 0.443, 0.885, 0.397, 0.080, 0.067, 0.370, -0.267, -0.380, 0.090, 0.876, -0.064, -5.000, -0.287, 0.664, -1.173, -5.000, 0.125, 0.620, -0.012, -0.088, 0.386, 0.620, 0.005, 0.513, -0.334, 0.169, -0.760, -5.000, -0.775, -0.015, -1.889, -0.323, -0.112, 0.413, 0.007, -0.550, 0.538, 0.401, -0.238, 0.241, 0.123, 0.779, -0.430, 0.259, -0.438, 0.124, -1.463, -1.318, -0.330, 0.298, -0.513, -0.504, -0.002, 0.393, -0.154, -0.209, -0.236, 0.373, -0.955, -0.449, -0.345, 0.410, -1.385, -1.176, -0.008, 0.570, -0.030, -0.211, 0.124, 0.380, -0.039, -0.485, 0.687, 1.180, 0.559, -5.000, 0.404, 0.667, -0.043, -5.000, 0.951, 1.171, 0.771, 0.547, 1.037, 0.977, 0.733, 1.187, 0.081, 0.665, -0.412, -5.000, -0.221, 0.333, -1.170, -0.153, 0.787, 1.039, 0.504, 0.273, 0.817, 0.342, -0.315, 0.489, 0.645, 0.889, 0.745, 1.013, 0.234, 0.606, -0.129, -0.385, 0.635, 1.082, 0.487, 0.372, 0.572, 0.398, 0.575, 0.403, 0.503, 1.043, 0.450, 0.716, 0.722, 1.071, 0.228, 0.143, 0.694, 1.182, 0.876, 0.480, 0.643, 0.825, 0.366, 0.541, -0.637, -0.291, -1.605, -5.000, -0.570, 0.144, -1.596, -5.000, -0.267, 0.603, -0.703, -0.661, -0.935, -0.366, -0.786, -0.517, -1.035, -0.223, -1.747, -5.000, -1.008, -0.339, -2.582, -0.824, -0.199, 0.527, -0.738, -0.846, -0.316, -0.729, -1.291, -0.659, -0.735, -1.152, -1.557, -1.213, -1.435, -0.516, -1.847, -1.685, -0.804, -0.262, -1.375, -1.491, -1.291, -0.649, -1.926, -1.801, -0.830, -0.885, -1.485, -1.009, -1.280, -0.140, -1.918, -2.048, -0.217, 0.326, -0.661, -0.704, -1.010, -0.872, -1.428, -1.470, -0.596, -0.097, -1.122, -5.000, -0.922, -0.144, -2.402, -5.000, -0.658, -0.387, -1.022, -1.090, -0.491, -0.657, -1.139, -1.028, -1.059, -0.398, -1.277, -5.000, -1.588, -0.912, -2.657, -1.494, -0.612, -0.323, -0.781, -1.190, -0.352, -0.833, -1.231, -0.903, -0.742, -0.491, -1.239, -0.746, -1.624, -0.763, -3.270, -3.346, -1.305, -0.317, -2.328, -1.994, -1.377, -0.649, -1.421, -1.389, -1.000, -0.261, -1.213, -1.055, -1.328, -0.424, -2.030, -1.987, -0.765, -0.277, -0.746, -1.279, -1.211, -0.671, -1.459, -1.298, 0.235, 0.843, 0.032, -5.000, 0.003, 0.740, -0.879, -5.000, 0.089, 0.557, -0.007, -0.158, 0.414, 0.566, 0.036, 0.571, -0.050, 0.452, -0.199, -5.000, -0.373, 0.529, -0.677, -0.101, 0.026, 0.576, 0.068, -0.610, 0.653, 0.630, -0.360, 0.297, 0.256, 0.612, 0.044, 0.468, -0.136, 0.180, -0.742, -1.355, 0.211, 0.598, 0.119, -0.509, 0.301, 0.459, -0.083, -0.072, -0.014, 0.598, -0.408, -0.114, -0.142, 0.566, -0.480, -1.238, 0.386, 0.522, 0.298, -0.217, 0.073, 0.590, -0.055, -0.022, 0.682, 1.257, 0.965, -5.000, 0.502, 1.168, -0.190, -5.000, 0.630, 0.955, 0.220, 0.312, 0.945, 1.043, 0.572, 1.013, 0.455, 1.027, 0.578, -5.000, 0.606, 1.024, 0.123, 0.503, 0.523, 0.750, -0.065, -0.085, 0.937, 0.788, 0.196, 0.690, 0.801, 1.198, 0.695, 1.087, 0.413, 0.627, -0.585, -0.432, 0.782, 1.087, 0.077, 0.272, 0.661, 0.834, 0.483, 0.261, 0.618, 1.224, 0.609, 0.701, 0.672, 1.208, 0.057, 0.000, 0.631, 1.121, 0.604, 0.354, 0.721, 0.980, 0.362, 0.257, 0.236, 0.867, 0.087, -5.000, 0.415, 0.733, -0.657, -5.000, 0.328, 0.280, -0.221, -0.273, 0.312, 0.499, 0.080, 0.237, -0.163, 0.462, -0.299, -5.000, 0.430, 0.487, -1.066, 0.174, -0.340, 0.219, -0.269, -0.691, 0.543, 0.334, -0.309, -0.031, 0.253, 0.961, -0.157, -0.068, -0.606, 0.562, -0.856, -0.948, 0.236, 0.235, -0.271, -0.507, 0.236, 0.427, -0.328, -0.113, 0.416, 1.124, 0.188, 0.295, 0.155, 0.884, -0.365, -0.320, 0.338, 0.456, -0.133, -0.093, 0.401, 0.586, -0.074, -0.236, -0.080, 0.559, -0.150, -5.000, -0.457, 0.028, -1.182, -5.000, -0.321, 0.081, -0.587, -0.761, -0.101, 0.011, -0.384, -0.041, -0.246, 0.404, -0.363, -5.000, -0.578, -0.399, -1.243, -0.333, -0.234, -0.443, -0.616, -0.979, 0.282, 0.067, -0.519, -0.036, -0.136, 0.489, -0.279, -0.001, -0.742, 0.185, -1.057, -1.243, -0.101, 0.156, -0.405, -0.774, -0.298, 0.217, -0.098, -0.583, -0.115, 0.621, -0.277, 0.056, -0.268, 0.553, -0.749, -1.213, 0.002, 0.269, -0.032, -0.535, -0.080, 0.318, 0.011, -0.394, 0.128, 0.897, -0.011, -5.000, -0.188, 0.502, -1.144, -5.000, -0.035, 0.564, -0.209, -0.496, 0.280, 0.391, -0.361, 0.190, -0.055, 0.671, -0.147, -5.000, -0.592, 0.404, -1.453, -0.766, 0.001, 0.488, -0.058, -0.254, 0.300, 0.356, -0.670, 0.038, 0.193, 0.650, -0.286, 0.248, -0.424, -0.095, -1.243, -1.670, -0.145, 0.334, -0.145, -0.622, 0.012, 0.217, -0.247, -0.399, 0.171, 0.739, -0.339, -0.108, -0.086, 0.527, -1.066, -1.132, 0.203, 0.800, 0.353, -0.212, 0.019, 0.517, -0.169, -0.248, 0.471, 1.068, 0.406, -5.000, -0.037, 0.839, -0.616, -5.000, 0.302, 0.889, 0.366, 0.057, 0.837, 0.817, 0.382, 0.753, 0.299, 0.722, -0.270, -5.000, 0.157, 0.722, -0.857, -0.045, 0.552, 0.819, 0.234, 0.114, 0.530, 0.490, -0.438, 0.173, 0.712, 1.022, 0.355, 0.728, 0.097, 0.620, -0.959, -1.086, 0.559, 0.918, 0.561, 0.067, 0.223, 0.663, 0.048, -0.170, 0.550, 1.077, 0.079, 0.403, 0.450, 0.968, -0.053, -0.515, 0.486, 1.040, 0.640, 0.281, 0.347, 0.690, 0.143, 0.199, 0.140, 0.788, -0.198, -5.000, 0.130, 0.739, -0.990, -5.000, 0.260, 0.599, -0.243, -0.259, 0.018, 0.072, -0.573, -0.107, -0.195, 0.597, -0.429, -5.000, -0.420, 0.155, -1.583, -0.261, -0.138, 0.298, -0.910, -0.686, 0.311, 0.150, -1.090, -0.160, -0.252, 0.353, -1.282, -0.741, -0.597, 0.247, -1.128, -1.446, -0.085, 0.338, -0.518, -0.645, -0.492, -0.145, -0.846, -0.849, -0.135, 0.470, -1.085, -0.416, -0.307, 0.312, -1.584, -1.828, -0.334, 0.354, -0.315, -0.375, -0.446, 0.003, -0.894, -0.983, -0.024, 0.654, -0.417, -5.000, -0.295, 0.406, -1.277, -5.000, -0.152, 0.183, -0.458, -0.614, -0.160, -0.112, -0.687, -0.301, -0.153, 0.569, -0.191, -5.000, -0.450, 0.134, -1.262, -0.565, -0.489, -0.061, -0.539, -1.111, 0.093, 0.169, -0.752, -0.169, -0.359, 0.387, -0.885, -0.450, -0.882, -0.059, -1.251, -1.630, -0.323, 0.166, -0.762, -0.796, -0.606, -0.449, -0.986, -0.990, -0.094, 0.607, -0.532, -0.361, -0.244, 0.401, -0.909, -1.537, -0.168, 0.265, -0.167, -0.492, -0.354, 0.109, -0.560, -0.566 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_8(struct _training *tptr) {
  struct _training tinf = {
    0.387, 11, 4.350, { 2.554, 0.142, 0.303 }, { 0.886, -1.323, -2.170 }, 1, 
    { -1.790, -1.889, -1.193, -0.722, -4.000, -4.000, -0.824, 0.429, -4.000, -0.949, 0.358, -4.000, 0.700, -0.123, 0.061, 1.705, 2.066, -0.287, 0.426, 1.426, 1.823, 2.536, 3.115, 1.475, 2.936, 2.188, 3.060, 3.325 }, 
    {{ 0.050, -0.233, -0.015, 0.086},{ 0.216, -0.355, -0.187, 0.054},{ 0.366, 0.029, -0.884, -0.095},{ 0.356, 0.006, -0.632, -0.145},{ 0.344, -0.108, -0.645, -0.046},{ 0.319, -0.336, -0.535, 0.064},{ 0.258, -0.212, -0.355, 0.014},{ 0.289, -0.195, -0.390, -0.020},{ 0.305, -0.336, -0.400, 0.031},{ 0.220, -0.272, -0.346, 0.086},{ 0.255, -0.187, -0.322, -0.009},{ 0.172, -0.308, -0.341, 0.150},{ 0.204, -0.131, -0.259, -0.005},{ 0.202, -0.191, -0.308, 0.052},{ 0.181, -0.079, -0.360, 0.039},{ 0.206, -0.112, -0.246, -0.024},{ 0.280, -0.082, -0.304, -0.114},{ 0.141, -0.022, -0.254, 0.004},{ 0.137, -0.086, -0.175, 0.006},{ 0.128, -0.029, -0.246, 0.019},{ 0.122, -0.171, -0.322, 0.134},{ 0.147, -0.046, -0.290, 0.029},{ 0.197, -0.112, -0.327, 0.025},{ 0.149, -0.195, -0.281, 0.101},{ 0.124, -0.090, -0.304, 0.084},{ 0.103, -0.025, -0.360, 0.094},{ 0.124, -0.131, -0.250, 0.082},{ 0.165, -0.135, -0.290, 0.058},{ 0.082, -0.124, -0.313, 0.147},{ 0.066, -0.127, -0.175, 0.103},{ 0.058, -0.139, -0.199, 0.128},{ 0.080, 0.090, -0.216, -0.020} }, 
    {{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}} }, 
    0.000, { 0.532, 0.986, 0.526, -5.000, -0.593, 0.576, 0.222, -5.000, 0.266, 0.440, 0.042, -0.186, -0.288, 0.033, 0.003, 0.492, 0.014, 0.568, -0.283, -5.000, -1.138, 0.536, -0.363, -0.310, -0.062, 0.416, -0.206, -0.859, 0.638, 0.355, -0.547, 0.182, 0.022, 0.578, -0.212, 0.317, -0.316, 0.423, 0.324, -1.458, 0.099, 0.490, -0.168, -0.670, 0.289, 0.446, 0.210, -0.344, 0.340, 0.848, -0.005, 0.502, 0.179, 0.906, 0.946, -0.729, 0.543, 1.087, 0.721, 0.186, 0.675, 0.709, 0.522, 0.223, 1.158, 1.439, 1.123, -5.000, 0.486, 1.113, 0.806, -5.000, 1.148, 1.421, 1.179, 0.836, 0.358, 1.113, 0.765, 1.167, 0.469, 0.992, 0.275, -5.000, -0.542, 0.631, 0.152, 0.216, 0.391, 0.752, 0.102, -0.207, 1.003, 0.951, -0.277, 0.552, 0.653, 0.966, 0.222, 0.591, 0.228, 0.944, 0.956, -1.077, 0.759, 0.998, 0.539, 0.026, 1.237, 1.028, 0.330, 0.015, 0.791, 1.218, 0.427, 0.916, 0.731, 1.280, 1.326, -0.356, 0.929, 1.264, 0.916, 0.617, 1.256, 1.138, 0.786, 0.786, 0.584, 1.026, 0.249, -5.000, -0.261, 0.654, 0.108, -5.000, 0.761, 1.026, 0.356, 0.200, -0.479, 0.442, -0.139, 0.547, 0.223, 0.761, -0.043, -5.000, -0.670, 0.489, -0.875, -0.384, 0.338, 0.686, -0.414, -0.376, 0.891, 0.468, -0.428, 0.287, -0.034, 0.514, -0.370, 0.173, -0.014, 0.389, 0.412, -1.320, 0.244, 0.743, -0.398, -0.608, 0.282, 0.005, -0.215, -0.186, 0.071, 0.750, -0.338, 0.166, 0.443, 0.718, 0.699, -0.808, 0.550, 1.034, 0.334, 0.226, 0.794, 0.648, -0.167, -0.214, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.873, -0.011, -0.761, -5.000, -1.598, -0.714, -1.493, -5.000, -0.603, -0.134, -0.819, -1.363, -0.933, -0.489, -0.516, -0.282, -0.866, -0.217, -0.874, -5.000, -1.560, -0.627, -2.084, -1.293, -0.729, -0.336, -0.567, -1.140, -0.123, -0.118, -0.638, -0.459, -1.337, -0.466, -0.893, -1.182, -1.789, -0.757, -0.654, -2.325, -0.795, -0.296, -1.530, -2.039, -0.781, -0.476, -0.796, -1.402, -0.583, -0.012, -0.683, -0.382, -0.740, -0.413, -0.541, -2.362, -0.499, 0.463, -0.401, -0.789, -0.067, -0.059, -0.512, -0.517, 0.635, 1.143, 0.648, -5.000, -0.082, 0.838, 0.146, -5.000, 0.879, 1.058, 0.949, 0.551, -0.072, 0.893, 0.853, 0.844, 0.281, 0.567, 0.233, -5.000, -0.667, 0.510, -0.297, 0.279, 0.526, 0.863, 0.578, -0.114, 0.971, 0.521, -0.181, 0.203, 0.114, 0.422, 0.108, 0.231, 0.219, 0.886, 0.258, -1.334, 0.380, 0.673, 0.364, -0.164, 0.771, 0.722, 0.137, -0.388, 0.270, 0.572, 0.029, 0.314, -0.107, 0.964, 0.892, -0.835, 0.486, 0.832, 0.536, 0.233, 0.670, 0.605, 0.272, 0.250, -0.066, 0.348, -0.274, -5.000, -0.400, -0.083, -0.799, -5.000, -0.580, -0.301, -1.070, -0.878, -0.991, -0.285, -0.949, -0.242, -0.339, 0.503, -0.405, -5.000, -1.137, 0.025, -1.517, -0.579, -0.525, -0.739, -1.282, -1.137, 0.118, -0.031, -1.280, -0.335, -0.253, -0.100, -1.119, -0.043, -0.271, 0.339, -0.191, -1.188, -0.454, -0.631, -1.185, -1.070, -0.005, -0.190, -0.905, -0.585, -0.112, 0.327, -0.557, -0.392, -0.023, 0.504, 0.430, -1.400, 0.068, 0.323, -0.787, -0.655, 0.724, 0.153, -0.431, -0.519, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.415, 0.917, 0.320, -5.000, -0.661, 0.695, 0.108, -5.000, 0.270, 0.501, 0.192, -0.117, -0.315, 0.443, 0.077, 0.447, -0.049, 0.589, 0.275, -5.000, -0.824, 0.649, -0.025, -0.103, 0.314, 0.655, 0.229, -0.366, 0.667, 0.669, -0.075, 0.239, -0.073, 0.343, 0.066, 0.486, -0.646, 0.198, -0.163, -1.458, -0.156, -0.023, -0.730, -0.704, 0.443, 0.169, 0.186, -0.062, 0.257, 0.801, 0.053, 0.592, 0.009, 0.722, 0.795, -0.857, 0.091, 0.399, -0.086, -0.339, 0.831, 0.424, -0.064, 0.387, 0.729, 1.201, 0.684, -5.000, -0.253, 0.932, 0.071, -5.000, 0.578, 0.877, 0.271, 0.034, -0.343, 0.846, 0.472, 0.666, 0.189, 0.771, 0.562, -5.000, -0.994, 0.669, 0.171, 0.113, 0.260, 0.683, 0.382, -0.471, 0.595, 0.662, -0.160, 0.351, -0.181, 0.532, -0.247, 0.202, -0.576, 0.521, 0.237, -1.345, 0.015, 0.388, -0.613, -0.476, 0.566, -0.045, -0.212, -0.409, 0.860, 1.078, 0.031, 0.800, 0.278, 1.025, 0.804, -0.542, 0.491, 0.630, -0.196, -0.062, 1.128, 0.573, 0.183, 0.582, 0.096, 0.304, -0.129, -5.000, -0.878, 0.526, -0.567, -5.000, 0.411, 0.316, -0.739, -0.571, -0.778, 0.089, 0.007, 0.104, -0.321, 0.465, -0.373, -5.000, -1.109, -0.249, -1.367, -0.726, 0.267, 0.149, -0.615, -0.779, 0.190, 0.469, -0.822, -0.043, 0.384, 0.818, 0.055, 0.518, -0.121, 0.477, 0.126, -0.882, 0.161, -0.062, -0.312, -0.760, 0.179, -0.167, -0.453, 0.121, 0.316, 0.934, -0.134, -0.153, -0.135, 0.542, 0.490, -1.304, 0.391, 0.270, -0.679, -0.293, 0.738, 0.318, -0.020, -0.260, -0.042, 0.376, -0.167, -5.000, -0.925, 0.032, -1.204, -5.000, -0.348, -0.385, -0.475, -0.926, -0.885, -0.047, -0.210, -0.023, -0.392, 0.266, -0.308, -5.000, -1.578, -0.296, -1.035, -0.969, -0.323, -0.258, -0.943, -1.422, 0.188, 0.052, -0.625, -0.069, -0.521, 0.045, -0.151, -0.262, -0.811, 0.258, -0.243, -1.453, -0.238, -0.049, -0.858, -0.818, 0.147, -0.019, -0.270, 0.054, -0.453, 0.285, -0.462, -0.195, -0.317, 0.484, 0.033, -1.402, -0.342, -0.056, -0.591, -0.852, 0.389, 0.067, -0.240, -0.167, -0.513, -0.170, -0.575, -5.000, -0.913, -0.315, -1.581, -5.000, -0.812, -0.851, -1.244, -1.472, -1.144, -0.864, -1.061, -0.556, -0.829, -0.209, -0.680, -5.000, -1.087, -0.034, -1.087, -1.045, -0.685, -0.706, -1.091, -1.098, -0.388, -0.567, -1.321, -0.888, -1.079, -0.380, -0.990, -1.112, -1.003, -0.500, -0.745, -1.598, -0.925, -0.540, -1.049, -1.738, -0.961, -0.706, -0.532, -1.262, -0.445, 0.238, -0.840, -0.145, -0.275, 0.058, -0.329, -0.802, -0.361, 0.069, -0.360, -0.424, -0.214, -0.314, -0.747, -0.416, 0.546, 1.067, 0.295, -5.000, -0.646, 0.693, -0.239, -5.000, 0.429, 0.554, 0.219, 0.016, -0.684, 0.108, -0.062, 0.358, -0.125, 0.320, -0.083, -5.000, -0.859, 0.726, -0.472, -0.123, -0.207, 0.193, -0.341, -0.563, 0.064, 0.069, -0.818, -0.155, -0.626, -0.002, -0.752, -0.471, -0.665, 0.173, -0.071, -1.092, -0.522, 0.076, -0.208, -0.977, -0.299, -0.369, -0.912, -0.960, 0.292, 0.572, -0.118, 0.695, -0.040, 0.686, 0.869, -0.576, 0.326, 0.562, 0.020, 0.047, 0.707, 0.309, 0.007, 0.208, 0.255, 0.787, 0.338, -5.000, -0.926, 0.583, -0.526, -5.000, 0.096, 0.470, -0.414, -0.462, -0.551, 0.157, -0.019, 0.150, -0.424, 0.421, -0.246, -5.000, -1.178, -0.011, -0.874, -0.600, -0.145, 0.079, -0.429, -0.572, -0.045, -0.070, -0.687, -0.281, -0.016, 0.387, -0.594, -0.122, -0.078, 0.624, 0.219, -1.059, 0.564, 0.735, -0.496, -0.323, 0.030, 0.180, -0.476, -0.487, 0.118, 0.400, -0.474, -0.122, 0.447, 0.675, 0.183, -0.864, 0.167, 0.587, -0.077, -0.317, 0.207, -0.044, -0.550, -0.408, 0.637, 1.257, 0.874, -5.000, -0.652, 0.427, -0.399, -5.000, 0.023, 0.085, -0.379, -0.474, -0.407, -0.016, -0.127, 0.351, 0.180, 1.042, 0.609, -5.000, -0.474, 0.296, -0.351, -0.267, 0.028, 0.117, -0.734, -0.990, 0.521, 0.175, -0.410, 0.162, 0.298, 0.866, 0.440, 0.353, 0.204, 0.725, 0.510, -0.678, 0.598, 0.747, -0.113, -0.252, 0.494, 0.634, 0.450, 0.102, 0.215, 1.003, 0.227, 0.330, 0.488, 0.727, 0.675, -0.677, 0.183, 0.557, -0.160, -0.402, 0.655, 0.452, 0.129, 0.053, -0.260, 0.627, -0.013, -5.000, -0.744, 0.182, -0.463, -5.000, -0.513, 0.003, -0.691, -0.911, -1.070, -0.657, -0.775, -0.219, -0.974, 0.222, -0.988, -5.000, -1.412, -0.098, -0.779, -0.948, -0.910, -0.209, -0.638, -0.995, -0.113, -0.128, -1.065, -0.674, -0.404, 0.488, -0.657, 0.048, -0.583, 0.381, 0.222, -1.443, -0.325, 0.444, -0.721, -1.101, -0.021, -0.114, -0.285, -0.854, -0.018, 0.701, -0.322, 0.395, 0.168, 0.689, 0.661, -1.015, 0.606, 0.990, 0.471, 0.210, 0.615, 0.576, 0.447, 0.102, 0.723, 1.227, 0.594, -5.000, 0.158, 0.906, 0.417, -5.000, 0.900, 1.219, 0.813, 0.552, -0.014, 0.809, 0.306, 0.897, 0.017, 0.821, -0.410, -5.000, -0.304, 0.710, 0.133, -0.155, 0.138, 0.690, 0.087, -0.110, 0.568, 0.607, -0.747, 0.144, 0.208, 0.710, -0.153, 0.126, 0.084, 0.493, 0.648, -0.848, 0.203, 0.695, 0.315, -0.162, 0.809, 0.378, 0.181, -0.500, 0.601, 1.158, 0.330, 0.870, 0.621, 1.097, 1.153, -0.105, 0.749, 1.085, 0.532, 0.442, 0.995, 0.958, 0.409, 0.426, 0.121, 0.605, -0.257, -5.000, -0.385, 0.472, -0.753, -5.000, 0.469, 0.741, -0.010, -0.173, -0.776, 0.020, -0.337, 0.167, -0.151, 0.694, -0.298, -5.000, -0.809, 0.379, -0.512, -0.551, 0.258, 0.602, -0.111, -0.453, 0.409, 0.195, -1.002, -0.159, -0.522, 0.373, -0.945, -0.389, -0.177, 0.314, -0.332, -1.688, -0.022, 0.395, -0.590, -1.266, -0.343, -0.539, -1.052, -1.088, 0.163, 0.886, -0.158, 0.185, 0.474, 0.735, 0.675, -0.693, 0.461, 0.824, 0.484, -0.177, 0.577, 0.355, -0.599, -0.632, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -1.105, -0.223, -1.035, -5.000, -1.820, -0.739, -1.448, -5.000, -1.030, -0.514, -1.443, -2.015, -1.485, -0.621, -1.060, -0.649, -1.192, -0.612, -1.210, -5.000, -1.235, -0.999, -2.476, -1.305, -1.202, -0.766, -1.069, -2.291, -0.634, -0.563, -1.540, -1.204, -1.623, -0.599, -1.079, -0.986, -1.486, -0.919, -1.055, -2.761, -2.090, -1.586, -1.500, -2.067, -1.424, -1.378, -1.323, -1.885, -1.000, -0.136, -1.303, -0.963, -1.235, -0.451, -1.101, -2.018, -0.930, 0.037, -0.624, -0.806, -0.337, -0.429, -0.311, -0.829, 0.652, 1.034, 0.487, -5.000, -0.212, 0.729, 0.743, -5.000, 0.942, 0.867, 0.687, 0.486, -0.168, 0.693, 0.555, 0.651, 0.033, 0.837, -0.069, -5.000, -0.498, 0.698, -0.184, -0.114, -0.051, 0.633, 0.145, -0.032, 0.629, 0.190, -0.072, -0.035, 0.019, 0.423, -0.084, 0.384, -0.804, 0.298, 0.302, -1.893, -1.177, 0.150, -2.044, -0.484, 0.642, 0.327, -0.495, -0.742, 0.288, 0.912, -0.021, 0.184, 0.052, 0.948, 0.774, -0.670, 0.102, 0.453, 0.059, -0.195, 0.450, 0.462, -0.093, 0.309, -0.237, 0.253, -0.074, -5.000, -1.072, -0.401, -1.238, -5.000, -0.682, -0.407, -1.098, -0.677, -1.549, -0.635, -1.158, -0.856, -0.386, 0.539, -0.332, -5.000, -1.161, -0.173, -1.763, -1.174, -0.987, -0.603, -1.916, -0.676, -0.397, -0.173, -1.472, -0.556, -0.637, -0.410, -0.329, -0.392, -1.338, 0.040, -0.373, -3.201, -0.650, -1.331, -1.464, -2.366, -1.031, -0.447, -1.522, -1.077, -0.519, 0.443, -0.835, -0.510, -0.124, -0.186, -0.195, -2.086, -0.671, 0.223, -0.617, -0.456, 0.261, -0.299, -0.473, -0.676, -0.301, 0.173, -0.537, -5.000, -1.725, -0.227, -1.412, -5.000, -0.686, -0.395, -1.052, -0.838, -1.539, -0.879, -0.795, -0.592, -0.367, 0.636, -0.043, -5.000, -1.206, -0.300, -0.953, -0.941, -0.592, -0.487, -0.539, -1.116, -0.467, -0.644, -0.849, -0.685, -0.245, 0.435, -0.442, -0.292, -1.023, 0.141, -0.451, -2.112, -0.600, -0.198, -0.668, -1.586, -0.463, -0.347, -1.111, -1.007, -0.709, 0.005, -0.838, -0.655, -0.857, 0.286, -0.147, -1.913, -0.355, 0.071, -0.487, -0.609, -0.357, -0.092, -0.540, -0.747, 0.116, 0.676, -0.129, -5.000, -1.125, 0.698, -0.289, -5.000, 0.228, 0.489, 0.083, -0.140, -0.804, 0.280, 0.001, 0.395, -0.494, 0.437, -0.256, -5.000, -1.101, 0.403, -0.490, -0.714, -0.838, 0.200, -0.130, -0.905, 0.207, 0.461, -0.499, -0.124, -0.264, 0.214, -0.804, 0.120, -0.947, -0.208, -0.323, -1.479, -0.901, -0.438, -1.333, -1.578, -0.362, -0.497, -0.649, -0.933, -0.102, 0.618, 0.050, 0.594, -0.768, 0.430, 0.748, -0.682, -0.069, 0.085, -0.670, -0.149, 0.406, -0.029, -0.836, -0.141, 0.380, 0.969, 0.203, -5.000, -0.540, 0.675, -0.212, -5.000, 0.530, 0.920, 0.578, -0.164, -0.514, 0.393, 0.222, 0.659, 0.086, 0.541, 0.215, -5.000, -0.991, 0.216, 0.248, -0.131, -0.321, 0.126, 0.215, 0.138, 0.210, 0.287, -0.620, 0.089, -0.870, 0.133, -0.459, 0.062, -1.508, -0.312, 0.076, -3.374, -0.484, 0.116, -1.238, -0.994, 0.044, -0.704, -1.688, -0.990, 0.595, 0.859, -0.001, 0.788, 0.086, 0.760, 0.913, -0.163, 0.407, 0.758, 0.188, 0.076, 0.963, 0.355, 0.044, 0.479, -0.103, 0.001, -0.558, -5.000, -0.654, 0.008, -1.128, -5.000, -0.025, 0.200, -0.530, -0.874, -0.871, 0.064, -0.632, -0.216, -0.633, 0.275, -0.639, -5.000, -1.087, -0.490, -1.511, -0.674, -0.356, -0.445, -0.665, -2.210, -0.340, -0.120, -0.868, -0.182, -0.418, 0.203, -0.403, -0.339, -0.751, -0.484, 0.011, -1.310, 0.166, -0.058, -0.994, -0.739, -0.181, -1.036, -0.598, -0.461, -0.273, 0.385, -0.617, -0.263, -0.065, 0.237, 0.166, -0.609, 0.047, 0.409, -0.684, -0.648, 0.442, 0.140, -0.337, -0.727, -0.393, -0.296, -0.670, -5.000, -0.996, -0.313, -1.334, -5.000, -0.959, -0.448, -0.691, -1.560, -1.236, -0.338, -1.285, -0.574, -1.202, -0.321, -0.481, -5.000, -1.071, -0.684, -1.716, -1.548, -1.181, -1.083, -1.133, -1.023, -0.271, -0.265, -1.296, -0.319, -0.851, -0.815, -0.349, -0.932, -1.255, 0.076, -0.664, -2.231, -0.868, -0.777, -1.783, -1.413, -0.762, -0.423, -0.564, -1.147, -0.614, -0.088, -0.525, -0.499, -0.653, 0.155, -0.443, -1.447, -1.155, -0.336, -0.922, -1.156, 0.110, -0.199, -0.159, -0.389, 0.202, 0.887, 0.323, -5.000, -0.505, 0.630, -0.347, -5.000, 0.030, 0.217, 0.051, -0.414, -0.993, -0.336, -0.244, 0.181, -0.253, 0.603, -0.126, -5.000, -0.910, 0.649, 0.268, -0.383, 0.030, 0.534, 0.066, -0.406, 0.337, 0.355, -0.282, -0.026, 0.249, 0.915, 0.476, 0.567, -0.079, 0.835, 0.643, -0.968, 0.559, 0.920, -0.536, -0.190, 0.555, 0.600, 0.177, -0.244, 0.357, 1.102, 0.444, 0.760, 0.310, 1.076, 1.021, -0.173, 0.290, 1.039, 0.401, 0.213, 0.616, 0.606, -0.140, 0.366, 0.526, 1.212, 0.435, -5.000, -0.613, 0.766, 0.250, -5.000, 0.449, 0.697, 0.051, 0.159, -0.761, 0.050, -0.090, 0.577, -0.109, 0.542, -0.130, -5.000, -0.514, 0.505, -0.060, -0.357, -0.087, 0.313, 0.038, -0.449, -0.096, 0.224, -1.131, -0.145, -0.448, 0.420, -0.593, 0.133, -0.454, 0.320, 0.066, -1.420, -0.863, -0.117, -0.777, -1.062, -0.118, -0.327, -0.240, -1.340, 0.725, 1.329, 0.520, 1.167, 0.346, 1.060, 1.221, -0.197, 0.149, 0.729, 0.190, 0.151, 0.839, 0.774, 0.116, 0.476, -0.103, 0.556, -0.072, -5.000, -0.900, 0.337, -0.751, -5.000, -0.146, 0.144, -0.578, -0.685, -0.883, -0.236, -0.454, 0.011, -1.031, -0.008, -0.477, -5.000, -1.502, -0.356, -0.676, -0.973, -0.793, -0.441, -0.674, -0.944, -0.391, -0.607, -1.554, -0.748, -0.631, -0.105, -0.913, -0.434, -0.918, -0.422, -0.345, -1.714, -0.059, 0.171, -1.064, -1.671, -0.891, -0.603, -1.339, -1.720, -0.455, 0.128, -0.973, -0.401, -0.101, 0.141, 0.202, -1.167, -0.395, 0.245, -0.343, -0.696, -0.416, -0.541, -1.327, -1.087, -0.036, 1.027, 0.190, -5.000, -1.225, 0.109, -0.487, -5.000, -0.120, -0.200, -0.529, -0.644, -1.075, -0.379, -0.627, -0.006, -0.472, 0.633, -0.042, -5.000, -1.462, -0.015, -1.033, -0.623, -0.869, -0.409, -1.306, -1.013, 0.158, -0.195, -1.095, -0.382, -0.119, 0.564, -0.273, 0.119, -0.475, 0.464, 0.396, -1.190, 0.344, 0.697, -0.640, -0.804, -0.083, 0.326, -0.188, -0.549, -0.420, 0.856, -0.149, 0.183, 0.168, 0.454, 0.459, -1.149, -0.107, 0.532, -0.143, -0.627, 0.124, 0.071, -0.332, -0.462, -0.108, 0.703, -0.068, -5.000, -1.207, 0.126, -0.498, -5.000, -0.349, 0.114, -0.222, -0.562, -0.987, -0.554, -0.349, 0.083, -0.641, 0.125, -0.848, -5.000, -1.622, -0.057, -0.554, -0.757, -0.887, -0.771, -1.072, -0.843, 0.225, -0.147, -0.991, -0.205, -0.328, 0.095, -0.338, 0.240, -1.034, -0.210, -0.045, -1.738, -0.419, 0.062, -0.842, -1.491, -0.285, -0.115, -0.437, -0.774, -0.136, 0.444, -0.408, 0.404, -0.336, 0.244, 0.699, -1.196, 0.061, 0.821, 0.525, -0.037, 0.391, 0.548, 0.160, -0.039, 0.735, 1.225, 0.610, -5.000, -0.175, 0.819, 0.430, -5.000, 0.849, 1.058, 0.656, 0.377, -0.236, 0.656, 0.486, 0.901, 0.246, 0.838, -0.023, -5.000, -0.699, 0.472, -0.631, -0.052, 0.160, 0.437, -0.581, -0.379, 0.595, 0.831, -0.385, 0.228, 0.011, 0.338, -0.475, 0.266, -0.359, 0.461, 0.453, -0.994, 0.056, 0.455, 0.127, -0.561, 0.596, 0.370, -0.290, -0.769, 0.435, 0.889, 0.041, 0.757, 0.246, 0.885, 0.922, -0.551, 0.486, 0.934, 0.343, 0.314, 0.788, 0.754, 0.376, 0.368, 0.244, 0.591, -0.292, -5.000, -0.918, 0.290, -0.984, -5.000, -0.038, 0.105, -0.566, -0.299, -1.195, 0.084, -0.490, -0.096, -0.329, 0.294, -0.263, -5.000, -1.384, -0.105, -0.582, -1.037, -0.334, -0.312, -0.600, -1.067, 0.431, 0.076, -0.925, -0.269, -0.452, 0.146, -0.702, -0.262, -0.656, -0.051, -0.420, -1.761, -0.024, 0.358, -1.091, -0.884, -0.524, -0.484, -0.854, -0.597, -0.463, 0.520, -0.423, -0.336, -0.260, 0.165, 0.393, -1.344, 0.099, 0.519, 0.197, -0.380, 0.362, 0.357, -0.233, -0.590, 0.388, 0.767, -0.004, -5.000, -1.311, -0.523, -0.879, -5.000, -0.290, -0.476, -0.591, -0.508, -0.468, -0.160, -0.360, -0.168, 0.232, 0.853, 0.343, -5.000, -1.302, -0.221, -0.817, -0.710, -0.790, -0.368, -1.500, -1.437, 0.623, -0.262, -1.003, -0.530, 0.400, 0.832, 0.393, 0.382, -0.587, 0.544, 0.553, -1.579, 0.403, 0.957, -0.100, -0.160, 0.103, 0.341, 0.192, -0.185, 0.256, 0.723, -0.046, -0.041, -0.376, 0.707, 0.565, -1.287, 0.550, 1.018, 0.387, 0.185, 0.387, 0.598, -0.045, -0.155, -0.850, 0.370, -0.562, -5.000, -1.760, -0.215, -0.970, -5.000, -0.418, -0.326, -0.585, -0.853, -1.421, -0.866, -0.570, -0.119, -1.021, 0.143, -0.712, -5.000, -1.787, -0.822, -1.616, -1.306, -0.891, -0.155, -0.441, -1.027, -0.062, -0.191, -0.900, -0.694, -1.102, -0.077, -1.145, -0.520, -1.701, -0.551, -0.519, -2.544, -0.687, -0.116, -1.556, -1.229, -1.013, -0.288, -0.979, -1.664, -0.550, 0.290, -0.709, -0.010, -0.793, 0.038, 0.207, -0.952, -0.183, 0.535, -0.099, -0.377, -0.264, -0.131, -0.420, -0.740, 0.332, 1.093, 0.162, -5.000, -0.399, 0.943, 0.529, -5.000, 0.656, 0.879, 0.657, 0.446, -0.603, 0.221, 0.778, 0.808, -0.147, 0.454, -0.029, -5.000, -0.905, 0.292, -0.905, -0.047, -0.161, 0.529, -0.232, -0.120, 0.627, 0.200, -0.376, -0.279, 0.135, 0.684, -0.037, 0.186, -0.726, 0.653, 0.461, -1.281, -0.495, 0.642, -0.186, -0.426, 0.256, 0.738, -0.260, -0.403, 0.215, 0.893, -0.172, 0.554, 0.039, 0.998, 1.043, -0.490, 0.189, 0.704, 0.184, 0.042, 0.414, 0.388, 0.082, 0.043, 0.508, 1.105, -0.044, -5.000, -0.510, 0.690, -0.524, -5.000, 0.028, -0.057, -0.208, -0.060, -1.151, -0.105, -0.049, 0.032, 0.030, 0.971, 0.220, -5.000, -1.104, -0.062, -0.956, -0.685, -0.451, 0.270, -0.092, -0.739, 0.341, 0.528, -0.292, 0.106, 0.013, 0.879, -0.136, 0.206, -0.366, 0.518, 0.471, -1.193, 0.023, 0.357, -0.268, -0.857, 0.117, 0.010, -0.304, 0.069, -0.044, 0.783, -0.199, -0.013, 0.109, 0.685, 1.004, -1.137, 0.154, 0.818, 0.091, -0.095, 0.942, 1.045, 0.333, -0.238, -1.477, -0.678, -1.547, -5.000, -2.462, -1.505, -2.699, -5.000, -1.728, -1.437, -1.935, -2.020, -2.038, -1.221, -1.191, -1.377, -1.832, -0.228, -0.361, -5.000, -2.325, -1.390, -1.135, -2.729, -2.542, -1.954, -1.889, -2.018, -0.754, -1.158, -1.403, -1.335, -1.684, -0.797, -0.905, -1.206, -2.953, -1.450, -1.305, -2.629, -1.564, -0.706, -1.399, -1.448, -1.693, -0.998, -1.454, -2.033, -1.641, -1.033, -1.580, -1.452, -1.867, -1.269, -1.716, -2.437, -1.445, -1.064, -1.677, -1.614, -1.268, -1.158, -1.250, -1.436, 0.228, 0.850, 0.451, -5.000, -0.763, 0.779, -0.426, -5.000, 0.146, 0.561, 0.148, 0.098, -1.072, 0.151, 0.151, 0.432, -0.262, 0.433, 0.232, -5.000, -0.695, 0.179, 0.001, -0.547, -0.210, 0.330, -0.038, -0.405, 0.437, 0.623, -0.101, 0.101, -0.498, 0.214, -0.117, 0.339, -1.497, -0.342, 0.161, -2.024, -0.521, -0.205, -1.274, -0.808, -0.058, 0.058, -0.340, -0.696, -0.068, 0.822, -0.015, 0.543, -0.719, 0.481, 0.744, -1.063, -0.278, 0.308, -0.185, -0.121, 0.432, 0.224, -0.506, -0.098, 0.542, 1.215, 0.696, -5.000, -0.236, 0.811, -0.650, -5.000, 0.500, 0.944, 0.428, 0.110, -0.674, 0.679, 0.419, 0.597, 0.043, 0.966, 0.727, -5.000, -0.266, 0.715, 0.497, -0.264, -0.008, 0.518, -0.366, -0.456, 0.456, 0.752, 0.087, 0.178, -0.311, 0.439, -0.438, 0.389, -0.511, 0.379, 0.381, -1.338, -0.375, 0.173, -0.396, -1.322, 0.217, 0.083, 0.049, -0.648, 0.645, 1.127, 0.326, 0.979, 0.089, 1.061, 1.065, -0.464, 0.476, 0.822, 0.273, 0.143, 0.952, 0.776, 0.351, 0.474, -0.311, 0.325, -0.408, -5.000, -0.683, 0.018, -1.090, -5.000, -0.610, -0.410, -1.249, -0.974, -1.273, -0.472, -0.394, -0.290, -1.013, -0.185, -0.356, -5.000, -1.728, -0.799, -1.743, -1.443, -0.674, -1.007, -1.090, -0.840, -0.597, -0.281, -1.062, -0.560, -0.377, 0.114, -0.112, -0.502, -0.447, -0.471, -0.225, -1.454, -0.851, -0.296, -1.500, -0.840, -0.653, -0.484, -1.454, -0.948, -0.227, 0.507, -0.380, -0.545, -0.535, 0.505, 0.295, -1.373, -0.277, 0.057, -0.845, -0.857, 0.142, -0.095, -0.234, -0.884, -0.384, 0.220, -0.491, -5.000, -1.736, -0.804, -0.970, -5.000, -1.171, -0.732, -0.937, -0.957, -1.268, -0.674, -0.463, -0.392, -0.708, -0.040, -0.044, -5.000, -1.664, -0.829, -1.864, -1.221, -0.993, -1.241, -1.787, -1.133, 0.045, -0.354, -0.709, -0.459, -0.940, -0.446, -0.977, -1.186, -1.436, -0.549, -0.583, -2.403, -0.873, -0.561, -0.867, -1.093, -1.185, -0.385, -0.622, -1.079, -0.789, -0.387, -0.603, -0.576, -0.872, -0.181, -0.440, -1.703, -0.758, -0.215, -0.659, -1.056, -0.077, -0.141, -0.543, -1.064, 0.042, 0.867, 0.043, -5.000, -0.924, 0.340, -0.582, -5.000, -0.027, -0.094, -0.186, -0.771, -1.322, -0.596, -0.529, 0.060, -0.570, 0.506, -0.251, -5.000, -1.566, 0.416, -0.788, -0.973, -0.424, 0.100, -0.231, -0.420, 0.057, 0.039, -0.683, -0.511, -0.217, 0.523, -0.368, 0.239, -1.005, 0.114, 0.209, -1.665, -0.012, 0.268, -0.761, -0.296, -0.102, 0.008, -0.433, -0.667, 0.050, 0.913, 0.168, 0.580, -0.183, 0.748, 0.958, -0.593, 0.265, 1.007, 0.301, 0.403, 0.494, 0.692, -0.014, 0.174, 0.308, 0.971, 0.299, -5.000, -0.842, 0.499, -0.410, -5.000, 0.305, 0.604, 0.109, -0.253, -1.012, -0.174, -0.072, 0.287, 0.032, 0.597, 0.288, -5.000, -0.665, 0.750, 0.203, -0.295, -0.016, 0.221, 0.241, -0.441, -0.024, 0.458, -0.794, -0.207, -0.498, 0.198, -0.788, -0.250, -0.726, 0.208, 0.551, -1.423, -0.251, 0.241, -0.204, -0.843, -0.175, -0.390, -0.798, -1.116, 0.393, 0.902, 0.077, 0.794, 0.294, 0.791, 0.882, -0.510, 0.154, 0.704, 0.398, 0.165, 0.691, 0.567, 0.061, 0.186, 0.083, 0.902, 0.184, -5.000, -1.328, 0.526, -0.244, -5.000, -0.034, 0.339, -0.288, -0.521, -1.204, -0.104, -0.267, 0.246, -0.535, 0.158, -0.110, -5.000, -1.159, 0.039, -1.132, -0.978, -0.816, -0.150, -1.302, -1.207, -0.146, -0.005, -1.048, -0.698, -0.161, 0.451, -0.256, 0.483, -0.508, 0.198, 0.178, -1.544, 0.438, 0.608, -0.353, -0.445, -0.394, -0.133, -0.705, -0.837, -0.209, 0.341, -0.478, 0.029, -0.182, 0.570, 0.295, -1.169, 0.074, 0.299, -0.107, -0.203, 0.032, 0.145, -0.465, -0.613, -0.197, 0.430, -0.390, -5.000, -1.547, -0.150, -0.571, -5.000, -0.483, -0.396, -0.682, -0.857, -1.244, -1.135, -0.679, -0.559, -0.710, -0.080, -0.194, -5.000, -1.532, -0.493, -0.854, -0.719, -1.002, -0.630, -1.305, -1.533, -0.390, -0.534, -1.304, -0.754, -0.586, 0.007, -0.948, -0.575, -1.343, -0.224, -0.180, -1.862, -0.338, 0.091, -1.024, -0.766, -0.958, -0.509, -0.767, -0.806, -0.752, 0.149, -0.620, -0.264, -0.460, 0.007, 0.145, -1.497, -0.196, 0.258, -0.368, -0.601, -0.307, -0.214, -0.469, -0.947, 0.226, 0.878, 0.191, -5.000, -0.721, 0.556, 0.047, -5.000, 0.071, 0.272, 0.064, -0.168, -0.808, -0.227, -0.232, 0.547, -0.357, 0.449, -0.538, -5.000, -1.285, 0.267, -0.727, -0.240, -0.485, -0.105, -0.209, -0.624, 0.611, 0.350, -0.596, 0.017, -0.354, 0.525, -0.062, 0.295, -0.828, 0.267, 0.114, -1.560, 0.023, 0.524, -0.224, -0.579, 0.052, 0.451, 0.092, -0.602, 0.033, 0.666, -0.097, 0.380, -0.117, 0.472, 0.688, -0.719, 0.439, 0.897, 0.596, 0.149, 0.634, 0.681, 0.355, 0.183, 1.058, 1.391, 0.894, -5.000, 0.196, 1.148, 0.904, -5.000, 1.081, 1.228, 0.983, 0.833, 0.100, 1.134, 0.929, 1.267, 0.608, 0.971, 0.201, -5.000, -0.404, 0.765, -0.151, 0.294, 0.591, 0.980, 0.895, 0.132, 1.082, 1.113, 0.189, 0.605, 0.294, 0.731, 0.103, 0.557, -0.173, 0.824, 0.751, -1.082, 0.329, 0.870, 0.072, -0.242, 0.638, 0.781, 0.153, -0.454, 0.651, 1.087, 0.335, 0.917, 0.574, 1.107, 1.090, -0.318, 0.733, 1.156, 0.609, 0.497, 1.134, 1.000, 0.584, 0.637, 0.111, 0.775, -0.014, -5.000, -0.887, 0.338, -0.665, -5.000, 0.200, 0.293, -0.228, -0.325, -0.934, 0.084, -0.241, 0.463, -0.159, 0.515, -0.271, -5.000, -1.188, 0.480, -0.796, -0.751, 0.080, -0.037, -0.657, -0.562, 0.427, 0.275, -0.742, -0.098, -0.342, 0.172, -0.574, -0.210, -0.509, -0.180, -0.195, -1.830, 0.074, 0.264, -0.706, -1.212, -0.255, -0.083, -0.632, -0.584, -0.158, 0.648, -0.511, -0.217, 0.044, 0.320, 0.435, -1.151, 0.115, 0.525, 0.128, -0.138, 0.449, 0.435, -0.227, -0.366, 0.270, 0.611, -0.178, -5.000, -0.964, -0.049, -1.038, -5.000, -0.216, -0.092, -0.616, -0.802, -0.248, -0.014, -0.217, -0.007, 0.248, 0.782, 0.359, -5.000, -0.829, 0.327, -0.591, -0.641, -0.453, -0.407, -0.554, -1.364, 0.748, 0.293, -0.199, 0.157, 0.340, 0.904, 0.056, 0.344, -0.392, 0.724, 0.643, -1.168, 0.903, 1.186, 0.350, 0.095, 0.621, 0.786, 0.481, -0.051, 0.274, 0.873, 0.075, 0.036, 0.095, 0.870, 0.704, -0.868, 0.874, 1.078, 0.400, 0.471, 0.566, 0.642, 0.213, -0.156, -0.242, 0.726, -0.118, -5.000, -0.901, 0.359, -0.485, -5.000, 0.067, 0.361, 0.053, -0.245, -0.799, -0.348, -0.240, 0.122, -0.249, 0.448, -0.415, -5.000, -1.132, -0.203, -0.983, -0.471, -0.026, 0.322, 0.334, -0.492, 0.574, 0.165, -0.444, 0.255, -0.471, 0.501, -0.171, 0.107, -0.798, 0.130, -0.157, -1.569, -0.075, 0.326, -1.270, -0.802, -0.044, 0.108, -0.089, -0.666, 0.110, 0.815, -0.512, 0.505, -0.063, 0.638, 0.299, -1.156, 0.470, 1.031, 0.543, 0.390, 0.529, 0.467, 0.238, -0.081, 0.701, 1.182, 0.471, -5.000, -0.362, 0.913, 0.450, -5.000, 1.045, 1.273, 1.250, 0.795, -0.034, 0.943, 0.873, 1.019, 0.059, 0.539, -0.042, -5.000, -1.344, 0.615, -0.421, -0.086, 0.506, 1.102, 0.380, 0.308, 0.720, 0.587, -0.452, 0.164, 0.146, 0.915, 0.176, 0.438, -0.224, 0.923, 0.656, -0.637, 0.332, 1.022, 0.433, 0.351, 0.969, 0.929, 0.262, 0.185, 0.628, 1.146, 0.351, 0.874, 0.499, 1.288, 1.254, -0.285, 0.726, 1.207, 0.669, 0.665, 0.990, 1.023, 0.634, 0.541, 0.833, 1.293, 0.769, -5.000, 0.040, 1.209, 0.032, -5.000, 0.627, 0.851, 0.146, 0.209, -0.688, 0.764, 0.412, 0.518, 0.470, 1.180, 0.188, -5.000, -0.979, 0.994, -0.404, -0.185, 0.319, 1.078, 0.111, -0.083, 0.966, 1.072, 0.176, 0.554, 0.470, 1.095, 0.166, 0.643, 0.222, 0.964, 0.894, -0.816, 0.564, 0.957, -1.149, -0.265, 0.745, 0.725, 0.200, 0.665, 0.552, 1.208, 0.146, 0.436, 0.676, 1.254, 1.315, -0.559, 0.803, 1.181, 0.519, 0.523, 1.119, 1.139, 0.681, 0.177, -0.835, -0.237, -1.188, -5.000, -1.624, -0.645, -2.425, -5.000, -1.276, -0.870, -1.203, -1.705, -1.602, -0.592, -1.054, -0.868, -0.933, -0.188, -0.890, -5.000, -2.155, -0.640, -1.835, -1.877, -1.128, -0.774, -1.456, -1.636, -0.158, -0.471, -0.838, -0.692, -0.985, -0.201, -0.913, -0.843, -1.747, -0.656, -0.907, -2.186, -0.948, -0.258, -1.509, -2.114, -0.875, -0.471, -0.907, -1.325, -0.994, -0.448, -0.955, -0.848, -1.547, -0.397, -0.700, -2.029, -0.747, -0.293, -1.366, -1.070, -0.341, -0.457, -0.805, -1.078, 0.116, 0.805, 0.128, -5.000, -0.575, 0.817, -0.047, -5.000, 0.350, 0.692, 0.165, 0.023, -0.598, 0.536, -0.167, 0.368, -0.131, 0.681, 0.066, -5.000, -1.098, 0.555, -0.586, -0.261, 0.281, 0.767, 0.320, -0.061, 0.623, 0.818, -0.141, 0.351, 0.019, 0.543, 0.035, 0.740, -0.356, 0.278, 0.334, -1.299, -0.001, 0.375, -0.758, -0.958, 0.223, 0.302, 0.067, -0.147, 0.266, 0.916, -0.023, 0.632, -0.046, 0.743, 0.673, -0.547, 0.369, 0.719, 0.330, -0.003, 0.701, 0.592, -0.019, 0.092, 0.914, 1.418, 1.005, -5.000, -0.084, 1.231, 0.189, -5.000, 0.921, 1.050, 0.543, 0.369, -0.215, 0.940, 0.744, 0.836, 0.503, 1.112, 0.770, -5.000, -0.532, 0.823, 0.299, 0.216, 0.588, 0.921, 0.238, 0.169, 0.719, 0.944, 0.260, 0.537, 0.233, 0.937, 0.302, 0.715, -0.209, 0.733, 0.364, -2.042, 0.244, 0.653, -0.027, -0.502, 0.696, 0.574, -0.124, -0.292, 0.970, 1.392, 0.718, 1.015, 0.515, 1.211, 1.211, -0.304, 0.667, 0.969, 0.371, 0.243, 1.215, 1.010, 0.641, 0.689, 0.182, 0.598, 0.093, -5.000, -0.685, 0.513, -0.735, -5.000, 0.429, 0.255, -0.781, -0.380, -0.829, 0.168, -0.236, -0.015, -0.142, 0.639, -0.014, -5.000, -0.835, 0.177, -1.087, -0.927, 0.285, 0.464, -0.691, -0.861, 0.204, 0.442, -0.516, 0.024, 0.291, 0.796, 0.325, 0.376, -0.138, 0.697, 0.043, -1.112, 0.380, 0.399, -0.235, -0.613, 0.237, 0.252, 0.197, -0.052, 0.482, 1.149, 0.445, 0.415, 0.201, 0.774, 0.439, -1.221, 0.311, 0.550, -0.402, -0.174, 0.728, 0.684, 0.335, -0.084, 0.154, 0.642, 0.166, -5.000, -1.212, 0.256, -0.805, -5.000, -0.269, -0.392, -0.385, -0.669, -0.757, 0.120, -0.202, 0.214, -0.158, 0.588, 0.245, -5.000, -1.363, 0.095, -0.763, -0.457, -0.133, -0.170, -0.507, -0.791, 0.514, 0.394, -0.316, 0.030, -0.486, 0.376, -0.061, -0.099, -0.863, 0.272, 0.120, -1.741, -0.024, 0.134, -0.544, -0.791, -0.065, 0.222, -0.024, -0.320, -0.402, 0.542, -0.065, 0.166, -0.387, 0.811, 0.201, -1.343, -0.079, 0.231, -0.247, -0.668, 0.304, 0.417, 0.018, -0.430, 0.525, 1.094, 0.566, -5.000, -0.686, 0.634, 0.069, -5.000, 0.032, 0.092, -0.001, -0.554, -1.072, -0.175, -0.393, 0.428, 0.373, 0.981, 0.586, -5.000, -0.697, 1.008, 0.446, 0.046, 0.632, 0.855, 0.679, 0.051, 0.755, 0.919, 0.234, 0.555, 0.166, 0.820, 0.268, 0.581, -0.148, 0.811, 0.636, -1.137, 0.556, 0.835, -0.148, -0.003, 0.348, 0.659, 0.401, -0.300, 0.651, 1.308, 0.533, 0.879, 0.453, 1.072, 1.069, -0.412, 0.834, 1.352, 0.911, 0.750, 0.895, 0.954, 0.428, 0.482, 0.671, 1.132, 0.541, -5.000, -0.495, 0.731, 0.050, -5.000, 0.668, 0.766, 0.357, 0.031, -0.469, 0.336, 0.014, 0.498, 0.261, 0.887, 0.493, -5.000, -0.641, 1.023, 0.316, -0.128, 0.594, 0.880, 0.337, -0.111, 0.470, 0.736, -0.401, 0.237, 0.017, 0.566, -0.199, 0.189, -0.471, 0.581, 0.411, -1.208, 0.436, 0.746, -0.078, -0.112, 0.416, 0.384, -0.031, -0.453, 0.559, 1.069, 0.080, 0.742, 0.434, 1.047, 0.991, -0.573, 0.627, 1.001, 0.600, 0.469, 0.858, 0.886, 0.313, 0.326, 0.296, 0.824, -0.012, -5.000, -0.779, 0.724, -0.203, -5.000, 0.501, 0.653, -0.072, -0.170, -0.687, 0.132, -0.283, 0.146, -0.285, 0.538, -0.168, -5.000, -1.115, 0.342, -0.736, -0.955, -0.049, 0.414, 0.046, -0.718, 0.390, 0.422, -0.826, -0.176, -0.014, 0.561, -0.226, 0.178, -0.206, 0.516, -0.175, -1.293, 0.581, 0.967, -0.489, -0.250, 0.147, 0.183, -0.467, -0.533, 0.114, 0.732, -0.604, -0.113, 0.121, 0.613, 0.262, -1.254, 0.121, 0.810, -0.075, -0.125, 0.247, 0.384, -0.461, -0.710, 0.158, 0.871, 0.302, -5.000, -1.190, 0.228, -0.678, -5.000, 0.011, 0.035, -0.375, -0.531, -0.856, -0.117, -0.411, -0.019, -0.326, 0.619, 0.410, -5.000, -1.236, 0.225, -0.708, -0.713, -0.485, -0.399, -0.652, -0.733, 0.275, 0.010, -0.743, -0.230, 0.004, 0.606, -0.153, -0.149, -0.477, 0.393, 0.380, -1.536, 0.423, 0.781, -0.246, -0.438, -0.099, 0.329, 0.162, -0.400, -0.235, 0.507, -0.057, -0.073, 0.072, 0.531, 0.233, -1.050, 0.021, 0.428, -0.150, -0.467, 0.114, 0.051, -0.312, -0.626 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_9(struct _training *tptr) {
  struct _training tinf = {
    0.620, 11, 4.350, { 0.606, 0.184, 2.210 }, { 0.838, -1.315, -2.142 }, 1, 
    { -1.202, -1.055, -1.034, -0.929, -1.876, -1.255, -0.074, -4.000, 0.248, -4.000, -1.202, -4.000, 0.042, 0.609, -0.168, 1.927, 1.816, -0.034, 1.391, 1.097, 0.592, 0.456, 3.008, 2.229, 2.452, -0.007, 2.754, 2.813 }, 
    {{ -0.116, -0.026, 0.339, -0.710},{ 0.065, -0.345, 0.110, 0.199},{ 0.194, -0.005, -0.144, 0.014},{ 0.285, -0.181, -0.129, 0.130},{ 0.191, 0.029, -0.153, -0.027},{ 0.141, -0.036, -0.044, -0.025},{ 0.228, -0.181, -0.055, 0.097},{ 0.202, -0.012, -0.077, -0.086},{ 0.039, -0.143, 0.095, 0.014},{ 0.181, -0.166, -0.092, 0.179},{ 0.104, -0.031, -0.049, 0.018},{ 0.011, 0.005, -0.001, -0.019},{ 0.140, -0.186, -0.073, 0.217},{ 0.184, -0.001, -0.060, -0.112},{ -0.025, -0.028, 0.031, 0.018},{ 0.041, -0.078, -0.044, 0.141},{ 0.158, -0.108, -0.020, 0.028},{ 0.022, -0.055, -0.031, 0.109},{ 0.161, -0.120, -0.078, 0.125},{ 0.125, -0.047, -0.050, 0.022},{ -0.005, -0.079, 0.024, 0.086},{ 0.083, -0.078, -0.072, 0.140},{ 0.126, 0.059, -0.179, 0.033},{ -0.075, 0.043, -0.059, 0.090},{ 0.043, -0.096, -0.078, 0.207},{ 0.046, 0.037, -0.081, 0.018},{ -0.077, -0.005, -0.055, 0.158},{ 0.151, -0.079, -0.113, 0.128},{ 0.095, -0.049, 0.029, -0.071},{ 0.031, 0.008, -0.026, -0.003},{ 0.104, -0.019, -0.099, 0.072},{ 0.083, -0.039, 0.005, -0.032} }, 
    {{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}} }, 
    0.000, { 0.387, 0.161, 0.074, -5.000, -0.482, -0.221, -0.782, -5.000, -0.359, -0.136, -0.316, -0.412, -0.188, -0.225, 0.467, -0.117, 0.593, 0.517, 0.232, -5.000, -0.412, -0.325, -0.730, -0.142, -0.090, 0.093, -0.022, -0.289, 0.375, 0.514, 0.741, 0.176, 0.304, 0.433, 0.164, 0.909, 0.076, 0.246, 0.110, -0.392, 0.682, 0.609, 0.281, 0.028, 0.569, 0.341, 0.512, 0.317, 0.042, 0.096, -0.302, 0.305, -0.052, -0.045, -0.780, -0.865, 0.132, 0.111, 0.157, -0.205, 0.371, -0.268, 0.492, 0.162, 0.012, -0.107, -1.102, -5.000, -0.922, -0.406, -1.563, -5.000, -0.489, -0.965, -1.265, -0.590, -0.492, -0.764, -0.317, -0.357, 1.017, 0.908, 0.313, -5.000, -0.191, 0.017, -0.144, 0.389, 0.420, 0.471, 0.269, 0.165, 0.725, 0.675, 0.737, 0.072, 0.511, 0.502, -0.208, 0.853, 0.238, 0.312, 0.121, -0.391, 0.790, 0.465, 0.399, 0.179, 0.744, 0.587, 0.622, 0.472, 0.278, -0.049, -0.388, 0.843, 0.064, -0.376, -0.214, -0.469, -0.161, -0.252, -0.450, -0.643, 0.090, -0.337, 0.267, 0.231, -0.156, -0.360, -0.949, -5.000, -0.690, -0.639, -1.627, -5.000, 0.025, -0.584, -0.806, -0.714, -0.384, -0.260, -1.872, -0.256, 0.230, 0.272, -0.211, -5.000, -0.547, -0.628, -1.002, -0.165, -0.040, -0.040, -0.353, -0.242, 0.147, 0.410, 0.550, 0.208, -0.152, -0.550, -0.756, -0.006, -0.534, -0.739, -1.263, -1.007, 0.245, -0.243, -0.319, -0.666, -0.094, -0.444, -0.547, -0.425, -0.072, -0.549, -1.065, -0.032, -0.496, -0.568, -0.945, -0.650, -0.316, -0.752, -0.921, -0.937, -0.220, -0.713, -0.730, -0.474, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.316, -0.678, -0.522, -5.000, -1.314, -1.331, -1.570, -5.000, -1.302, -0.869, -1.160, -1.151, -0.410, -0.593, -0.294, -0.987, -0.271, -0.062, -0.253, -5.000, -1.383, -1.110, -1.402, -1.391, -1.166, -0.960, -1.213, -1.432, -0.215, -0.116, -0.044, -0.262, -0.273, -0.436, -0.605, 0.051, -0.948, -0.676, -1.025, -1.436, -0.646, -0.741, -1.390, -0.883, -0.351, -0.249, -0.213, -0.336, -1.328, -1.127, -1.509, -0.783, -1.133, -0.948, -1.614, -2.010, -0.016, 0.096, -0.072, -0.468, -0.042, -0.251, 0.184, -0.140, -0.257, -0.314, -1.299, -5.000, -0.786, -0.784, -1.687, -5.000, -0.962, -1.175, -1.571, -1.259, -0.282, -0.548, 0.278, -0.148, 0.696, 0.572, 0.161, -5.000, -0.264, -0.167, -0.416, 0.135, 0.100, 0.024, -0.185, -0.281, 0.644, 0.199, 0.342, 0.060, 0.258, 0.109, -0.469, 0.484, -0.330, -0.123, -0.713, -1.037, 0.300, -0.217, -0.297, -0.369, 0.287, 0.212, 0.401, 0.229, -0.554, -0.492, -0.933, 0.037, -0.574, -0.760, -1.100, -1.187, -1.005, -1.384, -1.510, -1.347, -0.459, -0.585, 0.040, -0.016, -0.381, -0.797, -1.433, -5.000, -1.288, -0.989, -2.134, -5.000, -0.967, -1.405, -1.855, -1.446, -0.816, -1.027, -1.331, -1.370, -0.360, -0.347, -0.972, -5.000, -1.352, -1.247, -1.550, -1.383, -0.672, -0.904, -1.239, -1.196, -0.394, -0.202, -0.241, -0.557, -0.745, -1.132, -1.765, -0.787, -1.389, -1.317, -1.902, -1.869, -0.453, -0.855, -0.859, -1.181, -0.646, -0.985, -1.204, -0.830, -1.083, -1.629, -1.933, -0.986, -1.807, -1.746, -2.163, -2.091, -1.495, -1.887, -2.579, -1.968, -0.957, -1.176, -1.489, -1.343, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.449, -0.310, -0.652, -5.000, -1.394, -0.525, -1.725, -5.000, -1.244, -0.931, -1.136, -1.362, -0.651, -0.235, -0.510, -0.629, 0.284, 0.189, 0.077, -5.000, -0.882, -0.573, -1.047, -0.657, -0.324, -0.667, -0.821, -1.124, 0.153, 0.235, 0.593, 0.087, 0.011, 0.242, -0.352, 0.688, -0.753, 0.050, -0.477, -0.776, -0.405, -0.351, -1.072, -0.790, 0.163, 0.091, 0.225, -0.049, -0.721, -0.323, -0.810, 0.408, -1.284, -0.450, -0.981, -0.990, -1.888, -0.966, -1.218, -1.514, -0.296, -0.234, 0.081, -0.115, -0.415, -0.176, -1.219, -5.000, -0.757, -0.636, -1.860, -5.000, -1.119, -1.539, -2.036, -1.473, -0.414, -0.589, -0.072, -0.360, 0.194, 0.312, -0.141, -5.000, -1.109, -0.765, -1.015, -0.637, -0.694, -0.499, -0.856, -1.164, 0.008, 0.160, 0.027, -0.304, -0.139, -0.135, -0.817, 0.165, -0.782, -0.357, -1.085, -1.382, -0.264, -0.331, -0.514, -0.729, 0.198, 0.132, 0.238, 0.084, -0.007, -0.364, -0.941, 0.255, -0.878, -1.104, -1.267, -1.256, -1.409, -1.015, -1.326, -1.934, -0.131, -0.193, -0.101, -0.144, -0.608, -0.929, -1.075, -5.000, -2.073, -1.052, -1.982, -5.000, -1.426, -1.880, -1.753, -2.019, -0.885, -1.109, -1.250, -0.953, -0.410, -0.452, -0.702, -5.000, -1.154, -0.681, -1.295, -1.193, -0.702, -0.930, -0.935, -1.280, -0.372, -0.098, -0.143, -0.351, -0.359, -0.533, -1.386, -0.473, -0.739, -1.171, -1.618, -1.648, -0.561, -0.997, -0.957, -1.159, -0.811, -1.036, -0.850, -0.875, -0.260, -0.562, -1.213, -0.563, -0.865, -1.048, -1.408, -1.294, -0.751, -0.930, -1.444, -1.047, -0.291, -0.815, -1.137, -0.679, -0.395, -0.209, -0.712, -5.000, -1.415, -0.894, -1.893, -5.000, -1.177, -1.338, -1.316, -1.451, -0.722, -0.449, -1.086, -0.714, -0.094, -0.031, -0.015, -5.000, -1.184, -0.910, -1.299, -1.286, -0.736, -0.806, -0.904, -1.071, -0.535, 0.042, 0.198, -0.447, -0.554, -0.092, -0.433, 0.040, -1.050, -0.567, -1.043, -1.121, -0.605, -0.383, -0.451, -0.578, -0.439, -0.108, -0.118, -0.402, -0.677, -0.139, -0.894, -0.251, -1.128, -1.008, -1.187, -1.493, -1.151, -1.053, -1.519, -1.056, -0.408, -0.505, -0.522, -0.397, -0.479, -0.454, -0.625, -5.000, -0.390, -0.555, -0.764, -5.000, -1.110, -0.728, -0.751, -0.580, -0.578, -1.844, -0.392, 0.200, 0.288, -0.214, -0.519, -5.000, -0.769, -0.436, -0.640, -0.158, -0.399, -0.469, -0.518, -0.977, 0.098, 0.084, 0.100, -0.203, 0.048, -0.474, -0.792, 0.126, -0.404, -0.234, -1.003, -0.479, 0.008, -0.235, -0.616, -0.575, -0.151, -0.418, -0.555, -0.123, 0.043, -0.208, -0.362, -0.158, -0.561, -1.133, -0.980, -1.173, -0.579, -0.391, -1.126, -0.932, -0.401, -0.392, -0.071, -0.433, -0.208, -0.527, -1.007, -5.000, -0.949, -0.307, -1.513, -5.000, -0.397, -0.774, -1.291, -0.838, -1.104, -1.350, 0.181, 0.141, 0.311, 0.199, -0.339, -5.000, -0.516, -0.204, -0.242, 0.151, 0.064, -0.010, -0.163, -0.094, 0.155, 0.081, -0.085, -0.126, 0.157, -0.009, -0.391, 0.255, -0.456, -0.134, -0.368, -0.689, -0.151, -0.490, -0.187, -0.306, 0.027, -0.455, -0.139, 0.101, 0.164, -0.572, -1.152, 0.611, -0.096, -0.921, -0.631, -0.554, -0.786, -0.531, -0.794, -0.508, -0.471, -0.781, -1.004, -0.371, 0.042, 0.131, -0.627, -5.000, -0.602, -0.511, -1.798, -5.000, -0.130, -0.728, -0.908, -0.861, -0.214, -0.019, -1.209, -0.597, 0.087, -0.101, -0.312, -5.000, -0.565, -0.354, -0.833, -0.041, 0.039, 0.002, -0.303, -0.299, 0.183, 0.875, 0.697, 0.404, -0.307, -0.925, -1.078, -0.233, -0.724, -0.667, -1.070, -1.080, -0.089, -0.711, -0.207, -1.033, -0.067, -0.774, -0.491, -0.497, 0.151, -0.298, -1.206, 0.393, -0.699, -0.915, -1.346, -1.037, -0.605, -0.841, -1.088, -0.988, -0.067, -0.602, -0.759, -0.296, -0.330, 0.024, -0.681, -5.000, -0.603, -0.539, -1.141, -5.000, -0.227, -0.908, -0.766, -0.789, -0.425, -1.467, -1.231, -0.336, 0.031, 0.188, 0.348, -5.000, -0.289, -0.291, -0.298, -0.568, -0.377, -0.326, -0.315, -0.438, 0.036, 0.373, 0.173, 0.071, -0.214, -0.366, -0.709, -0.102, -0.542, -0.510, -0.680, -0.761, -0.403, -0.365, -0.534, -0.598, -0.140, -0.007, -0.189, -0.032, -0.251, -0.339, -0.569, 0.378, -0.516, -0.652, -0.486, -0.682, -0.553, -0.742, -1.033, -0.859, 0.085, -0.295, -0.225, -0.267, 0.514, 0.800, 0.146, -5.000, -0.404, 0.188, -0.383, -5.000, 0.031, 0.241, 0.072, 0.038, -0.289, 0.023, 0.416, 0.002, 1.113, 1.082, 0.620, -5.000, -0.315, -0.074, -0.385, 0.252, 0.122, 0.470, 0.378, 0.030, 0.618, 0.836, 1.106, 0.428, 1.189, 1.305, 0.880, 1.501, 0.730, 1.193, 0.859, 0.245, 1.308, 1.172, 0.880, 0.946, 1.248, 1.213, 1.138, 1.039, 0.080, 0.434, -0.125, 0.410, -0.140, 0.298, -0.190, -0.466, 0.767, 0.580, 0.335, -0.020, 0.386, 0.329, 0.660, 0.273, 0.775, 0.841, -0.105, -5.000, -0.415, 0.198, -0.512, -5.000, 0.339, -0.059, -0.682, 0.038, -0.055, -0.512, 0.074, 0.024, 1.207, 1.271, 0.888, -5.000, 0.207, 0.552, 0.376, 0.805, 0.678, 0.862, 0.606, 0.303, 1.035, 1.023, 1.133, 0.267, 1.014, 1.053, 0.559, 1.298, 0.473, 0.749, 0.648, 0.162, 0.943, 0.741, 0.598, 0.491, 1.017, 0.760, 0.897, 0.845, 0.587, 0.513, 0.280, 1.187, 0.252, 0.142, 0.269, -0.130, 0.041, 0.099, -0.138, 0.174, 0.198, -0.145, 0.371, 0.342, 0.175, 0.147, -0.256, -5.000, -0.225, 0.281, -1.005, -5.000, 0.051, 0.179, -0.282, -0.128, -0.236, 0.087, 0.183, -0.043, 0.866, 0.795, 0.258, -5.000, 0.152, 0.479, 0.006, 0.691, 0.626, 0.681, 0.427, 0.395, 0.824, 1.034, 0.896, 0.736, 0.652, 0.271, -0.620, 0.762, 0.360, 0.500, -0.174, -0.188, 0.860, 0.506, 0.228, 0.061, 0.656, 0.269, -0.072, 0.298, 0.342, 0.171, -0.080, 0.983, 0.227, -0.058, -0.256, -0.492, 0.251, 0.183, -0.090, -0.383, 0.646, 0.220, 0.089, 0.282, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.539, -0.262, -0.711, -5.000, -1.253, -1.035, -1.282, -5.000, -0.985, -0.863, -1.065, -1.374, -0.421, -0.345, -0.169, -0.366, -0.085, 0.026, -0.093, -5.000, -1.055, -0.649, -1.031, -0.830, -0.927, -0.669, -1.015, -1.259, 0.014, 0.132, 0.206, -0.268, -0.155, 0.175, -0.067, 0.420, -0.653, -0.034, -0.615, -1.184, -0.030, 0.171, -0.471, -0.608, -0.067, 0.001, 0.194, -0.234, -0.748, -1.078, -1.888, -0.390, -0.877, -0.660, -1.581, -1.585, -0.218, -0.177, -0.336, -0.104, 0.176, 0.060, -0.085, 0.157, 0.004, 0.064, -1.016, -5.000, -0.450, -0.507, -1.387, -5.000, -0.563, -0.797, -1.392, -0.863, -0.474, -0.429, 0.267, 0.147, 0.692, 0.817, 0.561, -5.000, -0.347, 0.207, -0.261, 0.321, 0.208, 0.262, 0.039, -0.081, 0.607, 0.391, 0.404, -0.134, 0.362, 0.420, -0.308, 0.598, -0.247, -0.003, -0.443, -0.774, 0.343, 0.008, -0.201, -0.260, 0.392, 0.176, 0.455, 0.193, -0.889, -0.342, -0.825, -0.031, -0.571, -0.423, -0.934, -1.400, -1.337, -1.308, -1.150, -1.293, -0.819, -0.715, -0.040, -0.249, -0.114, -0.098, -0.701, -5.000, -0.882, -0.256, -1.418, -5.000, -0.410, -0.758, -1.238, -1.216, -0.573, -0.304, -0.888, -0.917, 0.229, 0.424, -0.118, -5.000, -0.986, -0.406, -0.861, -0.563, -0.087, -0.153, -0.725, -0.691, 0.072, 0.538, 0.521, -0.007, 0.166, 0.048, -0.777, 0.304, -0.393, -0.203, -0.805, -1.090, 0.177, -0.193, -0.451, -0.703, 0.039, -0.278, -0.521, -0.274, -0.182, -0.792, -0.917, -0.070, -1.212, -1.388, -1.432, -1.591, -1.188, -1.582, -1.456, -1.709, -0.569, -0.954, -0.919, -0.745, 0.368, 0.522, 0.297, -5.000, -0.779, -0.353, -1.231, -5.000, -0.407, -0.307, -0.715, -0.866, -0.274, 0.105, -0.079, -0.136, 0.471, 0.919, 0.691, -5.000, -0.770, -0.493, -1.127, -0.444, -0.109, -0.237, -0.134, -0.658, 0.483, 0.747, 0.956, 0.359, 0.390, 0.949, 0.595, 0.851, -0.151, 0.403, -0.195, -1.040, 0.629, 0.410, 0.078, -0.366, 0.326, 0.583, 0.609, 0.220, -0.183, -0.053, -0.522, 0.364, -0.404, -0.353, -1.022, -1.464, -0.615, -1.151, -1.378, -1.504, -0.334, -0.217, -0.136, -0.360, 0.005, 0.289, -0.117, -5.000, -0.858, -0.047, -1.035, -5.000, -0.634, -0.391, -0.789, -0.944, -0.263, 0.026, -0.008, -0.325, 0.777, 0.699, 0.597, -5.000, -0.513, -0.044, -0.390, 0.010, 0.096, 0.181, -0.229, -0.566, 0.441, 0.719, 0.913, 0.193, 0.400, 0.732, 0.503, 1.156, -0.233, 0.710, 0.282, -0.453, 0.518, 0.458, 0.057, -0.127, 0.526, 0.656, 0.708, 0.533, 0.268, 0.600, 0.299, 1.041, -0.497, 0.183, 0.113, -1.109, -0.839, -0.573, -1.273, -1.327, 0.118, 0.029, 0.161, 0.258, 0.055, 0.366, -0.755, -5.000, -0.640, -0.159, -1.445, -5.000, -0.634, -0.822, -1.533, -1.217, -0.347, -0.344, 0.312, -0.336, 0.810, 0.998, 0.628, -5.000, -0.411, 0.225, -0.127, 0.281, 0.147, 0.341, -0.117, -0.376, 0.607, 0.737, 0.988, -0.189, 0.464, 0.514, 0.034, 0.779, -0.219, 0.443, -0.055, -0.714, 0.547, 0.428, 0.047, -0.183, 0.667, 0.630, 0.681, 0.480, 0.309, 0.384, 0.113, 1.097, -0.470, -0.167, -0.433, -1.005, -0.646, -0.416, -0.868, -1.025, 0.085, 0.027, 0.260, 0.241, -0.151, -0.044, -0.595, -5.000, -1.157, -0.036, -1.336, -5.000, -0.600, -0.733, -1.085, -1.170, -0.412, -0.002, -0.483, -0.890, 0.438, 0.478, 0.133, -5.000, -0.886, 0.074, -0.425, -0.493, 0.211, 0.061, -0.224, -0.550, 0.148, 0.709, 0.865, -0.080, 0.441, 0.217, -0.255, 0.501, -0.293, 0.028, -0.550, -0.710, 0.056, -0.081, -0.248, -0.372, 0.295, 0.046, -0.200, 0.033, 0.391, 0.455, -0.055, 0.505, -0.381, 0.065, -0.395, -0.777, -0.108, -0.079, -0.441, -0.724, 0.508, 0.138, -0.075, 0.068, -0.015, 0.099, -0.075, -5.000, -1.358, -0.380, -1.351, -5.000, -0.690, -0.526, -1.056, -0.952, -0.637, -0.141, -0.192, -0.599, 0.433, 0.541, 0.554, -5.000, -0.953, -0.402, -0.948, -0.433, -0.267, -0.193, -0.372, -0.523, -0.078, 0.431, 0.967, -0.095, -0.193, 0.359, 0.131, 0.668, -1.071, 0.293, -0.268, -0.992, 0.087, 0.159, -0.036, -0.288, 0.032, 0.411, 0.456, 0.176, 0.038, 0.182, -0.220, 0.475, -0.785, -0.021, -0.611, -1.305, -0.697, -0.445, -0.890, -0.968, -0.108, -0.125, -0.036, -0.039, 0.133, 0.603, 0.037, -5.000, -0.740, 0.065, -0.428, -5.000, -0.529, -0.431, -0.628, -0.850, -0.336, -0.270, 0.070, -0.233, 0.721, 0.858, 0.680, -5.000, -0.366, 0.090, 0.093, 0.132, 0.149, 0.492, 0.176, -0.167, 0.465, 0.882, 1.037, 0.108, 0.828, 0.921, 0.487, 1.184, 0.091, 0.924, 0.380, -0.094, 0.640, 0.426, -0.316, -0.047, 0.686, 0.574, 0.352, 0.677, 0.365, 0.527, 0.278, 0.977, -1.023, -0.387, -0.212, -1.429, -1.013, -0.403, -1.256, -1.146, -0.052, -0.267, -0.125, 0.003, 0.324, 0.685, -0.399, -5.000, -0.462, 0.155, -0.864, -5.000, -0.058, -0.034, -0.955, -0.275, -0.549, -0.073, 0.214, 0.205, 1.047, 1.138, 0.941, -5.000, -0.037, 0.626, 0.620, 0.636, 0.793, 0.889, 0.608, 0.448, 0.744, 1.103, 1.283, 0.051, 0.750, 1.012, 0.333, 1.248, 0.129, 0.868, 0.569, -0.069, 0.865, 0.619, 0.415, 0.160, 0.947, 0.887, 0.918, 1.010, 0.846, 0.651, 0.569, 1.306, 0.203, 0.177, 0.139, -0.380, -0.057, 0.075, -0.265, -0.254, 0.341, 0.193, 0.418, 0.399, 0.689, 1.044, 0.516, -5.000, 0.105, 0.802, -0.361, -5.000, 0.619, 0.427, -0.285, 0.198, 0.136, 0.383, 0.179, -0.225, 1.104, 0.862, 0.713, -5.000, 0.276, 0.748, 0.616, 0.734, 1.231, 1.154, 0.854, 0.837, 1.144, 1.446, 1.281, 0.859, 0.973, 0.785, 0.303, 1.154, 0.621, 0.797, 0.328, 0.196, 1.053, 0.558, 0.241, 0.280, 1.014, 0.605, 0.441, 0.948, 0.879, 0.757, 0.588, 1.303, 0.357, 0.309, 0.269, -0.234, 0.344, 0.405, 0.088, -0.095, 0.941, 0.637, 0.505, 0.805, 0.155, 0.599, 0.377, -5.000, -0.753, 0.170, -0.369, -5.000, -0.063, 0.103, -0.532, -0.401, -0.339, -0.068, -0.045, -0.356, 0.179, 0.722, 0.669, -5.000, -0.653, 0.194, 0.123, -0.216, 0.235, 0.357, 0.088, -0.191, 0.031, 0.600, 0.919, 0.062, -0.218, 0.020, 0.034, -0.314, -0.695, -0.013, -0.480, -0.888, -0.144, -0.013, -0.221, -0.677, -0.518, -0.281, -0.006, -0.472, -0.032, 0.106, 0.076, 0.250, -0.431, 0.079, -0.310, -0.714, -0.157, -0.134, -0.461, -0.588, 0.003, 0.094, 0.205, -0.098, 0.082, 0.369, -0.176, -5.000, -0.714, -0.247, -0.759, -5.000, -0.075, -0.156, -0.268, -0.169, -0.241, -0.052, 0.365, 0.135, 0.837, 0.842, 0.647, -5.000, -0.401, -0.260, -0.417, 0.409, -0.267, 0.119, 0.157, -0.231, 0.643, 0.600, 0.877, 0.171, 0.862, 0.993, 0.726, 1.368, 0.316, 0.939, 0.620, -0.097, 1.212, 1.134, 0.847, 0.898, 1.085, 1.191, 1.176, 0.946, 0.600, 0.506, 0.368, 0.911, 0.193, 0.344, 0.029, -0.762, 0.799, 0.527, 0.116, 0.092, 0.347, 0.346, 0.608, 0.513, 0.298, 0.447, -0.713, -5.000, -0.317, -0.042, -1.220, -5.000, -0.157, -0.471, -0.788, -0.289, -0.551, -0.671, 0.542, -0.247, 1.259, 1.062, 0.764, -5.000, 0.114, 0.207, -0.000, 0.755, 0.464, 0.560, 0.546, 0.305, 0.936, 0.900, 0.790, 0.162, 0.882, 0.767, 0.240, 1.310, 0.458, 0.662, 0.465, 0.094, 1.050, 0.685, 0.711, 0.543, 0.928, 0.827, 0.954, 0.832, 0.327, 0.269, 0.038, 1.231, -0.090, -0.301, -0.092, -0.126, -0.065, -0.237, -0.150, -0.575, 0.028, -0.378, 0.044, 0.206, 0.103, -0.303, -0.765, -5.000, -0.565, -0.151, -1.283, -5.000, -0.320, -0.732, -0.654, -0.541, -0.559, -0.489, -1.090, -0.742, 0.709, 0.343, -0.470, -5.000, -0.314, -0.200, -0.696, 0.206, 0.182, 0.017, 0.029, 0.011, 0.419, 0.703, 0.577, 0.323, 0.159, -0.204, -0.741, 0.473, 0.151, 0.131, -0.478, -0.382, 0.672, 0.237, -0.177, -0.266, 0.480, 0.161, -0.331, 0.278, 0.427, -0.123, -0.385, 0.932, 0.055, -0.267, -0.646, -0.583, 0.180, -0.144, -0.848, -0.842, 0.421, 0.137, -0.405, 0.136, 0.731, 0.694, 0.217, -5.000, -0.536, 0.060, -0.874, -5.000, 0.151, -0.118, -0.449, -0.072, -0.426, -0.077, -0.742, -0.129, 1.146, 1.063, 0.872, -5.000, -0.035, -0.032, -0.516, 1.029, -0.085, -0.134, 0.083, -0.213, 0.956, 0.958, 0.929, 0.207, 1.468, 1.511, 1.246, 1.534, 1.345, 1.291, 1.115, 0.735, 1.545, 1.449, 1.294, 1.386, 1.511, 1.548, 1.457, 1.488, 0.985, 1.104, 0.588, 1.409, 1.048, 0.809, 0.498, 0.087, 0.865, 0.901, 0.760, 0.218, 0.731, 0.764, 0.910, 0.480, 0.142, 0.280, -0.219, -5.000, -0.827, -0.589, -1.016, -5.000, -0.932, -0.431, -0.593, -0.880, -0.343, -0.202, 0.250, -0.387, 0.688, 0.706, 0.309, -5.000, -0.506, -0.285, -0.568, -0.067, -0.331, -0.119, -0.445, -0.645, 0.588, 0.447, 0.698, 0.033, 0.130, 0.547, 0.137, 0.756, -0.606, 0.351, -0.113, -0.922, -0.052, 0.033, -0.478, -0.551, 0.211, 0.400, 0.697, 0.146, -0.225, -0.139, -0.511, 0.035, -0.963, -0.619, -0.622, -1.124, -0.143, 0.104, -0.251, -0.279, 0.195, -0.095, 0.270, 0.174, 0.462, 0.543, -0.533, -5.000, -0.476, -0.297, -1.177, -5.000, -0.334, -0.377, -0.637, -0.595, -0.476, -0.577, 0.634, 0.269, 1.149, 1.037, 0.836, -5.000, -0.116, 0.205, -0.115, 0.811, 0.411, 0.519, 0.336, 0.223, 0.980, 0.744, 0.666, 0.208, 0.806, 0.765, 0.339, 1.102, 0.115, 0.522, 0.121, -0.350, 0.775, 0.494, 0.446, 0.249, 0.843, 0.760, 0.938, 0.721, 0.245, 0.112, -0.054, 0.864, -0.478, -0.369, -0.268, -0.844, -0.824, -0.825, -0.737, -0.910, -0.058, -0.283, 0.354, 0.270, -0.078, 0.204, -0.427, -5.000, -0.595, -0.091, -1.345, -5.000, -0.287, -0.606, -0.898, -0.754, -0.394, 0.043, -0.267, -0.379, 0.530, 0.531, -0.082, -5.000, -0.740, -0.272, -0.650, -0.376, 0.082, 0.064, -0.276, -0.402, 0.327, 0.867, 0.793, 0.203, 0.473, 0.314, -0.370, 0.639, -0.293, 0.189, -0.442, -0.818, 0.489, 0.183, -0.238, -0.207, 0.521, 0.225, -0.234, 0.335, 0.059, -0.149, -0.409, 0.595, -0.819, -0.738, -1.045, -1.563, -0.736, -0.781, -1.227, -1.392, 0.226, -0.156, -0.327, -0.045, -0.294, -0.393, -0.594, -5.000, -1.181, -0.980, -1.632, -5.000, -1.048, -0.788, -1.322, -1.070, -0.752, -0.365, -1.103, -0.513, -0.237, 0.240, -0.062, -5.000, -1.525, -0.821, -1.355, -0.809, -1.092, -0.718, -1.014, -1.141, -0.042, 0.217, 0.356, -0.048, -0.301, 0.126, -0.001, 0.258, -0.809, -0.201, -0.669, -1.179, -0.186, -0.160, -0.667, -0.679, -0.011, 0.137, 0.349, 0.037, -0.319, -0.308, -0.403, 0.244, -0.814, -0.679, -1.416, -1.147, -0.842, -1.031, -1.362, -1.348, -0.501, -0.496, -0.232, -0.690, 0.442, 0.691, 0.282, -5.000, -0.528, 0.325, -0.361, -5.000, -0.281, -0.070, -0.571, -0.450, -0.157, 0.116, 0.031, 0.062, 1.008, 0.947, 0.950, -5.000, -0.018, 0.249, 0.147, 0.672, 0.290, 0.495, 0.304, -0.042, 0.771, 0.906, 1.129, 0.152, 0.647, 0.990, 0.630, 1.239, -0.260, 0.981, 0.541, -0.095, 0.618, 0.680, 0.040, 0.139, 0.845, 0.959, 1.053, 0.855, 0.458, 0.666, 0.667, 1.197, -0.451, 0.288, 0.035, -1.319, -0.572, 0.184, -0.635, -0.652, 0.665, 0.472, 0.454, 0.675, 0.269, 0.626, -0.385, -5.000, -0.278, -0.029, -1.073, -5.000, -0.159, -0.199, -0.832, -0.699, -0.442, -0.370, 0.336, 0.120, 0.815, 0.927, 0.648, -5.000, -0.154, 0.159, 0.030, 0.417, 0.235, 0.358, 0.063, -0.136, 0.616, 0.725, 0.881, 0.003, 0.588, 0.660, 0.021, 0.920, -0.056, 0.577, 0.234, -0.407, 0.531, 0.439, 0.257, 0.029, 0.773, 0.710, 0.783, 0.634, 0.511, 0.264, 0.020, 1.112, -0.444, -0.777, -0.381, -0.468, -0.319, -0.473, -0.576, -0.876, 0.404, -0.000, 0.272, 0.491, 0.004, 0.085, -0.351, -5.000, -1.071, -0.072, -1.142, -5.000, -0.182, -0.603, -0.633, -0.981, -0.313, -0.118, -0.352, -0.374, 0.337, 0.387, 0.120, -5.000, -0.507, 0.074, -0.381, -0.276, 0.233, 0.180, -0.149, -0.304, 0.175, 0.675, 0.710, -0.042, 0.352, 0.469, -0.078, 0.158, -0.107, 0.260, -0.260, -0.459, 0.363, 0.147, -0.066, -0.266, 0.437, 0.266, 0.092, 0.396, 0.434, 0.642, 0.227, 0.596, -0.100, 0.245, -0.070, -0.838, 0.030, 0.138, -0.207, -0.343, 0.658, 0.486, 0.230, 0.378, 0.021, 0.167, -0.359, -5.000, -0.932, -0.515, -1.119, -5.000, -0.466, -0.387, -0.713, -0.669, -0.525, -0.211, -0.508, -0.384, 0.353, 0.480, 0.028, -5.000, -0.686, -0.405, -0.665, -0.293, -0.093, -0.016, -0.033, -0.272, 0.191, 0.468, 0.753, 0.019, 0.036, 0.514, 0.203, 0.374, -0.491, 0.446, -0.087, -0.541, 0.296, 0.232, 0.181, -0.189, 0.394, 0.543, 0.562, 0.422, -0.075, 0.090, -0.347, 0.359, -0.578, -0.368, -0.525, -1.157, -0.737, -0.339, -0.400, -0.930, 0.194, -0.041, 0.152, 0.065, 0.326, 0.561, 0.163, -5.000, -0.457, 0.131, -0.128, -5.000, -0.159, -0.154, -0.327, -0.546, -0.358, -0.300, 0.366, 0.068, 1.018, 0.973, 0.831, -5.000, 0.047, 0.247, 0.244, 0.528, 0.401, 0.666, 0.433, 0.126, 0.697, 1.040, 1.146, 0.361, 1.006, 0.991, 0.637, 1.232, 0.374, 0.999, 0.661, 0.086, 1.008, 0.735, -0.049, 0.114, 0.963, 0.864, 0.725, 0.911, 0.659, 0.819, 0.632, 1.231, -0.193, 0.294, 0.287, -0.258, -0.900, -0.087, -0.673, -0.573, 0.196, 0.411, 0.434, 0.506, 0.353, 0.463, -0.345, -5.000, -0.272, 0.124, -0.671, -5.000, 0.014, -0.432, -1.038, -0.470, -0.515, -0.423, 0.524, 0.005, 0.988, 0.924, 0.708, -5.000, -0.031, 0.520, 0.333, 0.586, 0.611, 0.593, 0.390, 0.287, 0.650, 1.007, 1.053, -0.047, 0.825, 0.778, 0.261, 1.169, 0.222, 0.585, 0.406, -0.072, 0.732, 0.408, 0.324, 0.135, 0.993, 0.622, 0.542, 0.856, 0.752, 0.461, 0.286, 1.346, 0.033, -0.152, 0.104, -0.294, -0.124, -0.305, -0.331, -0.315, 0.368, 0.158, 0.069, 0.696, 0.575, 0.868, 0.476, -5.000, -0.081, 0.438, -0.564, -5.000, 0.483, 0.451, -0.801, -0.080, -0.075, -0.013, -0.418, -0.657, 0.963, 0.819, 0.810, -5.000, 0.088, 0.562, 0.298, 0.589, 0.904, 0.764, 0.409, 0.511, 0.722, 1.198, 0.926, 0.493, 0.837, 0.641, -0.102, 0.892, 0.439, 0.538, -0.057, 0.080, 0.652, 0.202, -0.146, -0.004, 0.717, 0.150, -0.321, 0.540, 0.870, 0.667, 0.328, 1.282, 0.280, 0.313, 0.198, -0.184, 0.265, 0.077, -0.119, -0.304, 0.825, 0.278, 0.000, 0.633, 0.577, 0.646, 0.092, -5.000, -0.449, 0.221, -0.421, -5.000, -0.007, 0.073, -0.363, -0.177, -0.167, 0.365, -0.255, -0.125, 0.959, 0.807, 0.570, -5.000, -0.061, 0.334, 0.069, 0.523, 0.620, 0.604, 0.536, 0.409, 0.840, 1.212, 1.227, 0.581, 0.853, 0.913, 0.450, 1.127, 0.284, 0.647, 0.428, -0.043, 0.780, 0.534, 0.304, 0.046, 0.778, 0.558, 0.297, 0.642, 0.743, 0.651, 0.269, 1.012, 0.117, 0.242, 0.308, -0.629, 0.346, 0.136, -0.056, -0.364, 0.437, -0.004, -0.010, 0.234, -0.172, -0.288, -0.171, -5.000, -0.723, -0.803, -1.183, -5.000, -0.391, -0.339, -0.139, -0.318, 0.146, -0.026, 0.278, 0.333, 0.634, 0.441, 0.246, -5.000, -0.417, -0.494, -0.750, 0.137, -0.217, -0.163, -0.058, -0.288, 0.500, 0.482, 0.381, 0.082, 0.766, 0.834, 0.486, 1.297, 0.180, 0.551, 0.346, -0.477, 1.002, 0.983, 0.371, 0.569, 0.878, 0.996, 0.934, 0.720, 0.083, 0.274, -0.465, 0.744, -0.081, -0.265, -0.648, -0.932, 0.368, 0.371, -0.035, 0.045, 0.330, 0.322, 0.149, 0.170, -0.028, -0.274, -1.264, -5.000, -1.157, -0.608, -1.854, -5.000, -0.917, -1.143, -1.519, -0.732, -0.578, -1.171, 0.078, -0.405, 0.940, 0.720, 0.220, -5.000, -0.122, -0.239, -0.419, 0.392, 0.201, 0.104, 0.070, -0.028, 0.735, 0.560, 0.446, -0.025, 0.531, 0.249, -0.160, 0.951, 0.084, 0.132, -0.203, -0.476, 0.751, 0.372, 0.437, 0.209, 0.716, 0.605, 0.567, 0.623, -0.139, -0.220, -0.471, 0.765, -0.413, -0.790, -0.798, -0.870, -0.650, -0.678, -0.790, -0.659, 0.009, -0.441, -0.068, 0.132, -0.303, -0.418, -0.912, -5.000, -1.076, -0.601, -1.702, -5.000, -0.786, -0.904, -1.316, -0.994, -1.308, -0.919, -1.432, -0.914, 0.406, 0.277, -0.173, -5.000, -0.633, -0.459, -0.982, -0.080, -0.100, -0.060, -0.187, -0.285, 0.530, 0.811, 0.478, 0.119, 0.078, -0.259, -1.023, 0.204, -0.154, -0.036, -0.886, -0.442, 0.538, 0.156, -0.263, -0.234, 0.225, -0.071, -0.281, 0.014, 0.078, -0.245, -0.886, 0.605, -0.182, -0.391, -0.967, -0.923, -0.355, -0.107, -0.902, -0.716, 0.097, -0.422, -0.760, -0.230, 0.534, 0.503, -0.079, -5.000, -0.515, -0.401, -1.290, -5.000, -0.423, -0.464, -0.633, -0.596, -0.319, 0.389, -0.573, -0.379, 0.979, 0.936, 0.869, -5.000, 0.093, -0.006, -0.615, 0.341, -0.080, -0.176, 0.121, -0.186, 0.974, 0.858, 1.020, 0.338, 1.190, 1.411, 1.133, 1.442, 1.073, 1.224, 0.816, 0.414, 1.479, 1.468, 1.309, 1.234, 1.378, 1.513, 1.212, 1.263, 0.574, 0.752, 0.339, 1.150, 0.364, 0.607, 0.163, -0.333, 0.696, 0.830, 0.401, 0.082, 0.551, 0.685, 0.759, 0.315, -0.121, -0.334, -0.537, -5.000, -1.044, -1.036, -1.465, -5.000, -0.706, -0.565, -0.985, -0.962, -0.374, -0.401, -0.990, -0.809, 0.292, 0.401, 0.021, -5.000, -0.876, -0.835, -0.913, -0.634, -0.642, -0.494, -0.736, -0.705, 0.164, 0.246, 0.129, -0.032, -0.030, 0.235, 0.007, 0.601, -0.776, -0.098, -0.503, -1.004, -0.303, -0.408, -1.096, -0.758, -0.274, 0.130, 0.552, -0.085, -0.293, -0.677, -0.929, -0.328, -1.984, -0.848, -1.171, -1.418, -0.205, -0.143, -0.218, -0.142, -0.074, -0.924, -0.214, -0.130, -0.241, -0.385, -1.073, -5.000, -0.929, -0.859, -1.573, -5.000, -0.843, -0.987, -1.291, -1.161, -0.803, -0.953, 0.177, 0.409, 0.718, 0.590, 0.066, -5.000, -0.287, -0.390, -0.621, 0.352, 0.012, -0.170, -0.227, -0.157, 0.520, 0.100, -0.074, -0.104, 0.273, -0.108, -0.771, 0.506, -0.290, -0.086, -0.639, -0.877, 0.246, -0.223, -0.230, -0.361, 0.341, 0.037, 0.213, 0.261, -0.384, -0.725, -1.010, 0.220, -0.952, -0.849, -1.124, -1.189, -1.095, -1.375, -1.412, -1.352, -0.356, -0.846, -0.352, -0.180, -0.092, -0.446, -1.081, -5.000, -1.209, -0.840, -1.710, -5.000, -1.048, -0.875, -1.175, -1.004, -0.742, -0.526, -1.266, -0.847, 0.172, 0.128, -0.633, -5.000, -1.148, -0.762, -1.239, -0.804, -0.004, -0.408, -0.634, -0.449, 0.168, 0.584, 0.357, 0.214, 0.078, -0.244, -1.133, -0.002, -0.843, -0.322, -0.798, -1.473, 0.111, -0.256, -0.561, -0.537, 0.185, -0.167, -0.405, -0.094, -0.218, -0.653, -1.231, -0.282, -1.354, -1.175, -1.503, -1.938, -1.421, -1.020, -1.649, -1.775, -0.309, -0.714, -0.799, -0.491, -0.472, -0.802, -1.578, -5.000, -1.566, -1.499, -2.125, -5.000, -1.185, -0.949, -1.800, -1.513, -0.784, -0.791, -1.465, -1.352, -0.074, -0.434, -0.310, -5.000, -1.629, -1.125, -1.688, -1.048, -1.048, -1.121, -1.170, -1.293, -0.093, -0.026, 0.159, -0.232, -0.524, -0.217, -0.734, -0.297, -0.970, -0.944, -1.101, -1.468, -0.489, -0.635, -0.701, -0.878, -0.410, -0.134, -0.113, -0.386, -0.717, -0.802, -1.334, -0.333, -1.135, -1.041, -1.649, -1.671, -1.863, -1.413, -2.083, -1.603, -0.768, -0.800, -0.867, -0.813, -0.596, -0.596, -0.728, -5.000, -1.218, -1.057, -1.840, -5.000, -1.212, -1.284, -1.021, -1.163, -0.287, -0.512, -0.203, 0.047, 0.063, 0.136, 0.215, -5.000, -0.888, -0.419, -1.084, -0.359, -0.633, -0.321, -0.545, -0.837, 0.365, 0.382, 0.395, 0.064, 0.008, 0.286, -0.049, 0.628, -0.680, 0.167, -0.157, -0.749, 0.034, -0.016, -0.289, -0.560, 0.142, 0.340, 0.426, 0.098, -0.586, -0.392, -0.632, 0.010, -1.233, -0.451, -1.318, -2.073, -0.760, -0.963, -0.995, -0.776, -0.523, -0.251, -0.468, -0.169, -0.628, -0.391, -1.474, -5.000, -0.990, -1.029, -1.712, -5.000, -0.927, -1.309, -1.460, -1.505, -0.382, -0.695, 0.096, -0.249, 0.391, 0.437, -0.114, -5.000, -0.515, -0.524, -0.854, -0.448, -0.375, -0.339, -0.648, -0.710, 0.193, 0.205, 0.054, -0.143, -0.269, -0.473, -0.937, -0.165, -0.676, -0.543, -1.067, -1.205, -0.077, -0.301, -0.419, -0.714, 0.096, -0.078, 0.003, -0.169, -0.309, -0.585, -1.113, 0.245, -0.726, -1.199, -1.660, -1.370, -0.943, -1.087, -1.453, -1.587, -0.237, -0.535, -0.136, -0.008, -0.559, -0.809, -1.067, -5.000, -1.614, -1.066, -1.921, -5.000, -0.935, -1.374, -1.696, -1.751, -1.042, -0.463, -1.390, -0.852, -0.179, -0.198, -0.566, -5.000, -1.281, -0.929, -1.280, -1.054, -0.338, -0.710, -0.838, -1.044, -0.199, 0.330, 0.057, -0.289, -0.267, -0.574, -0.933, -0.434, -0.649, -0.893, -1.436, -1.484, -0.018, -0.593, -0.736, -0.865, -0.557, -0.599, -0.454, -0.583, -0.410, -0.729, -1.177, -0.310, -1.241, -0.635, -1.341, -1.615, -1.076, -0.904, -1.243, -1.330, -0.454, -0.968, -0.969, -0.664, -0.528, -0.799, -1.285, -5.000, -1.787, -1.256, -2.394, -5.000, -1.433, -1.575, -1.343, -1.177, -1.015, -1.017, -1.705, -0.948, -0.031, -0.368, -0.200, -5.000, -1.509, -0.917, -1.426, -0.986, -0.759, -0.686, -0.882, -1.028, -0.165, 0.106, 0.052, -0.223, -0.503, -0.080, -0.730, 0.179, -1.100, -0.590, -0.867, -0.633, -0.222, -0.169, -0.492, -0.498, -0.146, -0.094, 0.096, -0.050, -0.530, -0.669, -1.185, -1.012, -1.193, -0.897, -1.430, -1.467, -0.835, -1.217, -1.418, -1.688, -0.554, -1.131, -0.762, -0.717, 0.071, -0.007, -0.547, -5.000, -0.622, -0.198, -0.930, -5.000, -0.401, -0.742, -0.299, -0.450, -0.722, -0.738, 0.283, 0.169, 0.750, 0.512, 0.425, -5.000, -0.380, -0.083, -0.323, -0.083, 0.197, 0.297, -0.015, -0.166, 0.349, 0.707, 0.493, 0.280, 0.790, 0.476, -0.007, 0.797, 0.062, 0.574, 0.199, -0.282, 0.608, 0.360, 0.049, -0.136, 0.818, 0.619, 0.368, 0.558, 0.191, 0.234, -0.096, 0.535, -0.525, -0.207, -0.458, -1.126, -0.532, -0.237, -0.862, -0.871, -0.008, 0.048, 0.152, 0.105, -0.082, -0.373, -0.929, -5.000, -0.804, -0.560, -1.841, -5.000, -0.854, -0.994, -1.805, -1.195, -0.797, -1.114, -0.354, 0.051, 0.602, 0.454, 0.163, -5.000, -0.487, -0.215, -0.302, 0.051, 0.188, 0.068, -0.047, 0.045, 0.248, 0.549, 0.438, 0.038, 0.389, 0.053, -0.247, 0.423, -0.269, 0.108, -0.442, -0.762, 0.295, -0.235, -0.178, -0.416, 0.520, 0.115, -0.045, 0.337, 0.009, -0.290, -0.620, 0.503, -0.274, -0.717, -0.727, -0.867, -0.638, -0.925, -0.992, -0.819, -0.108, -0.701, -0.256, 0.266, 0.272, 0.004, -0.249, -5.000, -0.388, -0.051, -1.214, -5.000, -0.390, -0.417, -0.689, -0.696, -0.468, -0.603, -0.769, -0.733, 0.598, 0.401, 0.117, -5.000, -0.295, -0.005, -0.420, -0.313, 0.499, 0.274, -0.078, 0.058, 0.396, 0.634, 0.500, 0.352, 0.239, 0.009, -0.705, 0.248, -0.163, 0.063, -0.677, -0.661, 0.117, -0.475, -0.320, -0.329, 0.197, -0.437, -0.680, 0.105, 0.265, 0.047, -0.251, 0.540, -0.020, -0.095, -0.554, -0.796, -0.183, -0.227, -0.929, -0.799, 0.280, -0.343, -0.692, 0.017, 0.084, -0.098, -0.291, -5.000, -0.858, -0.226, -0.829, -5.000, -0.448, -0.448, -0.857, -0.948, -0.321, -0.372, -1.119, -0.777, 0.535, 0.549, 0.347, -5.000, -0.274, -0.168, -0.243, -0.239, 0.342, 0.154, 0.103, 0.008, 0.525, 0.778, 0.899, 0.426, 0.188, 0.417, -0.061, 0.698, 0.051, 0.314, -0.025, -0.599, 0.441, 0.167, 0.188, -0.110, 0.416, 0.268, 0.060, 0.567, 0.354, 0.267, 0.052, 0.558, -0.039, 0.004, -0.193, -0.574, -0.045, -0.338, -0.669, -0.501, -0.037, -0.079, -0.371, -0.249 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_10(struct _training *tptr) {
  struct _training tinf = {
    0.667, 11, 4.350, { 0.926, 0.140, 1.935 }, { 1.053, -2.035, -2.179 }, 1, 
    { -1.130, -3.008, -2.110, -0.971, -1.534, -4.000, -0.785, -4.000, -0.342, -0.615, -0.209, -4.000, 0.631, 0.276, -0.487, 2.014, 2.417, -0.842, 0.706, 0.016, 0.881, 1.888, 3.694, 3.355, 2.919, -4.000, 3.788, 3.434 }, 
    {{ -0.426, -0.248, 0.539, -1.037},{ 0.138, -0.656, 0.256, 0.208},{ 0.420, -0.380, -0.005, 0.115},{ 0.386, -0.475, 0.011, 0.234},{ 0.366, -0.468, 0.041, 0.202},{ 0.332, -0.472, 0.026, 0.268},{ 0.316, -0.468, 0.051, 0.242},{ 0.306, -0.390, 0.047, 0.177},{ 0.213, -0.353, 0.098, 0.141},{ 0.259, -0.338, 0.018, 0.218},{ 0.210, -0.281, 0.070, 0.107},{ 0.153, -0.271, 0.086, 0.122},{ 0.198, -0.232, 0.041, 0.106},{ 0.107, -0.203, 0.064, 0.115},{ 0.125, -0.171, 0.074, 0.027},{ 0.116, -0.235, 0.044, 0.187},{ 0.098, -0.159, 0.101, -0.021},{ -0.019, -0.134, 0.085, 0.089},{ 0.091, -0.254, 0.080, 0.172},{ 0.148, -0.090, -0.013, 0.039},{ 0.063, -0.142, 0.028, 0.134},{ 0.192, -0.195, -0.027, 0.180},{ 0.167, -0.119, 0.001, 0.040},{ 0.042, -0.093, 0.015, 0.098},{ 0.144, -0.152, 0.008, 0.106},{ 0.058, -0.067, 0.040, -0.013},{ 0.031, -0.034, 0.020, -0.005},{ 0.091, -0.128, 0.002, 0.132},{ 0.086, -0.067, 0.028, -0.017},{ -0.017, -0.094, 0.089, 0.009},{ 0.067, -0.128, 0.028, 0.109},{ -0.001, 0.001, -0.020, 0.037} }, 
    {{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}} }, 
    0.000, { -0.240, 0.205, -0.233, -5.000, -0.453, -0.628, -1.047, -5.000, -0.274, -0.244, -0.669, -0.470, -0.175, -0.012, 0.094, -0.127, 0.492, 0.383, 0.472, -5.000, -0.871, -0.133, -0.780, 0.002, -0.184, 0.310, -0.008, -0.296, 0.528, 0.485, 0.983, 0.225, 0.380, 0.608, 0.061, 0.376, -0.281, 0.092, -0.274, -0.244, 0.332, 0.381, 0.095, 0.087, 0.379, 0.428, 0.523, 0.081, -0.215, -0.170, -0.475, 0.220, -0.536, -0.296, -0.538, -0.171, 0.236, 0.029, 0.497, 0.169, 0.087, 0.070, 0.257, 0.156, 0.097, -0.197, -1.002, -5.000, -0.563, -0.490, -1.668, -5.000, -0.740, -0.953, -1.175, -0.768, -0.906, -0.728, -0.243, 0.046, 1.251, 0.866, 0.396, -5.000, 0.047, 0.148, -0.388, 1.203, 0.441, 0.589, 0.587, 0.554, 0.923, 0.174, 0.430, 0.170, 0.811, 0.666, -0.060, 1.129, 0.519, 0.634, -0.080, -0.182, 0.895, 0.405, 0.341, 0.392, 0.754, 0.461, 1.065, 0.695, 0.081, -0.465, -0.390, 0.977, -0.152, -0.234, -0.761, -0.922, -0.680, -1.341, -0.683, -0.315, -0.253, -0.672, -0.304, 0.230, -0.167, -0.318, -0.820, -5.000, -0.463, -0.863, -1.545, -5.000, -0.198, -0.158, -0.633, -0.422, -0.358, -1.486, -1.365, -0.444, 0.612, 0.283, -0.013, -5.000, -0.875, -0.262, -1.014, 0.311, 0.281, 0.102, -0.038, 0.013, 0.382, 0.399, 0.659, 0.146, 0.002, -0.691, -0.753, 0.069, -0.430, -0.451, -0.669, -0.814, 0.202, -0.106, -0.405, -0.203, -0.279, -0.344, -0.119, 0.098, -0.112, -0.921, -0.662, 0.105, -0.293, -1.051, -0.910, -0.889, -0.347, -0.864, -0.713, -0.686, -0.116, -1.152, -1.015, -0.468, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.856, -0.706, -1.144, -5.000, -2.345, -1.996, -2.420, -5.000, -1.454, -1.735, -1.161, -1.836, -0.563, -0.027, -0.299, -0.170, -0.590, -0.087, -0.586, -5.000, -1.089, -0.597, -1.203, -1.057, -1.614, -1.616, -1.616, -1.803, 0.284, -0.059, 0.101, 0.240, -0.865, -0.298, -0.762, -0.742, -1.505, -1.210, -1.782, -1.684, -1.876, -1.422, -2.398, -1.483, -0.462, -0.187, -0.217, -0.338, -1.427, -1.195, -1.590, -1.138, -1.923, -1.791, -2.048, -1.694, -0.491, -0.491, -0.039, 0.057, -0.196, 0.169, -0.293, -0.706, -0.053, -0.685, -1.073, -5.000, -1.036, -1.091, -1.994, -5.000, -1.266, -1.787, -1.593, -1.521, -0.268, -0.045, 0.089, 0.338, 0.111, 0.156, 0.195, -5.000, -0.751, -0.388, -1.155, 0.200, -0.581, -0.454, -0.553, -0.978, 0.083, -0.883, -0.446, 0.122, -0.173, -0.325, -0.700, 0.023, -0.797, -0.375, -1.390, -1.502, -0.676, -0.701, -0.917, -0.961, -0.200, -0.665, -0.076, -0.419, -1.054, -0.993, -1.346, -0.336, -1.676, -0.917, -1.754, -1.775, -1.962, -2.168, -1.616, -1.561, -0.448, -0.198, -0.440, 0.051, -0.680, -0.957, -1.386, -5.000, -1.798, -1.691, -2.226, -5.000, -2.137, -1.894, -1.784, -2.208, -1.361, -1.489, -2.172, -1.319, -0.540, -0.842, -1.049, -5.000, -1.721, -1.326, -1.913, -1.464, -1.551, -1.582, -2.033, -2.179, -0.683, -0.664, -0.604, -0.527, -0.759, -1.245, -1.631, -0.832, -1.978, -1.764, -2.119, -2.268, -1.387, -1.466, -1.122, -1.528, -0.877, -1.056, -0.848, -0.868, -1.076, -1.638, -1.754, -0.932, -1.822, -2.217, -2.343, -2.394, -1.977, -2.372, -2.495, -2.122, -1.166, -1.766, -2.032, -1.379, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.470, -0.458, -0.503, -5.000, -2.085, -2.066, -2.509, -5.000, -1.357, -1.544, -1.310, -1.835, -0.425, -0.416, -1.041, 0.020, -0.086, 0.266, 0.182, -5.000, -1.729, -0.879, -1.537, -0.685, -1.273, -1.002, -1.569, -1.584, 0.451, 0.139, 0.478, 0.170, -0.245, 0.099, -0.386, 0.307, -1.145, -0.664, -1.175, -1.702, -0.769, -1.091, -1.592, -1.488, -0.441, -0.032, 0.347, -0.032, -1.067, -0.662, -1.637, 0.156, -1.669, -1.467, -2.489, -2.697, -1.926, -2.187, -1.354, -2.164, -0.800, -0.437, -0.509, -0.408, -0.325, -0.022, -1.015, -5.000, -1.805, -1.170, -2.633, -5.000, -2.284, -1.865, -2.078, -2.433, -0.469, -0.488, -0.828, 0.125, 0.243, 0.640, 0.430, -5.000, -1.633, -0.478, -1.398, -0.219, -0.919, -0.528, -0.816, -1.190, 0.298, -0.010, 0.141, -0.239, 0.038, 0.288, -0.610, 0.115, -0.851, -0.022, -0.997, -1.428, -0.148, -0.205, -0.314, -0.795, 0.194, 0.236, 0.676, 0.141, 0.014, 0.027, -0.525, 0.541, -0.738, -0.363, -1.225, -1.059, -1.160, -1.286, -1.779, -1.764, -0.067, -0.359, -0.042, 0.037, -1.024, -1.224, -1.201, -5.000, -1.567, -1.519, -2.144, -5.000, -1.234, -1.721, -1.585, -1.760, -1.347, -1.396, -1.734, -1.022, -0.289, -0.909, -0.971, -5.000, -1.349, -0.921, -1.819, -1.368, -0.717, -1.077, -1.190, -1.195, -0.438, -0.372, -0.731, -0.419, -0.684, -0.768, -1.000, -0.538, -1.281, -1.245, -1.673, -1.598, -0.803, -1.233, -0.850, -1.036, -0.691, -1.336, -0.870, -0.850, -0.306, -1.328, -1.280, -0.296, -0.591, -1.475, -1.628, -1.648, -1.324, -1.465, -1.359, -1.505, -0.645, -1.447, -1.525, -0.816, -0.703, -0.957, -0.855, -5.000, -2.561, -1.938, -2.472, -5.000, -1.717, -1.623, -1.686, -2.095, -0.657, -0.891, -1.359, -0.284, -0.511, -0.223, -0.247, -5.000, -1.670, -1.258, -2.018, -1.201, -0.988, -1.169, -1.150, -1.611, 0.158, 0.062, 0.280, -0.127, -0.856, -0.044, -0.817, -0.223, -1.695, -1.513, -1.626, -1.676, -0.933, -1.229, -0.612, -1.085, -0.734, -0.740, -0.000, -0.094, -0.845, -0.524, -0.931, -0.467, -1.701, -1.389, -1.945, -1.936, -1.810, -1.684, -1.823, -2.192, -0.762, -1.111, -0.609, -0.523, -0.483, -0.898, -0.358, -5.000, -0.466, -0.882, -1.396, -5.000, -0.828, -1.270, -0.614, -0.842, -0.563, -0.528, 0.130, -0.174, 0.062, -0.817, -0.692, -5.000, -0.364, -0.606, -0.904, -0.434, -0.416, -0.567, -0.649, -0.820, 0.327, -0.253, -0.297, 0.105, -0.017, -0.544, -0.743, 0.100, -0.069, -0.137, -1.187, -1.104, -0.346, -0.935, -0.988, -0.434, -0.134, -0.099, -0.540, -0.440, -0.277, -0.407, -0.289, 0.157, -0.386, -0.478, -1.373, -0.885, -0.519, -1.477, -1.109, -1.338, -0.320, -0.491, -0.163, -0.836, 0.006, -0.491, -0.557, -5.000, -0.149, -0.021, -1.615, -5.000, -0.732, -1.266, -1.324, -1.480, -1.065, -0.847, -0.060, -1.654, 0.661, -0.050, -0.548, -5.000, -0.562, -0.014, -0.959, 0.289, 0.087, 0.015, -0.434, -0.148, 0.314, -0.336, -0.525, 0.170, 0.191, 0.128, -0.913, 0.255, -0.410, 0.024, -0.837, -0.957, -0.181, -0.607, -0.668, -0.660, 0.005, -0.513, -0.466, -0.117, 0.321, -0.756, -1.296, 0.531, -1.090, -0.569, -1.278, -0.519, -0.625, -1.724, -1.654, -1.109, 0.057, -0.991, -0.907, 0.020, 0.259, -1.040, -1.393, -5.000, -0.645, -0.851, -1.653, -5.000, -0.701, -0.787, -1.117, -0.926, -0.516, -1.200, -1.509, -0.923, 0.176, 0.017, -0.747, -5.000, -1.436, -0.868, -1.659, -0.194, -0.062, -0.491, -0.716, -0.124, 0.210, 0.191, 0.039, 0.260, -0.871, -1.369, -1.073, -0.684, -0.435, -1.001, -1.472, -0.601, -0.145, -0.497, -0.897, -0.463, 0.341, -0.706, -0.513, -0.734, -0.181, -1.067, -1.329, -0.067, 0.271, -1.456, -1.755, -0.863, -0.687, -1.451, -1.133, -1.494, -0.425, -1.495, -1.285, -0.556, -0.029, -0.392, -0.336, -5.000, -0.112, -1.049, -1.062, -5.000, -0.101, -0.600, -0.263, -0.654, 0.271, -0.719, -1.289, -0.690, -0.018, 0.507, -0.060, -5.000, -0.145, -0.230, -0.712, -0.296, -0.134, -0.616, -0.624, -0.400, 0.442, 0.307, 0.407, 0.149, 0.583, -0.247, -0.697, 0.271, -0.076, -0.839, -0.940, -0.747, -0.828, -0.863, -0.124, -0.184, 0.315, -1.051, -0.317, -0.286, -0.120, 0.229, -0.026, -0.287, -0.353, 0.163, -0.449, -0.820, 0.121, -0.924, -0.579, -0.519, -0.096, -0.473, -0.134, -0.117, 0.224, 0.816, 0.518, -5.000, -0.724, -0.305, -0.995, -5.000, -0.368, 0.303, -0.279, -0.329, -0.009, -0.055, 0.320, 0.145, 0.946, 1.175, 1.152, -5.000, -1.087, -0.003, -0.621, 0.366, 0.321, 0.877, 0.533, 0.015, 0.724, 1.121, 1.415, 0.279, 1.273, 1.453, 1.244, 1.534, 0.952, 1.300, 0.969, 0.428, 1.284, 0.856, 0.583, 0.831, 1.427, 1.252, 1.396, 1.373, 0.396, -0.122, 0.004, 0.243, -0.127, -0.253, -0.634, -0.268, 0.159, -0.030, -0.673, 0.295, 0.472, -0.370, -0.034, 0.188, 0.257, 0.800, -0.222, -5.000, -0.057, 0.054, -0.717, -5.000, 0.020, -0.110, -0.845, -0.092, -0.558, -0.582, 0.448, 0.512, 1.225, 1.191, 1.040, -5.000, 0.001, 0.384, 0.338, 1.179, 0.774, 1.030, 0.933, 0.728, 1.210, 0.842, 1.136, 0.262, 0.924, 0.602, -0.004, 1.287, 0.618, 0.698, 0.165, 0.083, 0.885, 0.373, 0.630, 0.676, 0.914, 0.550, 0.951, 0.618, 0.385, -0.008, 0.145, 1.018, -0.179, -0.160, -0.558, -0.483, -0.151, -0.895, -0.604, -0.727, -0.025, -0.730, -0.595, 0.006, 0.162, 0.021, 0.142, -5.000, -0.426, -0.454, -1.101, -5.000, 0.253, 0.412, -0.852, 0.127, -0.874, -0.490, -0.466, -0.318, 1.138, 0.461, 0.248, -5.000, -0.405, 0.600, -0.141, 0.910, 0.945, 0.759, 0.708, 0.819, 0.825, 1.032, 0.973, 0.594, 1.024, 0.799, 0.331, 1.289, 0.539, 0.635, 0.426, 0.041, 0.204, 0.087, -0.419, -0.617, 1.046, 0.405, -0.092, 0.890, 0.180, -0.468, -0.470, 1.147, -0.175, -0.578, -0.533, -0.473, 0.006, -0.471, -0.001, -0.289, 0.275, -0.703, -0.695, 0.017, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.669, -0.496, -0.776, -5.000, -1.401, -1.115, -2.256, -5.000, -1.828, -1.532, -0.833, -1.622, -0.650, -0.234, -0.303, 0.271, -0.652, -0.039, -0.037, -5.000, -0.966, -0.495, -1.015, -0.810, -1.299, -0.979, -1.161, -1.409, -0.012, -0.182, 0.425, -0.128, -1.097, -0.501, -0.969, -0.783, -1.262, -0.842, -1.234, -1.556, -1.556, -0.889, -0.656, -1.482, -0.845, -0.400, -0.204, -0.544, -0.709, -1.125, -1.464, -1.515, -1.329, -1.417, -1.591, -1.085, -0.114, -0.586, 0.020, -0.491, -0.791, 0.326, 0.713, -0.447, 0.512, 0.632, -0.409, -5.000, -0.521, -0.440, -1.094, -5.000, -0.957, -0.696, -1.471, -0.637, -0.399, -0.070, 0.494, 0.222, 1.108, 0.870, 1.085, -5.000, -0.420, 0.077, -0.551, 0.898, 0.663, 0.666, 0.482, 0.272, 0.906, 0.084, 0.280, 0.214, 0.477, 0.360, -0.026, 0.926, 0.056, 0.451, -0.250, -0.448, 0.317, 0.090, -0.154, -0.100, 0.386, 0.169, 0.780, 0.570, -0.790, -0.889, -0.736, 0.305, -0.895, -0.370, -1.089, -1.382, -1.694, -1.461, -1.596, -2.135, -0.279, -0.350, -0.039, 0.031, -0.367, -0.230, -0.723, -5.000, -1.423, -0.985, -1.867, -5.000, -1.343, -0.796, -1.210, -1.559, -1.123, -0.838, -1.718, -0.486, 0.111, 0.171, -0.258, -5.000, -1.118, -0.426, -1.040, -0.344, -0.543, -0.428, -0.642, -1.096, -0.271, 0.284, 0.523, -0.109, 0.264, 0.240, -0.492, 0.896, -0.658, -0.506, -0.869, -1.201, -0.537, -0.773, -0.828, -0.845, -0.085, -0.346, -0.395, 0.228, -1.017, -1.180, -1.074, -0.149, -1.837, -1.640, -2.009, -2.227, -1.859, -2.245, -2.289, -2.338, -1.083, -1.504, -1.399, -0.890, 0.284, 0.939, 0.705, -5.000, -1.215, -0.612, -1.266, -5.000, -1.206, 0.168, -0.872, -0.890, -0.347, 0.269, -0.174, 0.202, 0.642, 0.973, 0.931, -5.000, -1.504, -0.278, -1.001, 0.122, 0.490, 0.530, 0.612, 0.186, 0.668, 1.116, 1.471, 0.451, 0.505, 1.229, 0.788, 1.059, 0.042, 0.837, 0.184, -0.903, 0.033, -0.075, -0.501, -0.793, 0.633, 0.641, 0.863, 0.935, -0.163, -0.047, -0.306, -0.012, -0.460, -0.611, -1.030, -1.034, -0.375, -0.722, -1.037, -0.726, -0.293, -0.709, -0.408, -0.004, 0.046, 0.612, 0.138, -5.000, -1.798, -0.941, -1.829, -5.000, -1.373, -0.487, -1.192, -1.699, -0.308, -0.199, -0.126, -0.118, 1.118, 1.113, 1.089, -5.000, -1.143, 0.248, -0.632, 0.473, 0.068, 0.256, -0.201, -0.462, 0.906, 0.884, 1.221, 0.162, 0.523, 0.846, 0.422, 1.104, -0.317, 0.844, 0.245, -0.438, 0.168, 0.151, -0.620, -0.499, 0.493, 0.830, 1.169, 0.725, 0.166, 0.764, 0.425, 1.312, -0.917, -0.129, -0.816, -1.755, -1.624, -1.251, -1.071, -2.475, 0.061, -0.126, 0.016, 0.470, 0.083, 0.663, -0.485, -5.000, -1.405, -0.695, -2.130, -5.000, -1.926, -1.174, -1.737, -2.279, -0.871, -0.586, -0.018, -0.102, 0.974, 1.070, 0.913, -5.000, -1.094, 0.087, -0.769, 0.445, -0.126, 0.213, -0.070, -0.527, 0.833, 0.552, 0.813, -0.026, 0.572, 0.863, 0.087, 0.826, -0.190, 0.697, 0.038, -0.644, 0.546, 0.525, 0.317, 0.022, 0.718, 0.793, 1.246, 0.719, 0.609, 0.700, 0.557, 1.329, -0.154, 0.298, -0.258, -0.498, -0.591, -0.719, -1.114, -1.681, 0.211, -0.103, 0.173, 0.495, -0.200, 0.353, -0.240, -5.000, -1.493, -0.788, -1.914, -5.000, -0.696, -0.260, -1.209, -1.377, -0.793, -0.106, -0.496, -0.650, 0.356, 0.479, 0.311, -5.000, -1.171, 0.196, -0.793, -0.587, 0.364, 0.217, -0.110, -0.386, 0.221, 0.728, 0.999, -0.067, 0.774, 0.908, 0.252, 0.891, -0.251, 0.305, -0.484, -0.781, 0.048, -0.349, -0.575, -0.446, 0.257, 0.208, 0.061, 0.811, 0.592, 0.600, 0.412, 1.118, -0.576, -0.371, -0.634, -1.176, -0.668, -0.917, -1.122, -1.203, 0.848, -0.616, -0.804, 0.386, -0.197, 0.489, 0.059, -5.000, -1.979, -1.066, -1.881, -5.000, -1.383, -0.447, -1.413, -1.582, -0.850, -0.070, -0.854, -0.258, 0.345, 0.792, 0.623, -5.000, -1.413, -0.265, -1.294, -0.358, 0.055, 0.116, 0.020, -0.563, 0.229, 0.835, 1.325, -0.014, 0.013, 0.502, -0.131, 0.732, -0.644, 0.143, -0.713, -1.364, -0.637, -0.865, -0.553, -1.288, 0.009, -0.133, 0.655, 0.704, -0.149, 0.441, -0.032, 0.625, -1.005, -0.162, -0.965, -1.691, -1.200, -1.000, -1.330, -1.645, -0.264, -0.536, -0.222, 0.244, 0.115, 0.440, -0.177, -5.000, -0.491, -0.353, -0.850, -5.000, -0.342, -0.323, -0.567, -0.858, -0.473, -0.409, -0.185, -0.396, 0.880, 0.879, 0.986, -5.000, -0.679, 1.068, 0.328, 0.537, 0.526, 0.750, 0.362, 0.031, 0.816, 1.093, 1.392, 0.118, 1.012, 1.090, 0.747, 1.296, 0.236, 0.817, -0.027, -0.090, -0.161, -0.142, -0.528, -0.457, 0.960, 0.186, 0.175, 0.840, -0.230, 0.085, 0.126, 0.692, -1.038, -0.695, -1.012, -1.350, -1.696, -1.422, -1.196, -2.209, 0.243, -0.406, -0.556, -0.162, 0.655, 1.067, 0.185, -5.000, -0.565, -0.134, -1.266, -5.000, -0.591, -0.300, -1.072, -0.753, -0.695, -0.662, 0.464, -0.203, 1.293, 1.157, 0.947, -5.000, -0.112, 0.495, -0.134, 0.976, 0.795, 0.925, 0.613, 0.537, 1.141, 0.904, 1.111, 0.072, 0.988, 1.133, 0.613, 1.273, 0.218, 1.065, 0.541, -0.060, 0.841, 0.681, 0.508, 0.305, 0.947, 0.940, 1.327, 1.033, 0.313, 0.293, 0.328, 1.384, 0.085, 0.405, -0.193, -0.193, -0.375, -0.958, -1.004, -0.688, 0.009, -0.424, -0.480, 0.209, 0.829, 0.993, 0.771, -5.000, -0.290, 0.160, -0.688, -5.000, 0.486, 0.908, -0.455, 0.072, -0.195, -0.016, -0.403, -0.306, 1.317, 0.971, 0.819, -5.000, -0.259, 1.212, 0.542, 1.044, 1.353, 1.232, 1.056, 1.065, 1.215, 1.442, 1.361, 0.909, 1.473, 1.244, 0.763, 1.559, 1.216, 1.010, 0.569, 0.567, 0.555, -0.066, -0.120, 0.428, 1.305, 0.358, 0.141, 1.244, 0.645, 0.316, 0.438, 1.460, 0.252, 0.109, -0.219, -0.368, -0.457, -0.756, -0.325, -0.027, 0.602, -0.845, -0.768, 0.431, -0.094, 0.660, 0.516, -5.000, -0.619, 0.004, -0.578, -5.000, -0.129, 0.274, -0.597, -0.540, -0.275, -0.142, 0.109, 0.045, -0.109, 0.564, 0.685, -5.000, -0.913, 0.511, -0.081, -0.176, 0.249, 0.614, 0.090, -0.280, 0.012, 0.474, 0.875, -0.169, -0.354, 0.275, -0.247, -0.329, -0.757, 0.088, -0.385, -0.837, -0.548, -0.593, -0.688, -0.808, -0.734, -0.568, -0.137, -0.402, 0.006, 0.256, 0.175, 0.469, -0.476, 0.018, -0.360, -0.744, -0.363, -0.487, -0.408, -0.416, 0.073, -0.160, -0.187, 0.022, 0.039, 0.617, 0.076, -5.000, -0.993, -0.619, -1.040, -5.000, -0.429, -0.134, -0.411, -0.414, -0.057, -0.072, 0.229, -0.236, 0.783, 0.931, 1.068, -5.000, -1.029, -0.098, -0.475, 0.523, 0.255, 0.691, 0.335, -0.020, 0.717, 1.001, 1.289, 0.066, 1.206, 1.261, 1.017, 1.493, 0.485, 1.051, 0.629, -0.120, 1.342, 0.980, 0.415, 0.745, 1.307, 1.250, 1.247, 1.231, 0.249, 0.043, 0.114, 0.733, -0.179, 0.205, -0.081, -0.337, -0.134, 0.661, -0.367, -0.118, 0.077, 0.336, 0.457, 0.181, 0.319, 0.683, -0.760, -5.000, -0.187, -0.111, -1.146, -5.000, -0.486, -0.567, -1.006, -0.654, -0.353, -0.545, -0.114, 0.220, 1.449, 1.356, 1.186, -5.000, -0.081, 0.168, 0.134, 1.414, 0.696, 0.882, 0.814, 0.586, 1.251, 0.620, 0.653, 0.252, 0.950, 0.787, 0.242, 1.273, 0.461, 0.861, 0.351, 0.022, 0.956, 0.691, 0.712, 0.675, 0.945, 0.744, 1.153, 0.940, 0.113, -0.313, -0.068, 1.047, -0.309, -0.152, -0.657, -0.248, -0.326, -0.911, -0.642, -0.584, -0.263, -0.676, -0.162, 0.017, 0.036, -0.306, -0.625, -5.000, -0.830, -0.336, -1.354, -5.000, -0.165, -0.121, -1.107, -0.574, -1.220, -0.819, -1.120, -0.705, 0.823, 0.254, -0.248, -5.000, -0.948, -0.019, -0.683, 0.581, 0.452, 0.110, -0.008, -0.054, 0.450, 0.748, 0.664, 0.136, 0.668, 0.205, -0.180, 0.894, 0.094, 0.362, 0.034, -0.005, 0.094, -0.125, -0.642, -0.573, 0.723, 0.101, -0.157, 0.647, 0.454, -0.230, -0.236, 1.373, -0.033, -0.486, -0.665, -0.574, -0.208, -0.781, -0.660, -0.431, 0.296, -0.739, -0.964, 0.228, 0.543, 0.932, 0.686, -5.000, -0.969, -0.562, -0.992, -5.000, -0.463, 0.102, -0.484, -0.183, -0.394, -0.323, -0.708, -0.839, 1.092, 1.048, 1.083, -5.000, -1.320, 0.356, -0.580, 0.746, 0.702, 0.979, 0.683, 0.469, 0.925, 1.141, 1.411, 0.064, 1.585, 1.595, 1.445, 1.666, 1.536, 1.578, 1.392, 1.243, 1.612, 1.367, 1.059, 1.106, 1.639, 1.580, 1.590, 1.623, 1.002, 1.153, 0.972, 1.390, 0.729, 1.041, 0.633, 0.095, 1.020, 0.833, 0.771, 0.330, 0.661, 0.260, 0.681, 0.486, 0.186, 0.616, 0.309, -5.000, -1.630, -1.239, -1.960, -5.000, -1.466, -0.571, -0.853, -1.285, -0.777, -0.423, 0.330, -0.203, 1.071, 0.985, 1.137, -5.000, -0.669, 0.002, -0.708, 0.537, -0.196, -0.009, -0.507, -0.666, 1.082, 0.637, 1.126, 0.069, 0.106, 0.444, 0.137, 0.550, -0.530, 0.460, -0.167, -0.987, -0.451, -0.198, -1.107, -0.943, 0.041, 0.310, 0.648, 0.298, -0.397, -0.619, -0.878, -0.116, -1.079, -0.806, -1.474, -1.900, -0.447, 0.138, -0.268, -0.056, 0.127, 0.096, -0.293, 0.183, 0.655, 0.896, 0.119, -5.000, -0.813, -0.620, -1.817, -5.000, -1.011, -0.643, -1.066, -1.042, -0.632, -0.144, 0.692, 0.294, 1.207, 1.003, 1.325, -5.000, -1.051, -0.086, -0.883, 1.120, 0.608, 0.632, 0.620, 0.329, 1.237, 0.687, 0.869, 0.310, 0.938, 0.886, 0.327, 1.143, 0.227, 0.741, 0.001, -0.400, 0.619, 0.465, 0.399, 0.057, 0.961, 0.746, 1.266, 0.897, -0.060, -0.100, -0.019, 0.963, -0.538, -0.144, -0.608, -1.131, -1.713, -1.202, -1.086, -1.796, 0.126, -0.125, 0.641, 0.401, -0.077, 0.165, -0.403, -5.000, -1.667, -0.446, -1.596, -5.000, -1.027, -0.400, -1.147, -1.511, -1.136, -0.596, -0.944, -1.025, 0.570, 0.357, 0.032, -5.000, -1.266, 0.059, -0.557, 0.113, 0.136, 0.081, -0.235, -0.568, 0.184, 0.667, 0.836, 0.103, 0.732, 0.469, -0.529, 0.814, -0.291, 0.087, -0.408, -0.955, -0.018, -0.263, -0.617, -0.659, 0.599, -0.165, -0.534, 0.609, -0.113, -0.362, -0.425, 0.875, -1.120, -1.135, -1.364, -1.850, -1.365, -1.707, -1.691, -2.157, -0.019, -1.145, -1.098, -0.117, -0.760, -0.314, -0.716, -5.000, -1.939, -1.323, -1.712, -5.000, -1.534, -0.853, -1.190, -1.448, -0.611, -0.885, -1.292, -0.286, -0.318, -0.070, -0.181, -5.000, -1.550, -0.764, -1.570, -0.672, -1.133, -0.566, -0.871, -1.201, 0.071, 0.521, 0.981, -0.101, -0.309, 0.241, -0.149, 0.406, -1.121, -0.388, -1.050, -1.580, -0.713, -0.588, -0.914, -1.174, -0.016, 0.126, 0.377, 0.227, -0.653, -0.287, -0.362, 0.042, -1.063, -0.866, -1.224, -1.512, -1.160, -1.287, -1.591, -1.784, -0.641, -0.711, -0.479, -0.171, 0.343, 0.765, 0.215, -5.000, -1.526, -0.586, -1.239, -5.000, -1.105, -0.268, -0.748, -1.252, -0.551, -0.284, -0.065, 0.084, 1.202, 0.836, 1.046, -5.000, -0.981, 0.213, -0.090, 0.767, 0.239, 0.436, 0.145, -0.146, 0.999, 0.994, 1.302, 0.250, 0.477, 0.611, 0.124, 0.764, -0.364, 0.740, 0.100, -0.769, 0.333, 0.406, -0.026, -0.058, 0.503, 0.655, 0.935, 0.585, 0.128, 0.605, 0.257, 1.019, -0.856, 0.173, -0.592, -1.229, -1.362, -0.967, -0.858, -1.852, 0.274, -0.031, -0.066, 0.494, 0.189, 0.446, -0.321, -5.000, -1.419, -0.720, -1.815, -5.000, -1.194, -0.566, -1.218, -1.928, -0.911, -0.883, 0.183, -0.004, 1.084, 0.654, 0.679, -5.000, -0.871, -0.220, -0.547, 0.840, 0.330, 0.395, 0.295, -0.169, 0.809, 0.758, 0.925, 0.090, 0.168, 0.275, -0.609, 0.197, -0.301, 0.367, -0.427, -0.985, 0.292, 0.116, 0.108, -0.233, 0.578, 0.384, 0.915, 0.354, 0.115, 0.000, -0.239, 0.886, -0.145, -0.317, -0.778, -0.880, -0.429, -0.672, -0.706, -0.981, 0.343, -0.242, -0.046, 0.496, 0.024, -0.010, -0.424, -5.000, -0.974, -1.228, -1.578, -5.000, -0.345, -0.136, -0.937, -0.493, -0.536, 0.031, -0.501, -0.422, 0.240, -0.229, -0.291, -5.000, -0.765, 0.122, -0.530, 0.010, 0.309, 0.094, -0.068, -0.217, 0.322, 0.563, 0.719, -0.006, 0.524, 0.691, -0.062, 0.330, -0.216, 0.622, -0.124, -0.608, 0.506, 0.126, -0.223, -0.039, 0.196, 0.129, 0.011, 0.464, 0.325, 0.317, -0.224, 0.667, -0.160, -0.271, -0.510, -0.771, -0.488, -0.238, -0.533, -0.206, 0.663, -0.399, -0.519, 0.125, -0.318, -0.047, -0.310, -5.000, -2.046, -1.654, -1.848, -5.000, -1.398, -0.849, -1.113, -1.154, -0.807, -0.562, -1.018, -0.228, 0.423, 0.327, 0.360, -5.000, -1.353, -0.266, -0.924, -0.250, 0.100, 0.184, 0.079, -0.356, 0.260, 0.725, 1.146, 0.138, 0.204, 0.193, -0.086, 0.143, -0.476, 0.279, -0.194, -0.562, 0.190, 0.025, -0.061, -0.548, 0.274, 0.023, 0.437, 0.387, -0.119, -0.243, -0.527, 0.155, -1.071, -0.304, -1.147, -1.771, -1.319, -0.897, -0.660, -1.080, -0.279, -0.650, -0.139, 0.235, 0.324, 0.608, 0.191, -5.000, -0.345, -0.343, -0.675, -5.000, -0.309, 0.010, -0.419, -0.581, 0.045, -0.185, 0.191, -0.333, 1.112, 0.912, 1.087, -5.000, -0.945, 0.819, 0.459, 0.722, 0.688, 0.891, 0.423, 0.374, 0.901, 1.203, 1.450, 0.161, 1.096, 1.196, 0.800, 1.239, 0.245, 1.058, 0.398, -0.115, 0.213, 0.134, -0.619, -0.594, 0.840, 0.552, 0.611, 0.971, 0.499, 0.800, 0.940, 1.265, -0.422, 0.494, -0.363, -0.767, -0.954, -0.818, -0.838, -1.483, -0.203, -0.304, 0.283, 0.179, 0.646, 0.796, -0.107, -5.000, -0.621, -0.064, -0.836, -5.000, -0.148, 0.046, -1.048, -0.564, -0.715, -0.769, 0.292, 0.037, 1.199, 0.694, 0.502, -5.000, -0.137, 0.452, 0.065, 1.151, 0.864, 0.744, 0.657, 0.526, 1.048, 0.952, 0.906, -0.150, 0.907, 0.675, -0.104, 1.031, 0.054, 0.751, 0.040, -0.271, 0.662, 0.251, 0.282, 0.157, 0.881, 0.624, 1.087, 0.782, 0.310, -0.047, -0.057, 1.326, 0.328, 0.263, -0.479, -0.287, -0.501, -0.995, -0.820, -0.409, 0.142, -0.599, -0.556, 0.432, 0.648, 1.029, 0.544, -5.000, 0.070, 0.456, -0.182, -5.000, 0.696, 1.074, -0.445, -0.075, 0.115, 0.199, -0.442, -0.379, 1.294, 0.916, 0.780, -5.000, -0.563, 1.184, 0.647, 1.181, 1.251, 1.106, 0.905, 1.040, 1.118, 1.292, 1.277, 0.757, 1.424, 0.972, 0.406, 1.416, 1.264, 1.112, 0.507, 0.544, 0.793, 0.326, -0.107, 0.368, 1.188, 0.045, -0.007, 0.981, 1.029, 0.778, 0.536, 1.541, 0.719, 0.587, 0.187, 0.005, -0.274, -0.829, -0.302, -0.038, 0.974, -0.856, -0.833, 0.772, 0.626, 0.791, 0.291, -5.000, -0.986, -0.030, -0.666, -5.000, -0.085, 0.566, -0.480, -0.294, -0.422, 0.145, -0.475, -0.079, 1.158, 0.675, 0.743, -5.000, -0.868, 0.581, 0.127, 0.892, 1.086, 1.072, 0.867, 0.868, 0.947, 1.353, 1.426, 0.410, 1.200, 0.822, 0.652, 1.289, 0.569, 1.069, 0.724, 0.186, 0.526, -0.256, -0.701, -0.744, 0.981, 0.051, 0.386, 1.028, 0.746, 0.914, 0.755, 1.208, 0.257, 0.548, 0.249, -0.339, 0.066, -0.543, -0.226, -0.479, 0.504, -0.317, -0.412, 0.373, -0.146, -0.407, -0.301, -5.000, -1.326, -1.159, -1.566, -5.000, -0.296, -0.223, -0.293, -0.464, -0.196, -0.186, -0.134, -0.167, 0.491, 0.135, 0.418, -5.000, -0.547, -0.296, -0.771, 0.278, -0.220, -0.021, -0.207, -0.390, 0.610, 0.594, 0.934, 0.194, 0.666, 0.691, 0.429, 0.258, 0.139, 0.532, 0.165, -0.392, 0.933, 0.635, -0.068, 0.283, 0.666, 0.907, 1.007, 0.823, -0.002, -0.404, -0.856, 0.037, -0.462, -0.542, -0.883, -0.531, 0.222, 0.009, 0.387, -0.091, 0.220, 0.141, -0.134, -0.215, -0.233, -0.590, -1.586, -5.000, -0.845, -0.876, -2.239, -5.000, -1.135, -1.436, -1.888, -0.944, -0.667, -0.902, -0.060, -0.170, 1.212, 0.640, 0.220, -5.000, -0.338, -0.409, -1.130, 1.065, -0.104, -0.227, -0.302, 0.078, 0.695, 0.014, -0.151, 0.051, 0.678, 0.198, -0.417, 0.891, 0.268, 0.157, -0.481, -0.557, 0.741, 0.260, 0.428, 0.433, 0.634, 0.306, 0.658, 0.577, -0.233, -1.133, -0.994, 0.290, -0.876, -1.274, -1.545, -1.115, -0.828, -1.719, -1.369, -0.462, -0.159, -1.114, -0.711, -0.241, -0.358, -0.523, -0.971, -5.000, -0.947, -0.886, -1.726, -5.000, -0.420, -0.785, -1.074, -0.858, -0.670, -1.320, -1.899, -0.543, 0.607, 0.202, -0.227, -5.000, -1.047, -0.196, -0.880, 0.428, 0.043, -0.153, -0.273, -0.372, 0.242, 0.535, 0.599, 0.046, 0.371, 0.086, -0.438, 0.559, 0.134, 0.251, -0.264, -0.209, 0.235, -0.282, -0.623, -0.042, 0.421, -0.168, -0.199, 0.413, -0.029, -0.492, -0.599, -0.021, -0.082, -0.428, -0.656, -0.562, -0.272, -0.739, -0.625, -0.513, 0.088, -1.150, -0.920, -0.001, 0.255, 0.691, -0.017, -5.000, -0.886, -0.642, -0.971, -5.000, -0.134, -0.263, -0.868, -0.363, 0.255, -0.199, -0.865, -0.032, 0.958, 1.072, 1.046, -5.000, -1.082, 0.375, -0.458, 0.733, 0.410, 0.722, 0.392, 0.341, 0.931, 1.170, 1.414, 0.396, 1.383, 1.504, 1.228, 1.399, 1.237, 1.560, 1.319, 0.630, 1.518, 1.504, 1.125, 1.037, 1.506, 1.533, 1.517, 1.433, 0.122, 0.613, 0.125, -0.851, 0.073, 0.855, 0.718, 0.172, 0.851, 0.753, 0.319, 0.353, 0.478, 0.741, 0.649, 0.361, -0.240, -0.527, -0.810, -5.000, -2.108, -1.589, -2.268, -5.000, -1.128, -1.082, -0.598, -1.548, -0.974, -0.648, -0.386, 0.120, 0.455, 0.444, 0.604, -5.000, -0.791, 0.009, -0.876, -0.225, -0.384, -0.359, -1.058, -0.878, 0.479, 0.316, 0.581, 0.380, -0.217, 0.394, -0.120, 0.347, -0.783, -0.093, -1.057, -1.269, -1.071, -0.847, -1.730, -1.330, -0.209, 0.039, 0.060, 0.063, -1.296, -0.991, -1.473, -0.386, -1.428, -1.328, -2.016, -1.926, -0.086, -0.601, -0.673, 0.097, -0.134, -0.828, -0.429, -0.303, -0.014, -0.468, -1.033, -5.000, -1.122, -1.270, -2.043, -5.000, -1.891, -1.796, -1.510, -1.965, -0.840, -1.150, 0.132, 0.202, 0.758, 0.215, 0.576, -5.000, -0.948, -0.431, -0.995, 0.504, 0.127, -0.067, -0.238, -0.288, 0.585, -0.110, 0.177, 0.301, 0.333, -0.078, -0.732, 0.518, -0.402, 0.027, -0.989, -0.951, 0.017, -0.327, -0.355, -0.592, 0.376, -0.189, 0.388, 0.265, -0.666, -0.845, -0.791, 0.188, -0.986, -0.731, -1.536, -1.716, -2.079, -1.867, -1.900, -2.072, -0.215, -0.764, -0.651, 0.089, -0.391, -0.789, -1.150, -5.000, -1.666, -1.290, -2.051, -5.000, -1.759, -1.457, -1.839, -1.982, -1.437, -1.479, -1.484, -1.264, 0.108, -0.278, -0.663, -5.000, -1.455, -0.648, -1.289, -0.468, -0.582, -0.694, -0.962, -1.307, -0.307, -0.047, 0.166, -0.205, -0.054, -0.470, -1.054, 0.096, -1.036, -0.760, -1.225, -1.744, -0.781, -0.918, -0.794, -0.971, -0.164, -0.474, -0.584, -0.034, -0.609, -1.246, -1.135, -0.150, -1.428, -1.535, -1.813, -1.852, -1.668, -1.924, -1.915, -1.856, -0.737, -1.647, -1.551, -0.773, -0.314, -0.677, -0.499, -5.000, -1.769, -1.547, -2.015, -5.000, -1.811, -1.517, -1.676, -1.792, -0.540, -0.782, -1.264, -0.260, -0.846, -0.325, -0.286, -5.000, -1.738, -0.875, -1.849, -1.358, -1.512, -1.149, -1.606, -2.008, -0.420, 0.009, 0.349, -0.078, -1.184, -0.289, -0.832, -0.086, -2.101, -1.194, -2.156, -2.142, -1.198, -0.893, -0.892, -1.421, -0.460, -0.386, 0.174, -0.180, -0.252, -0.627, -0.630, -0.358, -1.522, -1.424, -2.159, -1.550, -0.945, -1.512, -2.094, -1.879, -0.329, -0.665, -0.631, -0.485, -0.336, -0.789, -0.900, -5.000, -2.033, -1.874, -2.235, -5.000, -1.478, -1.708, -1.249, -1.965, -0.502, -0.586, 0.271, -0.753, 0.173, -0.399, 0.159, -5.000, -0.939, -0.661, -1.108, -0.504, -1.022, -1.129, -1.006, -1.129, 0.461, 0.045, 0.551, 0.339, -0.625, -0.289, -0.541, 0.191, -0.783, -0.887, -1.205, -1.714, -0.727, -0.750, -0.786, -0.811, -0.535, -0.309, 0.215, -0.188, -1.251, -1.141, -0.796, 0.307, -1.476, -1.630, -2.151, -2.767, -1.652, -1.703, -1.617, -1.518, -0.868, -0.625, -1.125, -0.225, -0.596, -1.252, -1.459, -5.000, -1.456, -1.602, -2.554, -5.000, -2.228, -1.967, -1.997, -2.369, -0.773, -1.024, 0.041, -0.657, -0.074, -0.214, -0.256, -5.000, -1.278, -1.320, -1.747, -0.755, -0.923, -0.993, -0.940, -1.346, -0.006, -0.523, -0.421, -0.105, -0.695, -1.210, -1.541, -0.736, -1.301, -1.130, -1.928, -1.940, -0.473, -1.005, -0.826, -0.997, -0.506, -0.911, -0.368, -0.674, -0.461, -1.102, -1.422, -0.187, -1.393, -1.534, -2.012, -1.930, -1.798, -1.769, -2.021, -1.862, -0.967, -1.112, -0.709, -0.281, -0.483, -1.329, -1.595, -5.000, -1.783, -1.921, -2.304, -5.000, -1.319, -1.504, -2.014, -1.708, -1.318, -1.521, -2.031, -1.184, -0.358, -0.879, -0.980, -5.000, -1.787, -1.373, -1.849, -1.198, -0.655, -1.152, -0.997, -1.193, -0.284, -0.510, -0.071, -0.293, -0.292, -0.288, -0.708, 0.026, -1.305, -0.942, -1.340, -1.694, -0.153, -0.725, -0.717, -0.481, -0.680, -0.319, -0.250, -0.151, -0.697, -1.688, -1.521, -0.518, -0.984, -1.445, -1.575, -1.482, -0.992, -1.189, -1.183, -1.301, -0.729, -1.751, -1.780, -0.913, -0.948, -1.060, -1.198, -5.000, -2.497, -2.436, -2.645, -5.000, -2.057, -2.089, -2.458, -1.658, -0.812, -1.246, -1.612, -1.010, -0.331, -0.566, -0.398, -5.000, -2.294, -1.319, -1.793, -1.215, -0.973, -1.227, -1.261, -1.328, 0.028, -0.381, -0.020, -0.078, -1.121, -0.413, -0.833, -1.065, -1.744, -1.058, -1.430, -1.680, -0.652, -0.843, -0.398, -0.343, -0.440, -0.510, -0.014, -0.263, -0.775, -0.738, -0.897, -0.386, -2.033, -1.464, -2.178, -1.870, -1.677, -1.670, -1.594, -1.686, -0.994, -0.881, -0.822, -0.556, -0.017, -0.249, -0.369, -5.000, -0.562, -0.940, -1.330, -5.000, -0.641, -0.987, -0.627, -0.693, -0.012, 0.191, 0.258, -0.105, 0.664, 0.518, 0.702, -5.000, -0.479, 0.209, -0.123, 0.211, 0.218, 0.353, -0.157, -0.319, 0.628, 0.920, 1.082, 0.433, 0.633, 0.650, 0.313, 0.593, 0.129, 0.565, -0.422, -0.621, 0.040, -0.140, -0.743, -0.649, 0.627, 0.442, 0.275, 0.468, 0.020, 0.188, -0.230, 0.303, -0.725, -0.517, -1.230, -1.355, -0.603, -1.070, -0.575, -0.957, 0.062, -0.524, -0.258, -0.056, -0.443, -1.024, -1.233, -5.000, -1.016, -0.918, -1.933, -5.000, -1.835, -1.778, -1.807, -1.909, -0.696, -0.940, 0.202, 0.132, 0.489, -0.450, -0.470, -5.000, -0.857, -0.593, -1.080, -0.237, -0.170, -0.421, -0.409, -0.427, 0.210, -0.108, -0.208, 0.002, 0.004, -0.749, -1.069, 0.020, -0.867, -0.646, -1.236, -1.094, -0.150, -0.809, -0.447, -0.546, -0.018, -0.682, -0.047, -0.085, -0.348, -1.175, -0.927, 0.037, -0.578, -1.043, -1.587, -0.661, -1.089, -1.724, -1.672, -1.088, -0.090, -1.076, -0.627, 0.003, -0.278, -0.916, -0.743, -5.000, -0.605, -1.386, -1.522, -5.000, -0.746, -0.814, -1.415, -1.199, -0.418, -1.130, -1.290, -0.586, 0.464, -0.542, -0.524, -5.000, -0.656, -0.367, -1.172, -0.068, 0.113, -0.455, -0.501, -0.414, 0.246, 0.041, 0.086, 0.038, 0.111, -0.670, -0.679, 0.045, -0.459, -0.698, -1.058, -1.064, -0.230, -1.117, -0.571, -0.460, -0.202, -0.741, -0.546, -0.323, 0.111, -0.784, -0.730, 0.468, -0.362, -0.776, -0.942, -1.062, -0.643, -1.318, -0.334, -0.507, -0.040, -1.364, -1.203, -0.273, 0.135, -0.112, -0.393, -5.000, -1.002, -0.591, -1.326, -5.000, -0.314, -0.345, -0.773, -0.784, -0.116, -0.389, -0.936, -0.117, 0.575, 0.570, 0.289, -5.000, -0.432, -0.096, -0.488, 0.353, 0.355, 0.416, 0.021, -0.030, 0.497, 0.901, 1.028, 0.352, 0.673, 0.236, 0.118, 0.699, 0.342, 0.474, 0.149, -0.281, 0.418, 0.044, -0.472, -0.239, 0.557, 0.521, 0.451, 0.554, 0.311, 0.254, -0.035, 0.168, 0.027, -0.005, -0.256, -0.678, -0.009, -0.607, -0.593, -0.673, -0.094, -0.299, -0.274, -0.127 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_11(struct _training *tptr) {
  struct _training tinf = {
    0.498, 11, 4.350, { 1.705, 0.250, 1.045 }, { 0.843, -0.419, -2.986 }, 1, 
    { -0.638, -0.686, -0.396, -1.194, -4.000, -4.000, 0.197, 0.540, 1.859, -4.000, -4.000, -4.000, 0.104, 0.511, 0.917, 0.986, 1.574, 0.441, 1.222, 0.658, 0.790, -4.000, 1.473, 2.797, 2.075, -4.000, 2.743, 2.086 }, 
    {{ -0.282, -0.266, -0.233, 0.520},{ -0.149, 0.009, -0.158, 0.242},{ -0.155, 0.029, -0.410, 0.370},{ -0.097, 0.063, -0.433, 0.319},{ -0.059, 0.120, -0.569, 0.308},{ -0.103, 0.019, -0.417, 0.349},{ 0.034, 0.039, -0.342, 0.193},{ -0.075, 0.142, -0.314, 0.172},{ -0.064, -0.055, -0.314, 0.323},{ -0.032, 0.053, -0.307, 0.214},{ -0.204, 0.096, -0.201, 0.234},{ -0.185, 0.096, -0.182, 0.210},{ -0.059, 0.073, -0.286, 0.206},{ -0.092, 0.129, -0.293, 0.185},{ -0.309, 0.129, -0.194, 0.266},{ -0.143, 0.082, -0.279, 0.254},{ -0.070, 0.177, -0.300, 0.124},{ -0.236, 0.147, -0.158, 0.181},{ -0.053, 0.073, -0.146, 0.105},{ -0.001, 0.078, -0.226, 0.115},{ -0.032, 0.009, -0.328, 0.262},{ 0.019, 0.029, -0.099, 0.044},{ -0.001, 0.096, -0.152, 0.039},{ -0.097, 0.058, -0.307, 0.258},{ 0.014, 0.044, -0.272, 0.163},{ 0.034, -0.007, -0.071, 0.039},{ -0.097, 0.024, -0.170, 0.202},{ -0.032, 0.087, -0.146, 0.073},{ -0.027, 0.110, -0.387, 0.206},{ 0.049, 0.014, -0.220, 0.124},{ -0.179, 0.053, -0.055, 0.150},{ -0.155, 0.039, -0.082, 0.168} }, 
    {{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}} }, 
    0.000, { 0.128, 0.458, -0.245, -5.000, -0.193, -0.117, -0.935, -5.000, -0.164, 0.159, -0.322, -0.279, 0.595, 0.457, 0.579, 0.229, 0.260, 0.446, -0.098, -5.000, -0.243, 0.051, -1.077, -0.702, -0.170, 0.395, -0.244, -0.072, 0.544, 0.667, 0.314, 0.194, 0.197, 0.664, -0.003, 0.227, 0.011, 0.285, -0.166, -0.388, -0.106, 0.338, -0.169, -0.022, 0.445, 0.308, 0.566, 0.101, -0.005, 0.550, -0.165, 0.206, 0.089, 0.369, 0.003, -0.140, 0.123, 0.367, 0.240, 0.489, 0.413, 0.541, 0.432, 0.423, 0.456, 0.794, 0.149, -5.000, 0.148, 0.431, -0.311, -5.000, 0.230, 0.419, 0.169, 0.172, 0.966, 0.731, 0.760, 0.566, 0.920, 0.985, 0.478, -5.000, 0.610, 0.598, -0.048, -0.293, 0.125, 0.729, 0.423, 0.416, 0.725, 0.886, 0.668, 0.787, 0.654, 1.096, 0.378, 0.828, 0.587, 0.581, 0.228, -0.089, 0.526, 0.564, 0.349, 0.416, 0.464, 0.761, 0.506, 0.470, 0.490, 0.985, 0.190, 0.450, 0.404, 0.466, 0.190, -0.256, 0.510, 0.500, 0.266, 0.531, 0.762, 0.884, 0.591, 0.694, -0.151, 0.379, -0.308, -5.000, -0.710, -0.117, -1.158, -5.000, -0.306, -0.097, -0.678, -0.293, 0.171, 0.130, 0.070, -0.085, 0.241, 0.436, -0.287, -5.000, -0.267, -0.256, -0.803, -0.908, -0.288, -0.033, -0.462, -0.428, 0.106, 0.348, 0.006, -0.027, -0.010, 0.191, -0.457, -0.252, -0.141, -0.048, -0.770, -0.721, -0.416, 0.042, -0.645, -0.528, -0.411, 0.052, -0.768, -0.575, -0.411, -0.060, -0.949, -0.494, -0.450, -0.653, -1.273, -1.107, -0.438, -0.443, -0.898, -0.424, -0.160, -0.228, -0.648, -0.212, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.435, -0.388, -0.634, -5.000, -0.835, -0.854, -1.347, -5.000, -0.722, -0.264, -0.940, -0.668, 0.348, 0.092, -0.080, -0.161, -0.334, 0.311, -0.425, -5.000, -0.502, -0.758, -1.379, -0.961, -0.835, -0.323, -0.396, -0.622, -0.154, 0.197, -0.197, -0.357, 0.028, 0.410, -0.267, -0.009, -0.272, -0.076, -0.399, -0.797, -0.158, 0.108, -0.266, -0.057, 0.014, 0.267, 0.212, -0.111, -0.408, 0.164, -0.388, -0.409, -0.145, 0.182, -0.365, -0.639, -0.261, 0.073, -0.222, -0.087, 0.625, 0.288, 0.326, 0.021, -0.038, 0.060, -0.374, -5.000, -0.515, 0.092, -1.157, -5.000, -0.236, -0.289, -0.410, -0.461, 0.522, 0.372, 0.209, 0.258, 0.533, 0.582, -0.089, -5.000, -0.167, 0.277, -0.332, -0.831, -0.110, 0.073, -0.253, -0.419, 0.276, 0.524, 0.345, 0.362, 0.270, 0.613, 0.116, 0.199, 0.353, 0.355, -0.133, -0.487, 0.061, 0.345, -0.043, 0.008, 0.066, 0.067, 0.226, 0.214, 0.201, 0.601, -0.163, -0.218, -0.326, 0.238, -0.425, -0.579, 0.075, 0.042, -0.284, -0.135, 0.236, 0.179, 0.137, -0.153, -0.686, -0.465, -0.867, -5.000, -1.765, -0.740, -0.961, -5.000, -0.937, -0.954, -1.082, -1.045, -0.301, -0.783, -0.738, -1.044, -0.346, -0.019, -1.013, -5.000, -1.108, -1.091, -1.106, -1.370, -1.265, -0.579, -0.996, -0.686, -0.008, -0.075, -0.285, -0.365, -0.444, -0.119, -0.781, -0.878, -0.559, -0.595, -1.129, -1.132, -1.072, -0.620, -0.688, -1.348, -1.038, -0.707, -0.804, -0.749, -0.998, -0.311, -0.990, -1.132, -0.991, -0.719, -1.222, -1.353, -0.941, -1.226, -0.890, -1.356, -0.500, -0.595, -0.696, -0.765, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.301, 0.020, -0.535, -5.000, -0.575, -0.248, -1.158, -5.000, -0.531, -0.347, -0.680, -0.939, 0.166, 0.215, -0.062, -0.565, -0.248, 0.275, -0.532, -5.000, -0.532, -0.333, -1.045, -0.942, -0.700, -0.490, -0.609, -0.827, -0.287, 0.045, -0.335, -0.507, -0.122, 0.539, -0.246, -0.127, -0.204, 0.173, -0.438, -0.691, -0.152, -0.015, -0.290, -0.356, 0.030, 0.052, 0.087, 0.014, -0.209, 0.527, -0.515, -0.457, -0.499, -0.014, -0.982, -0.600, -0.415, 0.131, -0.279, -0.183, -0.007, 0.432, 0.068, 0.117, -0.058, 0.533, -0.209, -5.000, -0.318, 0.011, -1.003, -5.000, -0.265, 0.029, -0.445, -0.602, 0.366, 0.309, 0.189, -0.290, 0.466, 0.737, 0.116, -5.000, 0.155, 0.338, -0.313, -0.803, -0.328, 0.219, -0.315, -0.305, 0.185, 0.548, 0.278, 0.012, 0.308, 0.676, -0.070, 0.022, -0.024, 0.329, -0.160, -0.639, 0.061, 0.401, -0.073, -0.105, 0.068, 0.337, 0.291, 0.113, 0.275, 0.861, -0.308, 0.150, 0.247, 0.360, -0.190, -0.514, -0.025, 0.399, -0.195, 0.007, 0.404, 0.610, 0.425, 0.101, -0.454, -0.180, -0.790, -5.000, -0.840, -0.725, -0.977, -5.000, -0.578, -0.600, -0.754, -1.018, -0.082, -0.196, -0.614, -0.673, -0.203, -0.056, -0.348, -5.000, -0.694, -0.091, -1.020, -1.036, -0.567, -0.390, -0.683, -0.792, -0.085, 0.095, -0.268, -0.584, -0.098, 0.264, -0.463, -0.303, -0.339, -0.137, -0.617, -0.759, -0.448, -0.460, -0.584, -0.635, -0.337, 0.090, -0.650, -0.366, -0.290, 0.610, -0.705, -0.419, -0.385, -0.203, -0.739, -0.846, -0.550, -0.370, -0.757, -0.548, -0.153, 0.075, -0.469, -0.702, -0.382, 0.223, -0.329, -5.000, -0.629, -0.644, -1.212, -5.000, -0.838, -0.328, -0.771, -0.970, 0.019, -0.051, -0.375, -0.710, 0.066, 0.617, -0.043, -5.000, -0.545, 0.153, -0.504, -0.774, -0.605, -0.049, -0.600, -0.636, 0.241, 0.432, 0.343, -0.278, -0.354, 0.090, -0.397, -0.274, -0.652, -0.089, -0.885, -0.852, -0.370, -0.048, -0.550, -0.476, -0.116, 0.167, -0.047, -0.479, -0.293, 0.087, -0.678, -0.323, -0.413, -0.338, -0.674, -0.498, -0.813, -0.109, -1.160, -0.682, -0.230, 0.018, -0.323, -0.396, 0.401, 0.777, 0.083, -5.000, 0.303, 0.566, -0.663, -5.000, 0.004, 0.447, -0.014, 0.076, 0.779, 0.869, 0.386, 0.193, 0.659, 0.951, 0.011, -5.000, 0.443, 0.404, -0.231, -0.364, 0.049, 0.443, -0.044, 0.005, 0.491, 0.748, 0.378, 0.192, 0.755, 0.978, 0.489, 0.663, 0.465, 0.669, 0.212, 0.014, 0.466, 0.593, 0.278, 0.520, 0.448, 0.639, 0.477, 0.463, 0.365, 0.866, 0.096, 0.100, 0.180, 0.443, -0.178, -0.654, 0.162, 0.659, 0.121, 0.284, 0.370, 0.745, 0.477, 0.246, 0.364, 0.816, -0.086, -5.000, 0.020, 0.367, -0.538, -5.000, 0.113, 0.394, -0.004, 0.248, 0.831, 0.580, 0.291, 0.209, 0.605, 0.904, 0.217, -5.000, 0.334, 0.512, -0.335, -0.379, 0.123, 0.438, 0.241, 0.290, 0.482, 0.618, 0.368, 0.353, 0.435, 1.008, 0.215, 0.586, 0.222, 0.452, -0.068, -0.339, 0.494, 0.472, 0.227, 0.378, 0.142, 0.531, 0.289, 0.215, 0.507, 1.004, 0.034, 0.292, 0.328, 0.445, 0.039, -0.360, 0.500, 0.409, -0.006, 0.352, 0.359, 0.697, 0.309, 0.322, 0.401, 0.712, -0.337, -5.000, -0.562, 0.292, -1.351, -5.000, 0.022, -0.047, -0.397, -0.263, 0.534, 0.528, 0.106, -0.112, 0.650, 0.899, 0.077, -5.000, 0.038, 0.457, -0.062, -0.562, 0.002, 0.491, -0.088, 0.085, 0.490, 0.721, 0.168, 0.222, 0.235, 0.927, -0.124, 0.064, 0.084, 0.316, -0.105, -0.213, -0.112, 0.426, -0.315, 0.031, -0.142, 0.479, -0.004, 0.147, -0.023, 0.522, -0.521, 0.020, -0.048, -0.112, -0.823, -1.076, -0.146, -0.181, -0.988, -0.214, 0.031, 0.257, -0.402, -0.127, -0.140, 0.416, -0.504, -5.000, -0.372, 0.007, -1.120, -5.000, -0.125, -0.101, -0.555, -0.424, 0.150, 0.029, -0.426, -0.407, 0.284, 0.621, -0.013, -5.000, -0.062, 0.186, -0.526, -0.472, -0.464, 0.202, -0.424, -0.348, 0.080, 0.456, 0.140, -0.057, -0.004, 0.519, -0.189, 0.052, -0.530, -0.172, -0.734, -0.562, -0.271, -0.201, -0.971, -0.431, -0.190, -0.075, -0.049, -0.014, 0.001, 0.639, -0.203, -0.058, -0.545, -0.208, -1.069, -0.996, -0.296, -0.090, -0.546, -0.419, -0.022, 0.143, -0.308, 0.009, 0.425, 0.752, 0.125, -5.000, 0.117, 0.229, -1.001, -5.000, -0.087, 0.499, -0.303, -0.258, 0.800, 0.809, 0.477, 0.321, 0.784, 0.976, 0.198, -5.000, 0.257, 0.470, -0.554, -0.331, -0.229, 0.676, -0.183, -0.331, 0.584, 0.935, 0.568, 0.343, 0.547, 0.974, 0.201, 0.497, 0.366, 0.799, 0.262, -0.264, 0.303, 0.787, 0.132, 0.296, 0.624, 0.815, 0.666, 0.441, 0.493, 0.900, -0.017, 0.441, 0.513, 1.017, 0.040, -0.130, 0.600, 1.024, 0.387, 0.632, 0.923, 1.054, 0.678, 0.737, 0.871, 1.074, 0.368, -5.000, 0.272, 0.576, -0.150, -5.000, 0.331, 0.678, 0.112, 0.246, 1.077, 0.984, 0.940, 0.566, 1.128, 1.091, 0.718, -5.000, 0.646, 0.819, 0.370, 0.013, 0.377, 0.820, 0.202, 0.392, 0.800, 0.910, 0.816, 0.720, 0.765, 1.152, 0.659, 0.768, 0.693, 0.765, 0.587, 0.116, 0.569, 0.837, 0.574, 0.533, 0.687, 0.822, 0.698, 0.544, 0.939, 1.140, 0.340, 0.614, 0.776, 0.946, 0.683, 0.289, 0.718, 0.910, 0.415, 0.567, 0.832, 1.020, 0.787, 0.694, 0.076, 0.536, -0.172, -5.000, -0.331, 0.264, -0.636, -5.000, -0.310, 0.221, -0.280, -0.135, 0.242, 0.232, -0.166, -0.164, 0.466, 0.833, 0.004, -5.000, 0.224, 0.485, -0.408, -0.510, -0.117, 0.228, -0.087, -0.021, 0.304, 0.606, 0.179, 0.079, -0.026, 0.634, -0.414, -0.359, 0.073, 0.281, -0.271, -0.821, -0.207, 0.104, -0.514, -0.187, -0.270, -0.308, -0.458, -0.250, 0.013, 0.444, -0.568, -0.180, -0.220, -0.196, -0.669, -0.902, -0.261, 0.098, -0.453, -0.139, 0.142, 0.114, -0.220, -0.053, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.019, 0.526, -0.488, -5.000, -0.229, 0.051, -1.005, -5.000, -0.555, 0.043, -0.833, -0.439, 0.434, 0.306, 0.062, -0.303, 0.205, 0.723, -0.251, -5.000, -0.549, -0.055, -1.150, -0.593, -0.672, 0.142, -0.556, -0.576, -0.106, 0.276, -0.196, -0.098, 0.429, 0.754, -0.041, 0.284, -0.048, 0.429, 0.045, -0.596, 0.121, 0.418, -0.052, 0.132, 0.285, 0.555, 0.440, 0.084, 0.387, 0.587, -0.173, 0.111, 0.236, 0.723, 0.061, -0.340, 0.370, 0.588, 0.310, 0.426, 0.567, 0.810, 0.508, 0.343, 0.075, 0.704, -0.317, -5.000, -0.127, 0.445, -0.441, -5.000, -0.108, 0.181, -0.777, -0.401, 0.790, 0.469, -0.097, 0.046, 0.732, 0.922, 0.291, -5.000, 0.250, 0.509, -0.248, -0.342, -0.031, 0.452, -0.096, -0.064, 0.596, 0.657, 0.215, 0.302, 0.605, 0.957, 0.351, 0.386, 0.412, 0.584, 0.201, -0.202, 0.445, 0.718, 0.099, 0.222, 0.321, 0.591, 0.364, 0.251, 0.466, 0.896, -0.043, -0.059, 0.158, 0.708, -0.089, -0.180, 0.471, 0.639, 0.167, 0.452, 0.476, 0.662, 0.480, 0.242, -0.275, 0.227, -0.521, -5.000, -0.966, -0.301, -0.922, -5.000, -0.696, -0.410, -0.868, -0.882, -0.013, -0.053, -0.601, -0.700, 0.144, 0.491, -0.294, -5.000, -0.490, -0.134, -0.877, -0.700, -0.696, -0.035, -0.764, -0.813, 0.091, 0.253, -0.318, -0.270, -0.182, 0.146, -0.637, -0.443, -0.717, -0.176, -0.740, -1.322, -0.761, -0.134, -0.998, -0.700, -0.631, -0.302, -0.826, -0.663, -0.446, 0.147, -0.785, -0.835, -0.302, -0.005, -0.917, -1.822, -0.573, -0.358, -1.115, -0.727, -0.494, -0.247, -0.538, -0.501, -0.380, -0.168, -0.626, -5.000, -0.870, -0.271, -0.920, -5.000, -0.832, -0.332, -1.008, -1.029, -0.430, -0.556, -0.922, -0.784, 0.021, 0.528, -0.454, -5.000, -0.581, -0.270, -0.863, -1.005, -0.469, -0.195, -0.304, -0.484, -0.428, 0.024, -0.253, -0.303, -0.410, 0.317, -0.608, -0.518, -0.863, -0.628, -0.946, -1.123, -0.637, -0.372, -0.718, -0.510, -1.039, -0.671, -0.869, -0.758, -0.313, 0.190, -0.844, -0.476, -0.441, -0.350, -1.060, -0.906, -0.668, -0.437, -0.872, -0.658, -0.680, -0.531, -0.745, -0.631, -0.257, 0.237, -0.341, -5.000, -0.435, -0.041, -1.007, -5.000, -0.452, -0.102, -0.844, -0.977, 0.012, 0.354, 0.038, -0.572, -0.004, 0.287, -0.130, -5.000, -0.252, 0.198, -0.870, -0.882, -0.574, -0.164, -0.492, -0.575, 0.143, 0.258, -0.291, -0.349, 0.108, 0.460, -0.191, -0.038, -0.371, 0.096, -0.155, -0.665, -0.235, -0.086, -0.283, -0.282, -0.008, 0.355, 0.074, 0.076, -0.081, 0.282, -0.506, -0.599, -0.424, 0.130, -0.685, -0.927, -0.340, 0.174, -0.434, -0.287, 0.110, 0.261, 0.024, -0.210, 0.100, 0.672, -0.344, -5.000, -0.198, 0.124, -0.738, -5.000, -0.213, 0.215, -0.448, -0.416, 0.439, 0.310, 0.061, -0.163, 0.611, 0.999, 0.381, -5.000, 0.339, 0.610, -0.362, -0.492, -0.281, 0.455, -0.134, 0.101, 0.481, 0.625, 0.422, 0.366, 0.341, 0.845, 0.304, 0.347, 0.168, 0.307, -0.025, -0.409, 0.181, 0.516, 0.201, 0.175, 0.378, 0.657, 0.403, 0.260, 0.386, 0.878, 0.251, 0.158, 0.323, 0.585, -0.127, -0.042, 0.086, 0.447, -0.100, 0.408, 0.537, 0.804, 0.540, 0.327, -0.454, -0.289, -0.518, -5.000, -0.837, -0.280, -0.795, -5.000, -0.355, -0.220, -0.790, -0.772, 0.066, -0.046, -0.139, -0.758, -0.013, 0.470, -0.127, -5.000, 0.125, 0.180, -0.392, -0.710, -0.530, -0.053, -0.490, -0.567, -0.044, 0.293, 0.028, -0.306, -0.053, 0.612, -0.059, -0.127, -0.096, 0.032, -0.529, -0.644, -0.397, 0.099, -0.358, -0.351, -0.166, 0.031, -0.401, -0.079, -0.127, 0.913, -0.259, 0.086, -0.076, 0.205, -0.612, -0.757, 0.148, 0.004, -0.544, -0.295, -0.141, 0.235, -0.161, -0.421, -0.134, 0.413, -0.571, -5.000, -0.451, -0.550, -2.276, -5.000, -0.575, -0.023, -0.424, -0.627, -0.014, 0.348, 0.029, -0.486, 0.285, 0.527, 0.043, -5.000, 0.136, 0.178, -0.661, -1.234, -0.494, 0.114, -0.294, -0.556, 0.222, 0.489, 0.395, -0.034, -0.340, 0.356, -0.023, -0.216, -0.320, 0.009, -0.544, -0.559, -0.349, -0.026, -0.508, -0.336, -0.237, 0.261, -0.150, -0.178, -0.255, 0.142, -0.097, -0.075, -0.313, 0.089, -0.719, -0.797, -0.640, -0.085, -0.445, -0.321, -0.072, 0.276, 0.045, -0.039, 0.199, 0.859, 0.027, -5.000, 0.171, 0.220, -0.814, -5.000, -0.203, 0.328, -0.303, -0.183, 0.494, 0.451, 0.396, -0.051, 0.293, 0.806, 0.035, -5.000, 0.189, 0.258, -0.515, -0.512, -0.279, 0.352, -0.269, -0.320, 0.243, 0.510, 0.210, -0.153, 0.434, 0.924, 0.422, 0.407, 0.253, 0.758, 0.073, -0.140, 0.317, 0.566, 0.033, 0.375, 0.420, 0.718, 0.650, 0.445, 0.028, 0.774, -0.230, 0.010, -0.144, 0.372, -0.207, -0.348, -0.297, 0.396, -0.089, 0.221, 0.366, 0.584, 0.556, 0.160, 0.443, 0.948, -0.024, -5.000, 0.240, 0.582, -0.556, -5.000, 0.131, 0.347, -0.038, 0.107, 0.870, 0.720, 0.343, -0.021, 0.944, 1.026, 0.375, -5.000, 0.588, 0.710, -0.106, -0.310, 0.116, 0.580, 0.339, 0.222, 0.551, 0.759, 0.415, 0.394, 0.557, 0.952, 0.368, 0.467, 0.481, 0.833, -0.106, -0.283, 0.438, 0.643, 0.322, 0.611, 0.571, 0.746, 0.484, 0.362, 0.649, 1.119, 0.117, 0.368, 0.287, 0.730, -0.135, 0.011, 0.258, 0.552, 0.220, 0.446, 0.591, 0.810, 0.535, 0.532, 0.148, 0.836, -0.141, -5.000, -0.098, 0.133, -0.650, -5.000, 0.061, 0.301, -0.195, -0.159, 0.395, 0.506, 0.261, 0.025, 0.743, 0.984, 0.359, -5.000, 0.358, 0.746, 0.037, -0.279, 0.396, 0.632, 0.091, 0.094, 0.470, 0.790, 0.447, 0.239, 0.206, 0.798, 0.115, 0.277, 0.356, 0.494, 0.013, -0.143, 0.079, 0.375, -0.171, 0.305, -0.136, 0.348, -0.143, -0.081, 0.179, 0.849, -0.347, -0.049, -0.113, 0.202, -0.290, -0.669, -0.036, 0.240, -0.190, 0.039, 0.127, 0.466, -0.186, -0.211, -0.145, 0.586, -0.399, -5.000, -0.274, 0.095, -1.232, -5.000, -0.657, 0.308, -0.429, -0.337, 0.294, 0.340, -0.150, -0.409, 0.230, 0.742, 0.136, -5.000, 0.073, 0.457, -0.252, -0.521, -0.224, 0.306, -0.229, -0.174, 0.311, 0.474, 0.198, -0.089, 0.014, 0.702, -0.119, -0.209, -0.319, 0.241, -0.564, -0.734, -0.317, 0.124, -0.357, -0.388, -0.488, 0.108, -0.290, -0.173, 0.085, 0.846, -0.346, 0.074, -0.400, -0.111, -0.418, -0.570, -0.208, 0.043, -0.488, -0.143, 0.174, 0.440, 0.026, 0.146, 0.038, 0.610, -0.115, -5.000, -0.024, 0.075, -0.479, -5.000, -0.105, 0.242, -0.179, -0.227, 0.600, 0.680, 0.566, 0.041, 0.187, 0.549, -0.101, -5.000, -0.132, 0.099, -0.401, -0.377, -0.700, 0.402, -0.164, -0.265, 0.533, 0.815, 0.410, 0.251, 0.190, 0.588, -0.197, 0.160, 0.023, 0.302, -0.123, -0.469, -0.125, 0.176, -0.311, -0.030, 0.239, 0.388, 0.185, 0.020, 0.297, 0.678, -0.075, 0.391, 0.378, 0.457, 0.192, 0.116, -0.084, 0.401, -0.004, 0.263, 0.678, 0.638, 0.194, 0.654, 0.887, 0.963, 0.322, -5.000, 0.289, 0.564, 0.091, -5.000, 0.411, 0.487, 0.166, 0.380, 1.106, 1.062, 0.935, 0.867, 0.872, 0.928, 0.372, -5.000, 0.543, 0.789, 0.453, 0.127, 0.205, 0.708, 0.352, 0.509, 0.886, 1.005, 0.783, 0.583, 0.642, 0.955, 0.472, 0.740, 0.539, 0.520, 0.388, 0.141, 0.468, 0.498, 0.415, 0.418, 0.560, 0.689, 0.616, 0.631, 0.745, 1.053, 0.321, 0.656, 0.638, 0.916, 0.733, 0.374, 0.704, 0.630, 0.375, 0.650, 0.848, 1.012, 0.577, 0.937, -0.017, 0.224, -0.302, -5.000, -0.394, 0.202, -0.573, -5.000, -0.282, 0.131, -0.423, -0.043, 0.369, 0.232, 0.172, -0.183, 0.258, 0.508, -0.237, -5.000, -0.070, 0.333, -0.306, -0.431, -0.221, 0.045, -0.392, -0.101, 0.246, 0.436, 0.170, 0.158, -0.087, 0.471, -0.457, -0.160, 0.101, 0.016, -0.432, -0.389, -0.280, -0.086, -0.577, -0.400, -0.282, -0.135, -0.713, -0.429, -0.155, 0.402, -0.585, -0.410, -0.543, -0.258, -0.930, -0.704, -0.329, -0.252, -0.632, -0.111, 0.149, -0.157, -0.185, 0.158, 0.181, 0.455, -0.287, -5.000, -0.060, 0.133, -0.637, -5.000, -0.299, 0.175, -0.316, 0.005, 0.308, 0.339, 0.267, -0.069, 0.581, 0.767, -0.057, -5.000, 0.107, 0.588, -0.121, -0.305, -0.089, 0.391, -0.067, -0.090, 0.442, 0.558, 0.248, 0.012, 0.365, 0.817, 0.125, 0.262, 0.220, 0.261, -0.442, -0.223, -0.180, 0.097, -0.152, 0.138, -0.286, 0.066, -0.271, 0.127, 0.128, 0.466, -0.305, -0.097, 0.163, -0.002, -0.339, -0.180, -0.112, -0.111, -0.208, 0.211, 0.065, -0.124, -0.143, 0.133, 0.028, 0.474, -0.368, -5.000, -0.518, -0.097, -0.708, -5.000, -0.454, -0.009, -0.671, -0.529, 0.383, 0.374, 0.207, -0.051, 0.333, 0.553, -0.169, -5.000, -0.317, -0.012, -0.594, -0.584, -0.534, 0.056, -0.559, -0.297, 0.201, 0.502, 0.183, -0.103, -0.015, 0.630, -0.005, 0.070, -0.138, 0.258, -0.115, -0.621, -0.159, 0.191, -0.339, -0.292, 0.125, 0.346, -0.119, -0.218, 0.015, 0.680, -0.340, -0.095, 0.182, 0.664, -0.106, -0.462, -0.023, 0.281, 0.041, 0.017, 0.395, 0.691, 0.140, 0.106, 0.349, 0.577, -0.259, -5.000, -0.184, 0.071, -0.617, -5.000, -0.297, 0.155, -0.614, -0.148, 0.795, 0.550, 0.367, 0.267, 0.600, 0.797, 0.209, -5.000, 0.323, 0.367, -0.423, -0.372, -0.308, 0.532, 0.080, -0.006, 0.658, 0.692, 0.384, 0.363, 0.413, 0.870, 0.406, 0.442, 0.272, 0.439, -0.080, -0.250, 0.312, 0.504, 0.025, 0.376, 0.400, 0.498, 0.149, 0.349, 0.412, 0.874, -0.191, 0.077, 0.330, 0.579, 0.108, -0.211, 0.135, 0.164, -0.121, 0.273, 0.524, 0.645, 0.227, 0.403, -0.177, 0.183, -0.492, -5.000, -0.806, -0.290, -0.550, -5.000, -0.454, -0.198, -0.807, -0.687, 0.245, 0.092, -0.118, -0.281, 0.039, 0.583, -0.117, -5.000, -0.209, 0.323, -0.458, -0.511, -0.402, 0.074, -0.711, -0.527, 0.252, 0.491, 0.019, -0.072, -0.281, 0.024, -0.401, -0.220, -0.497, -0.442, -0.510, -0.750, -0.501, -0.347, -0.770, -0.496, -0.464, -0.230, -0.457, -0.314, -0.095, 0.277, -0.728, -0.380, -0.354, -0.229, -0.675, -0.673, -0.515, -0.592, -0.989, -0.559, -0.037, -0.291, -0.679, -0.222, -0.571, 0.110, -0.691, -5.000, -0.757, -0.349, -1.011, -5.000, -0.720, -0.324, -0.994, -0.718, -0.218, -0.238, -0.416, -0.554, -0.179, 0.262, -0.489, -5.000, -0.535, -0.127, -0.640, -0.917, -0.545, -0.099, -0.619, -0.432, -0.123, 0.224, -0.341, -0.133, -0.460, 0.114, -0.454, -0.616, -0.822, -0.630, -1.102, -0.980, -0.592, -0.362, -0.823, -0.727, -0.578, -0.412, -0.658, -0.525, -0.803, -0.227, -0.852, -0.582, -0.822, -0.635, -1.076, -1.069, -0.736, -0.750, -1.165, -0.778, -0.428, -0.482, -0.707, -0.469, 0.091, 0.522, -0.345, -5.000, -0.227, 0.098, -0.783, -5.000, -0.412, 0.052, -0.487, -0.533, 0.271, 0.264, -0.060, -0.204, 0.211, 0.596, -0.071, -5.000, -0.063, 0.120, -0.851, -0.395, -0.279, 0.142, -0.446, -0.719, 0.330, 0.244, -0.051, -0.137, -0.079, 0.442, -0.382, 0.046, -0.243, 0.291, -0.366, -0.718, -0.258, -0.089, -0.343, -0.344, 0.025, 0.251, 0.057, -0.208, -0.301, 0.479, -0.372, -0.275, -0.154, 0.215, -0.218, -0.769, -0.269, 0.102, -0.447, -0.369, 0.335, 0.483, 0.070, 0.243, 0.168, 0.657, -0.349, -5.000, 0.132, 0.057, -0.622, -5.000, -0.220, 0.014, -0.578, -0.124, 0.505, 0.201, 0.120, -0.098, 0.667, 0.841, 0.218, -5.000, 0.161, 0.569, -0.150, -0.676, -0.225, 0.401, -0.245, 0.084, 0.560, 0.646, 0.281, 0.252, 0.148, 0.609, -0.200, 0.159, -0.164, 0.448, -0.031, -0.369, 0.050, 0.198, -0.017, -0.105, 0.286, 0.543, 0.400, 0.047, 0.245, 0.796, -0.121, 0.206, 0.172, 0.424, -0.015, -0.175, 0.140, 0.226, -0.207, -0.005, 0.460, 0.671, 0.310, 0.474, -0.444, -0.058, -0.416, -5.000, -0.764, -0.552, -0.626, -5.000, -0.397, -0.325, -0.728, -0.642, 0.056, 0.025, -0.108, -0.420, -0.045, 0.367, -0.384, -5.000, -0.096, 0.038, -0.753, -0.745, -0.499, -0.253, -0.357, -0.538, -0.102, 0.218, 0.032, -0.134, -0.155, 0.273, -0.356, -0.488, -0.539, 0.000, -0.602, -0.893, -0.273, -0.261, -0.556, -0.401, -0.231, 0.209, -0.607, -0.199, -0.250, 0.683, -0.442, -0.453, -0.280, -0.226, -0.736, -0.588, -0.149, -0.103, -0.430, -0.188, 0.258, 0.243, -0.223, 0.022, -0.056, 0.506, -0.388, -5.000, -0.526, -0.169, -1.010, -5.000, -0.783, -0.230, -0.630, -0.365, 0.017, 0.153, 0.201, -0.160, 0.424, 0.773, 0.205, -5.000, -0.086, 0.478, -0.242, -0.447, -0.134, 0.131, -0.243, -0.348, 0.380, 0.459, 0.238, 0.018, -0.053, 0.435, -0.401, -0.029, -0.444, 0.299, -0.282, -0.735, -0.536, -0.004, -0.528, -0.216, -0.260, 0.175, -0.015, -0.030, -0.261, 0.468, -0.473, -0.028, -0.312, -0.041, -0.681, -0.666, -0.522, -0.407, -0.518, -0.176, 0.114, 0.358, 0.191, 0.198, 0.251, 0.532, -0.465, -5.000, -0.144, 0.103, -0.575, -5.000, -0.236, 0.190, -0.528, -0.216, 0.250, 0.485, 0.273, -0.198, 0.421, 0.558, -0.150, -5.000, 0.045, 0.361, -0.550, -0.448, -0.274, 0.248, -0.236, 0.182, 0.374, 0.426, 0.090, -0.102, 0.058, 0.551, -0.352, -0.064, -0.103, 0.336, -0.356, -0.624, -0.199, -0.074, -0.172, -0.133, 0.027, 0.240, -0.003, -0.001, -0.083, 0.426, -0.477, -0.271, -0.433, 0.203, -0.761, -1.113, -0.501, 0.087, -0.572, -0.338, 0.282, 0.371, -0.055, 0.056, 0.273, 0.559, -0.381, -5.000, 0.061, -0.076, -0.413, -5.000, -0.160, 0.379, -0.233, -0.103, 0.678, 0.680, 0.590, 0.203, 0.603, 0.938, 0.309, -5.000, 0.264, 0.575, -0.081, -0.388, 0.274, 0.490, 0.104, 0.197, 0.542, 0.821, 0.537, 0.428, 0.300, 0.711, -0.101, 0.314, 0.231, 0.463, -0.160, -0.204, -0.002, 0.080, -0.148, 0.218, 0.145, 0.369, 0.021, 0.199, 0.175, 0.623, -0.238, -0.181, 0.048, 0.286, -0.320, -0.447, 0.094, -0.106, -0.195, 0.126, 0.177, 0.625, 0.144, 0.393, 0.119, 0.451, -0.183, -5.000, -0.389, -0.526, -0.484, -5.000, -0.261, -0.017, -0.501, -0.069, 0.327, 0.101, 0.157, 0.337, 0.464, 0.735, 0.002, -5.000, 0.380, 0.510, -0.156, -0.508, 0.062, 0.267, -0.273, 0.061, 0.403, 0.648, 0.243, 0.142, 0.069, 0.313, -0.324, -0.210, -0.324, 0.122, -0.568, -0.592, -0.335, -0.077, -0.528, -0.200, -0.440, -0.058, -0.331, -0.249, -0.216, 0.463, -0.613, -0.191, -0.893, -0.170, -0.392, -0.721, -0.480, -0.141, -0.674, -0.112, 0.094, -0.019, -0.324, 0.112, 0.043, 0.311, -0.198, -5.000, 0.002, -0.179, -0.886, -5.000, -0.238, 0.226, -0.227, 0.089, 0.249, 0.187, -0.125, -0.379, 0.387, 0.763, -0.009, -5.000, 0.263, 0.628, -0.060, -0.198, 0.264, 0.454, 0.197, 0.106, 0.434, 0.673, 0.435, -0.011, 0.060, 0.441, -0.430, -0.113, -0.225, 0.052, -0.374, -0.691, -0.318, -0.363, -0.486, -0.234, -0.509, -0.144, -0.575, -0.070, -0.186, 0.347, -0.651, -0.272, -0.280, -0.227, -0.791, -0.506, -0.249, -0.103, -0.400, -0.146, -0.092, -0.177, -0.156, 0.139, 0.177, 0.387, -0.246, -5.000, -0.335, 0.073, -0.915, -5.000, -0.230, 0.204, -0.480, -0.484, 0.453, 0.490, 0.133, 0.059, 0.242, 0.576, -0.231, -5.000, -0.039, -0.017, -0.533, -0.340, -0.080, 0.369, 0.050, -0.186, 0.517, 0.843, 0.421, 0.229, 0.354, 0.777, 0.040, 0.294, 0.111, 0.349, -0.002, -0.559, 0.150, 0.202, -0.303, -0.372, 0.205, 0.426, 0.264, 0.311, 0.051, 0.404, -0.340, 0.073, -0.187, 0.166, 0.080, -0.180, 0.289, 0.190, -0.053, 0.091, 0.596, 0.601, 0.435, 0.373, 0.772, 0.886, 0.377, -5.000, 0.370, 0.383, -0.127, -5.000, 0.471, 0.580, 0.323, 0.462, 1.057, 1.030, 0.917, 0.844, 0.988, 1.011, 0.493, -5.000, 0.696, 0.796, 0.228, 0.125, 0.399, 0.798, 0.337, 0.261, 0.861, 0.991, 0.687, 0.883, 0.646, 1.033, 0.283, 0.918, 0.682, 0.580, 0.346, -0.033, 0.607, 0.726, 0.507, 0.710, 0.672, 0.912, 0.626, 0.764, 0.735, 1.054, 0.162, 0.718, 0.584, 0.746, 0.534, 0.059, 0.582, 0.705, 0.285, 0.584, 0.837, 0.984, 0.658, 0.758, -0.416, 0.207, -0.800, -5.000, -0.404, -0.074, -0.577, -5.000, -0.347, -0.131, -0.559, -0.374, 0.068, -0.146, -0.120, -0.132, 0.027, 0.490, -0.230, -5.000, -0.322, 0.208, -0.639, -0.778, -0.144, -0.049, -0.390, -0.428, 0.223, 0.369, -0.014, 0.046, -0.259, 0.425, -0.328, -0.363, -0.073, -0.276, -0.492, -0.876, -0.285, -0.189, -0.478, -0.374, -0.545, -0.212, -0.400, -0.510, -0.484, -0.080, -0.760, -0.867, -1.065, -0.940, -0.832, -0.861, -0.429, -0.354, -0.549, -0.494, -0.301, -0.424, -0.737, -0.372, 0.067, 0.438, -0.336, -5.000, -0.504, -0.033, -0.718, -5.000, -0.451, 0.107, -0.241, -0.509, 0.188, 0.036, -0.268, -0.337, 0.398, 0.653, 0.162, -5.000, 0.030, 0.339, -0.351, -0.440, -0.076, 0.304, 0.037, -0.352, 0.147, 0.452, 0.288, 0.082, 0.285, 0.771, -0.210, -0.235, -0.167, 0.010, -0.414, -0.449, -0.246, 0.027, -0.567, -0.104, -0.824, -0.581, -0.469, -0.129, 0.072, 0.623, -0.448, -0.393, -0.316, -0.195, -0.455, -0.588, -0.152, -0.241, -0.394, -0.021, -0.035, 0.040, -0.178, 0.003, -0.161, 0.374, -0.326, -5.000, -0.571, -0.493, -1.017, -5.000, -0.282, -0.051, -0.243, -0.305, 0.347, 0.441, 0.041, -0.212, 0.329, 0.574, -0.232, -5.000, -0.405, -0.075, -0.829, -0.602, -0.293, 0.075, -0.409, -0.212, 0.455, 0.463, 0.294, 0.034, 0.112, 0.621, -0.176, -0.070, -0.038, 0.111, -0.299, -0.633, 0.037, 0.267, -0.244, 0.052, 0.284, 0.195, 0.114, -0.168, -0.138, 0.408, -0.311, -0.199, 0.209, 0.368, -0.340, -0.588, 0.053, 0.288, 0.092, 0.051, 0.436, 0.620, 0.389, 0.400, 0.131, 0.586, -0.328, -5.000, -0.204, 0.048, -0.754, -5.000, 0.101, 0.044, -0.445, -0.039, 0.870, 0.641, 0.514, 0.318, 0.682, 0.797, 0.102, -5.000, 0.330, 0.179, -0.317, -0.423, 0.067, 0.474, 0.010, 0.253, 0.758, 0.628, 0.480, 0.559, 0.314, 0.888, 0.323, 0.218, 0.184, 0.535, 0.015, -0.430, 0.247, 0.448, 0.200, 0.277, 0.174, 0.420, 0.308, 0.361, 0.297, 0.805, 0.018, -0.094, 0.411, 0.440, -0.029, -0.243, 0.276, 0.522, -0.021, 0.546, 0.453, 0.720, 0.314, 0.568, -0.140, -0.135, -0.636, -5.000, -0.954, -0.303, -0.771, -5.000, -0.339, -0.038, -0.923, -0.591, -0.107, -0.277, -0.233, -0.372, 0.317, 0.439, -0.396, -5.000, -0.086, -0.120, -0.773, -0.883, -0.211, 0.055, -0.420, -0.542, 0.324, 0.374, 0.138, 0.079, -0.253, 0.314, -0.598, -0.401, -0.484, -0.279, -0.713, -0.858, -0.554, -0.021, -0.835, -0.439, -0.440, -0.201, -0.871, -0.355, -0.174, 0.178, -0.885, -0.453, -0.266, -0.368, -0.781, -0.810, -0.431, -0.266, -0.848, -0.316, -0.345, -0.176, -0.374, -0.213, -0.369, -0.372, -0.657, -5.000, -1.025, -0.479, -1.050, -5.000, -0.630, -0.365, -1.276, -0.918, -0.005, -0.273, -1.020, -0.522, 0.034, 0.182, -0.310, -5.000, -0.736, -0.078, -0.637, -1.043, -0.276, -0.053, -0.555, -0.661, 0.158, 0.256, 0.200, 0.105, -0.304, 0.273, -0.534, -0.330, -0.680, -0.507, -0.961, -0.849, -0.718, -0.753, -1.088, -0.915, -0.668, -0.833, -0.618, -0.654, -0.373, -0.018, -0.602, -0.389, -0.534, -0.445, -0.827, -0.932, -0.749, -0.629, -1.066, -0.611, -0.470, -0.441, -0.557, -0.499, -0.006, 0.447, -0.590, -5.000, -0.186, -0.158, -1.006, -5.000, -0.582, -0.026, -0.386, -0.629, 0.078, 0.230, 0.121, -0.153, 0.183, 0.391, -0.201, -5.000, -0.499, 0.335, -0.821, -0.442, -0.343, 0.088, -0.071, -0.349, 0.448, 0.458, 0.196, -0.132, 0.132, 0.460, -0.276, -0.270, -0.113, 0.376, -0.364, -0.730, -0.289, 0.188, -0.111, -0.263, 0.146, 0.342, 0.038, -0.023, -0.165, 0.297, -0.534, -0.612, -0.090, 0.236, -0.403, -0.659, -0.527, 0.286, -0.267, 0.064, 0.367, 0.510, 0.178, 0.168, -0.019, 0.427, -0.338, -5.000, -0.207, -0.306, -0.509, -5.000, -0.178, 0.171, -0.788, -0.602, 0.597, 0.454, 0.280, 0.238, 0.704, 0.888, 0.270, -5.000, 0.344, 0.493, -0.516, -0.304, -0.102, 0.416, -0.100, -0.036, 0.668, 0.575, 0.503, 0.398, 0.232, 0.591, -0.094, 0.185, 0.111, 0.157, -0.069, -0.429, 0.193, 0.352, -0.311, 0.047, -0.051, 0.416, 0.293, 0.095, 0.097, 0.712, -0.138, -0.115, 0.045, 0.358, 0.023, -0.391, 0.328, 0.314, -0.111, -0.047, 0.374, 0.613, 0.263, 0.363, -0.461, -0.071, -0.673, -5.000, -0.589, -0.732, -1.001, -5.000, -0.425, -0.229, -0.899, -0.872, 0.106, 0.178, -0.188, -0.589, -0.111, 0.213, -0.425, -5.000, -0.333, -0.187, -0.675, -0.377, -0.191, -0.063, -0.631, -0.626, -0.057, 0.381, -0.134, -0.208, -0.109, 0.680, -0.625, -0.555, -0.231, 0.072, -0.624, -1.111, -0.497, -0.220, -0.715, -0.454, -0.275, -0.150, -0.379, -0.505, -0.016, 0.633, -0.459, -0.607, -0.537, 0.095, -0.145, -0.761, -0.244, -0.268, -0.506, -0.450, 0.173, 0.189, -0.430, -0.355, 0.139, 0.400, -0.274, -5.000, -0.494, -0.210, -0.995, -5.000, -0.345, 0.071, -0.497, -0.570, 0.189, 0.203, 0.030, -0.224, 0.683, 0.912, -0.056, -5.000, 0.190, 0.488, -0.057, -0.486, -0.047, 0.312, -0.226, -0.134, 0.497, 0.737, 0.623, 0.320, -0.314, 0.466, -0.166, 0.176, -0.342, 0.242, -0.424, -0.572, -0.204, 0.075, -0.370, -0.121, -0.110, 0.376, 0.044, -0.121, -0.078, 0.404, -0.503, -0.217, -0.516, 0.466, -0.148, -0.761, -0.299, -0.068, -0.691, -0.158, 0.067, 0.355, 0.097, -0.012, 0.397, 0.682, -0.019, -5.000, 0.143, 0.164, -0.422, -5.000, 0.055, 0.446, -0.200, 0.046, 0.576, 0.537, 0.327, 0.142, 0.678, 0.785, 0.024, -5.000, 0.346, 0.421, -0.455, -0.259, 0.096, 0.558, 0.278, -0.203, 0.637, 0.786, 0.434, 0.211, 0.392, 0.742, 0.063, 0.450, 0.219, 0.453, -0.206, -0.214, 0.207, 0.178, -0.243, 0.049, 0.245, 0.364, 0.194, 0.528, 0.076, 0.562, -0.055, -0.328, -0.189, 0.462, -0.486, -0.358, -0.123, 0.277, -0.121, 0.071, 0.441, 0.643, 0.139, 0.385, 0.454, 0.736, -0.052, -5.000, 0.235, 0.263, -0.381, -5.000, 0.271, 0.378, 0.051, 0.045, 0.859, 0.745, 0.584, 0.364, 0.774, 0.965, 0.329, -5.000, 0.564, 0.599, -0.043, -0.396, 0.374, 0.640, 0.475, 0.490, 0.835, 0.891, 0.601, 0.613, 0.535, 1.036, 0.225, 0.573, 0.542, 0.497, -0.106, -0.306, 0.558, 0.538, -0.053, 0.402, 0.429, 0.491, 0.351, 0.435, 0.534, 0.908, 0.052, 0.184, 0.257, 0.476, -0.160, -0.122, 0.256, 0.348, -0.050, 0.445, 0.669, 0.732, 0.488, 0.554, 0.390, 0.612, -0.261, -5.000, -0.434, -0.362, -0.375, -5.000, 0.078, 0.267, -0.515, -0.289, 0.448, 0.271, 0.077, 0.051, 0.602, 0.906, 0.034, -5.000, 0.402, 0.544, -0.046, -0.330, 0.088, 0.542, -0.099, 0.141, 0.487, 0.776, 0.407, 0.316, 0.062, 0.610, -0.180, -0.025, 0.058, 0.129, -0.160, -0.501, -0.293, 0.044, -0.670, -0.185, -0.159, -0.031, -0.503, -0.401, -0.091, 0.540, -0.383, -0.286, -0.316, 0.006, -0.158, -0.815, -0.554, -0.112, -0.767, -0.217, 0.011, 0.037, -0.205, 0.101, 0.151, 0.510, -0.275, -5.000, -0.376, -0.146, -0.910, -5.000, -0.143, 0.374, -0.177, 0.140, 0.207, 0.403, 0.251, -0.297, 0.560, 0.809, 0.359, -5.000, 0.554, 0.711, -0.012, -0.278, 0.014, 0.646, 0.474, 0.333, 0.633, 0.796, 0.495, 0.350, 0.180, 0.729, -0.061, 0.025, 0.175, 0.208, -0.231, -0.388, -0.200, 0.027, -0.352, -0.293, -0.155, 0.018, -0.264, 0.143, 0.118, 0.549, -0.225, -0.000, -0.109, -0.033, -0.555, -0.542, -0.223, -0.155, -0.498, -0.115, -0.091, 0.226, -0.041, 0.103 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_12(struct _training *tptr) {
  struct _training tinf = {
    0.554, 11, 4.350, { 0.518, 0.192, 2.289 }, { 0.866, -2.140, -2.719 }, 1, 
    { -0.745, -0.780, -0.880, -0.373, -0.783, 0.058, -0.631, -1.567, 0.051, -0.563, -1.047, -4.000, 0.102, 0.258, 0.619, 0.312, 1.456, -0.170, 1.488, 0.979, 0.568, 1.562, 2.148, 2.056, 2.075, 0.217, 2.403, 2.056 }, 
    {{ -0.169, -0.052, 0.001, 0.197},{ 0.020, -0.216, 0.039, 0.158},{ 0.249, -0.066, -0.220, 0.041},{ 0.280, -0.176, -0.220, 0.115},{ 0.269, -0.127, -0.107, -0.035},{ 0.179, -0.138, -0.150, 0.128},{ 0.239, -0.237, -0.144, 0.147},{ 0.252, -0.129, -0.150, 0.035},{ 0.043, -0.104, -0.050, 0.130},{ 0.210, -0.235, -0.106, 0.139},{ 0.233, -0.121, -0.094, -0.009},{ 0.216, -0.229, -0.077, 0.100},{ 0.315, -0.224, -0.275, 0.163},{ 0.267, -0.127, -0.222, 0.084},{ 0.244, -0.248, -0.229, 0.222},{ 0.229, -0.197, -0.309, 0.257},{ 0.156, -0.132, -0.237, 0.221},{ 0.134, -0.150, -0.162, 0.195},{ 0.231, -0.284, -0.166, 0.212},{ 0.172, -0.092, -0.144, 0.084},{ 0.264, -0.203, -0.156, 0.100},{ 0.338, -0.323, -0.193, 0.147},{ 0.296, -0.109, -0.129, -0.069},{ 0.195, -0.130, -0.129, 0.083},{ 0.313, -0.174, -0.189, 0.043},{ 0.210, -0.043, -0.111, -0.053},{ 0.150, -0.136, -0.125, 0.132},{ 0.254, -0.160, -0.199, 0.111},{ 0.249, -0.015, -0.237, -0.003},{ 0.138, -0.134, -0.127, 0.145},{ 0.259, -0.176, -0.115, 0.039},{ 0.152, -0.061, -0.119, 0.047} }, 
    {{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}} }, 
    0.000, { 0.088, 0.200, -0.281, -5.000, 0.022, 0.388, -0.173, -5.000, 0.312, 0.551, -0.032, -0.065, 0.193, 0.328, 0.006, 0.081, 0.687, 0.586, 0.256, -5.000, -0.257, 0.266, -0.269, -0.219, 0.210, 0.417, -0.051, -0.280, 0.586, 0.659, 0.548, 0.198, 0.504, 0.162, -0.047, 0.513, 0.170, 0.006, -0.250, -0.345, 0.470, 0.595, -0.226, -0.250, 0.706, 0.645, 0.476, 0.275, 0.290, 0.200, 0.030, 0.188, 0.001, 0.056, -0.338, -0.402, 0.152, 0.542, 0.071, 0.084, 0.117, 0.097, 0.106, 0.163, 0.096, -0.251, -1.291, -5.000, -0.593, -0.357, -1.323, -5.000, 0.044, 0.145, -0.563, -0.341, 0.114, -0.278, 0.442, 0.195, 0.655, 0.548, 0.115, -5.000, -0.148, 0.074, -0.122, -0.048, -0.405, -0.316, -0.209, -0.610, 0.433, 0.274, 0.144, -0.215, 0.578, 0.349, -0.186, 0.719, 0.207, 0.104, 0.072, -0.310, 0.621, 0.445, -0.332, -0.360, 0.725, 0.618, 0.783, 0.351, 0.423, 0.020, -0.148, 0.459, 0.242, -0.405, -0.223, -0.517, 0.087, -0.006, -0.235, -0.167, 0.281, 0.004, 0.624, 0.524, -0.036, -0.368, -0.842, -5.000, -0.685, -0.820, -1.437, -5.000, -0.149, -0.447, -0.842, -0.772, -0.343, -0.813, -1.046, -0.664, -0.002, -0.371, -0.294, -5.000, -0.733, -0.623, -1.319, -0.811, -0.378, -0.738, -0.581, -1.061, -0.082, -0.321, -0.712, -0.582, -0.235, -0.855, -1.335, -0.436, -0.539, -1.176, -1.621, -1.158, -0.335, -0.115, -0.957, -1.031, -0.373, -0.380, -0.587, -0.444, -0.357, -0.897, -0.948, -0.462, -0.622, -1.084, -1.424, -1.069, -0.750, -0.898, -1.390, -0.971, -0.275, -1.022, -1.052, -0.336, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.630, -0.933, -1.357, -5.000, -0.989, -0.864, -1.596, -5.000, -0.701, -0.632, -0.875, -1.039, -0.360, -0.348, -0.830, -0.413, -0.148, -0.267, -0.703, -5.000, -0.914, -0.603, -0.858, -1.073, -0.986, -1.085, -1.487, -1.291, -0.121, -0.583, -0.594, -0.444, -0.238, -0.369, -0.973, -0.385, -0.631, -0.483, -0.981, -0.864, -0.312, -0.152, -0.963, -0.815, 0.109, 0.431, 0.211, -0.310, -0.407, -0.710, -1.418, -0.507, -0.859, -0.934, -1.653, -1.127, -0.229, 0.142, -0.138, -0.263, -0.185, -0.125, 0.083, -0.105, 0.216, -0.090, -1.778, -5.000, -1.207, -0.722, -1.828, -5.000, -0.280, -0.337, -1.033, -0.751, 0.193, -0.166, 0.063, 0.003, 0.411, 0.395, -0.041, -5.000, -0.595, -0.138, -0.497, -0.331, -0.650, -0.883, -0.963, -1.079, 0.310, -0.011, -0.218, -0.517, 0.502, 0.627, -0.483, 0.399, -0.059, 0.211, -0.385, -0.147, 0.176, 0.067, -0.807, -0.520, 0.657, 0.550, 0.708, 0.295, 0.245, -0.117, -0.427, 0.127, -0.056, -0.404, -0.426, -0.444, -0.487, -0.557, -1.062, -0.810, 0.313, 0.044, 0.410, 0.397, -0.151, -0.434, -1.791, -5.000, -1.455, -1.236, -2.056, -5.000, -0.553, -0.515, -1.728, -1.154, -0.742, -1.457, -2.230, -0.709, -0.098, -0.420, -0.853, -5.000, -1.217, -1.384, -1.549, -1.541, -1.250, -1.174, -1.622, -1.540, -0.358, -0.866, -1.027, -1.096, -0.691, -0.959, -1.609, -0.429, -1.276, -1.518, -2.078, -1.842, -0.823, -0.628, -1.680, -1.377, -0.113, -0.720, -0.612, -0.523, -0.795, -1.485, -1.906, -1.152, -1.525, -1.985, -2.126, -1.802, -1.836, -1.707, -2.344, -1.952, -0.512, -1.389, -1.193, -0.820, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.011, -0.221, -0.813, -5.000, -0.615, -0.159, -1.393, -5.000, -0.034, 0.022, -0.402, -0.716, -0.034, 0.094, 0.055, -0.107, 0.472, 0.480, 0.198, -5.000, -0.354, 0.279, -0.296, -0.408, 0.207, 0.250, -0.027, -0.431, 0.365, 0.417, 0.261, 0.008, 0.321, 0.169, -0.316, 0.476, -0.243, -0.173, -0.978, -0.423, 0.373, 0.294, -0.337, -0.289, 0.344, 0.233, 0.134, 0.163, 0.037, 0.026, -0.229, 0.217, -0.603, -0.568, -1.231, -0.744, -0.313, 0.015, -1.069, -0.581, -0.141, 0.169, 0.131, 0.173, 0.469, 0.273, -1.296, -5.000, -0.951, -0.354, -1.857, -5.000, -0.030, 0.122, -1.192, -0.936, 0.509, 0.468, 0.562, -0.123, 0.886, 0.869, 0.390, -5.000, -0.243, 0.432, -0.080, -0.043, 0.085, 0.129, -0.300, -0.367, 0.531, 0.507, 0.513, -0.359, 0.586, 0.603, -0.491, 0.668, -0.027, 0.236, -0.264, -0.367, 0.433, 0.423, -0.679, -0.474, 0.792, 0.713, 0.771, 0.431, 0.665, 0.374, -0.057, 0.716, 0.238, -0.016, -0.149, -0.240, 0.064, 0.180, -0.570, -0.401, 0.646, 0.321, 0.945, 0.607, 0.079, -0.416, -1.010, -5.000, -1.235, -1.157, -2.387, -5.000, -0.304, -0.493, -1.181, -1.086, -0.529, -0.527, -1.089, -0.450, 0.083, -0.294, -0.596, -5.000, -1.166, -0.729, -1.443, -1.530, -0.106, -0.582, -0.900, -1.291, -0.060, -0.100, -0.374, -0.585, 0.098, -0.239, -0.831, -0.153, -0.525, -0.747, -1.298, -0.944, 0.179, -0.188, -0.670, -0.517, 0.193, -0.102, -0.201, -0.196, -0.065, -0.534, -0.769, -0.206, -0.758, -1.145, -1.406, -1.132, -0.283, -0.586, -1.318, -0.876, 0.096, -0.439, -0.663, -0.355, -0.107, -0.117, -0.819, -5.000, -1.040, -1.177, -1.799, -5.000, -0.518, -0.364, -1.068, -0.925, -0.363, -0.317, -0.488, -0.456, 0.146, 0.275, -0.260, -5.000, -0.872, -0.673, -1.376, -1.118, -0.383, -0.599, -0.725, -1.018, -0.149, -0.263, -0.233, -0.520, -0.045, 0.035, -0.693, 0.186, -0.842, -0.250, -0.817, -0.920, 0.126, 0.182, -0.277, -0.428, 0.174, 0.541, 0.713, 0.265, -0.055, -0.192, -0.746, -0.134, -0.661, -0.470, -1.060, -1.042, -1.055, -0.337, -1.008, -0.956, -0.308, -0.311, -0.162, -0.063, -0.175, -0.111, -0.536, -5.000, -0.520, -0.183, -0.647, -5.000, -0.226, 0.065, -0.283, -0.526, -0.378, -0.385, -0.123, -0.091, 0.259, 0.200, -0.066, -5.000, -0.361, -0.059, -0.212, -0.474, 0.087, 0.110, -0.274, -0.405, 0.084, 0.201, 0.012, -0.049, 0.012, -0.192, -0.675, 0.038, -0.361, -0.498, -0.817, -0.392, 0.109, -0.133, -0.722, -0.353, 0.126, -0.094, -0.131, -0.089, -0.097, -0.207, -0.474, -0.098, -0.328, -0.530, -0.711, -0.564, -0.588, 0.007, -0.633, -0.649, -0.021, -0.454, -0.129, -0.088, -0.103, -0.626, -0.994, -5.000, -0.884, -0.507, -1.444, -5.000, -0.448, -0.078, -0.712, -0.495, -0.242, -0.377, 0.246, 0.165, 0.467, 0.202, -0.319, -5.000, -0.246, 0.090, -0.593, -0.407, 0.120, -0.228, -0.499, -0.238, 0.189, 0.236, 0.054, -0.100, 0.322, -0.305, -0.720, 0.103, -0.343, -0.146, -1.178, -0.882, 0.073, -0.167, -0.942, -0.639, 0.243, -0.054, -0.231, -0.116, 0.266, -0.258, -0.389, 0.396, -0.146, -0.351, -0.493, -0.119, -0.448, -0.326, -0.826, -0.325, 0.109, -0.400, 0.049, 0.149, -0.036, -0.354, -0.749, -5.000, -0.685, -0.603, -1.681, -5.000, -0.388, 0.038, -0.496, -0.814, -0.295, -0.392, -1.790, -0.564, -0.290, 0.081, -0.783, -5.000, -0.708, -0.461, -0.872, -0.887, -0.100, -0.176, -0.465, -0.459, 0.020, 0.212, -0.085, -0.242, -0.149, -0.505, -1.430, -0.425, -0.561, -1.044, -1.780, -1.074, -0.235, 0.122, -0.550, -0.371, 0.295, -0.169, -0.189, -0.143, -0.012, -0.477, -0.590, -0.415, -0.648, -1.097, -1.533, -1.110, -0.616, -0.631, -1.294, -1.000, -0.052, -0.946, -0.651, -0.051, 0.055, 0.005, -0.231, -5.000, -0.438, -0.465, -1.007, -5.000, -0.236, 0.016, -0.482, -0.235, -0.182, -0.145, -0.397, -0.302, 0.006, 0.147, -0.039, -5.000, -0.483, 0.008, -0.509, -0.426, -0.148, 0.107, -0.379, -0.246, 0.242, 0.271, 0.117, -0.083, -0.190, 0.301, -0.501, 0.099, -0.133, -0.062, -0.674, -0.827, 0.086, -0.008, -0.439, -0.138, -0.140, 0.173, 0.419, 0.070, -0.073, -0.022, -0.291, -0.028, -0.481, -0.457, -0.812, -0.567, -0.550, -0.406, -0.875, -0.615, -0.097, -0.377, -0.333, -0.041, 0.221, 0.628, 0.011, -5.000, 0.280, 0.966, 0.189, -5.000, 0.381, 0.726, 0.389, -0.026, 0.085, 0.612, 0.464, 0.468, 1.035, 1.007, 0.898, -5.000, -0.004, 0.700, 0.571, 0.282, 0.355, 0.658, 0.219, -0.383, 0.746, 0.892, 0.969, 0.173, 1.112, 1.144, 0.639, 1.192, 0.818, 0.997, 0.493, 0.408, 1.147, 1.232, 0.560, 0.761, 1.298, 1.181, 0.776, 0.896, 0.729, 0.852, 0.558, 0.784, 0.475, 0.774, 0.266, 0.335, 0.412, 1.117, 0.319, 0.751, 0.481, 0.483, 0.518, 0.391, 0.610, 0.384, -0.213, -5.000, 0.129, 0.201, -0.727, -5.000, 0.337, 0.765, -0.063, 0.081, 0.159, 0.028, 0.803, 0.356, 1.078, 0.966, 0.841, -5.000, 0.298, 0.748, 0.736, 0.541, 0.075, 0.252, 0.330, -0.200, 0.892, 0.758, 0.725, -0.126, 0.902, 0.958, 0.583, 1.021, 0.510, 0.575, 0.770, 0.098, 0.811, 0.846, 0.158, 0.268, 0.997, 0.847, 0.900, 0.632, 0.646, 0.659, 0.482, 0.752, 0.467, 0.389, 0.662, 0.225, 0.491, 0.780, 0.417, 0.293, 0.603, 0.478, 0.978, 0.693, 0.702, 0.802, -0.165, -5.000, -0.112, 0.487, -0.178, -5.000, 0.477, 0.763, -0.030, 0.220, 0.023, -0.010, 0.020, 0.142, 0.792, 0.634, 0.413, -5.000, -0.012, 0.546, 0.145, 0.141, 0.397, 0.564, 0.131, -0.098, 0.641, 0.721, 0.406, -0.019, 0.841, 0.431, -0.013, 0.887, 0.154, 0.001, -0.389, -0.287, 0.784, 0.906, 0.187, 0.178, 0.782, 0.697, 0.413, 0.453, 0.398, -0.018, -0.384, 0.307, -0.039, -0.491, -0.461, -0.411, 0.211, 0.146, -0.641, -0.460, 0.371, -0.028, -0.188, 0.249, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.375, -0.772, -1.051, -5.000, -0.993, -0.519, -1.325, -5.000, -0.695, -0.675, -0.790, -0.873, -0.380, -0.543, -0.406, -0.368, -0.222, -0.354, -0.329, -5.000, -0.849, -0.280, -0.449, -0.705, -0.870, -0.794, -1.126, -1.274, 0.061, -0.201, -0.473, -0.511, 0.079, 0.124, -0.585, -0.139, -0.509, 0.020, -0.581, -0.589, 0.043, 0.233, -0.736, -0.590, 0.265, 0.601, 0.455, -0.298, -0.449, -0.368, -1.380, -0.878, -1.006, -0.821, -1.250, -1.214, 0.306, 0.305, -0.690, -0.138, 0.044, 0.103, 0.136, -0.020, 0.775, 0.621, -1.385, -5.000, -0.503, -0.098, -1.402, -5.000, -0.127, 0.255, -0.651, -0.386, 0.205, 0.156, -0.089, 0.167, 0.862, 0.910, 0.521, -5.000, -0.303, 0.417, 0.296, 0.243, -0.361, -0.380, -0.381, -0.520, 0.685, 0.319, 0.184, -0.294, 0.779, 1.052, 0.073, 0.800, 0.231, 0.877, 0.346, 0.329, 0.591, 0.691, -0.079, -0.029, 0.885, 0.846, 1.155, 0.663, 0.339, 0.270, -0.107, 0.651, 0.007, 0.257, -0.028, -0.052, -0.241, -0.130, -0.793, -0.582, 0.595, 0.441, 0.901, 0.677, 0.558, 0.509, -0.778, -5.000, -0.794, -0.172, -1.103, -5.000, -0.111, 0.377, -0.579, -0.527, -0.076, -0.579, -0.750, -0.306, 0.874, 0.633, 0.351, -5.000, -0.500, -0.093, -0.238, -0.270, -0.457, -0.018, -0.330, -0.507, 0.531, 0.214, 0.036, -0.351, 0.356, 0.324, -0.406, 0.601, -0.317, -0.335, -0.769, -0.814, 0.173, 0.390, -0.538, -0.434, 0.593, 0.398, 0.369, 0.294, -0.061, -0.380, -1.038, -0.196, -1.002, -1.020, -1.375, -1.178, -1.482, -1.296, -2.040, -1.793, 0.006, -0.382, -0.187, -0.022, 0.206, 0.148, -0.490, -5.000, -0.760, -0.491, -1.135, -5.000, -0.754, -0.160, -0.803, -0.600, -0.556, -0.502, -1.496, -0.524, 0.406, 0.276, -0.010, -5.000, -1.152, -0.489, -0.810, -0.579, -0.582, -0.537, -0.907, -0.644, 0.021, -0.409, -0.684, -0.235, 0.043, 0.509, -0.165, 0.431, -0.283, 0.215, -0.550, -0.770, 0.064, 0.378, -0.399, -0.313, 0.235, 0.432, 0.581, 0.104, -0.362, -0.392, -1.178, -0.500, -0.747, -0.737, -1.302, -1.556, -0.897, -0.974, -1.731, -1.409, -0.578, -1.148, -1.137, -0.412, 0.073, -0.078, -0.892, -5.000, -0.600, -0.094, -1.277, -5.000, 0.097, 0.317, -0.021, -0.577, 0.058, 0.320, 0.101, 0.046, 0.792, 0.852, 0.519, -5.000, -0.334, 0.599, 0.255, -0.297, 0.511, 0.540, 0.260, -0.248, 0.397, 0.760, 0.783, -0.018, 0.947, 0.784, 0.483, 1.105, 0.008, 0.500, -0.405, 0.023, 0.704, 0.686, 0.078, -0.036, 0.832, 0.813, 0.493, 0.649, 0.515, 0.528, 0.089, 0.736, -0.541, -0.066, -1.034, -0.668, -0.132, 0.360, -0.815, -0.611, 0.213, 0.532, 0.538, 0.566, 0.687, 0.608, -1.094, -5.000, -0.901, 0.084, -1.469, -5.000, 0.061, 0.304, -1.056, -0.758, 0.419, 0.326, -0.122, -0.337, 1.006, 1.080, 0.661, -5.000, -0.165, 0.730, 0.475, 0.098, 0.291, 0.485, -0.165, -0.319, 0.556, 0.637, 0.649, -0.357, 0.819, 1.103, 0.197, 0.953, 0.057, 0.384, 0.171, -0.384, 0.626, 0.651, -0.523, -0.631, 0.847, 0.776, 0.729, 0.366, 0.931, 0.754, 0.552, 0.876, 0.397, 0.512, 0.133, 0.248, 0.174, 0.456, -0.324, -0.271, 0.758, 0.632, 0.966, 0.782, 0.314, 0.054, -0.593, -5.000, -0.911, -0.483, -1.236, -5.000, -0.053, -0.279, -1.057, -1.054, -0.479, -0.279, -0.608, -0.507, 0.582, 0.325, 0.084, -5.000, -0.895, 0.017, -0.451, -0.740, 0.265, -0.013, -0.338, -0.655, 0.288, 0.449, 0.235, -0.400, 0.610, 0.501, -0.009, 0.503, -0.158, 0.019, -0.516, -0.038, 0.535, 0.436, -0.356, -0.229, 0.461, 0.445, 0.353, 0.360, 0.211, -0.163, -0.265, 0.136, -0.231, -0.309, -0.728, -0.147, 0.078, 0.084, -0.944, -0.744, 0.352, 0.061, 0.045, -0.055, 0.076, 0.119, -0.473, -5.000, -1.058, -0.579, -1.388, -5.000, -0.561, -0.317, -0.925, -0.990, -0.632, -0.197, -0.408, -0.626, 0.301, 0.567, 0.248, -5.000, -0.874, -0.139, -0.572, -0.657, -0.123, -0.357, -0.543, -0.781, -0.001, -0.365, -0.234, -0.541, 0.208, 0.577, -0.081, 0.711, -0.591, 0.253, -0.627, -0.763, 0.252, 0.420, -0.210, -0.483, 0.442, 0.806, 1.141, 0.445, 0.239, 0.210, -0.363, 0.165, -0.541, 0.081, -0.760, -0.554, -0.593, 0.013, -0.855, -0.998, -0.099, -0.008, 0.278, 0.064, -0.053, -0.045, -0.461, -5.000, -0.202, 0.106, -0.475, -5.000, -0.158, 0.180, -0.248, -0.611, -0.186, 0.086, 0.081, -0.205, 0.893, 0.933, 0.735, -5.000, -0.074, 0.707, 0.551, -0.124, 0.675, 0.815, 0.197, -0.002, 0.615, 0.851, 0.804, 0.217, 0.744, 0.714, 0.326, 0.900, 0.004, 0.231, -0.221, 0.141, 0.253, 0.496, -0.450, -0.236, 0.827, 0.418, 0.373, 0.637, 0.524, 0.539, 0.295, 0.640, 0.073, 0.086, -0.190, -0.193, -0.427, 0.290, -0.983, -0.853, 0.183, -0.146, 0.060, 0.347, 0.389, 0.476, -0.724, -5.000, -0.615, 0.075, -0.948, -5.000, 0.123, 0.383, -0.233, -0.445, 0.001, 0.012, 0.136, 0.023, 0.913, 1.036, 0.739, -5.000, -0.108, 0.754, 0.620, -0.001, 0.676, 0.736, 0.431, 0.165, 0.520, 0.770, 0.788, -0.345, 0.841, 1.008, 0.332, 0.983, -0.038, 0.584, 0.173, 0.062, 0.648, 0.767, -0.546, -0.316, 0.773, 0.758, 0.613, 0.414, 0.948, 0.974, 0.787, 1.158, 0.526, 0.415, 0.374, 0.453, 0.096, 0.474, -0.362, -0.297, 0.591, 0.482, 0.588, 0.724, 1.011, 0.860, 0.055, -5.000, -0.061, 0.303, -0.565, -5.000, 0.367, 0.547, -0.112, -0.147, -0.147, 0.109, -0.195, -0.024, 0.806, 0.250, 0.543, -5.000, 0.076, 0.793, 0.375, 0.144, 0.931, 0.939, 0.437, 0.346, 0.861, 1.099, 0.810, 0.308, 1.065, 0.959, 0.340, 1.111, 0.349, 0.130, -0.271, 0.002, 0.850, 1.040, 0.070, 0.086, 0.871, 0.438, 0.259, 0.616, 0.610, 0.355, 0.059, 0.615, 0.268, -0.097, -0.155, -0.001, -0.094, 0.152, -0.697, -0.488, 0.409, -0.234, -0.352, 0.404, 0.300, 0.172, -0.229, -5.000, -0.579, -0.201, -0.791, -5.000, -0.383, -0.093, -0.421, -0.608, -0.361, -0.243, -0.279, -0.222, 0.233, 0.372, 0.434, -5.000, -0.555, 0.080, 0.028, -0.547, 0.041, -0.002, -0.249, -0.373, 0.019, 0.130, 0.404, -0.134, -0.368, -0.078, -0.403, -0.213, -0.758, -0.475, -0.845, -0.809, -0.583, -0.420, -0.732, -0.757, -0.395, -0.428, -0.132, -0.545, -0.073, -0.169, -0.365, -0.180, -0.515, -0.278, -0.735, -0.622, -0.890, -0.729, -0.938, -1.080, -0.182, -0.514, -0.350, -0.137, 0.109, 0.159, -0.244, -5.000, -0.021, 0.674, -0.225, -5.000, -0.081, 0.473, 0.001, -0.270, 0.101, 0.472, 0.271, 0.364, 0.861, 0.830, 0.684, -5.000, -0.096, 0.508, 0.265, 0.159, 0.401, 0.707, 0.297, -0.054, 0.510, 0.917, 0.933, 0.243, 1.056, 0.900, 0.447, 1.100, 0.372, 0.789, -0.272, -0.016, 1.167, 1.201, 0.316, 0.615, 0.987, 0.991, 0.748, 0.856, 0.464, 0.530, 0.307, 0.700, 0.002, 0.428, -0.289, -0.310, 0.544, 0.647, 0.031, -0.125, 0.243, 0.307, 0.313, 0.277, 0.134, -0.264, -1.089, -5.000, -0.369, -0.059, -1.105, -5.000, 0.092, 0.387, -0.600, -0.083, -0.252, -0.467, 0.617, 0.066, 1.138, 0.828, 0.658, -5.000, 0.173, 0.677, 0.341, 0.451, 0.161, 0.535, 0.250, 0.139, 0.951, 0.993, 0.754, 0.119, 0.825, 0.451, 0.015, 1.021, 0.448, 0.456, 0.139, -0.006, 0.833, 0.784, 0.088, 0.109, 0.978, 0.770, 0.796, 0.857, 0.560, 0.169, 0.456, 0.807, 0.114, -0.229, -0.163, -0.143, 0.083, 0.057, -0.209, -0.056, 0.171, -0.091, 0.403, 0.556, 0.347, 0.074, -0.900, -5.000, -0.706, -0.551, -1.266, -5.000, -0.049, -0.027, -0.620, -0.626, -0.436, -0.567, -1.247, -0.721, 0.406, 0.222, -0.277, -5.000, -0.494, -0.197, -0.573, -0.415, 0.248, 0.006, 0.014, -0.353, 0.455, 0.153, -0.123, -0.321, 0.268, -0.232, -0.691, 0.341, -0.126, -0.236, -0.835, -0.357, 0.569, 0.673, -0.168, -0.159, 0.425, 0.334, 0.229, 0.204, -0.138, -0.694, -0.729, -0.068, -0.470, -0.852, -1.191, -0.840, -0.166, -0.223, -0.853, -0.877, -0.185, -0.676, -0.675, -0.195, 0.343, 0.403, -0.459, -5.000, -0.333, 0.335, -0.490, -5.000, -0.243, 0.214, -0.286, -0.185, -0.120, -0.156, -0.638, -0.313, 1.018, 1.070, 0.772, -5.000, -0.101, 0.849, 0.547, 0.180, 0.647, 0.623, 0.643, 0.429, 0.619, 0.479, 0.836, 0.023, 1.333, 1.334, 0.787, 1.180, 0.177, 1.069, 0.652, 0.426, 1.535, 1.587, 0.864, 0.859, 1.350, 1.518, 1.218, 1.201, 0.461, 0.854, 0.458, 0.837, 0.873, 0.260, 0.003, 0.214, 0.080, 0.622, 0.017, -0.478, 0.001, -0.062, -0.137, 0.109, -0.274, -0.441, -0.707, -5.000, -0.760, -0.360, -1.498, -5.000, -0.547, -0.093, -0.361, -0.438, -0.026, -0.005, -0.541, -0.045, 0.328, 0.437, 0.200, -5.000, -0.741, 0.062, -0.385, -0.458, -0.107, -0.151, -0.553, -0.761, 0.603, 0.242, 0.281, -0.228, 0.419, 0.418, -0.223, 0.441, -0.334, -0.186, -1.060, -0.674, 0.113, 0.065, -0.770, -0.426, 0.418, 0.449, 0.264, 0.096, 0.142, -0.065, -0.705, -0.042, -0.219, -0.484, -1.039, -0.741, 0.187, 0.232, -0.737, -0.494, -0.031, -0.119, -0.431, 0.136, -0.059, -0.345, -1.703, -5.000, -1.065, -0.780, -1.963, -5.000, -0.297, -0.055, -0.901, -0.231, -0.099, -0.486, 0.155, 0.711, 0.486, -0.001, -0.177, -5.000, -0.490, -0.144, -0.439, -0.024, -0.502, -0.444, -0.410, -0.353, 0.759, 0.265, 0.011, -0.160, 0.708, 0.511, -0.203, 0.877, 0.105, 0.388, -0.350, -0.184, 0.639, 0.503, -0.234, -0.058, 0.779, 0.625, 0.751, 0.656, 0.380, -0.174, -0.131, 0.660, -0.209, -0.227, -0.449, -0.255, -0.365, -0.423, -0.772, -0.620, 0.245, -0.142, 0.332, 0.577, 0.031, -0.346, -0.845, -5.000, -0.802, -0.915, -1.591, -5.000, -0.229, 0.270, -0.558, -0.787, -0.305, -1.044, -1.257, -0.353, 0.219, -0.155, -0.199, -5.000, -0.820, -0.573, -0.471, -0.582, -0.321, -0.071, -0.298, -0.685, 0.553, 0.132, -0.247, -0.363, -0.060, -0.353, -0.961, 0.198, -0.776, -1.017, -1.328, -1.203, -0.088, 0.274, -0.658, -0.539, 0.206, -0.020, 0.373, -0.181, -0.376, -1.210, -1.379, -0.429, -1.530, -1.562, -1.817, -1.283, -1.008, -1.232, -1.808, -1.388, -0.327, -1.161, -0.811, -0.586, -0.200, -0.322, -0.960, -5.000, -0.893, -0.583, -1.307, -5.000, -0.873, -0.581, -1.061, -0.828, -0.712, -0.861, -1.349, -1.044, 0.314, 0.086, -0.183, -5.000, -1.025, -0.354, -0.520, -0.825, -1.011, -0.690, -0.821, -0.702, -0.059, -0.591, -0.995, -0.415, -0.011, 0.068, -0.199, 0.141, -0.635, -0.521, -0.820, -0.582, -0.150, 0.213, -0.627, -0.489, 0.157, 0.348, 0.195, -0.031, -0.332, -0.639, -0.648, -0.474, -0.737, -0.890, -1.134, -0.586, -1.146, -1.244, -1.861, -1.184, -0.402, -0.930, -1.339, -0.827, 0.101, -0.035, -0.633, -5.000, -0.366, 0.328, -0.816, -5.000, 0.181, 0.437, 0.139, -0.321, 0.209, 0.408, 0.297, 0.067, 0.756, 0.854, 0.639, -5.000, 0.041, 0.712, 0.457, -0.197, 0.482, 0.612, 0.368, 0.032, 0.853, 0.950, 0.943, 0.261, 1.102, 0.779, 0.536, 1.100, 0.018, 0.680, -0.322, 0.064, 0.832, 0.705, 0.072, 0.166, 0.897, 0.956, 0.859, 0.753, 0.486, 0.453, 0.180, 0.719, -0.210, -0.130, -0.833, -0.346, 0.075, 0.288, -0.645, -0.609, -0.004, -0.030, 0.240, 0.334, 0.577, 0.468, -1.132, -5.000, -0.531, 0.402, -1.134, -5.000, 0.308, 0.520, -0.619, -0.336, 0.436, 0.274, 0.938, 0.340, 0.983, 0.951, 0.754, -5.000, 0.049, 0.945, 0.490, 0.275, 0.628, 0.787, 0.216, -0.012, 0.907, 0.965, 1.058, -0.061, 0.881, 0.793, 0.082, 0.946, 0.148, 0.579, -0.251, 0.005, 0.645, 0.598, -0.587, -0.241, 0.958, 0.870, 1.041, 0.759, 0.766, 0.591, 0.504, 0.992, 0.255, 0.187, 0.147, 0.253, 0.169, 0.244, -0.292, -0.358, 0.581, 0.382, 0.643, 0.766, 0.053, -0.412, -0.851, -5.000, -1.070, -0.542, -1.541, -5.000, -0.162, -0.388, -0.812, -0.860, -0.574, -0.768, -0.628, -0.346, 0.181, -0.017, -0.362, -5.000, -0.875, -0.436, -0.930, -1.092, -0.265, -0.367, -0.643, -1.044, 0.198, -0.077, -0.154, -0.329, 0.278, -0.157, -0.555, 0.111, -0.437, -0.260, -0.711, -0.567, 0.331, 0.167, -0.378, -0.542, 0.223, 0.105, 0.131, -0.060, -0.208, -0.497, -0.699, -0.156, -0.714, -0.731, -1.221, -0.933, -0.311, -0.566, -1.097, -1.129, 0.051, -0.307, -0.232, -0.173, 0.050, -0.108, -0.360, -5.000, -0.975, -0.687, -1.350, -5.000, -0.497, -0.284, -0.662, -0.600, -0.421, -0.462, -0.639, -0.410, 0.423, 0.457, 0.103, -5.000, -0.805, -0.014, -0.673, -0.647, -0.464, -0.305, -0.317, -0.589, 0.028, -0.517, -0.432, -0.636, 0.047, 0.190, -0.405, 0.240, -0.591, 0.010, -0.687, -0.727, 0.211, 0.154, -0.343, -0.568, 0.267, 0.501, 0.818, 0.291, 0.049, -0.153, -0.385, 0.048, -0.442, -0.420, -0.844, -0.721, -0.714, -0.329, -0.877, -0.963, -0.244, -0.427, -0.466, -0.174, 0.001, 0.085, -0.350, -5.000, -0.160, 0.587, -0.231, -5.000, 0.334, 0.550, 0.159, -0.084, -0.013, 0.257, 0.260, 0.165, 1.003, 1.030, 0.805, -5.000, 0.115, 0.999, 0.692, 0.270, 0.874, 0.892, 0.523, 0.292, 0.701, 1.088, 1.063, 0.371, 1.033, 0.805, 0.069, 0.959, 0.148, 0.431, -0.459, 0.012, 0.747, 0.786, -0.177, -0.015, 0.978, 0.754, 0.504, 0.787, 0.662, 0.750, 0.602, 0.866, 0.386, 0.520, 0.025, 0.281, 0.257, 0.501, -0.297, -0.257, 0.367, 0.356, 0.318, 0.381, 0.299, -0.006, -0.825, -5.000, -0.114, 0.308, -0.778, -5.000, 0.464, 0.573, -0.258, 0.114, -0.406, -0.014, 0.552, 0.012, 0.997, 0.811, 0.513, -5.000, 0.210, 0.942, 0.601, 0.364, 0.846, 0.887, 0.388, 0.411, 0.970, 0.997, 0.961, -0.122, 1.061, 0.809, -0.003, 1.046, 0.264, 0.494, -0.413, 0.135, 0.811, 0.752, -0.575, -0.274, 0.905, 0.840, 0.674, 0.808, 1.004, 0.711, 0.637, 1.150, 0.583, 0.632, 0.316, 0.444, 0.354, 0.492, -0.101, 0.003, 0.471, 0.268, 0.459, 0.918, 0.893, 0.745, 0.304, -5.000, 0.097, 0.444, -0.229, -5.000, 0.724, 0.860, 0.233, 0.164, -0.019, 0.075, -0.516, -0.003, 0.992, 0.698, 0.998, -5.000, 0.362, 0.979, 0.529, 0.535, 1.069, 1.147, 0.599, 0.694, 1.085, 1.142, 0.953, 0.494, 0.988, 0.800, 0.022, 0.968, 0.450, 0.566, -0.199, -0.027, 1.142, 1.201, 0.104, 0.576, 1.017, 0.857, 0.653, 0.813, 0.268, 0.239, -0.194, 0.483, 0.011, 0.027, -0.392, -0.412, -0.058, 0.090, -0.775, -0.209, 0.469, 0.010, -0.273, 0.385, 0.417, 0.352, -0.134, -5.000, -0.127, 0.414, -0.228, -5.000, 0.301, 0.521, -0.023, -0.020, 0.020, 0.058, -0.474, -0.234, 0.898, 0.739, 0.517, -5.000, -0.067, 0.789, 0.509, 0.078, 0.570, 0.756, 0.380, 0.460, 0.565, 0.023, 0.053, -0.258, 0.926, 1.083, 0.469, 0.957, -0.027, 0.343, -0.481, -0.189, 0.814, 0.694, -0.280, -0.052, 0.727, 0.970, 0.998, 0.581, 0.215, 0.636, 0.092, 0.290, 0.139, 0.320, -0.247, -0.319, -0.293, -0.063, -0.933, -0.793, -0.042, -0.192, -0.380, -0.105, -0.059, 0.097, -0.258, -5.000, -0.142, 0.300, -0.422, -5.000, -0.127, 0.416, 0.072, -0.039, -0.021, 0.318, -0.408, 0.164, 0.619, 0.577, 0.348, -5.000, -0.123, 0.271, -0.004, -0.131, 0.302, 0.463, 0.067, -0.177, 0.452, 0.636, 0.525, 0.316, 0.697, 0.495, -0.074, 0.533, 0.258, 0.261, -0.340, -0.139, 0.791, 0.868, 0.020, 0.193, 0.810, 0.870, 0.557, 0.652, 0.136, 0.166, -0.089, 0.252, -0.027, -0.303, -0.545, -0.414, -0.220, 0.301, 0.044, -0.096, -0.084, -0.128, 0.202, 0.161, -0.060, -0.460, -1.079, -5.000, -0.511, -0.518, -1.486, -5.000, -0.262, -0.031, -0.845, -0.452, -0.257, -0.410, 0.062, -0.085, 0.714, 0.489, 0.048, -5.000, -0.142, 0.316, -0.261, -0.190, -0.086, 0.026, -0.209, -0.156, 0.607, 0.599, 0.195, 0.120, 0.508, -0.133, -0.580, 0.314, 0.113, -0.338, -0.515, -0.737, 0.646, 0.434, -0.503, -0.238, 0.742, 0.411, 0.363, 0.495, 0.352, -0.266, -0.409, 0.484, -0.210, -0.867, -0.757, -0.653, -0.183, -0.308, -0.714, -0.388, -0.052, -0.543, -0.072, 0.287, 0.086, -0.260, -1.092, -5.000, -0.900, -0.695, -1.428, -5.000, -0.189, -0.276, -1.089, -0.952, -0.386, -0.880, -1.389, -0.329, 0.468, 0.125, -0.199, -5.000, -0.424, -0.006, -0.676, -0.601, 0.143, -0.141, -0.420, -0.686, 0.271, 0.028, -0.360, -0.359, 0.140, -0.116, -0.513, 0.265, -0.353, -0.302, -0.915, -0.797, 0.477, 0.516, -0.618, -0.323, 0.406, 0.290, 0.053, 0.041, -0.103, -0.721, -0.762, -0.177, -0.590, -0.636, -0.840, -0.676, -0.327, -0.321, -1.177, -0.706, -0.088, -0.661, -0.660, -0.261, 0.064, 0.005, -0.626, -5.000, -0.567, -0.137, -0.986, -5.000, -0.215, -0.043, -0.712, -0.524, -0.291, -0.268, -0.799, -0.328, 0.719, 0.694, 0.515, -5.000, -0.139, 0.581, 0.121, -0.234, 0.526, 0.453, 0.081, -0.107, 0.588, 0.373, 0.421, 0.043, 0.996, 1.102, 0.541, 0.771, 0.132, 0.527, 0.316, -0.024, 1.354, 1.394, 0.743, 0.565, 1.195, 1.341, 1.046, 0.856, 0.297, 0.441, -0.020, 0.526, 0.691, 0.066, -0.490, -0.079, 0.014, 0.439, -0.327, -0.595, -0.163, -0.090, -0.273, -0.134, -0.230, -0.318, -1.263, -5.000, -0.801, -0.347, -1.718, -5.000, -0.501, -0.077, -0.691, -0.473, -0.330, -0.084, 0.273, -0.022, 0.349, 0.417, 0.127, -5.000, -0.646, -0.015, -0.538, -0.523, -0.349, -0.288, -0.706, -0.756, 0.442, 0.246, 0.106, -0.082, 0.319, 0.262, -0.316, 0.300, -0.302, -0.157, -1.116, -0.656, 0.098, -0.040, -0.680, -0.595, 0.372, 0.541, 0.264, 0.055, -0.119, -0.180, -1.093, -0.174, -0.545, -0.652, -1.772, -1.170, 0.360, 0.261, -0.833, -0.714, 0.040, -0.002, -0.158, -0.121, -0.256, -0.666, -1.719, -5.000, -1.137, -0.913, -2.034, -5.000, -0.477, -0.535, -1.263, -0.967, -0.467, -0.687, 0.127, 0.071, 0.434, 0.051, -0.179, -5.000, -0.527, -0.326, -0.763, -0.309, -0.457, -0.729, -0.782, -0.701, 0.484, 0.070, -0.086, -0.227, 0.331, -0.067, -0.702, 0.323, -0.162, -0.069, -0.928, -0.617, 0.211, -0.049, -0.842, -0.548, 0.475, 0.282, 0.411, 0.301, 0.142, -0.298, -0.641, 0.325, -0.141, -0.651, -1.110, -0.726, -0.554, -0.945, -1.117, -0.828, 0.226, -0.281, 0.274, 0.465, -0.033, -0.307, -1.118, -5.000, -1.283, -0.850, -1.572, -5.000, -0.585, 0.017, -1.303, -0.940, -0.602, -1.185, -1.355, -0.279, 0.244, -0.261, -0.349, -5.000, -0.691, -0.580, -0.906, -0.599, -0.758, -0.597, -0.545, -0.819, 0.299, -0.115, -0.439, -0.358, -0.146, -0.598, -1.233, 0.000, -0.843, -1.126, -1.477, -1.327, -0.061, 0.096, -0.636, -0.663, 0.117, -0.010, 0.328, -0.178, -0.383, -1.347, -1.351, -0.507, -1.301, -1.593, -1.564, -1.163, -1.176, -1.108, -1.826, -1.356, -0.385, -1.330, -0.702, -0.495, -0.124, -0.587, -1.299, -5.000, -0.950, -1.021, -1.577, -5.000, -1.135, -0.799, -1.377, -0.940, -0.759, -0.623, -1.806, -0.763, 0.121, -0.298, -0.304, -5.000, -1.149, -0.398, -1.054, -1.009, -0.518, -0.848, -1.160, -0.958, 0.127, -0.376, -0.806, -0.360, -0.037, 0.089, -0.256, 0.134, -0.221, -0.389, -0.746, -0.788, 0.156, 0.432, -0.422, -0.506, 0.282, 0.419, 0.430, -0.116, -0.441, -0.554, -0.682, -0.573, -0.778, -0.953, -1.636, -1.403, -0.934, -0.640, -1.494, -1.425, -0.468, -0.915, -1.522, -0.715, -0.430, -0.886, -1.400, -5.000, -0.932, -0.679, -1.869, -5.000, -0.477, -0.269, -0.727, -0.811, -0.354, -0.287, -0.170, -0.098, 0.527, 0.323, -0.076, -5.000, -0.529, -0.214, -0.434, -0.609, 0.070, -0.001, -0.316, -0.495, 0.479, 0.523, 0.506, 0.103, 0.402, -0.296, -0.513, 0.389, -0.386, -0.291, -1.218, -0.893, 0.323, 0.154, -0.657, -0.344, 0.552, 0.530, 0.206, 0.359, -0.036, -0.246, -0.640, 0.011, -0.802, -0.784, -1.346, -0.795, -0.623, -0.145, -0.708, -1.205, 0.051, -0.096, 0.012, -0.137, 0.510, 0.181, -1.077, -5.000, -0.659, -0.197, -1.116, -5.000, -0.199, 0.078, -0.904, -0.526, 0.420, 0.596, 0.022, 0.218, 0.618, 0.735, 0.154, -5.000, -0.393, 0.358, -0.358, -0.274, -0.091, 0.280, -0.563, -0.504, 0.589, 0.592, 0.381, -0.345, 0.185, -0.240, -0.893, 0.234, -0.352, -0.458, -0.986, -0.810, -0.012, -0.019, -1.478, -0.981, 0.486, 0.275, 0.141, 0.062, 0.277, -0.331, -0.455, 0.119, -0.210, -0.801, -0.812, -0.661, -0.680, -0.615, -1.119, -0.774, 0.158, -0.164, 0.466, 0.300, -0.350, -0.926, -1.022, -5.000, -1.348, -1.201, -2.150, -5.000, -0.758, -1.076, -1.580, -1.356, -0.597, -0.897, -1.176, -0.633, -0.119, -0.434, -0.601, -5.000, -1.171, -1.076, -1.335, -1.166, -0.400, -1.102, -1.025, -1.396, -0.086, -0.294, -0.416, -0.357, -0.090, -0.465, -1.047, -0.314, -0.791, -0.846, -1.563, -0.892, -0.064, -0.401, -0.879, -0.809, 0.034, -0.203, -0.271, -0.316, -0.547, -0.927, -1.080, -0.583, -0.728, -1.111, -1.725, -1.118, -0.631, -1.207, -1.496, -1.235, -0.355, -0.813, -0.685, -0.288, -0.168, -0.297, -0.881, -5.000, -1.008, -1.239, -1.743, -5.000, -0.689, -0.579, -1.130, -0.890, -0.323, -0.633, -0.711, -0.568, 0.092, 0.031, -0.400, -5.000, -1.146, -0.715, -1.262, -0.914, -0.809, -0.783, -0.804, -1.257, -0.119, -0.557, -0.714, -0.363, -0.579, -0.229, -0.659, 0.075, -0.493, -0.557, -1.236, -1.081, -0.255, -0.120, -0.705, -0.755, -0.026, 0.244, 0.409, -0.047, -0.282, -0.481, -0.855, -0.493, -0.381, -0.589, -1.121, -0.793, -1.422, -0.654, -1.277, -1.261, -0.387, -1.010, -0.916, -0.451, -0.068, 0.013, -0.251, -5.000, -0.282, 0.033, -1.075, -5.000, 0.043, 0.195, -0.114, -0.175, 0.014, -0.017, -0.284, -0.009, 0.566, 0.593, 0.183, -5.000, -0.087, 0.475, 0.152, -0.161, 0.494, 0.623, 0.173, -0.066, 0.432, 0.769, 0.436, 0.370, 0.290, 0.067, -0.432, 0.286, -0.166, -0.214, -0.573, -0.497, 0.274, 0.192, -0.426, -0.203, 0.535, 0.399, 0.057, 0.251, 0.096, 0.267, -0.165, 0.298, -0.162, -0.090, -0.452, -0.120, 0.068, 0.422, -0.310, -0.138, 0.096, 0.037, -0.041, 0.133, -0.148, -0.815, -1.422, -5.000, -0.896, -0.737, -1.629, -5.000, -0.427, -0.570, -1.115, -0.917, -0.253, -0.495, 0.347, 0.108, 0.474, 0.374, -0.159, -5.000, -0.251, 0.437, -0.461, -0.264, 0.089, 0.133, -0.223, -0.124, 0.357, 0.387, 0.132, -0.008, 0.291, -0.354, -1.152, 0.047, -0.413, -0.291, -1.096, -0.773, 0.040, -0.166, -1.065, -0.710, 0.343, 0.078, -0.331, -0.028, 0.347, -0.280, -0.330, 0.292, -0.032, -0.478, -0.369, -0.388, -0.282, -0.221, -0.688, -0.521, -0.039, -0.286, -0.156, 0.141, 0.571, -0.053, -0.362, -5.000, -0.330, -0.050, -1.069, -5.000, 0.281, 0.212, -0.589, -0.228, -0.340, -0.910, -0.827, -0.036, 0.305, 0.171, 0.146, -5.000, -0.064, 0.549, -0.111, 0.258, 0.494, 0.599, -0.095, -0.029, 0.628, 0.592, 0.285, 0.025, 0.461, 0.092, -0.768, 0.310, -0.090, -0.106, -0.809, -0.367, 0.595, 0.592, -0.624, -0.051, 0.501, 0.105, -0.093, 0.183, -0.007, -0.569, -0.860, 0.087, -0.235, -0.500, -0.872, -0.561, -0.660, -0.647, -1.340, -0.640, -0.158, -0.596, -0.723, -0.115, 0.049, 0.081, -0.571, -5.000, -0.168, 0.345, -0.298, -5.000, 0.144, 0.392, -0.128, -0.072, -0.109, -0.091, -0.242, -0.178, 0.387, 0.433, 0.022, -5.000, -0.126, 0.474, 0.150, -0.102, 0.444, 0.660, 0.275, 0.404, 0.459, 0.164, 0.009, 0.118, 0.474, 0.907, 0.072, 0.623, 0.093, 0.143, -0.456, 0.032, 0.580, 0.631, -0.245, -0.051, 0.580, 0.816, 0.696, 0.458, -0.125, 0.329, -0.146, -0.023, 0.026, 0.213, -0.200, -0.295, -0.142, 0.162, -0.580, -0.699, -0.281, -0.207, -0.437, -0.227 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_13(struct _training *tptr) {
  struct _training tinf = {
    0.475, 11, 4.350, { 1.973, 0.156, 0.871 }, { 0.989, -1.492, -2.976 }, 1, 
    { -1.934, -1.761, -1.255, -0.498, -0.830, -1.427, 0.001, -4.000, -0.008, -0.840, -1.520, -4.000, 1.139, 0.826, -0.561, 2.595, 2.533, -0.401, 1.863, 1.178, 1.452, 1.551, 3.469, 3.096, 2.736, -4.000, 3.327, 2.927 }, 
    {{ -0.084, -0.399, 0.135, 0.222},{ -0.031, -0.610, 0.042, 0.341},{ 0.281, -0.165, -0.307, 0.051},{ 0.304, -0.297, -0.273, 0.090},{ 0.275, -0.229, -0.236, 0.058},{ 0.208, -0.254, -0.192, 0.122},{ 0.226, -0.324, -0.059, 0.048},{ 0.161, -0.279, -0.088, 0.116},{ 0.143, -0.300, -0.131, 0.176},{ 0.199, -0.364, -0.052, 0.096},{ 0.137, -0.149, -0.055, 0.027},{ 0.073, -0.216, -0.078, 0.156},{ 0.135, -0.287, -0.100, 0.156},{ 0.102, -0.156, -0.041, 0.058},{ 0.074, -0.232, -0.058, 0.150},{ 0.113, -0.132, -0.091, 0.069},{ 0.129, -0.135, -0.066, 0.034},{ 0.041, -0.099, -0.121, 0.137},{ 0.104, -0.143, -0.084, 0.081},{ 0.129, -0.113, -0.043, -0.003},{ 0.013, -0.160, -0.007, 0.120},{ 0.095, -0.200, -0.057, 0.108},{ 0.088, -0.086, -0.106, 0.071},{ 0.013, -0.109, -0.113, 0.162},{ 0.132, -0.140, -0.142, 0.093},{ 0.082, -0.057, -0.117, 0.062},{ 0.064, -0.103, -0.166, 0.149},{ 0.052, -0.088, -0.080, 0.089},{ 0.098, -0.010, -0.100, -0.008},{ 0.034, -0.043, -0.104, 0.089},{ 0.074, -0.078, -0.078, 0.057},{ 0.039, 0.001, -0.098, 0.042} }, 
    {{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}} }, 
    0.000, { 0.378, 0.787, 0.316, -5.000, -0.770, -0.021, -0.578, -5.000, -0.375, 0.199, -0.198, -0.417, -0.124, 0.339, 0.406, 0.329, 0.297, 0.862, 0.256, -5.000, -0.883, 0.320, -0.856, -0.159, -0.181, 0.562, 0.244, -0.363, 0.516, 0.527, 0.813, 0.403, 0.053, 0.359, -0.150, 0.134, -0.090, 0.323, 0.268, -1.008, 0.194, 0.510, -0.120, -0.201, 0.253, 0.538, 0.215, 0.049, 0.289, 0.771, 0.182, 0.467, 0.396, 0.799, 0.740, -0.419, 0.324, 0.754, 0.625, 0.426, 0.494, 0.566, 0.482, 0.473, 0.930, 1.118, 0.762, -5.000, -0.454, 0.106, 0.063, -5.000, 0.388, 0.876, 0.539, 0.131, 0.362, 0.944, 1.028, 1.010, 0.141, 0.682, 0.789, -5.000, -0.885, 0.461, 0.314, 0.550, 0.336, 0.785, 0.828, 0.318, 0.916, 0.811, 1.138, 1.011, 0.667, 0.835, 0.121, 0.597, 0.519, 0.706, 0.763, -0.260, 0.727, 0.903, 0.263, 0.515, 0.896, 1.070, 0.752, 0.701, 0.745, 1.131, 0.634, 0.828, 0.662, 0.949, 1.214, 0.172, 0.537, 0.862, 0.512, 0.467, 1.028, 0.955, 0.721, 0.912, 0.467, 0.996, 0.607, -5.000, -0.575, -0.126, -0.488, -5.000, 0.512, 0.907, 0.504, 0.263, 0.050, 0.756, 0.735, 0.991, 0.417, 0.946, 0.569, -5.000, -1.043, 0.449, -0.485, -0.039, 0.218, 0.626, 0.183, 0.004, 0.731, 0.662, 0.792, 0.739, -0.100, 0.086, -0.537, -0.175, 0.047, -0.011, -0.066, -1.004, 0.146, 0.219, -0.708, -0.450, -0.044, 0.032, -0.391, 0.149, 0.108, 0.426, -0.377, 0.131, -0.061, 0.032, 0.245, -0.494, 0.170, 0.309, -0.223, 0.051, 0.355, -0.168, -0.691, -0.418, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.665, -0.503, -1.114, -5.000, -1.551, -1.414, -1.788, -5.000, -1.544, -0.959, -1.088, -1.212, -0.726, -0.465, -0.330, -0.472, -1.022, -0.340, -0.991, -5.000, -1.379, -0.796, -1.395, -1.284, -1.058, -0.919, -1.483, -1.688, -0.350, -0.489, -0.595, -0.687, -1.026, -0.422, -1.183, -1.305, -1.373, -0.962, -1.244, -1.861, -1.341, -0.606, -1.630, -1.434, -0.915, -0.611, -0.720, -0.900, -0.600, -0.420, -1.063, -0.565, -0.878, -0.762, -0.794, -1.359, -0.815, -0.603, -0.522, -0.636, -0.588, -0.557, -0.078, -0.687, 0.256, 0.480, 0.066, -5.000, -0.679, -0.257, -0.697, -5.000, -0.582, -0.472, -0.273, -0.913, -0.328, 0.124, 0.586, 0.244, -0.455, 0.194, 0.142, -5.000, -1.010, -0.210, -0.720, -0.318, -0.494, -0.145, -0.321, -0.687, 0.069, -0.066, 0.051, -0.060, -0.563, -0.438, -0.963, -0.708, -0.630, -0.246, -0.750, -1.431, -0.314, -0.031, -0.408, -0.617, -0.139, 0.001, -0.033, -0.564, -0.305, -0.237, -0.554, -0.582, -0.309, -0.098, -0.201, -1.120, -1.298, -0.820, -0.749, -1.224, -0.492, -0.924, -0.554, -0.907, -0.516, 0.031, -0.430, -5.000, -1.451, -0.900, -1.235, -5.000, -0.823, -0.539, -1.121, -1.093, -1.217, -0.459, -0.355, -0.315, -0.904, 0.127, -0.453, -5.000, -1.859, -0.562, -1.295, -1.403, -0.823, -0.736, -1.299, -1.310, -0.307, -0.340, -0.358, -0.142, -0.723, -0.509, -1.139, -1.121, -0.567, -0.582, -0.922, -2.029, -0.397, -0.174, -0.821, -0.764, -0.355, -0.340, -1.021, -0.563, -0.846, -0.720, -1.010, -1.153, -0.871, -0.794, -0.700, -1.625, -0.692, -0.642, -0.808, -0.957, -0.424, -0.719, -1.346, -1.017, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.045, 0.488, -0.212, -5.000, -1.038, -0.552, -1.123, -5.000, -0.776, -0.285, -0.578, -0.750, -0.757, -0.547, -0.293, -0.209, -0.507, 0.332, -0.020, -5.000, -1.327, 0.414, -0.348, -0.400, -0.067, 0.207, -0.230, -0.587, 0.148, 0.247, 0.498, -0.082, -0.542, -0.178, -0.522, -0.287, -0.742, -0.122, -0.194, -1.245, -0.224, -0.261, -0.738, -0.729, -0.231, 0.008, 0.019, -0.111, -0.063, 0.255, -0.427, -0.145, -0.203, -0.057, -0.138, -1.045, -0.477, -0.220, 0.143, -0.411, -0.185, -0.400, -0.350, -0.315, 0.556, 0.972, 0.456, -5.000, -0.934, -0.336, -0.542, -5.000, -0.463, 0.046, -0.606, -0.703, -0.460, 0.091, 0.100, 0.243, -0.242, 0.660, 0.618, -5.000, -1.230, 0.268, -0.228, -0.217, 0.123, 0.503, -0.010, -0.398, 0.293, 0.375, 0.692, 0.325, -0.249, 0.175, -0.490, -0.462, -0.260, 0.294, -0.000, -1.097, 0.316, 0.501, -0.088, -0.388, 0.255, 0.532, 0.186, -0.059, 0.342, 0.799, 0.146, 0.258, 0.296, 0.606, 0.519, -0.446, 0.047, 0.235, -0.217, -0.255, 0.405, 0.010, -0.317, 0.018, -0.336, 0.087, -0.470, -5.000, -1.404, -0.942, -1.335, -5.000, -0.165, -0.170, -0.746, -0.772, -1.181, -0.328, -0.146, -0.302, -0.474, 0.268, -0.212, -5.000, -1.311, 0.024, -0.717, -0.435, -0.063, -0.295, -0.731, -0.885, -0.097, -0.045, 0.043, -0.122, 0.190, 0.394, -0.325, -0.345, -0.085, 0.170, -0.122, -0.802, 0.109, -0.182, -0.961, -0.662, 0.242, 0.137, -0.393, 0.140, 0.050, 0.340, -0.463, -0.325, -0.287, -0.046, 0.117, -0.867, -0.336, -0.321, -0.371, -0.694, 0.188, -0.318, -1.202, -0.820, -0.392, 0.234, -0.410, -5.000, -1.580, -1.193, -1.500, -5.000, -0.730, -0.566, -0.811, -0.974, -0.930, -0.452, -0.483, -0.436, -0.470, 0.276, -0.114, -5.000, -1.539, -0.662, -1.459, -0.754, -0.443, -0.489, -0.591, -1.026, 0.101, -0.185, 0.235, 0.088, -0.452, 0.016, -0.598, -0.480, -0.582, -0.072, -0.377, -1.287, 0.242, 0.288, -0.306, -0.485, -0.062, 0.220, 0.022, -0.047, -0.536, 0.015, -0.529, -0.735, -0.306, 0.189, -0.147, -1.187, -0.810, -0.327, -0.431, -0.838, -0.213, -0.285, -0.509, -0.482, -0.161, 0.206, -0.218, -5.000, -0.874, -0.546, -0.969, -5.000, -0.694, -0.566, -0.902, -0.920, -0.746, -0.754, -0.505, -0.599, -0.478, 0.250, -0.207, -5.000, -0.997, -0.219, -0.952, -0.685, -0.718, -0.328, -0.587, -0.992, -0.198, -0.151, -0.256, -0.498, -0.620, -0.329, -0.692, -0.616, -0.711, -0.437, -0.631, -1.333, -0.631, -0.561, -0.798, -0.945, -0.540, -0.377, -0.520, -1.108, -0.151, 0.221, -0.459, -0.068, -0.206, -0.145, -0.058, -0.779, -0.269, -0.252, -0.318, -0.530, -0.324, -0.387, -0.529, -0.351, 0.394, 0.714, 0.318, -5.000, -0.668, -0.311, -0.180, -5.000, -0.283, 0.058, -0.556, -0.556, -0.313, 0.075, 0.251, 0.339, -0.416, 0.359, 0.258, -5.000, -0.788, 0.416, -0.049, -0.244, 0.108, 0.464, 0.015, -0.278, 0.280, 0.523, 0.579, 0.144, -0.066, 0.288, -0.618, -0.546, -0.130, 0.285, -0.076, -0.963, -0.007, 0.069, -0.367, -0.397, -0.108, 0.283, -0.235, -0.374, 0.227, 0.647, 0.039, 0.180, 0.289, 0.434, 0.560, -0.492, -0.102, -0.069, -0.309, -0.256, 0.318, -0.176, -0.749, -0.107, 0.161, 0.506, 0.345, -5.000, -0.898, -0.061, -0.908, -5.000, 0.209, 0.437, -0.134, -0.483, -0.503, 0.147, 0.130, -0.081, 0.164, 0.927, 0.567, -5.000, -0.871, 0.478, -0.412, -0.142, 0.520, 0.488, -0.044, -0.224, 0.508, 0.526, 0.710, 0.363, 0.091, 0.350, -0.369, -0.386, 0.117, 0.309, 0.241, -0.672, 0.349, 0.326, -0.296, -0.306, 0.112, 0.261, -0.351, 0.190, 0.145, 0.531, -0.300, -0.082, -0.026, 0.313, 0.142, -0.729, -0.258, -0.242, -0.414, -0.508, 0.320, -0.473, -0.989, -0.415, 0.326, 0.983, 0.748, -5.000, -0.570, 0.083, -0.483, -5.000, 0.423, 0.705, 0.084, -0.023, -0.145, 0.613, 0.435, 0.331, 0.258, 1.008, 0.814, -5.000, -0.801, 0.457, -0.096, 0.063, 0.449, 0.609, 0.138, -0.159, 0.555, 0.690, 0.805, 0.498, 0.150, 0.555, 0.005, -0.047, -0.006, 0.401, 0.463, -0.769, 0.702, 0.601, 0.001, -0.264, 0.253, 0.563, 0.095, 0.228, 0.230, 0.953, 0.221, 0.146, -0.000, 0.613, 0.600, -0.650, -0.395, -0.097, -0.367, -0.407, 0.287, -0.120, -0.522, -0.150, -0.039, 0.576, -0.095, -5.000, -0.987, -0.550, -1.150, -5.000, -0.919, -0.381, -0.905, -1.184, -0.778, -0.676, -0.396, -0.340, -0.488, 0.665, -0.191, -5.000, -1.362, -0.294, -1.293, -0.592, -0.678, 0.125, -0.414, -1.157, 0.007, 0.005, 0.013, -0.337, -0.306, 0.406, -0.710, -0.256, -0.552, 0.248, -0.101, -1.189, 0.055, 0.342, -0.789, -0.294, -0.033, 0.218, -0.162, -0.332, 0.120, 0.608, -0.027, 0.172, 0.198, 0.724, 0.702, -0.459, 0.333, 0.570, 0.425, 0.103, 0.438, 0.520, 0.382, 0.292, 1.081, 1.368, 0.951, -5.000, -0.285, 0.369, 0.081, -5.000, 0.261, 0.760, 0.482, 0.152, 0.147, 0.739, 1.065, 0.902, 0.205, 0.810, 0.854, -5.000, -0.392, 0.461, 0.292, 0.374, 0.218, 0.804, 0.360, 0.034, 0.870, 0.844, 1.066, 0.913, 0.398, 0.739, 0.121, 0.341, 0.251, 0.739, 0.628, -0.476, 0.650, 0.902, 0.344, 0.428, 0.663, 0.808, 0.495, 0.266, 0.669, 1.065, 0.560, 0.719, 0.625, 0.993, 1.101, 0.223, 0.308, 0.736, 0.405, 0.428, 0.814, 0.846, 0.673, 0.760, 0.425, 0.994, 0.648, -5.000, -0.756, -0.041, -0.581, -5.000, 0.462, 0.937, 0.485, 0.344, -0.112, 0.668, 0.593, 0.896, 0.328, 1.042, 0.524, -5.000, -0.528, 0.618, -0.283, 0.174, -0.055, 0.478, -0.002, -0.098, 0.516, 0.572, -0.043, 0.437, -0.120, 0.114, -0.416, -0.009, 0.146, 0.036, 0.039, -0.895, 0.030, 0.093, -0.627, -0.617, -0.155, 0.048, -0.625, 0.007, 0.298, 0.584, 0.143, 0.616, 0.168, 0.431, 0.690, -0.355, 0.372, 0.620, 0.131, 0.315, 0.476, 0.207, -0.411, -0.314, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.885, -0.756, -1.242, -5.000, -1.330, -1.526, -1.470, -5.000, -1.480, -1.285, -0.981, -1.348, -1.030, -0.930, -0.838, -0.656, -1.249, -0.421, -0.711, -5.000, -1.064, -0.756, -0.946, -1.438, -1.422, -1.090, -1.753, -1.995, -0.595, -0.635, -0.918, -0.961, -1.612, -0.696, -1.175, -1.311, -1.527, -1.087, -1.468, -1.741, -1.466, -0.950, -1.316, -1.593, -1.375, -0.843, -1.108, -1.342, -0.756, -0.211, -1.466, -0.768, -1.131, -1.032, -0.795, -1.200, -0.925, -0.559, -0.491, -0.606, -0.593, -0.622, -0.704, -0.823, 0.888, 1.111, 0.851, -5.000, -0.517, 0.386, -0.383, -5.000, -0.255, 0.344, 0.301, -0.510, -0.077, 0.448, 0.957, 0.897, -0.199, 0.927, 0.837, -5.000, -0.917, 0.486, -0.363, -0.013, 0.288, 0.680, 0.256, -0.489, 0.838, 0.711, 0.858, 0.684, -0.285, -0.068, -0.499, -0.552, -0.403, 0.092, -0.343, -1.265, 0.235, 0.399, -0.791, -0.380, 0.155, 0.681, 0.247, -0.259, 0.081, 0.436, -0.263, -0.078, 0.080, 0.535, 0.235, -0.657, -0.424, -0.035, -0.081, -0.610, 0.051, 0.131, 0.035, -0.096, -0.347, 0.396, 0.005, -5.000, -1.383, -0.924, -1.170, -5.000, -0.343, -0.287, -0.511, -0.939, -1.005, -0.094, 0.053, -0.024, -0.601, 0.479, -0.090, -5.000, -1.501, -0.212, -0.834, -1.044, -0.647, -0.238, -1.166, -1.101, -0.407, -0.304, -0.263, -0.255, -0.379, -0.094, -1.091, -0.945, -0.228, -0.162, -0.322, -1.346, -0.402, -0.276, -1.143, -1.002, -0.388, 0.109, -1.107, -0.533, -0.469, 0.095, -0.729, -0.467, -0.601, -0.527, -0.009, -1.056, -0.506, -0.322, -0.736, -0.730, -0.238, -0.363, -1.346, -0.696, -0.246, 0.293, -0.118, -5.000, -1.706, -0.781, -1.775, -5.000, -0.519, -0.218, -0.543, -0.491, -1.057, -0.224, -0.177, -0.158, -0.707, 0.524, -0.058, -5.000, -1.554, -0.506, -1.596, -0.789, -0.602, -0.300, -0.437, -0.989, -0.084, 0.002, 0.257, -0.072, -0.199, 0.615, -0.648, -0.464, -0.219, 0.162, -0.235, -1.377, 0.405, 0.537, -0.543, -0.612, -0.303, 0.043, -0.498, -0.319, -0.435, 0.258, -0.571, -0.571, -0.094, -0.033, -0.017, -1.155, -0.050, -0.015, -0.169, -0.572, -0.349, -0.402, -0.679, -0.456, 0.153, 0.574, 0.029, -5.000, -0.940, -0.013, -0.734, -5.000, -0.427, -0.140, -0.401, -0.591, -0.812, -0.301, -0.248, 0.004, -0.406, 0.782, 0.071, -5.000, -1.289, 0.669, -0.220, -0.161, -0.063, 0.368, 0.012, -0.101, 0.280, 0.570, 0.422, 0.194, -0.250, 0.335, 0.015, -0.078, -0.254, 0.238, -0.003, -1.354, 0.048, 0.122, -0.397, -0.387, -0.126, 0.412, -0.108, -0.620, -0.019, 0.570, -0.023, 0.151, -0.048, 0.382, 0.309, -0.586, -0.342, -0.308, -0.071, -0.201, 0.008, -0.225, -0.492, -0.135, 0.737, 1.229, 0.664, -5.000, -0.697, -0.099, -0.246, -5.000, -0.513, 0.123, -0.597, -0.579, -0.380, 0.058, 0.246, 0.593, -0.093, 0.977, 0.827, -5.000, -0.895, 0.584, 0.170, -0.143, 0.076, 0.533, 0.088, -0.396, 0.505, 0.517, 0.686, 0.429, 0.079, 0.472, 0.021, -0.088, -0.142, 0.428, 0.218, -0.870, 0.277, 0.589, 0.009, -0.270, 0.318, 0.748, 0.232, -0.272, 0.527, 1.051, 0.555, 0.600, 0.508, 0.745, 0.701, -0.231, 0.048, 0.466, 0.093, -0.044, 0.588, 0.440, -0.190, 0.246, 0.028, 0.485, 0.059, -5.000, -1.395, -0.566, -1.201, -5.000, 0.135, 0.190, -0.494, -0.490, -0.797, -0.098, -0.068, 0.175, -0.471, 0.329, -0.054, -5.000, -1.307, 0.202, -0.615, -0.794, -0.069, -0.061, -0.708, -1.003, -0.033, 0.087, 0.124, -0.107, 0.008, 0.357, -0.366, -0.515, 0.025, 0.303, 0.055, -0.858, 0.166, 0.053, -0.536, -0.573, 0.320, 0.239, -0.353, 0.312, 0.153, 0.693, -0.059, -0.071, -0.299, 0.266, 0.473, -0.680, 0.120, 0.408, -0.319, -0.350, 0.528, 0.079, -0.691, -0.577, -0.275, 0.343, -0.202, -5.000, -1.649, -1.128, -1.694, -5.000, -0.637, -0.346, -0.905, -0.995, -1.088, -0.542, -0.528, -0.430, -0.576, 0.237, 0.054, -5.000, -1.822, -0.593, -1.804, -0.976, -0.495, -0.603, -0.777, -1.301, -0.017, -0.382, 0.128, -0.184, -0.243, 0.002, -0.507, -0.422, -0.515, 0.178, -0.337, -1.203, 0.335, 0.364, -0.236, -0.510, -0.099, 0.489, 0.158, -0.110, -0.629, 0.028, -0.524, -0.542, -0.424, 0.252, -0.030, -1.092, -0.839, -0.392, -0.348, -0.921, -0.236, -0.139, -0.463, -0.695, 0.295, 1.030, 0.466, -5.000, -0.500, 0.132, -0.300, -5.000, -0.490, 0.016, -0.287, -0.381, -0.790, -0.332, -0.315, 0.030, -0.237, 0.943, 0.469, -5.000, -0.701, 0.678, 0.033, -0.273, 0.029, 0.799, -0.022, -0.049, 0.372, 0.596, 0.473, 0.093, 0.059, 0.646, -0.108, 0.007, 0.047, 0.694, 0.358, -0.642, 0.432, 0.534, -0.334, -0.176, 0.391, 0.500, -0.244, -0.274, 0.434, 1.125, 0.630, 0.776, 0.451, 0.852, 0.987, -0.259, 0.078, 0.182, -0.093, -0.029, 0.521, 0.182, -0.377, 0.451, 0.821, 1.319, 0.797, -5.000, -0.461, 0.057, 0.227, -5.000, -0.338, -0.003, -0.532, -0.564, -0.391, 0.297, 0.470, 0.800, -0.184, 0.939, 0.661, -5.000, -0.599, 0.837, 0.239, -0.158, 0.229, 0.577, 0.008, -0.113, 0.459, 0.729, 0.788, 0.417, 0.181, 0.707, -0.282, -0.391, -0.056, 0.640, 0.224, -1.077, 0.346, 0.368, -0.258, -0.275, 0.568, 0.686, 0.106, -0.038, 0.632, 1.236, 0.628, 0.851, 0.523, 0.998, 0.759, 0.061, -0.012, 0.061, -0.246, -0.244, 0.677, 0.320, -0.651, 0.349, 0.822, 1.217, 0.901, -5.000, -0.570, 0.208, -0.270, -5.000, 0.823, 0.982, 0.491, 0.369, -0.167, 0.692, 0.770, 0.823, 0.454, 1.176, 0.389, -5.000, -0.902, 0.773, 0.147, -0.010, 0.748, 0.948, 0.391, 0.250, 0.691, 0.842, 0.580, 0.420, 0.524, 0.777, 0.006, 0.227, 0.524, 0.714, 0.547, -0.334, 0.622, 0.556, -0.329, -0.150, 0.446, 0.595, -0.145, 0.524, 0.762, 1.109, 0.442, 0.754, 0.450, 0.903, 1.044, -0.020, 0.437, 0.618, 0.093, 0.252, 0.850, 0.431, -0.651, -0.103, 0.192, 0.922, 0.554, -5.000, -0.970, -0.136, -0.711, -5.000, 0.439, 0.672, -0.103, 0.043, -0.478, 0.335, 0.169, 0.263, 0.022, 0.974, 0.482, -5.000, -1.272, 0.414, -0.104, -0.016, 0.392, 0.717, 0.152, -0.056, 0.484, 0.590, 0.447, 0.220, 0.075, 0.535, -0.114, -0.175, 0.001, 0.426, 0.324, -0.823, 0.557, 0.530, -0.252, -0.390, 0.089, 0.577, 0.052, 0.003, 0.062, 0.822, 0.118, 0.228, -0.016, 0.520, 0.615, -0.695, -0.271, -0.064, -0.317, -0.349, 0.226, -0.238, -0.786, -0.350, 0.039, 0.651, -0.086, -5.000, -0.934, -0.686, -1.134, -5.000, -0.716, -0.476, -0.653, -0.801, -0.789, -0.416, -0.132, -0.110, -0.200, 0.576, -0.031, -5.000, -1.244, -0.265, -1.134, -0.281, -0.769, -0.065, -0.256, -0.759, 0.250, -0.024, 0.283, -0.082, -0.232, 0.352, -0.453, 0.153, -0.508, -0.109, -0.118, -1.401, -0.091, -0.031, -0.815, -0.758, -0.050, 0.187, -0.014, -0.254, 0.294, 0.621, 0.163, 0.646, 0.087, 0.627, 0.675, -0.400, 0.448, 0.573, 0.347, 0.237, 0.369, 0.485, 0.310, 0.361, 0.874, 1.110, 0.611, -5.000, -0.741, -0.057, -0.158, -5.000, -0.086, 0.396, -0.141, -0.143, 0.080, 0.494, 0.704, 0.773, 0.228, 0.764, 0.796, -5.000, -1.034, 0.046, -0.006, 0.345, -0.166, 0.204, 0.174, -0.474, 0.833, 0.598, 0.860, 0.698, 0.204, 0.376, -0.240, 0.406, -0.116, 0.219, 0.073, -0.679, 0.249, 0.404, 0.012, 0.021, 0.395, 0.551, 0.383, 0.251, 0.449, 0.836, 0.226, 0.713, 0.222, 0.527, 0.674, -0.135, 0.044, 0.330, -0.132, 0.100, 0.540, 0.484, 0.408, 0.593, -0.044, 0.515, -0.247, -5.000, -1.341, -0.602, -1.220, -5.000, -0.370, -0.090, -0.369, -0.706, -0.505, -0.110, 0.064, 0.220, -0.215, 0.511, -0.316, -5.000, -1.255, 0.096, -1.124, -0.814, -0.803, -0.476, -0.635, -1.224, 0.004, -0.180, 0.108, 0.034, -0.430, -0.038, -0.815, -0.564, -0.299, -0.040, -0.286, -1.165, -0.185, -0.197, -0.730, -0.724, -0.177, -0.109, -0.604, -0.164, -0.260, 0.059, -0.631, -0.147, -0.350, -0.034, -0.052, -0.874, -0.114, -0.126, -0.432, -0.300, -0.005, -0.138, -1.061, -0.762, -0.064, 0.107, -0.416, -5.000, -1.209, -0.644, -1.428, -5.000, -0.771, -0.648, -1.045, -0.882, -0.706, -0.025, -0.597, -0.181, -0.198, 0.392, -0.365, -5.000, -1.624, -0.704, -1.545, -0.709, -1.337, -0.786, -0.605, -0.994, 0.239, -0.080, 0.184, -0.072, 0.612, 0.754, 0.132, 0.445, 0.439, 0.421, 0.301, -0.662, 0.527, 0.508, 0.024, 0.096, 0.254, 0.308, 0.133, 0.200, -0.084, 0.706, -0.483, -0.038, -0.164, 0.281, 0.169, -0.831, 0.260, 0.326, 0.298, 0.021, -0.042, -0.036, -0.432, -0.509, -0.084, 0.371, -0.073, -5.000, -1.418, -1.129, -1.450, -5.000, -1.340, -0.735, -0.365, -0.919, -0.837, -0.640, -0.028, 0.187, -0.547, 0.488, -0.196, -5.000, -0.980, -0.074, -0.856, -0.164, -0.809, -0.456, -0.620, -0.972, 0.290, -0.207, 0.228, -0.157, -0.025, 0.561, -0.212, 0.196, -0.219, 0.154, -0.184, -1.159, 0.112, 0.131, -0.673, -0.619, 0.075, 0.249, 0.040, -0.379, 0.010, 0.424, -0.280, 0.305, 0.170, 0.410, 0.391, -0.673, 0.211, 0.099, 0.062, -0.293, 0.024, -0.044, 0.312, -0.200, 0.880, 1.078, 0.650, -5.000, -0.718, 0.022, -0.401, -5.000, -0.457, 0.110, -0.142, -0.502, -0.178, 0.268, 0.935, 0.860, -0.144, 0.822, 0.597, -5.000, -1.172, 0.192, -0.430, -0.075, -0.182, 0.371, -0.003, -0.384, 0.546, 0.501, 0.634, 0.525, 0.147, 0.394, -0.289, 0.153, -0.181, 0.131, -0.030, -1.006, 0.257, 0.518, -0.061, 0.036, 0.376, 0.783, 0.262, 0.130, 0.272, 0.793, 0.055, 0.509, 0.227, 0.502, 0.601, -0.303, -0.285, -0.046, -0.117, -0.346, 0.382, 0.164, 0.240, 0.275, 0.161, 0.744, 0.182, -5.000, -1.200, -0.469, -0.995, -5.000, -0.209, 0.136, -0.246, -0.597, -0.758, 0.256, 0.408, 0.391, -0.101, 0.848, 0.150, -5.000, -1.417, 0.228, -0.509, -0.616, -0.576, 0.174, -0.433, -0.641, 0.325, 0.428, 0.497, 0.211, 0.100, 0.576, -0.382, -0.197, 0.041, 0.360, 0.045, -0.896, 0.252, 0.477, -0.486, -0.097, 0.500, 0.520, -0.548, 0.431, -0.112, 0.569, -0.456, -0.024, -0.242, 0.098, 0.325, -1.137, 0.232, 0.430, -0.150, -0.149, 0.437, 0.211, -0.751, -0.102, -1.077, -0.508, -1.107, -5.000, -2.048, -1.540, -2.012, -5.000, -1.317, -1.120, -1.379, -1.536, -1.301, -0.991, -0.943, -0.690, -1.138, -0.274, -0.912, -5.000, -1.906, -1.074, -1.826, -1.416, -1.738, -1.219, -1.341, -1.698, -0.687, -0.523, -0.289, -0.548, -0.856, -0.413, -0.866, -0.982, -0.970, -0.516, -0.875, -1.671, -0.684, -0.426, -1.262, -1.107, -0.909, -0.359, -0.734, -0.809, -1.189, -0.353, -0.949, -0.899, -0.987, -0.617, -0.927, -1.756, -0.930, -0.643, -0.977, -1.130, -0.675, -0.727, -1.024, -1.140, 0.437, 0.879, 0.264, -5.000, -0.917, 0.050, -0.275, -5.000, -0.333, 0.261, -0.107, -0.344, -0.399, -0.118, 0.183, 0.334, -0.017, 0.859, 0.225, -5.000, -0.726, 0.673, 0.116, 0.241, 0.062, 0.462, 0.230, -0.228, 0.528, 0.662, 0.726, 0.365, -0.007, 0.333, -0.067, 0.409, -0.235, 0.350, 0.159, -0.870, 0.344, 0.258, -0.369, -0.205, 0.194, 0.479, 0.061, -0.000, 0.199, 0.829, 0.333, 0.838, 0.189, 0.608, 0.623, -0.243, 0.191, 0.044, 0.250, 0.095, 0.400, 0.055, -0.174, 0.279, 0.812, 1.206, 0.716, -5.000, -0.619, 0.112, -0.232, -5.000, -0.348, 0.226, -0.429, -0.427, -0.362, 0.020, 0.395, 0.614, -0.029, 0.927, 0.579, -5.000, -1.191, 0.624, -0.045, -0.055, -0.125, 0.390, 0.045, -0.361, 0.351, 0.507, 0.763, 0.423, -0.015, 0.308, -0.118, 0.015, -0.067, 0.340, 0.192, -0.826, 0.272, 0.527, -0.024, -0.250, 0.415, 0.720, 0.056, 0.024, 0.485, 1.067, 0.439, 0.839, 0.249, 0.729, 0.667, -0.407, 0.025, 0.308, -0.050, -0.015, 0.864, 0.594, 0.108, 0.602, 0.018, 0.468, -0.026, -5.000, -1.021, -0.780, -1.147, -5.000, -0.390, -0.318, -0.872, -0.734, -0.691, -0.203, 0.048, 0.166, -0.438, 0.338, -0.284, -5.000, -1.300, -0.266, -0.685, -1.052, -0.585, -0.458, -0.978, -1.101, -0.241, 0.057, -0.022, -0.324, -0.220, 0.335, -0.393, -0.239, -0.553, -0.140, -0.362, -0.977, 0.099, -0.020, -0.450, -0.725, 0.037, 0.504, -0.049, 0.065, -0.222, 0.183, -0.536, -0.255, -0.828, -0.016, -0.263, -1.148, -0.357, -0.105, -0.319, -0.398, 0.100, -0.026, -0.335, -0.602, -0.155, 0.529, -0.130, -5.000, -1.607, -1.146, -1.523, -5.000, -0.855, -0.412, -0.874, -0.867, -1.014, -0.501, -0.416, -0.168, -0.371, 0.413, 0.079, -5.000, -0.998, -0.539, -1.456, -0.692, -0.583, -0.079, -0.602, -1.031, 0.235, -0.139, 0.414, 0.074, -0.127, 0.415, -0.151, 0.007, -0.206, 0.217, -0.073, -0.988, 0.431, 0.461, -0.197, -0.136, 0.320, 0.576, 0.467, 0.348, -0.659, 0.330, -0.574, -0.439, -0.729, 0.155, -0.258, -1.446, -0.788, -0.292, -0.571, -0.744, -0.135, 0.039, -0.060, -0.503, 0.197, 0.791, 0.407, -5.000, -0.784, -0.400, -0.330, -5.000, -0.536, -0.138, -0.364, -0.597, -0.825, -0.594, -0.109, 0.056, -0.107, 0.888, 0.301, -5.000, -0.942, 0.563, -0.087, -0.272, -0.164, 0.340, 0.063, -0.392, 0.485, 0.747, 0.703, 0.276, -0.179, 0.225, -0.472, -0.014, -0.403, 0.159, -0.078, -0.857, 0.210, 0.248, -0.294, -0.290, -0.028, 0.095, -0.397, -0.539, 0.271, 0.924, 0.351, 0.771, 0.276, 0.728, 0.945, -0.030, 0.504, 0.630, 0.386, 0.258, 0.467, 0.394, 0.085, 0.237, 0.855, 1.161, 0.767, -5.000, -0.313, -0.048, 0.108, -5.000, -0.057, 0.340, -0.062, -0.142, -0.333, 0.417, 0.707, 0.873, 0.156, 0.927, 0.752, -5.000, -0.665, 0.698, 0.284, 0.200, 0.210, 0.570, 0.371, -0.042, 0.407, 0.781, 0.880, 0.513, 0.186, 0.588, 0.048, 0.050, -0.219, 0.428, 0.149, -0.982, 0.297, 0.458, 0.139, -0.003, 0.399, 0.550, -0.022, -0.107, 0.384, 1.028, 0.532, 0.845, 0.435, 0.822, 0.744, 0.136, 0.079, 0.352, 0.278, 0.074, 0.844, 0.509, -0.101, 0.631, 0.174, 0.556, 0.440, -5.000, -0.741, -0.134, -0.394, -5.000, 0.300, 0.525, -0.069, -0.136, -0.232, 0.260, 0.545, 0.425, 0.136, 0.578, 0.170, -5.000, -0.923, 0.223, -0.286, -0.541, -0.205, 0.142, -0.161, -0.469, 0.273, 0.394, 0.229, -0.038, 0.093, 0.231, -0.473, -0.018, -0.034, -0.048, -0.166, -1.097, 0.256, 0.321, -0.457, -0.205, 0.340, 0.336, -0.456, 0.324, 0.089, 0.608, -0.120, 0.168, -0.157, -0.178, 0.116, -0.974, -0.161, -0.066, -0.149, -0.205, 0.124, 0.020, -0.597, -0.455, 0.088, 0.651, 0.071, -5.000, -1.114, -0.222, -0.683, -5.000, -0.124, 0.245, -0.133, -0.332, -0.746, 0.038, -0.006, 0.016, -0.252, 0.817, 0.017, -5.000, -1.506, 0.017, -0.912, -0.136, -0.292, 0.106, 0.041, -0.409, 0.310, 0.448, 0.416, 0.082, 0.318, 0.355, -0.069, 0.216, 0.132, 0.173, 0.137, -0.578, 0.239, 0.267, -0.278, 0.145, -0.082, 0.306, -0.562, 0.168, -0.109, 0.619, -0.095, 0.070, 0.118, 0.391, 0.443, -0.850, -0.131, 0.169, 0.029, -0.323, 0.018, -0.175, -0.401, -0.408, 0.269, 0.621, 0.022, -5.000, -0.709, -0.353, -0.750, -5.000, -0.587, -0.250, -0.537, -0.417, -0.353, -0.293, -0.076, 0.217, 0.267, 0.760, 0.177, -5.000, -1.002, 0.306, -0.755, 0.069, -0.209, 0.409, 0.284, -0.154, 0.538, 0.563, 0.597, 0.372, 0.049, 0.348, -0.133, 0.243, -0.197, 0.142, 0.091, -1.032, 0.117, 0.307, -0.149, -0.102, 0.192, 0.537, 0.398, -0.082, 0.249, 0.581, 0.047, 0.348, 0.254, 0.513, 0.616, -0.425, 0.166, 0.513, 0.497, 0.176, 0.410, 0.421, 0.503, 0.395, 1.122, 1.262, 0.769, -5.000, -0.439, 0.060, 0.014, -5.000, 0.112, 0.575, 0.091, -0.030, 0.371, 0.656, 0.916, 1.156, 0.324, 0.842, 0.915, -5.000, -0.597, 0.408, 0.085, 0.573, 0.377, 0.676, 0.613, 0.225, 0.943, 0.860, 1.200, 1.022, 0.567, 0.707, 0.220, 0.673, 0.264, 0.492, 0.556, -0.425, 0.709, 0.978, 0.444, 0.594, 0.789, 1.042, 0.826, 0.631, 0.610, 0.932, 0.368, 0.820, 0.518, 0.752, 0.927, 0.024, 0.241, 0.618, 0.260, 0.455, 0.894, 0.766, 0.725, 0.814, 0.107, 0.664, 0.166, -5.000, -1.134, -0.276, -0.947, -5.000, -0.057, 0.177, -0.307, -0.304, -0.326, 0.380, 0.302, 0.632, 0.066, 0.681, -0.004, -5.000, -1.247, 0.118, -0.781, -0.548, -0.210, -0.117, -0.414, -0.914, 0.249, 0.258, 0.344, 0.238, -0.216, 0.167, -0.518, -0.241, -0.097, 0.043, -0.091, -0.958, 0.306, 0.258, -0.256, 0.036, -0.027, 0.123, -0.281, 0.092, -0.138, 0.110, -0.340, -0.143, -0.228, 0.095, 0.056, -0.712, -0.005, 0.094, 0.102, -0.026, 0.220, 0.081, -0.644, -0.441, 0.213, 0.401, -0.072, -5.000, -1.098, -0.590, -1.375, -5.000, -0.756, -0.516, -0.861, -0.595, -0.350, -0.346, -0.331, -0.055, 0.052, 0.590, 0.173, -5.000, -1.207, -0.249, -1.327, -0.216, -0.363, -0.146, -0.350, -0.599, 0.678, 0.488, 0.672, 0.547, 0.684, 0.920, 0.322, 0.367, 0.524, 0.525, 0.609, -0.524, 0.835, 0.947, 0.392, 0.459, 0.556, 0.757, 0.647, 0.480, 0.174, 0.609, -0.170, -0.093, 0.264, 0.433, 0.446, -0.589, 0.392, 0.800, 0.730, 0.225, 0.241, 0.257, -0.170, -0.057, 0.283, 0.531, 0.147, -5.000, -1.248, -0.696, -0.969, -5.000, -0.777, -0.377, -0.023, -0.671, -0.530, -0.364, 0.340, 0.414, -0.254, 0.639, 0.144, -5.000, -0.420, 0.175, -0.638, -0.164, -0.502, -0.213, -0.315, -0.631, 0.517, 0.251, 0.460, 0.163, 0.216, 0.784, 0.209, 0.251, 0.033, 0.516, 0.228, -1.020, 0.253, 0.328, -0.434, -0.328, 0.358, 0.527, 0.543, 0.095, 0.068, 0.267, -0.300, -0.135, 0.224, 0.160, 0.215, -0.932, 0.257, -0.031, 0.406, 0.039, 0.190, -0.174, 0.086, 0.091, 0.851, 1.081, 0.679, -5.000, -0.687, -0.141, -0.119, -5.000, -0.153, 0.466, 0.165, -0.155, 0.075, 0.538, 1.004, 1.113, -0.021, 0.766, 0.511, -5.000, -1.383, -0.063, -0.067, -0.321, 0.232, 0.740, 0.339, 0.106, 0.518, 0.745, 0.839, 0.628, 0.400, 0.655, 0.195, 0.416, 0.221, 0.552, 0.400, -0.559, 0.637, 0.814, 0.216, 0.416, 0.714, 0.967, 0.492, 0.499, 0.543, 0.871, 0.287, 0.695, 0.387, 0.487, 0.733, -0.096, -0.257, 0.044, 0.227, 0.150, 0.811, 0.233, 0.190, 0.754, 0.640, 1.027, 0.496, -5.000, -0.688, 0.029, -0.537, -5.000, 0.046, 0.699, 0.335, -0.119, -0.416, 0.763, 0.774, 0.851, 0.341, 1.156, 0.465, -5.000, -1.060, 0.650, -0.038, -0.094, 0.259, 0.680, 0.049, -0.268, 0.775, 0.944, 0.977, 0.712, 0.431, 0.859, -0.088, 0.201, 0.488, 0.874, 0.602, -0.510, 0.740, 0.916, -0.153, 0.346, 0.809, 0.989, 0.093, 0.872, 0.169, 0.769, -0.039, 0.262, 0.009, 0.548, 0.769, -0.566, 0.529, 0.700, 0.188, 0.284, 0.887, 0.727, -0.578, 0.345, -0.537, -0.069, -0.604, -5.000, -1.605, -0.947, -1.679, -5.000, -1.076, -0.549, -1.250, -1.091, -1.055, -0.585, -0.416, -0.350, -0.793, -0.055, -0.535, -5.000, -1.648, -0.538, -1.375, -0.973, -0.955, -0.309, -1.043, -1.290, -0.002, -0.045, 0.285, -0.011, -0.656, -0.020, -0.721, -0.719, -0.820, -0.180, -0.729, -1.462, -0.215, 0.026, -0.905, -0.709, -0.289, -0.091, -0.242, -0.403, -0.784, -0.143, -0.610, -0.589, -0.764, -0.102, -0.524, -1.179, -0.612, -0.179, -0.561, -0.801, -0.209, -0.482, -0.683, -0.547, -0.166, 0.451, -0.082, -5.000, -1.003, -0.414, -0.822, -5.000, -0.857, -0.313, -0.725, -0.692, -0.693, -0.523, -0.580, -0.004, -0.371, 0.516, 0.202, -5.000, -0.813, 0.589, -0.134, -0.157, 0.036, 0.324, -0.090, -0.341, 0.259, 0.520, 0.588, 0.290, -0.373, 0.164, -0.429, 0.030, -0.402, 0.132, -0.062, -0.937, -0.042, 0.072, -0.487, -0.410, 0.122, 0.457, -0.015, -0.200, 0.089, 0.691, -0.025, 0.404, 0.135, 0.391, 0.445, -0.344, -0.283, -0.114, 0.029, 0.041, 0.319, 0.078, -0.234, 0.101, 0.520, 1.012, 0.483, -5.000, -0.796, -0.226, -0.494, -5.000, -0.578, 0.090, -0.715, -0.644, -0.315, -0.076, 0.084, 0.560, -0.077, 0.821, 0.669, -5.000, -0.985, 0.419, -0.095, -0.249, 0.015, 0.490, 0.071, -0.302, 0.385, 0.545, 0.670, 0.451, -0.234, 0.256, -0.371, -0.245, -0.386, 0.102, 0.103, -1.196, 0.086, 0.509, -0.212, -0.209, 0.348, 0.634, 0.099, -0.036, 0.367, 0.857, 0.293, 0.547, 0.254, 0.639, 0.632, -0.412, -0.077, 0.309, -0.116, 0.009, 0.728, 0.465, -0.246, 0.485, 0.091, 0.589, 0.124, -5.000, -1.246, -0.592, -1.311, -5.000, 0.023, 0.177, -0.576, -0.499, -0.483, 0.102, -0.000, 0.342, -0.298, 0.492, 0.146, -5.000, -1.000, 0.051, -0.453, -0.710, -0.075, -0.072, -0.689, -0.779, 0.041, 0.242, 0.361, 0.185, 0.200, 0.761, 0.080, -0.153, -0.024, 0.400, 0.054, -0.724, 0.134, 0.201, -0.331, -0.330, 0.502, 0.604, 0.166, 0.513, 0.269, 0.648, 0.022, 0.001, -0.432, 0.262, 0.428, -0.533, -0.215, -0.013, -0.024, -0.063, 0.657, 0.376, -0.427, -0.144, -0.101, 0.543, -0.083, -5.000, -1.232, -1.069, -1.157, -5.000, -0.552, -0.438, -0.895, -0.495, -0.795, -0.425, -0.544, -0.127, -0.094, 0.516, 0.247, -5.000, -1.136, -0.433, -1.375, -0.625, -0.348, -0.197, -0.555, -0.830, 0.444, 0.224, 0.591, 0.366, -0.359, 0.517, -0.351, -0.022, -0.367, 0.183, -0.182, -1.121, 0.374, 0.443, -0.290, -0.012, 0.199, 0.575, 0.492, 0.263, -0.463, 0.209, -0.651, -0.353, -0.405, 0.443, 0.155, -0.897, -0.470, -0.121, -0.187, -0.414, 0.018, 0.202, -0.006, -0.207, 0.509, 0.942, 0.460, -5.000, -0.712, 0.019, -0.069, -5.000, -0.279, -0.081, -0.324, -0.279, -0.413, -0.437, -0.193, 0.221, 0.181, 0.903, 0.459, -5.000, -1.028, 0.705, -0.055, -0.037, 0.389, 0.805, 0.258, -0.056, 0.530, 0.806, 0.719, 0.489, 0.030, 0.378, 0.114, 0.015, 0.015, 0.360, 0.298, -0.774, 0.448, 0.550, -0.007, -0.038, 0.345, 0.537, -0.017, -0.195, 0.547, 0.974, 0.442, 0.531, 0.427, 0.765, 0.850, -0.093, 0.440, 0.626, 0.567, 0.320, 0.637, 0.479, 0.232, 0.448, 0.636, 0.959, 0.519, -5.000, -0.817, -0.480, -0.393, -5.000, -0.627, -0.354, -0.850, -0.746, -0.207, 0.019, 0.140, 0.689, 0.022, 0.738, 0.657, -5.000, -0.776, 0.410, 0.029, -0.077, 0.076, 0.454, 0.116, -0.055, 0.322, 0.633, 0.674, 0.404, 0.044, 0.204, -0.369, -0.480, -0.400, 0.228, -0.061, -1.016, 0.213, 0.235, -0.192, -0.145, 0.418, 0.495, -0.348, 0.105, 0.297, 0.753, 0.149, 0.436, 0.215, 0.537, 0.621, -0.233, -0.145, 0.082, -0.103, -0.090, 0.607, 0.216, -0.494, 0.462, 0.079, 0.595, 0.175, -5.000, -0.939, -0.797, -0.680, -5.000, 0.057, 0.139, -0.646, -0.474, -0.391, -0.054, 0.086, 0.277, -0.048, 0.623, 0.100, -5.000, -1.289, -0.093, -0.726, -0.799, -0.259, -0.132, -0.698, -0.660, 0.063, 0.073, 0.080, 0.004, -0.233, 0.152, -0.572, -0.481, -0.348, -0.187, -0.222, -1.191, 0.138, -0.077, -0.823, -0.366, 0.242, 0.255, -0.297, 0.269, 0.053, 0.261, -0.281, -0.164, -0.302, -0.192, 0.053, -0.849, -0.616, -0.397, -0.549, -0.695, 0.058, -0.243, -1.050, -0.344, 0.115, 0.501, 0.127, -5.000, -0.949, -0.317, -0.957, -5.000, 0.011, 0.312, -0.332, -0.228, -0.407, 0.167, -0.032, 0.023, 0.163, 0.815, 0.143, -5.000, -1.343, -0.064, -0.704, -0.224, -0.290, 0.098, -0.106, -0.449, 0.493, 0.410, 0.595, 0.266, 0.235, 0.346, -0.213, -0.042, 0.025, 0.188, 0.237, -0.735, 0.415, 0.473, -0.105, 0.012, -0.085, 0.372, -0.248, 0.167, 0.001, 0.612, -0.048, -0.177, 0.188, 0.516, 0.481, -0.581, -0.098, 0.319, 0.138, -0.243, 0.035, -0.081, -0.482, -0.360 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_14(struct _training *tptr) {
  struct _training tinf = {
    0.324, 11, 4.350, { 2.593, 0.250, 0.157 }, { 0.659, -1.121, -1.911 }, 1, 
    { -0.227, -1.593, -0.349, -0.154, -0.549, -0.250, -0.251, -4.000, 0.190, -0.507, 0.831, -4.000, 0.269, 0.638, -4.000, 1.396, 1.276, 0.569, -4.000, 0.172, 0.114, 1.188, 1.718, -4.000, 1.366, -4.000, 1.055, 1.014 }, 
    {{ 0.062, -0.940, -0.502, 0.348},{ 0.168, -0.652, -0.272, 0.149},{ 0.242, -0.298, -0.429, 0.017},{ 0.317, -0.429, -0.491, -0.020},{ 0.285, -0.307, -0.238, -0.107},{ 0.247, -0.399, -0.491, 0.062},{ 0.232, -0.470, -0.307, 0.044},{ 0.280, -0.380, -0.316, -0.043},{ 0.217, -0.470, -0.255, 0.044},{ 0.282, -0.603, -0.390, 0.044},{ 0.181, -0.272, -0.289, 0.035},{ 0.181, -0.399, -0.214, 0.050},{ 0.199, -0.316, -0.238, 0.011},{ 0.202, -0.198, -0.136, -0.079},{ 0.105, -0.289, -0.167, 0.080},{ 0.251, -0.343, -0.144, -0.086},{ 0.181, -0.122, -0.247, -0.040},{ 0.125, -0.159, -0.093, -0.020},{ 0.152, -0.190, -0.190, 0.002},{ 0.141, -0.122, -0.100, -0.053},{ 0.105, -0.174, -0.078, 0.002},{ 0.176, -0.114, -0.100, -0.100},{ 0.094, -0.167, -0.100, 0.020},{ 0.017, -0.051, -0.057, 0.032},{ 0.053, 0.028, -0.010, -0.066},{ 0.020, -0.004, -0.122, 0.035},{ 0.097, -0.071, -0.057, -0.043},{ 0.088, -0.144, -0.129, 0.029},{ 0.050, -0.044, -0.078, 0.005},{ 0.002, 0.131, -0.114, -0.017},{ 0.065, -0.085, -0.064, 0.002},{ 0.097, -0.247, -0.093, 0.044} }, 
    {{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}} }, 
    0.000, { 0.461, 0.965, 0.463, -5.000, -0.203, 0.506, -0.343, -5.000, 0.325, 0.817, 0.411, 0.048, 0.322, 0.536, 0.027, 0.533, 0.183, 0.998, 0.214, -5.000, -0.835, 0.516, -0.857, 0.162, -0.108, 0.057, 0.351, -0.431, 0.527, 0.204, -0.485, -0.212, -0.156, 0.434, -0.288, -0.589, -0.341, 0.380, -0.455, -1.135, -0.084, 0.296, -0.434, -0.443, -0.092, -0.029, -0.420, -0.413, 0.560, 1.079, 0.386, 0.300, 0.383, 1.029, 0.607, -0.307, 0.693, 1.062, 0.776, 0.298, 0.455, 0.631, 0.571, 0.090, 1.145, 1.443, 1.033, -5.000, 0.646, 1.127, 0.510, -5.000, 0.832, 1.107, 0.855, 0.670, 1.026, 1.121, 0.819, 0.978, 0.598, 0.998, 0.411, -5.000, 0.180, 0.904, -0.303, 0.645, 0.952, 0.566, 0.910, 0.525, 0.949, 0.435, 0.102, 0.154, 0.860, 0.975, 0.480, 0.244, 0.714, 1.253, 0.746, 0.100, 0.431, 0.922, 0.516, 0.385, 0.811, 0.958, 0.527, 0.306, 0.999, 1.340, 0.853, 0.774, 0.927, 1.410, 1.124, 0.414, 0.990, 1.270, 1.225, 0.764, 1.161, 1.202, 1.009, 0.822, 0.740, 1.208, 0.367, -5.000, 0.585, 1.040, -0.582, -5.000, 0.629, 1.104, 0.513, 0.526, 0.438, 0.740, 0.222, 0.668, 0.074, 0.729, 0.234, -5.000, -0.095, 0.676, -1.450, 0.438, 0.333, 0.638, 0.526, -0.290, 0.530, 0.262, -0.213, -0.241, 0.054, 0.487, -0.320, -0.531, -0.047, -0.485, -0.407, -0.773, 0.117, 0.232, -0.958, -0.713, -0.141, -0.424, -1.216, -0.334, 0.407, 0.893, -0.087, -0.025, 0.250, 0.857, 0.335, -0.242, 0.617, 0.819, 0.368, 0.192, 0.415, 0.330, -0.404, -0.133, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.127, 0.472, 0.142, -5.000, -0.523, -0.006, -1.210, -5.000, -0.016, 0.531, -0.261, -0.270, 0.130, 0.396, -0.346, 0.292, -0.485, 0.625, -0.177, -5.000, -0.953, -0.592, -1.482, -0.355, -0.566, -0.501, -0.220, -1.136, 0.150, -0.287, -0.428, -1.022, -0.267, 0.200, -0.024, -0.664, -0.971, 0.143, -0.748, -1.777, -0.549, 0.516, -0.043, -0.587, -0.328, -0.049, -0.737, -1.005, 0.122, 0.744, 0.023, -0.249, -0.236, 0.930, -0.047, -0.824, 0.561, 0.686, 0.276, -0.241, 0.300, 0.609, 0.473, -0.310, 0.871, 1.302, 0.867, -5.000, 0.331, 1.092, 0.344, -5.000, 0.689, 0.792, 0.695, 0.378, 0.827, 0.944, 0.699, 0.660, 0.085, 1.231, -0.144, -5.000, -0.983, 0.616, -1.336, 0.726, 0.573, 0.066, 0.618, 0.464, 1.006, 0.134, 0.153, -0.269, 0.441, 1.115, 0.252, 0.155, 0.519, 1.372, 0.254, -0.076, 0.192, 0.701, 0.643, -0.040, 0.291, 0.798, 0.413, -0.020, -0.001, 0.782, 0.509, -0.181, 0.154, 1.060, 0.371, -0.181, 0.027, 0.465, 0.664, -0.053, 0.381, 0.888, 0.827, 0.182, -0.301, 0.503, -0.470, -5.000, -0.582, 0.589, -0.737, -5.000, -0.300, 0.682, -0.287, -0.467, -0.602, 0.303, -0.404, -0.285, -0.605, 0.381, -0.577, -5.000, -1.566, 0.504, -2.458, -0.282, -0.295, -0.007, 0.277, -0.688, 0.176, -0.411, -0.121, 0.002, -1.334, -0.347, -2.509, -1.759, -0.886, -1.594, -1.786, -1.814, -1.114, -0.870, -1.488, -1.306, -1.306, -0.861, -1.103, -1.822, -0.750, -0.008, -1.074, -1.283, -1.414, 0.383, -0.653, -1.729, -0.037, -0.184, -0.461, -1.136, -0.782, -0.495, -0.477, -0.802, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.336, 0.962, 0.546, -5.000, -0.099, 0.555, -0.811, -5.000, -0.018, 0.429, 0.171, -0.182, 0.184, 0.598, 0.197, 0.480, -0.199, 0.714, -0.340, -5.000, -0.876, 0.372, -2.435, 0.137, -0.095, -0.168, 0.351, 0.021, 0.177, -0.048, -0.220, -0.307, -0.395, 0.356, -0.525, -0.347, -0.647, 0.550, -0.960, -1.328, 0.015, 0.214, -0.304, -0.014, -0.221, 0.021, -0.487, -0.383, 0.365, 0.933, 0.269, 0.117, 0.062, 0.770, 0.169, -0.400, 0.384, 0.602, 0.540, 0.179, 0.205, 0.644, 0.318, -0.141, 0.809, 1.244, 0.717, -5.000, 0.463, 1.114, -0.121, -5.000, 0.487, 0.872, 0.150, -0.108, 0.777, 0.904, 0.509, 0.544, 0.208, 0.955, 0.317, -5.000, -0.478, 0.952, -0.862, 0.665, 0.524, 0.370, 0.277, 0.071, 1.059, 0.299, -0.043, -0.054, 0.247, 0.454, -0.536, -0.272, 0.213, 1.086, 0.771, -1.189, 0.222, 0.557, -0.243, -0.169, 0.481, 0.168, 0.086, -0.337, 0.688, 1.259, 0.427, 0.621, 0.547, 1.179, 0.195, -0.016, 0.553, 0.758, 0.396, 0.104, 0.748, 0.872, 0.770, 0.404, 0.138, 0.552, -0.102, -5.000, 0.098, 0.738, -1.308, -5.000, -0.009, 0.097, 0.024, -0.246, -0.008, 0.081, -0.334, -0.014, -0.218, -0.075, -0.099, -5.000, -1.154, 0.516, -1.375, 0.362, -0.377, 0.293, -0.208, -0.282, 0.133, -0.165, -0.956, -0.197, 0.130, 0.804, -0.433, -0.741, -0.815, -1.532, -1.343, -1.312, 0.195, -0.161, -0.472, -0.628, -0.133, -0.043, -0.907, -0.210, 0.330, 0.888, 0.129, -0.075, -0.018, 0.796, -0.061, -0.349, 0.516, 0.375, 0.583, 0.187, 0.392, 0.423, -0.645, -0.231, 0.062, 0.732, 0.205, -5.000, -0.117, -0.306, -1.600, -5.000, -0.281, 0.099, -0.161, -0.645, -0.233, 0.211, -0.349, -0.009, 0.100, 0.543, 0.192, -5.000, -0.709, -0.052, -1.393, 0.083, -0.656, -0.092, -0.197, -0.503, 0.467, 0.131, -0.354, -0.108, -0.350, 0.279, -0.187, -0.638, -0.203, 0.590, 0.027, -1.027, 0.031, 0.349, -0.534, -0.548, -0.023, 0.100, -0.527, -0.274, 0.033, 0.547, 0.202, -0.119, -0.224, 0.804, 0.223, -0.842, 0.149, 0.257, 0.218, -0.493, 0.173, 0.211, -0.156, -0.338, 0.316, 0.941, 0.260, -5.000, 0.048, 0.535, -0.439, -5.000, 0.093, 0.458, -0.021, -0.235, -0.017, 0.201, -0.417, 0.165, -0.233, 0.720, 0.015, -5.000, -0.649, 0.444, -1.044, -0.065, -0.184, 0.055, -0.017, -0.411, 0.154, 0.042, -0.590, -0.462, -0.289, 0.238, -0.495, -0.705, -0.391, 0.266, -0.337, -0.900, -0.155, -0.340, -0.935, -0.730, -0.547, -0.336, -0.892, -0.803, 0.385, 1.070, 0.054, 0.110, 0.379, 0.935, 0.482, -0.106, 0.554, 0.732, 0.634, 0.163, 0.201, 0.499, 0.094, -0.018, 0.791, 1.169, 0.176, -5.000, 0.695, 0.926, -0.378, -5.000, 0.597, 0.874, -0.009, 0.347, 0.537, 0.662, 0.129, 0.558, 0.021, 0.443, -0.016, -5.000, -0.073, 0.783, -0.615, 0.394, -0.026, 0.130, 0.158, -0.230, 0.601, 0.231, -0.304, -0.110, 0.416, 0.875, 0.019, -0.194, 0.329, 0.818, 0.164, -0.298, 0.199, 0.746, 0.111, 0.208, 0.240, 0.456, -0.650, -0.101, 0.682, 1.119, 0.603, 0.481, 0.594, 1.154, 0.829, 0.068, 0.573, 0.628, 0.605, 0.211, 0.331, 0.624, 0.003, 0.241, 0.214, 0.778, -0.319, -5.000, 0.070, 0.501, -1.065, -5.000, 0.113, 0.184, -0.154, -0.428, -0.224, -0.218, -0.834, -0.112, 0.227, 0.675, 0.057, -5.000, -0.371, 0.604, -1.457, 0.069, -0.027, 0.275, -0.002, -0.348, 0.137, -0.213, -1.193, -0.633, -0.298, -0.118, -1.170, -1.134, -0.010, -0.064, -0.758, -0.974, -0.390, -0.048, -0.672, -0.737, -0.561, -0.759, -1.149, -0.414, 0.275, 0.618, -0.533, -0.243, 0.353, 0.450, -0.406, -0.658, 0.162, -0.050, -0.030, -0.296, -0.067, -0.344, -1.056, -0.549, 0.429, 1.000, 0.400, -5.000, 0.144, 0.537, -0.809, -5.000, 0.378, 0.644, -0.128, -0.164, 0.216, 0.234, -0.535, 0.179, 0.253, 0.935, 0.403, -5.000, -0.021, 0.519, -1.119, 0.222, 0.240, 0.182, 0.126, -0.087, 0.568, 0.268, -0.234, -0.100, 0.244, 0.652, -0.105, -0.450, 0.212, 0.542, -0.403, -0.668, 0.403, 0.481, -0.033, -0.299, 0.094, -0.303, -0.569, 0.109, 0.586, 1.122, 0.358, 0.282, 0.485, 0.846, 0.445, -0.173, 0.689, 0.719, 0.470, -0.019, 0.266, 0.237, -0.249, 0.007, -0.009, 0.779, -0.312, -5.000, -0.503, 0.040, -0.744, -5.000, 0.153, 0.375, 0.037, -0.260, -0.264, 0.067, -0.772, -0.084, -0.800, 0.433, -0.680, -5.000, -1.213, 0.234, -2.487, -0.582, -0.489, -0.022, -0.625, -0.988, -0.277, -0.400, -1.343, -0.998, -0.845, -0.053, -0.680, -0.914, -1.016, -0.126, -0.876, -1.634, -0.884, -0.480, -1.316, -1.104, -0.793, -0.139, -1.044, -1.133, 0.413, 1.076, -0.151, 0.056, 0.203, 1.026, 0.138, -0.488, 0.615, 0.936, 0.808, 0.261, 0.390, 0.747, 0.400, -0.035, 0.936, 1.296, 0.451, -5.000, 0.653, 1.080, -0.108, -5.000, 0.840, 1.096, 0.688, 0.701, 0.835, 0.898, 0.314, 0.759, -0.186, 0.425, -0.234, -5.000, -0.220, 0.469, -1.055, 0.123, 0.101, 0.028, 0.210, -0.270, 0.622, 0.217, -0.449, -0.662, 0.306, 0.983, -0.275, -0.767, 0.483, 1.014, -0.019, -0.227, 0.347, 1.070, 0.699, 0.413, 0.714, 0.681, 0.659, 0.122, 0.858, 1.374, 0.672, 0.578, 0.929, 1.348, 1.008, 0.319, 0.821, 1.217, 0.979, 0.775, 1.061, 1.122, 0.950, 0.693, 0.193, 1.022, -0.069, -5.000, 0.535, 1.044, -1.177, -5.000, 0.318, 0.907, -0.502, 0.283, 0.212, 0.492, -0.637, 0.280, -0.375, 0.752, -0.265, -5.000, -0.576, 0.980, -1.976, 0.100, 0.114, 0.362, -0.052, -0.155, 0.280, 0.222, -0.874, -0.422, -0.505, 0.228, -0.988, -1.243, -0.026, -0.838, -0.849, -1.196, -0.870, 0.407, -0.549, -1.638, 0.034, -1.418, -1.296, -0.737, 0.088, 0.828, -0.418, -0.291, 0.338, 1.039, -0.209, -0.220, 0.581, 0.460, 0.124, -0.041, 0.138, 0.243, -0.613, -0.578, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.733, -0.072, -0.595, -5.000, -1.059, -0.783, -1.250, -5.000, -0.587, 0.198, -0.618, -0.787, -0.561, 0.007, -0.860, -0.312, -1.137, 0.089, -0.994, -5.000, -1.594, -0.623, -1.715, -1.209, -0.700, -0.834, -0.767, -0.931, -0.424, -0.447, -2.036, -1.262, -1.820, -0.286, -0.858, -1.569, -1.278, -1.410, -0.435, -1.840, -1.021, -0.754, -2.049, -2.332, -1.629, -1.166, -1.025, -2.084, -0.711, 0.230, -0.508, -1.123, -0.836, 0.267, -0.115, -0.779, -0.028, 0.239, -0.208, -0.278, -0.332, -0.005, -0.463, -1.001, 0.816, 1.464, 0.603, -5.000, 0.293, 1.092, 0.031, -5.000, 0.879, 1.029, 0.944, 0.316, 0.903, 0.957, 0.657, 0.718, -0.072, 1.085, -0.185, -5.000, -0.108, 0.442, -0.313, 0.504, 0.360, 0.188, 0.804, -0.389, 0.784, 0.050, -0.772, -0.745, 0.370, 0.958, 0.284, -0.099, 0.392, 1.082, 0.280, -0.243, -1.135, 0.473, 0.322, -0.456, 0.600, 0.748, -0.112, 0.057, -0.063, 0.804, 0.096, -0.417, 0.152, 0.864, 0.254, -0.843, -0.322, -0.007, 0.842, -0.737, 0.228, 0.928, 0.847, 0.237, -1.823, -0.307, -1.835, -5.000, -2.540, -0.218, -2.467, -5.000, -1.221, -0.417, -0.302, -1.811, -1.548, -0.782, -0.592, -1.346, -1.230, -0.797, -1.602, -5.000, -1.164, -0.285, -2.637, -1.142, -1.515, -1.093, -0.371, -1.563, -0.724, -0.641, -1.033, -1.138, -1.566, -1.237, -2.251, -2.865, -2.514, -1.761, -1.594, -3.360, -2.798, -2.272, -0.477, -2.272, -2.227, -1.456, -1.673, -3.285, -2.090, -0.817, -2.780, -1.943, -1.942, -0.472, -1.296, -1.729, -1.046, -1.121, -0.767, -1.052, -1.545, -0.737, -0.988, -1.763, 0.368, 0.864, 0.118, -5.000, 0.111, 0.540, -1.086, -5.000, 0.023, 0.248, 0.137, 0.144, -0.448, 0.032, -0.521, 0.354, -0.258, 0.797, 0.111, -5.000, -1.118, 0.076, -2.141, 0.175, -0.828, -0.366, 0.147, -0.223, 0.343, 0.159, -0.197, -0.342, 0.407, 0.968, -0.043, -0.414, 0.193, 1.039, -0.043, -0.767, -0.472, -1.015, -0.309, -1.161, -0.796, -0.783, -0.647, -0.884, 0.477, 0.991, 0.163, -0.040, 0.094, 0.809, 0.153, -0.582, -0.211, 0.212, 0.642, -0.099, 0.164, 0.047, -0.309, -0.124, -0.236, 0.844, -0.313, -5.000, -0.270, 0.676, -0.814, -5.000, 0.046, 0.659, -0.286, 0.013, -0.188, 0.454, -0.043, 0.184, -0.908, 0.351, -0.757, -5.000, -1.499, -0.192, -1.211, -0.126, -0.685, 0.250, 0.453, 0.359, 0.167, -0.343, -0.756, -0.785, -0.279, 0.633, -0.540, -1.195, -0.806, 0.347, -0.719, -0.737, -0.132, -0.080, -0.375, -0.679, -0.529, -0.518, -1.013, -0.603, 0.133, 1.056, 0.162, 0.286, 0.008, 1.111, -0.034, -0.280, 0.434, 0.573, 0.278, 0.227, 0.139, 0.538, 0.023, -0.263, 0.211, 0.899, -0.307, -5.000, 0.289, 0.729, -0.633, -5.000, 0.378, 0.508, -0.631, -0.220, 0.205, 0.300, -0.446, -0.177, -0.947, 0.346, -0.875, -5.000, -1.346, 0.675, -2.360, 0.449, -0.134, -0.781, -0.390, -0.688, 0.435, -0.043, -0.849, -1.031, 0.039, -0.043, -0.610, -0.817, -0.112, 0.724, -0.737, -0.838, -0.261, 0.362, -0.103, -0.257, -0.085, -0.582, -0.202, -0.988, 0.133, 1.014, -0.009, 0.013, 0.492, 1.219, 0.092, -0.187, 0.098, 0.362, 0.396, -0.098, 0.206, 0.403, 0.269, 0.021, 0.283, 0.697, -0.105, -5.000, 0.749, 0.899, -0.449, -5.000, 0.490, 0.505, 0.162, -0.144, 0.169, 0.501, -0.262, 0.139, 0.115, 0.669, 0.138, -5.000, -0.112, 0.376, -1.786, 0.640, 0.346, -0.582, -0.047, 0.080, 0.415, 0.324, -0.589, -0.264, 0.062, 0.767, -0.196, -0.925, -0.036, 0.398, -1.262, -0.744, -0.126, 0.318, -0.495, -0.777, 0.055, 0.182, -1.748, -0.210, 0.508, 1.244, 0.640, -0.043, 0.250, 1.263, 0.398, -0.184, 0.574, 0.377, 0.231, -0.055, 0.426, 0.480, -0.486, -0.250, -0.030, 0.611, -0.005, -5.000, 0.124, 0.288, -2.241, -5.000, -0.353, 0.074, -0.199, -0.411, -0.442, 0.301, -0.799, 0.061, -0.617, 0.443, -0.106, -5.000, -0.427, -0.198, -1.365, 0.378, 0.034, -0.366, -0.069, -0.536, 0.602, -0.033, -1.177, -0.400, -0.820, 0.334, -0.582, -0.870, -0.130, 0.365, -0.767, -1.145, -0.326, 0.100, -0.662, -0.806, -0.229, -0.027, -1.207, -0.628, -0.167, 0.586, -0.112, -0.227, 0.059, 0.765, 0.365, -0.431, 0.068, -0.100, 0.533, -0.354, -0.142, 0.320, -0.500, -0.408, 0.342, 1.081, 0.277, -5.000, 0.390, 0.299, -0.582, -5.000, 0.305, 0.540, 0.217, 0.437, -0.096, 0.368, -0.277, 0.449, -0.275, 0.747, 0.156, -5.000, -1.126, 0.328, -1.508, -0.050, -0.213, 0.446, 0.265, -0.158, 0.283, -0.072, -0.714, -0.356, -0.447, 0.510, -0.418, -0.554, -0.622, 0.439, -0.856, -0.851, -0.137, 0.206, -0.960, -0.590, -0.510, -0.212, -0.928, -0.278, 0.342, 1.018, -0.092, 0.087, 0.411, 1.129, 0.722, -0.006, 0.815, 1.019, 0.816, 0.453, 0.268, 0.563, 0.065, 0.096, 0.275, 0.929, -0.177, -5.000, 0.091, 0.894, -0.688, -5.000, 0.481, 0.639, -0.267, -0.032, 0.226, 0.497, -0.262, 0.296, -0.825, 0.493, -0.740, -5.000, -0.126, -0.013, -2.068, -0.085, -0.784, -0.852, -0.488, -0.751, 0.218, 0.046, -0.518, -0.444, 0.245, 0.646, -0.449, -0.898, -0.056, 0.161, -0.322, -0.418, -0.080, 0.209, -0.259, -0.224, -0.129, -0.185, -1.029, -0.798, 0.102, 0.965, -0.255, -0.071, 0.143, 0.664, 0.271, -0.343, 0.462, -0.034, 0.366, -0.213, -0.162, 0.198, -0.275, -0.202, -0.198, 0.557, -0.377, -5.000, -0.604, 0.528, -0.329, -5.000, -0.336, 0.054, -0.112, -0.477, -0.351, -0.070, -0.719, -0.086, -0.253, 0.446, -0.884, -5.000, -0.590, 0.540, -0.850, -0.322, -0.704, 0.376, 0.148, -0.240, 0.012, -0.572, -1.173, -1.074, -0.921, -0.743, -1.482, -1.907, -1.093, -0.525, -1.243, -1.241, -1.093, -0.769, -1.571, -1.333, -0.936, -1.510, -1.641, -0.928, -0.250, 0.180, -1.250, -0.941, -0.601, 0.305, -0.505, -0.887, -0.309, -0.281, -0.147, -0.400, -0.593, -0.855, -1.040, -0.870, -0.439, 0.439, -0.613, -5.000, -0.208, -0.198, -1.245, -5.000, -0.210, 0.061, -0.408, -0.465, -0.399, -0.389, -1.179, -0.280, -0.866, 0.304, -0.600, -5.000, -0.646, 0.155, -2.346, -0.561, -0.588, -0.546, -0.554, -0.160, -0.107, -0.489, -2.062, -0.402, -1.033, -0.375, -1.544, -1.409, -1.243, -0.514, -1.280, -1.787, -1.291, -0.566, -1.026, -1.213, -1.302, -1.245, -1.457, -1.150, -0.294, 0.410, -0.500, -0.709, -0.390, -0.001, -0.267, -0.901, -0.161, 0.226, -0.121, -0.660, -0.703, -0.544, -1.306, -1.004, 0.092, 0.656, -0.091, -5.000, -0.612, 0.052, -0.798, -5.000, -0.177, 0.179, 0.062, -0.344, -0.213, 0.253, -0.355, 0.217, -0.679, 0.471, -0.532, -5.000, -1.302, -0.122, -3.371, -0.476, -0.662, -0.414, -0.468, -0.328, 0.114, -0.454, -1.515, -0.868, -0.551, 0.171, -0.629, -0.939, -0.851, -0.434, -0.142, -1.488, -0.361, -0.014, -1.735, -0.904, -0.636, -0.501, -1.090, -0.855, 0.182, 0.711, -0.248, -0.124, -0.190, 0.538, 0.042, -0.715, 0.351, 0.612, 0.596, -0.159, 0.213, 0.501, 0.171, -0.138, 0.947, 1.172, 0.319, -5.000, 0.530, 1.127, -0.279, -5.000, 0.666, 0.822, -0.090, 0.347, 0.823, 0.591, 0.382, 0.741, -0.366, 0.319, -0.241, -5.000, -0.797, 0.615, -1.042, -0.112, 0.031, -0.055, 0.202, -0.242, 0.678, -0.607, -0.118, -0.647, 0.595, 0.691, -0.185, -0.625, 0.260, 0.917, -0.072, -0.777, -0.287, -0.016, 0.237, -0.268, 0.258, 0.585, -0.508, -0.123, 0.415, 0.715, 0.400, 0.295, 0.512, 1.117, 0.804, -0.070, 0.662, 0.954, 0.798, 0.461, 0.619, 1.044, 0.514, 0.526, -0.054, 0.388, -0.489, -5.000, -0.204, 0.804, -1.063, -5.000, -0.005, 0.321, 0.075, 0.038, -0.389, -0.116, -0.729, 0.002, -0.909, -0.187, -1.185, -5.000, -1.994, -5.000, -2.144, -1.130, -0.495, 0.153, -0.206, -0.123, -0.320, -0.359, -0.891, -0.785, -0.657, -0.001, -1.312, -1.522, -0.529, -0.249, -1.296, -0.969, -0.462, 0.024, -0.931, -0.931, -0.703, -0.076, -1.082, -0.566, -0.179, 0.232, -0.640, -0.595, -0.251, 0.491, -0.055, -0.314, -0.101, 0.120, 0.092, -0.162, -0.194, 0.293, -1.217, -0.538, -0.537, -0.083, -0.834, -5.000, -0.919, -0.026, -2.043, -5.000, -1.042, -0.629, -1.338, -0.778, -0.940, -0.683, -0.963, -0.383, -1.366, -0.365, -1.436, -5.000, -2.602, -0.582, -2.279, -0.816, -0.920, -0.668, -1.312, -0.846, -0.446, -0.858, -1.233, -0.806, -0.922, -0.522, -1.605, -1.399, -0.650, -0.607, -1.779, -2.402, -1.149, -0.756, -1.479, -1.391, -1.593, -1.058, -1.465, -1.461, -0.411, 0.193, -0.716, -0.884, -0.784, 0.254, -0.912, -1.172, -0.177, 0.050, 0.067, -0.220, -0.501, -0.645, -0.790, -0.807, -0.298, 0.535, -0.238, -5.000, -0.882, 0.072, -1.177, -5.000, -0.484, 0.205, -0.161, -0.269, -0.357, 0.036, -0.452, 0.224, -1.042, -0.070, -0.568, -5.000, -1.458, -0.094, -1.874, -0.950, -0.841, -0.449, -1.276, -0.772, 0.075, -0.630, -1.348, -1.109, -0.707, 0.068, -0.300, -0.945, -0.824, -0.171, -0.017, -1.674, -0.300, -0.054, -0.883, -0.779, -0.582, -0.534, -1.540, -1.423, -0.052, 0.654, -0.165, -0.493, 0.077, 0.632, 0.017, -0.553, 0.446, 0.495, 0.288, -0.098, 0.191, 0.493, 0.436, -0.620, 0.784, 1.110, 0.511, -5.000, 0.221, 0.639, 0.161, -5.000, 0.630, 0.960, 0.776, 0.558, 0.802, 0.897, 0.713, 0.850, -0.027, 0.655, -0.075, -5.000, -3.173, 0.548, -1.081, 0.111, 0.254, 0.330, 0.724, 0.160, 0.685, 0.191, -1.059, -0.843, 0.662, 1.241, 0.751, 0.188, 0.770, 1.209, 0.111, -0.323, -0.061, 0.661, 0.530, -0.221, 0.336, 0.869, 0.242, 0.120, -0.039, 0.362, -0.144, -0.206, 0.129, 1.076, 0.114, -0.221, -0.177, 0.015, 0.855, -0.246, -0.036, 0.430, 0.971, 0.131, -0.083, 0.637, -0.011, -5.000, 0.019, 0.626, -0.772, -5.000, -0.007, 0.462, 0.270, -0.285, -0.425, -0.049, -0.387, -0.258, -0.214, 0.750, 0.153, -5.000, -1.594, 1.283, -5.000, -1.316, -0.043, 0.111, -1.093, -0.007, -0.719, -0.134, -1.142, -0.748, -1.346, -0.832, -1.594, -1.958, -1.146, -5.000, -1.106, -2.292, -1.019, -0.458, -0.495, -0.197, -1.461, -1.847, -0.567, -0.950, -0.635, 0.549, -0.426, -0.939, -0.682, 0.603, 0.250, -1.015, -0.269, 0.166, 0.054, -0.243, -0.878, -0.974, -0.431, -0.608, -1.006, -0.368, -0.685, -5.000, -1.071, -1.034, -2.123, -5.000, -1.243, -0.575, -0.733, -0.799, -0.860, -0.840, -1.350, -0.768, -1.689, -0.516, -0.884, -5.000, -2.144, -1.255, -2.060, -1.262, -2.292, -0.636, -0.822, -1.012, -0.628, -0.979, -1.258, -1.097, -1.390, -0.737, -1.956, -2.083, -1.333, -0.618, -1.134, -1.687, -1.733, -0.917, -1.456, -1.236, -1.587, -1.799, -1.433, -1.705, -0.856, -0.424, -0.514, -1.374, -1.417, -0.213, -1.072, -1.186, -1.246, -0.799, -0.999, -1.637, -1.027, -0.748, -0.926, -1.425, 0.220, 0.621, 0.124, -5.000, -0.406, 0.341, -1.087, -5.000, -0.003, 0.582, 0.270, -0.291, -0.063, 0.474, 0.198, 0.364, -0.651, 0.293, -1.142, -5.000, -2.196, -0.582, -2.608, -1.042, -0.415, -0.090, 0.038, -0.870, 0.356, -0.137, -1.142, -0.495, -0.592, -0.043, -0.468, -1.344, -0.516, 0.087, -0.613, -1.975, -0.304, -0.177, -1.173, -0.877, -0.959, -0.357, -1.386, -1.335, 0.022, 0.437, -0.439, -0.362, -0.353, 0.546, -0.826, -1.140, 0.164, 0.339, 0.449, 0.070, 0.150, 0.340, 0.165, -0.146, 0.479, 1.051, 0.094, -5.000, 0.224, 1.015, 0.120, -5.000, 0.254, 0.397, -0.591, -0.043, 0.417, 0.440, 0.083, 0.442, 0.332, 0.750, 0.198, -5.000, -1.189, 0.603, -0.295, 0.414, 0.576, 0.475, 0.031, 0.352, 0.622, 0.087, 0.414, -0.380, -0.217, 0.228, -0.245, -0.612, -0.079, -0.400, 0.436, -0.249, -1.217, -0.370, -1.221, -1.563, -0.430, -0.806, -0.213, -0.813, 0.425, 0.986, 0.387, 0.149, 0.350, 1.186, 0.101, -0.034, 0.429, 0.695, 0.382, 0.178, 0.573, 0.739, 0.688, 0.414, -0.410, 0.160, -0.251, -5.000, 0.127, 0.148, -5.000, -5.000, -0.034, -0.002, -0.160, -0.395, -0.229, -0.177, -0.425, 0.105, -0.953, -1.189, -0.729, -5.000, -0.375, 0.111, -5.000, 0.160, -0.557, -0.662, -0.475, -1.393, -0.192, -0.449, -1.823, -0.970, -0.405, 0.352, -0.662, -1.009, -0.645, -1.142, -0.195, -1.217, -0.355, -0.599, -2.256, -0.458, -0.759, -1.465, -0.592, -0.960, 0.021, 0.417, -0.365, -0.573, -0.132, 0.670, -0.480, -1.049, 0.017, 0.243, 0.131, -0.081, -0.555, -0.458, -0.694, -0.776, -0.277, 0.283, -0.046, -5.000, -0.678, -0.214, -2.708, -5.000, -0.540, -0.495, -1.276, -0.806, -0.619, 0.065, -0.331, -0.154, -1.393, 0.026, -0.261, -5.000, -1.356, -0.257, -3.290, -1.134, -0.765, -0.942, -0.218, -0.797, -0.133, -0.722, -1.458, -0.798, -0.878, -0.595, -1.442, -1.908, -0.797, -0.238, -0.619, -2.039, -0.931, -0.386, -1.681, -1.251, -1.079, -1.488, -1.459, -1.326, -0.274, 0.064, -0.280, -0.650, -0.802, 0.216, -0.271, -1.270, -0.023, -0.159, 0.099, -0.462, -0.241, 0.076, -0.312, -0.644, -0.043, 0.618, -0.014, -5.000, -0.479, 0.274, -0.287, -5.000, -0.217, 0.122, -0.495, -0.295, -0.283, 0.101, -0.073, 0.240, -0.711, 0.493, -0.331, -5.000, -1.393, 0.129, -1.453, -0.775, -0.572, -0.342, -0.318, -0.811, 0.132, -0.238, -0.972, -0.926, -0.662, -0.146, -1.168, -1.199, -1.114, -0.554, -0.955, -1.733, -0.822, -0.582, -1.059, -1.569, -0.935, -0.403, -1.334, -1.182, 0.123, 0.570, -0.249, -0.485, -0.611, 0.405, -0.192, -0.802, 0.103, 0.317, 0.477, -0.289, -0.144, 0.100, -0.368, -0.402, 0.366, 0.621, -0.202, -5.000, -0.024, 0.601, -0.359, -5.000, 0.161, 0.453, -0.449, -0.312, 0.350, 0.609, 0.104, 0.523, -0.632, 0.311, -0.944, -5.000, -1.015, -0.090, -1.430, -0.672, -0.777, -0.362, -0.244, -0.774, 0.146, 0.394, -1.786, -0.861, -0.426, 0.061, -0.938, -0.988, -0.343, 0.383, -0.960, -1.264, -0.938, -0.684, -0.295, -1.015, -0.686, -0.775, -0.898, -0.685, 0.211, 0.491, -0.068, -0.092, 0.129, 0.384, -0.794, -0.308, -0.037, -0.169, 0.407, -0.275, -0.045, 0.111, -0.385, -0.119, -0.249, 0.548, -0.631, -5.000, -0.698, 0.496, -1.195, -5.000, -0.134, 0.556, -0.426, -0.254, -0.253, -0.206, -0.782, -0.019, -0.725, -0.363, -0.843, -5.000, -1.267, 0.316, -2.339, -0.565, -0.359, 0.344, -0.560, -0.772, -0.234, -0.726, -0.967, -0.983, -0.728, -0.340, -1.704, -1.503, -1.030, -0.349, -1.479, -2.726, -0.651, -0.954, -1.093, -1.367, -1.520, -1.024, -1.233, -0.924, -0.452, 0.118, -0.692, -1.034, -0.202, 0.475, -1.259, -0.896, -0.458, -0.421, -0.254, -0.727, -0.895, -0.936, -1.321, -1.250, -0.258, 0.382, -0.102, -5.000, -0.456, -0.058, -1.574, -5.000, -0.170, -0.073, -1.063, -0.155, -0.554, 0.079, -0.738, -0.120, -0.740, -0.027, -0.582, -5.000, -1.255, -0.112, -1.323, -0.349, -1.269, -0.706, -0.364, -0.431, -0.186, -0.218, -1.233, -1.034, -0.940, -0.155, -1.904, -1.779, -0.983, -0.352, -1.093, -1.911, -1.689, -1.345, -1.607, -1.699, -1.406, -1.320, -1.983, -1.499, -0.327, 0.308, -0.516, -0.791, -0.557, 0.187, -0.337, -0.970, -0.219, -0.334, 0.179, -0.526, -0.752, -0.447, -0.746, -0.836, 0.384, 0.983, 0.396, -5.000, -0.428, 0.275, -0.548, -5.000, 0.322, 0.694, 0.459, 0.119, 0.225, 0.362, -0.031, 0.410, 0.045, 0.856, 0.378, -5.000, -0.702, 0.359, -1.608, 0.198, 0.022, 0.281, 0.384, 0.099, 0.605, 0.283, -0.592, -0.165, -0.103, 0.500, -0.047, -0.399, -0.428, 0.097, -0.083, -1.105, 0.230, 0.213, -0.082, -0.304, -0.137, -0.122, -0.412, -0.580, 0.580, 0.902, 0.370, 0.279, 0.319, 0.808, 0.459, -0.270, 0.667, 0.862, 0.943, 0.351, 0.418, 0.653, 0.611, 0.099, 1.139, 1.389, 0.976, -5.000, 0.519, 1.118, 0.390, -5.000, 0.779, 1.143, 0.784, 0.590, 1.037, 1.102, 0.747, 1.029, 0.639, 1.083, 0.361, -5.000, 0.171, 0.813, -0.601, 0.721, 0.865, 0.830, 0.616, 0.571, 0.991, 0.624, 0.123, 0.090, 0.847, 1.106, 0.266, 0.363, 0.733, 1.166, 0.251, -0.018, 0.523, 1.179, 0.583, 0.571, 0.814, 0.821, 0.484, 0.472, 0.941, 1.309, 0.863, 0.728, 0.899, 1.338, 1.034, 0.472, 0.932, 1.044, 1.171, 0.743, 1.028, 1.121, 0.965, 0.741, 0.397, 0.922, -0.037, -5.000, 0.106, 0.896, -1.090, -5.000, 0.380, 0.973, 0.095, 0.370, 0.076, 0.592, -0.175, 0.378, -0.071, 0.709, 0.002, -5.000, -0.540, 0.736, -1.629, 0.233, 0.347, 0.668, 0.503, -0.020, 0.312, 0.206, -0.344, -0.159, -0.017, 0.316, -0.276, -0.672, -0.064, -0.400, -0.582, -1.046, -0.174, -0.157, -0.796, -0.905, -0.355, -0.505, -0.934, -0.453, 0.097, 0.816, -0.048, -0.272, 0.101, 0.929, -0.008, -0.146, 0.433, 0.683, 0.419, 0.122, 0.136, 0.177, -0.475, -0.384, 0.200, 0.824, 0.058, -5.000, -0.310, 0.328, -1.113, -5.000, -0.165, 0.171, -0.370, -0.104, -0.082, 0.185, -0.539, 0.033, -0.339, 0.446, -0.134, -5.000, -1.204, 0.090, -1.578, 0.131, -0.662, -0.117, -0.287, -0.633, 0.506, -0.188, -0.677, -0.510, -0.357, 0.301, -0.716, -1.242, -0.217, 0.387, -0.681, -1.202, -0.395, -0.078, -0.626, -0.743, -0.759, -0.546, -1.050, -0.814, 0.073, 0.754, -0.172, -0.507, -0.095, 0.789, -0.003, -0.413, 0.474, 0.694, 0.667, 0.168, -0.079, 0.224, -0.474, -0.459, 0.062, 0.686, 0.371, -5.000, -0.480, 0.367, -0.542, -5.000, 0.363, 0.612, 0.033, -0.014, 0.068, 0.407, 0.046, 0.538, -0.266, 0.742, -0.400, -5.000, -1.051, -0.144, -2.021, -0.006, 0.043, 0.187, 0.196, -0.382, 0.583, 0.380, -0.554, -0.285, -0.128, 0.411, -0.288, -0.455, -0.498, 0.378, -0.253, -1.233, -0.477, 0.228, -0.792, -0.260, -0.201, 0.192, -0.329, -0.549, 0.290, 1.024, 0.055, -0.071, 0.310, 0.867, 0.335, -0.275, 0.646, 0.848, 0.595, 0.018, 0.346, 0.551, 0.537, -0.142, 0.989, 1.325, 1.156, -5.000, 0.529, 0.935, 0.885, -5.000, 1.099, 1.252, 1.186, 0.768, 1.082, 1.095, 0.758, 0.952, 0.134, 1.089, 0.206, -5.000, -0.430, 0.504, -0.413, 0.483, 0.716, 0.796, 0.986, 0.677, 1.056, 0.473, 0.228, -0.197, 1.152, 1.433, 1.000, 0.925, 1.009, 1.542, 1.047, 0.345, 0.695, 1.168, 1.046, 0.490, 0.870, 1.285, 1.041, 0.813, 0.394, 0.944, 0.714, 0.335, 0.525, 1.184, 0.609, 0.060, 0.622, 0.784, 1.033, 0.704, 0.408, 0.830, 1.100, 0.476, 0.606, 1.144, 0.693, -5.000, 0.373, 1.107, -0.238, -5.000, 0.573, 1.064, 0.502, 0.046, 0.480, 0.724, 0.143, 0.442, 0.378, 1.020, 0.824, -5.000, -0.225, 0.854, -2.312, 0.721, -0.177, 0.873, 0.500, 0.293, 0.953, 0.733, 0.342, 0.265, -0.347, -0.048, -1.438, -1.139, -0.405, -0.380, -0.828, -1.555, -0.090, 0.203, -0.509, -0.825, -0.821, -0.421, -0.998, -0.835, 0.353, 0.885, 0.464, -0.050, 0.258, 0.971, 0.819, -0.095, 0.323, 0.894, 0.804, 0.289, 0.473, 0.372, 0.427, -0.108, -0.370, 0.442, -0.229, -5.000, -0.792, 0.132, -0.852, -5.000, -0.544, 0.181, -0.415, -0.623, -0.233, 0.162, -0.448, -0.141, -0.585, -0.054, -0.017, -5.000, -1.075, -0.025, -2.018, -0.351, -1.064, -0.988, -0.075, -1.099, 0.398, 0.452, -0.623, -0.449, -0.528, -0.244, -1.465, -1.434, -0.589, 0.091, -0.721, -0.977, -0.980, -0.256, -1.340, -1.242, -0.634, -0.838, -0.644, -0.960, -0.228, 0.445, -0.229, -0.487, -0.163, 0.260, -0.598, -0.906, -0.458, 0.129, -0.192, -0.762, -0.272, -0.035, -0.657, -0.784, 0.463, 0.945, 0.618, -5.000, 0.134, 0.645, -0.709, -5.000, 0.287, 0.681, 0.172, -0.017, 0.316, 0.686, 0.326, 0.484, 0.217, 0.897, 0.471, -5.000, -0.326, 0.031, -2.192, 0.141, 0.335, 0.389, 0.578, 0.251, 0.891, 0.533, -0.080, -0.111, 0.058, 0.840, 0.143, -0.110, -0.552, 0.620, 0.277, -1.072, 0.290, 0.407, -0.072, -0.465, 0.098, 0.373, -0.108, -0.395, 0.584, 1.062, 0.430, 0.189, 0.420, 1.082, 0.573, -0.086, 0.749, 0.633, 0.727, 0.341, 0.478, 0.650, 0.546, 0.189, 0.722, 1.164, 0.519, -5.000, 0.356, 1.075, 0.052, -5.000, 0.485, 0.880, 0.242, 0.208, 0.644, 0.716, 0.161, 0.453, 0.249, 1.078, 0.427, -5.000, -0.407, 0.868, -1.240, 0.284, 0.432, 0.593, 0.365, -0.059, 0.797, 0.424, 0.276, -0.126, 0.373, 0.595, 0.078, -0.124, -0.177, 0.327, 0.293, -1.173, -0.070, 0.642, -0.052, -0.150, 0.393, 0.373, 0.432, -0.003, 0.795, 1.171, 0.885, 0.683, 0.569, 1.177, 0.595, 0.352, 0.815, 0.804, 0.508, 0.332, 0.724, 0.821, 0.789, 0.487, 0.610, 0.961, 0.627, -5.000, 0.523, 0.996, -0.186, -5.000, 0.656, 0.616, 0.309, 0.187, 0.489, 0.799, 0.306, 0.678, 0.370, 1.084, 0.609, -5.000, -0.238, 0.779, -0.806, 0.986, 0.483, 0.804, 0.205, 0.156, 0.751, 0.910, -0.001, 0.144, 0.725, 1.336, 0.375, -0.197, 0.254, 0.198, 0.312, -0.846, 0.652, 0.411, 0.017, -0.123, 0.507, 0.525, -0.163, 0.036, 0.727, 1.320, 0.796, 0.493, 0.436, 1.091, 0.735, 0.174, 0.755, 0.786, 0.686, 0.312, 0.514, 0.694, 0.214, 0.250, 0.232, 0.600, 0.293, -5.000, -0.134, -0.208, -1.142, -5.000, -0.287, 0.081, -0.088, -0.417, -0.115, 0.265, -0.189, 0.295, 0.100, 0.784, 0.516, -5.000, -0.849, -0.279, -1.316, 0.321, -0.076, 0.070, 0.117, -0.400, 0.706, 0.083, -0.381, -0.167, -0.302, 0.582, 0.120, -0.611, -0.350, 0.403, -0.324, -1.252, 0.111, 0.027, -0.472, -0.804, -0.117, -0.395, -0.553, -0.418, 0.047, 0.645, 0.070, -0.185, 0.044, 0.739, 0.117, -0.680, 0.368, 0.322, 0.445, -0.350, 0.104, 0.214, -0.057, -0.353, 0.286, 0.878, 0.392, -5.000, -0.307, 0.465, -0.319, -5.000, 0.177, 0.583, -0.201, -0.083, 0.023, 0.329, -0.108, 0.369, -0.116, 0.658, 0.252, -5.000, -0.936, 0.630, -1.085, -0.114, 0.095, 0.403, 0.367, 0.124, 0.380, 0.183, -0.471, -0.269, -0.529, 0.057, -0.466, -0.966, -0.661, 0.118, -0.403, -1.166, -0.453, 0.039, -1.074, -0.757, -0.532, -0.178, -0.512, -0.681, 0.378, 0.854, 0.054, -0.097, 0.068, 0.889, 0.497, -0.288, 0.656, 0.787, 0.745, 0.222, 0.226, 0.504, 0.261, 0.043, 0.668, 0.916, 0.332, -5.000, 0.140, 0.630, -0.214, -5.000, 0.343, 0.769, 0.106, 0.175, 0.565, 0.683, 0.133, 0.645, 0.044, 0.648, 0.205, -5.000, -0.428, 0.658, -0.854, 0.408, 0.379, 0.359, 0.234, 0.192, 0.463, 0.351, -0.029, -0.154, 0.353, 0.635, -0.249, -0.683, 0.201, 0.761, -0.549, -0.618, -0.037, 0.607, 0.341, -0.079, 0.101, -0.147, -0.308, -0.255, 0.639, 1.048, 0.496, 0.237, 0.550, 1.101, 0.733, -0.108, 0.539, 0.604, 0.542, 0.069, 0.327, 0.368, 0.263, 0.210, 0.385, 1.022, 0.079, -5.000, 0.372, 1.105, -0.292, -5.000, 0.494, 1.005, -0.023, 0.100, 0.365, 0.594, -0.153, 0.282, 0.177, 0.802, 0.156, -5.000, -0.117, 1.142, -1.147, 0.495, 0.407, 0.479, 0.415, 0.255, 0.432, 0.279, -0.444, -0.170, -0.102, 0.327, -1.136, -1.222, 0.026, 0.378, -0.177, -0.857, -0.084, 0.449, -0.640, -0.631, -0.504, -0.605, -0.706, -0.870, 0.097, 0.763, -0.449, -0.355, 0.259, 0.917, 0.054, -0.371, 0.340, 0.600, 0.231, 0.013, -0.365, -0.205, -0.819, -0.769, 0.094, 0.754, 0.098, -5.000, -0.379, 0.351, -1.069, -5.000, -0.092, 0.209, -0.532, -0.351, -0.257, 0.299, -0.580, 0.037, -0.148, 0.720, 0.236, -5.000, -0.628, 0.672, -1.837, 0.118, -0.222, 0.165, 0.287, -0.162, 0.338, 0.215, -0.795, -0.473, -0.421, 0.147, -0.744, -1.044, -0.270, 0.392, -0.413, -1.276, -0.551, -0.282, -0.579, -0.962, -0.793, -0.536, -1.130, -0.887, 0.015, 0.623, -0.092, -0.420, -0.006, 0.552, -0.093, -0.702, 0.211, 0.287, 0.422, -0.274, -0.227, -0.082, -0.558, -0.401 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_15(struct _training *tptr) {
  struct _training tinf = {
    0.350, 11, 4.350, { 2.706, 0.152, 0.142 }, { 0.797, -1.140, -2.213 }, 0, 
    { 0.157, -0.678, -1.183, -0.864, 0.101, 0.057, -0.901, -4.000, -4.000, -1.063, -1.113, -4.000, -2.291, -1.040, -4.000, 0.666, 0.590, -0.420, -4.000, -0.310, -0.665, -4.000, -1.801, -4.000, 1.569, -4.000, -4.000, 0.036 }, 
    {{ -0.594, -1.271, -0.026, 0.615},{ 0.085, -0.297, 0.056, 0.019},{ 0.162, -0.632, -0.073, 0.109},{ 0.184, -0.502, -0.221, 0.111},{ 0.285, -0.670, -0.133, 0.001},{ 0.173, -0.651, -0.122, 0.123},{ 0.111, -0.359, -0.041, 0.065},{ 0.178, -0.519, -0.073, 0.060},{ 0.137, -0.291, -0.252, 0.104},{ 0.111, -0.478, -0.144, 0.148},{ 0.102, -0.203, 0.033, -0.026},{ 0.144, -0.380, -0.185, 0.102},{ 0.106, -0.352, -0.455, 0.219},{ 0.240, -0.502, -0.110, -0.002},{ 0.116, -0.380, -0.133, 0.109},{ 0.111, -0.373, -0.297, 0.173},{ 0.171, -0.366, -0.100, 0.029},{ 0.032, -0.203, -0.317, 0.193},{ 0.144, -0.191, -0.478, 0.135},{ 0.089, -0.122, -0.246, 0.082},{ 0.050, -0.203, -0.432, 0.213},{ 0.139, -0.227, -0.144, 0.032},{ 0.128, -0.221, -0.297, 0.104},{ 0.219, -0.265, -0.317, 0.027},{ 0.135, -0.239, -0.185, 0.060},{ -0.034, 0.018, -0.387, 0.180},{ 0.089, -0.031, -0.278, 0.052},{ 0.175, -0.227, -0.324, 0.065},{ 0.065, -0.246, -0.167, 0.125},{ 0.070, -0.317, -0.127, 0.130},{ 0.085, -0.138, -0.221, 0.085},{ 0.132, -0.057, -0.304, 0.029} }, 
    {{{ -4.000, -4.000, -4.000, 0.126, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -0.416, -4.000, -4.000, 0.425, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, 1.396, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -0.101, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, 0.434, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { 0.851, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { 0.588, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, 0.195, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ 0.166, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 1.150, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, 0.997, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 0.787, -4.000, -4.000, 1.281, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { 1.005, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 1.841, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, 0.088, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -0.402, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 1.503, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ 0.572, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { 1.889, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, 1.286, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}} }, 
    -1.119, { 0.483, 1.090, 0.688, -5.000, -0.077, 0.744, 0.455, -5.000, 0.214, 0.614, -0.147, -0.182, 0.218, 0.612, 0.144, 0.395, 0.188, 0.905, 0.219, -5.000, -0.336, 0.553, 0.087, 0.197, -0.372, 0.335, -0.069, -0.696, 0.386, 0.200, -0.384, -0.123, 0.079, 0.833, -0.315, -0.255, -0.197, 0.558, 0.289, -1.108, 0.189, 0.608, 0.030, -0.187, 0.111, 0.290, 0.179, -0.347, 0.477, 1.079, 0.398, 0.250, 0.291, 0.849, 0.978, -0.607, 0.548, 0.966, 0.858, 0.196, 0.584, 0.528, 0.546, 0.275, 1.096, 1.439, 1.283, -5.000, 0.654, 1.341, 1.122, -5.000, 1.037, 1.379, 1.051, 0.738, 1.103, 1.308, 0.995, 1.237, 0.495, 1.237, 0.668, -5.000, 0.139, 0.777, 0.574, 0.609, 0.653, 0.981, 0.136, 0.287, 0.711, 0.696, 0.081, 0.338, 0.764, 1.400, 0.798, 0.415, 0.608, 1.116, 0.850, -0.323, 0.783, 1.195, 0.697, 0.280, 0.502, 0.761, 0.120, 0.264, 1.065, 1.516, 0.861, 0.963, 1.019, 1.213, 1.144, 0.513, 0.969, 1.180, 1.023, 0.660, 1.016, 0.825, 0.564, 0.867, 0.691, 1.299, 0.997, -5.000, 0.221, 1.149, 0.393, -5.000, 0.934, 1.407, 0.745, 0.488, 0.706, 0.952, 0.423, 0.912, 0.557, 1.196, 0.813, -5.000, -0.206, 0.810, 0.220, 0.202, 0.714, 0.849, 0.441, 0.283, 0.618, 0.623, 0.134, 0.468, 0.594, 1.022, 0.482, 0.186, 0.295, 0.616, 0.452, -0.544, 0.426, 0.680, 0.072, -0.231, 0.310, 0.226, -0.258, 0.039, 0.652, 1.002, 0.305, 0.394, 0.441, 0.542, 0.552, -0.347, 0.559, 0.800, 0.871, 0.465, 0.694, 0.378, 0.236, 0.303, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.136, 0.587, 0.108, -5.000, -0.631, 0.172, -0.162, -5.000, -0.563, 0.018, -0.651, -0.560, -0.052, 0.354, -0.003, 0.282, -0.310, 0.211, -0.479, -5.000, -1.049, -0.073, -0.591, -0.706, -1.064, -0.352, -0.989, -0.892, -0.146, -0.208, -0.954, -0.157, -0.307, 0.254, -0.560, -0.967, -1.053, -0.015, -0.368, -1.887, -0.580, -0.022, -0.437, -1.417, -0.502, -0.592, -0.522, -0.750, -0.221, 0.548, -0.244, -0.344, -0.578, 0.219, 0.430, -1.314, 0.030, 0.576, 0.261, -0.182, 0.014, -0.009, -0.054, -0.208, 0.928, 1.359, 1.248, -5.000, 0.185, 1.241, 0.389, -5.000, 0.658, 0.946, 0.734, 0.412, 0.936, 1.020, 1.019, 1.071, 0.557, 0.984, 0.832, -5.000, -0.101, 0.795, 0.157, 0.741, 0.451, 0.662, 0.334, -0.022, 0.592, 0.542, 0.041, 0.096, 0.314, 0.800, 0.499, -0.143, -0.079, 1.260, 0.028, -0.762, 0.535, 0.305, 0.172, -0.068, -0.187, 0.177, 0.066, 0.140, 0.553, 1.069, 0.625, 0.596, 0.472, 0.984, 0.799, 0.128, 0.548, 0.725, 0.634, 0.192, 0.491, 0.224, 0.049, 0.423, 0.401, 0.816, 0.472, -5.000, -0.579, 0.792, -0.826, -5.000, -0.292, 0.518, -0.321, -0.347, -0.216, 0.585, -0.118, 0.103, 0.373, 0.836, 0.458, -5.000, -0.995, -0.066, -0.498, -0.028, -1.461, -0.388, -0.452, -5.000, 0.577, -0.045, -0.312, -0.205, -0.140, 0.778, 0.442, -0.092, -0.061, 0.043, 0.328, -0.254, -0.229, 0.519, -0.388, -0.427, 0.023, 0.061, -0.584, -0.383, 0.219, 0.729, 0.464, -0.073, -0.711, 0.414, 0.691, -0.793, -0.147, -0.388, 0.073, -0.529, 0.434, 0.185, 0.444, -0.003, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.474, 1.000, 0.502, -5.000, -0.175, 0.772, -0.282, -5.000, 0.152, 0.257, 0.042, -0.453, 0.208, 0.441, -0.001, 0.344, 0.297, 0.613, 0.022, -5.000, -0.270, 0.532, -0.289, -0.232, -0.530, -0.245, -0.288, -0.169, 0.420, 0.279, -0.298, 0.080, -0.229, 0.683, 0.261, -0.318, -0.349, 0.502, 0.180, -1.577, -0.028, 0.242, -0.376, -0.832, 0.123, 0.263, 0.185, -0.545, 0.471, 1.043, 0.320, 0.187, 0.068, 0.703, 0.507, -0.924, 0.442, 0.556, 0.366, -0.025, 0.461, 0.522, 0.383, 0.067, 0.804, 1.258, 1.003, -5.000, 0.102, 0.976, -0.109, -5.000, 0.609, 0.815, 0.284, -0.068, 0.653, 0.766, 0.560, 0.734, 0.338, 1.058, 0.441, -5.000, -0.013, 0.859, 0.225, 0.193, 0.358, 0.212, 0.020, -0.660, 0.483, 0.593, -0.106, 0.058, 0.102, 0.758, -0.192, -0.212, -0.363, 0.650, -0.918, -1.144, -0.044, 0.434, -0.622, -1.024, -0.793, 0.186, -0.238, -0.323, 0.915, 1.276, 0.643, 0.624, 0.538, 0.925, 0.623, -0.479, 0.618, 0.848, 0.186, -0.088, 0.667, 0.253, -0.040, 0.209, 0.115, 0.746, 0.142, -5.000, -0.672, 0.033, -0.520, -5.000, 0.540, 0.334, -0.434, -0.320, -0.204, 0.032, -0.416, 0.167, -0.014, 0.552, 0.058, -5.000, -0.389, 0.123, 0.533, -0.976, 0.159, -0.138, -0.340, -0.483, -0.023, -0.142, -0.703, -0.202, 0.108, 0.866, -0.219, -0.589, -0.482, -0.355, -0.159, -1.088, 0.009, -0.382, -0.870, -0.955, -0.457, -0.445, -0.728, -0.382, 0.357, 1.045, 0.206, 0.028, -0.249, 0.278, 0.081, -0.925, 0.448, 0.082, -0.194, -0.276, 0.266, 0.138, -0.187, -0.365, 0.145, 0.612, 0.121, -5.000, -0.855, -0.208, -0.369, -5.000, -0.450, -0.211, -0.638, -1.090, -0.493, -0.386, -0.513, -0.254, 0.029, 0.449, 0.144, -5.000, -0.897, 0.123, -0.872, -0.358, -0.319, -0.165, -0.408, -0.826, 0.447, -0.286, -0.602, 0.027, -0.549, 0.411, -0.612, -0.519, -0.743, -0.075, -0.759, -1.673, -0.119, -0.524, -0.442, -1.279, -0.408, -0.239, -0.160, -0.421, -0.116, 0.528, -0.127, -0.156, 0.011, 0.550, -0.241, -1.172, -0.028, -0.067, -0.254, -0.936, -0.044, -0.078, -0.217, -0.554, 0.255, 0.946, 0.464, -5.000, 0.107, 0.437, -0.111, -5.000, -0.151, 0.186, -0.331, -0.405, -0.487, 0.071, -0.325, -0.015, 0.011, 0.740, 0.031, -5.000, -0.450, 0.359, -0.170, -0.021, -0.364, -0.280, -0.894, -1.103, 0.078, -0.031, -0.430, -0.304, 0.220, 0.482, -0.097, -0.379, -0.324, 0.503, 0.268, -1.565, 0.233, 0.423, -0.420, -0.611, -0.181, -0.331, -0.308, -0.879, 0.259, 1.001, 0.417, 0.130, 0.064, 0.672, 0.550, -0.644, 0.275, 0.621, 0.308, -0.074, 0.325, 0.303, 0.108, 0.023, 0.612, 1.207, 0.991, -5.000, 0.246, 0.897, 0.532, -5.000, 0.587, 0.820, 0.345, 0.057, 0.384, 0.664, 0.162, 0.429, 0.344, 0.811, 0.326, -5.000, -0.085, 0.433, 0.379, 0.207, 0.376, 0.172, 0.012, -0.113, 0.023, 0.150, -0.299, 0.126, 0.106, 0.828, 0.040, -0.709, -0.310, 0.921, 0.110, -1.167, -0.134, 0.594, -0.426, -0.438, 0.006, 0.190, -0.271, -0.342, 0.714, 1.079, 0.660, 0.523, 0.446, 0.885, 0.981, -0.309, 0.624, 0.722, 0.367, 0.146, 0.674, 0.235, -0.220, 0.122, 0.464, 0.942, 0.571, -5.000, 0.073, 0.784, -0.118, -5.000, 0.505, 0.526, -0.062, -0.215, 0.131, 0.047, -0.435, 0.239, 0.319, 0.796, 0.181, -5.000, -0.029, 0.393, -0.455, -0.526, 0.513, 0.338, -0.207, -0.558, 0.098, -0.098, -0.673, -0.023, 0.191, 0.528, -0.508, -0.663, -0.253, -0.067, -0.674, -0.951, -0.115, -0.060, -0.511, -0.982, -0.572, -0.825, -1.287, -1.004, 0.303, 0.658, -0.201, -0.260, -0.023, 0.074, -0.037, -0.951, -0.303, -0.187, -0.452, -0.705, -0.115, -0.592, -1.156, -0.621, 0.371, 1.093, 0.743, -5.000, -0.074, 0.797, 0.459, -5.000, 0.462, 0.720, 0.265, -0.187, 0.180, 0.460, -0.108, 0.279, 0.339, 1.081, 0.680, -5.000, -0.117, 0.636, 0.324, -0.267, 0.362, 0.489, 0.196, -0.051, 0.344, 0.372, -0.191, 0.217, 0.367, 0.892, 0.168, 0.023, 0.240, 0.452, 0.025, -0.803, 0.555, 0.653, 0.206, -0.095, 0.251, 0.279, -0.067, -0.050, 0.462, 0.985, 0.467, 0.222, 0.292, 0.558, 0.506, -0.585, 0.381, 0.599, 0.313, -0.159, 0.208, 0.178, -0.059, -0.044, 0.311, 0.861, 0.440, -5.000, -0.170, 0.417, -0.062, -5.000, -0.143, 0.133, -0.710, -0.672, -0.349, 0.240, -0.533, 0.085, -0.325, 0.263, -0.510, -5.000, -0.649, 0.193, -0.971, -0.506, -1.141, -0.021, -0.936, -0.906, 0.049, -0.219, -0.908, -0.566, -0.188, 0.470, -1.009, -0.784, -0.432, 0.404, -0.102, -1.268, 0.071, 0.294, -0.281, -0.996, 0.167, 0.196, 0.247, -0.395, 0.262, 0.834, 0.309, 0.013, 0.148, 0.668, 0.762, -0.811, 0.560, 1.021, 0.692, 0.124, 0.504, 0.642, 0.429, 0.124, 0.926, 1.440, 1.158, -5.000, 0.587, 1.156, 1.084, -5.000, 0.861, 1.225, 0.825, 0.783, 0.767, 1.173, 0.747, 0.978, 0.066, 0.834, 0.127, -5.000, -0.499, 0.662, -0.209, 0.299, 0.197, 0.662, 0.236, -0.361, 0.311, 0.291, -0.198, -0.021, 0.622, 0.958, 0.509, 0.432, 0.516, 0.894, 0.542, -0.078, 0.650, 0.788, 1.052, 0.015, 0.123, 1.009, 0.506, -0.109, 1.022, 1.336, 0.677, 1.029, 0.954, 1.156, 1.108, 0.216, 0.808, 1.048, 0.838, 0.446, 0.748, 0.507, 0.104, 0.574, 0.403, 1.100, 0.494, -5.000, -0.166, 0.833, 0.508, -5.000, 0.638, 1.055, 0.140, 0.080, 0.287, 0.469, 0.008, 0.420, -0.096, 0.778, -0.055, -5.000, -0.394, 0.313, -0.105, -0.428, 0.265, 0.390, -0.017, -0.442, 0.156, 0.228, -0.489, 0.033, 0.189, 0.935, -0.167, -0.184, 0.133, 0.662, 0.305, -0.809, 0.259, 0.522, -0.152, -0.555, 0.010, -0.236, -0.460, -0.324, 0.445, 0.868, 0.141, 0.157, 0.253, 0.496, 0.618, -0.278, 0.549, 0.703, 0.745, 0.555, 0.459, 0.195, -0.246, 0.185, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.320, 0.391, -0.147, -5.000, -0.773, -0.059, -0.580, -5.000, -0.816, -0.271, -1.590, -1.269, -0.694, -0.044, -0.461, 0.076, -0.555, -0.282, -0.982, -5.000, -1.091, -0.769, -0.585, -0.902, -1.234, -0.147, -0.994, -0.897, -0.446, -0.752, -1.017, -0.560, -0.866, -0.063, -1.336, -1.215, -1.343, -0.432, -0.451, -2.818, -0.503, -0.392, -1.317, -1.626, -1.141, -0.960, -0.761, -1.613, -0.368, 0.461, -0.885, -0.637, -0.404, 0.256, 0.039, -1.135, -0.376, 0.156, 0.162, -0.128, -0.414, -0.302, -0.371, -0.469, 0.644, 1.105, 0.974, -5.000, -0.045, 0.951, 0.406, -5.000, 0.669, 0.906, 0.184, 0.164, 0.606, 0.868, 0.724, 0.779, -0.104, 0.831, 0.278, -5.000, -0.567, 0.723, -0.388, 0.033, -0.580, 0.590, -0.031, -0.611, 0.296, 0.245, -0.495, -0.034, -0.031, 0.448, -0.506, -0.831, -0.305, 0.233, 0.151, -1.228, 0.090, 0.223, -0.165, 0.305, 0.047, -0.483, -0.858, -0.611, 0.129, 0.789, 0.380, 0.167, 0.204, 0.895, 0.672, -0.309, -0.060, 0.520, 0.223, -0.149, 0.010, 0.091, -0.764, 0.246, -0.025, 0.923, 0.645, -5.000, -0.452, 0.593, -0.650, -5.000, 0.033, -0.012, -0.175, -0.562, -0.434, 0.091, -0.638, -0.145, 0.236, 0.865, 0.228, -5.000, -1.001, 0.560, 0.069, -1.102, -0.185, 0.305, -1.081, -0.452, 0.207, -0.445, -0.664, -0.165, -0.134, 0.452, -0.274, -0.393, -0.614, 0.321, -0.513, -1.506, -0.521, 0.162, 0.123, -1.206, -0.323, -0.858, -1.710, -0.925, -0.070, 0.594, 0.160, -0.093, 0.210, -0.734, 1.017, -0.886, 0.103, 0.132, -0.221, -0.504, 0.057, -0.277, -0.557, -0.357, 0.195, 0.788, 0.469, -5.000, -0.742, 0.300, 0.429, -5.000, -0.166, 0.097, -0.512, -1.011, -0.271, -0.215, -0.485, -0.101, -0.191, 0.642, -0.016, -5.000, -1.071, 0.237, -0.595, -0.488, -1.121, -0.457, -0.357, -0.658, 0.003, -0.806, -1.079, -0.565, 0.082, 0.660, -0.112, -0.598, -0.485, 0.386, 0.374, -1.719, -0.168, -0.512, -0.487, -1.163, -0.396, -0.721, -0.510, -0.688, 0.109, 0.493, 0.112, -0.325, -0.233, 0.294, -0.153, -1.272, 0.048, 0.215, 0.075, -0.322, -0.261, -0.281, -0.789, -0.329, -0.001, 0.700, 0.014, -5.000, -0.483, 0.393, -0.270, -5.000, -0.122, -0.229, -0.483, -0.341, -0.099, 0.285, 0.049, 0.391, -0.582, 0.448, -0.267, -5.000, -0.812, 0.619, -0.858, -0.175, -1.206, -0.205, -2.074, -1.324, 0.164, -0.057, -0.822, 0.089, -0.654, 0.555, -0.171, -0.653, -1.027, -0.023, -0.553, -2.555, -0.499, 0.227, -0.868, -0.472, -0.714, -0.556, -0.684, -0.455, 0.065, 0.851, 0.496, -0.077, -0.390, 0.474, 0.328, -0.626, 0.616, 0.420, 0.559, -0.190, 0.105, 0.285, 0.160, -0.458, 0.400, 1.095, 0.433, -5.000, -0.195, 0.583, -0.205, -5.000, 0.163, 0.547, -0.624, -0.404, 0.358, 0.488, 0.147, 0.671, -0.165, 0.786, -0.079, -5.000, -0.709, 0.546, 0.001, -0.495, 0.018, 0.197, -0.002, -0.771, -0.328, -0.276, -0.918, -0.458, -0.498, 0.975, -0.650, -0.165, -0.252, 0.673, -0.724, -0.513, -1.284, 0.334, -0.542, -0.889, -1.417, 0.090, 0.697, -0.942, 0.510, 1.110, 0.230, 0.102, 0.090, 0.646, 0.476, -0.539, 0.151, 0.330, 0.338, -0.185, 0.207, -0.082, -0.364, -0.692, -0.570, 0.361, 0.064, -5.000, -0.988, 0.266, -0.695, -5.000, 0.446, 0.562, -0.500, 0.001, -0.257, 0.065, -0.534, -0.041, -0.188, -0.233, -0.643, -5.000, -1.025, -0.619, -0.598, -1.095, 0.087, -0.724, -1.435, -0.498, -0.664, -0.108, -0.441, -0.266, -0.009, 0.473, -0.105, -1.251, -0.546, -0.680, 0.202, -1.823, -0.165, 0.161, -1.081, -0.759, -1.280, 0.018, -0.304, -0.314, 0.268, 0.855, 0.062, -0.129, 0.034, -0.570, 0.241, -0.982, 0.591, 0.023, -0.498, 0.102, 0.459, 0.180, -0.071, -0.585, 0.203, 0.890, -0.147, -5.000, -1.196, -0.212, 0.250, -5.000, -0.102, -0.479, -0.775, -0.956, -0.525, -0.039, -0.598, -0.269, -0.016, 0.492, 0.283, -5.000, -0.780, -1.212, 0.093, -0.463, -1.696, 0.018, -1.343, -1.114, -0.000, -0.202, -0.878, 0.286, -0.953, 0.724, -0.947, -1.274, -0.968, -1.049, 0.113, -1.427, -0.622, -0.737, -0.733, -1.054, -0.858, -0.736, -0.570, -0.946, -0.465, 0.188, -0.475, -0.906, -0.100, 0.217, 0.172, -0.793, -0.503, 0.090, -0.469, -0.666, -0.458, -0.304, -0.674, -0.670, 0.109, 0.812, 0.296, -5.000, -0.164, 0.507, -0.027, -5.000, -0.298, 0.045, -0.913, -0.836, -0.518, 0.115, -0.389, 0.151, -0.231, 0.469, -0.005, -5.000, -0.382, 0.297, -0.048, -0.071, -0.425, -0.392, -0.821, -0.922, 0.128, 0.427, -0.363, -0.227, 0.043, 0.685, -0.098, -0.831, -0.489, 0.579, 0.521, -1.040, 0.068, 0.537, -0.584, -0.386, 0.030, 0.320, 0.258, -0.794, 0.018, 0.810, 0.196, -0.021, -0.057, 0.797, 0.435, -0.732, 0.274, 0.803, 0.480, 0.300, 0.288, 0.265, -0.022, 0.060, 0.234, 0.937, 0.542, -5.000, 0.008, 0.611, -0.205, -5.000, 0.288, 0.579, -0.014, -0.297, 0.068, 0.246, -0.172, 0.194, -0.197, 0.311, 0.105, -5.000, -0.146, 0.296, 0.132, -0.470, 0.009, -0.379, -0.536, -0.197, -0.186, -0.229, -0.588, -0.424, -0.521, 0.222, -0.716, -1.384, -0.781, 0.008, -0.044, -1.185, -0.100, -0.087, 0.123, -0.774, -0.468, 0.113, -0.184, -1.108, 0.490, 0.979, 0.389, 0.363, 0.204, 0.724, 0.548, -0.701, 0.203, 0.390, 0.445, -0.237, 0.198, -0.282, -0.741, -0.322, 0.281, 0.512, 0.298, -5.000, -0.383, 0.434, -0.268, -5.000, 0.201, 0.602, -0.087, 0.161, -0.306, -0.094, -0.856, -0.086, -0.130, 0.374, -0.236, -5.000, -0.910, -0.172, -0.596, -0.711, 0.026, -0.471, 0.066, -0.533, -0.608, -0.653, -0.986, -0.753, 0.183, 0.349, -1.049, -1.257, -0.625, -0.499, -0.462, -1.406, -0.640, -0.365, -0.563, -1.179, -1.095, -0.835, -1.854, -1.455, -0.234, 0.357, -0.698, -0.838, -0.776, -0.480, -0.100, -1.033, -0.551, -0.568, -0.326, -0.479, -0.673, -1.097, -1.441, -0.910, -0.129, 0.734, 0.119, -5.000, -0.517, 0.522, -0.080, -5.000, 0.192, 0.550, -0.365, -0.310, -0.469, 0.051, -0.530, -0.151, 0.005, 0.615, 0.189, -5.000, -0.470, 0.253, -0.123, -0.713, -0.057, 0.216, -0.180, -0.370, 0.093, 0.208, -0.490, -0.548, -0.137, 0.277, -0.388, -0.731, -0.628, 0.105, 0.136, -1.243, -0.208, 0.047, -0.393, -1.141, -0.670, -0.701, -0.648, -0.785, -0.286, 0.367, -0.316, -0.292, -0.259, 0.104, -0.019, -0.934, -0.330, 0.206, 0.121, -0.330, -0.446, -0.373, -0.678, -0.814, 0.044, 0.790, 0.252, -5.000, -0.504, 0.287, -0.000, -5.000, -0.243, -0.092, -0.761, -1.003, -0.227, 0.027, -0.459, 0.056, -0.288, 0.305, -0.266, -5.000, -1.196, -0.126, -0.408, -0.240, -0.329, 0.063, -1.024, -0.307, 0.004, 0.036, -0.648, -0.720, -0.115, 0.475, -0.053, -0.838, -0.508, 0.318, -0.128, -1.283, -0.001, 0.417, -0.347, -1.051, 0.098, 0.188, 0.191, -0.668, 0.187, 0.687, 0.127, 0.124, -0.151, 0.392, 0.551, -0.974, 0.384, 0.670, 0.704, -0.135, 0.170, 0.326, 0.336, -0.036, 0.806, 1.244, 1.115, -5.000, 0.382, 1.154, 0.768, -5.000, 0.805, 1.144, 0.926, 0.712, 0.741, 0.998, 0.750, 0.913, 0.041, 0.769, -0.065, -5.000, -0.697, 0.328, 0.711, 0.438, 0.298, 0.144, 0.058, -0.307, 0.187, 0.418, -0.536, -0.280, 0.479, 1.263, 0.538, 0.072, 0.230, 0.934, 0.678, -0.455, 0.528, 0.607, 0.433, -0.465, 0.506, 0.087, -0.250, 0.049, 0.642, 0.893, 0.717, 0.604, 0.558, 0.950, 1.118, 0.207, 0.698, 0.980, 0.832, 0.287, 0.669, 0.506, 0.506, 0.650, -0.045, 0.690, 0.068, -5.000, -0.796, 0.605, -0.570, -5.000, 0.087, 0.584, 0.101, -0.302, -0.123, 0.017, -0.555, 0.268, -0.400, 0.245, -0.337, -5.000, -0.496, -0.009, -0.316, -0.835, -0.176, 0.102, -0.290, -0.962, -0.687, -0.348, -1.232, -0.103, -0.422, 0.311, -0.678, -1.006, -0.382, 0.265, -0.219, -1.884, -0.233, -0.308, -1.077, -0.766, -0.900, -0.444, -0.913, -1.322, -0.007, 0.553, -0.474, -0.679, -0.546, 0.425, 0.030, -0.560, -0.091, 0.439, 0.222, -0.045, -0.088, -0.257, -0.535, -0.373, -0.304, 0.158, -0.403, -5.000, -1.099, 0.157, -0.459, -5.000, -0.645, -0.372, -0.695, -1.459, -0.651, -0.497, -0.714, -0.385, -0.307, -0.101, -0.404, -5.000, -1.322, -0.432, -0.957, -0.557, -0.696, -0.858, -1.733, -1.141, -0.409, -0.661, -1.130, -0.930, -0.199, 0.102, -0.658, -0.939, -0.777, -0.034, -0.280, -1.776, -0.347, -0.415, -0.252, -1.383, -0.762, -1.035, -0.983, -1.629, -0.350, 0.242, -0.593, -0.657, -0.780, -0.147, 0.534, -1.259, -0.252, -0.076, -0.239, -0.354, -0.657, -0.258, -0.952, -0.743, -0.484, 0.276, 0.067, -5.000, -1.163, 0.001, -0.625, -5.000, -0.641, -0.330, -0.761, -0.889, -0.248, -0.003, -0.300, 0.033, -0.626, 0.155, -0.052, -5.000, -1.436, -0.727, 0.123, -0.721, -0.660, -0.131, -0.743, -0.639, -0.312, -0.332, -0.741, -0.689, -0.765, 0.297, -1.429, -1.470, -1.164, -0.288, -0.190, -2.293, -0.639, -0.249, -0.810, -1.642, -0.716, -0.407, -0.918, -1.390, -0.389, 0.276, -0.593, -0.442, -0.513, 0.042, -0.040, -1.285, 0.002, 0.248, 0.335, -0.450, 0.082, -0.195, -0.254, -0.429, 0.409, 1.002, 0.988, -5.000, -0.176, 0.911, 0.331, -5.000, 0.777, 1.032, 0.587, 0.541, 0.633, 0.819, 0.765, 0.863, -0.286, 0.665, -0.333, -5.000, -0.853, 0.277, 0.266, 0.081, 0.144, 0.377, 0.082, -0.212, 0.259, 0.018, -0.321, -0.019, -0.808, 0.517, 0.341, -0.997, -0.820, 0.480, -0.225, -0.842, 0.036, 0.480, 0.069, -0.221, -0.276, -1.097, -0.627, -0.531, 0.107, 0.766, 0.038, 0.066, 0.187, 0.948, 0.692, -0.169, 0.482, 0.483, 0.322, 0.026, 0.145, -0.305, -0.320, 0.094, 0.172, 0.326, 0.460, -5.000, -0.401, 0.123, 0.385, -5.000, 0.159, 0.557, -0.323, -0.368, -0.011, 0.032, -0.048, -0.071, -0.170, 0.977, 0.267, -5.000, -0.947, -0.256, -1.012, -0.338, 0.374, 0.082, -0.388, -0.793, 0.186, 0.292, 0.544, 0.203, -0.006, 0.714, -0.225, 0.172, -0.059, -0.005, 0.503, 0.190, 0.048, 0.268, -0.837, -0.987, -0.483, -0.837, -0.350, -0.599, 0.112, 0.640, -0.312, 0.452, -0.576, 0.166, 0.775, -0.891, 0.134, 0.027, 0.258, -0.575, 0.309, -0.055, -0.309, -0.625, -0.824, -0.563, -1.434, -5.000, -2.021, -1.070, -1.444, -5.000, -1.669, -0.622, -2.052, -1.913, -0.820, -0.848, -1.039, -0.968, -1.380, -0.546, -1.205, -5.000, -2.178, -1.343, -1.453, -1.806, -1.866, -2.046, -1.111, -2.618, -1.160, -0.367, -1.869, -1.555, -1.361, -0.456, -1.167, -1.737, -1.985, -0.614, -1.245, -2.255, -1.170, -1.563, -1.835, -2.595, -1.681, -1.441, -2.089, -1.765, -1.086, -0.525, -1.091, -1.322, -1.040, -0.541, -0.198, -1.787, -0.944, -0.967, -0.751, -1.290, -1.263, -0.901, -1.128, -1.563, 0.153, 0.757, 0.365, -5.000, -0.354, 0.649, -0.477, -5.000, 0.104, 0.090, -0.180, -0.376, -0.205, 0.297, -0.126, 0.510, -0.293, 0.855, 0.031, -5.000, -0.370, 0.445, -0.570, 0.158, 0.031, -0.265, -0.115, -0.535, 0.130, -0.097, -0.524, -0.216, -0.861, 0.254, -0.685, -0.678, -1.096, 0.163, 0.321, -1.434, -0.336, 0.078, -0.511, -0.893, -0.454, -0.388, -0.153, -0.716, -0.031, 0.403, -0.082, -0.107, -0.285, 0.504, 0.491, -1.162, 0.336, 0.713, 0.537, -0.386, 0.213, 0.519, 0.117, -0.381, 0.412, 1.116, 0.795, -5.000, -0.196, 0.957, -0.295, -5.000, 0.379, 0.750, 0.033, -0.090, 0.210, 0.718, 0.262, 0.592, -0.275, 0.662, 0.151, -5.000, -0.467, 0.396, 0.108, -0.278, -0.191, 0.189, -0.298, -0.483, 0.220, 0.345, -0.418, -0.035, -1.293, 0.350, -0.765, -1.116, -0.490, 0.597, -1.199, -1.456, -0.084, -0.088, -0.594, -2.252, -0.710, -0.406, -0.971, -1.417, 0.366, 1.016, 0.078, 0.065, -0.191, 0.812, 0.848, -0.844, 0.301, 0.685, 0.395, -0.233, 0.425, 0.334, -0.256, -0.036, -0.025, 0.480, -0.027, -5.000, -0.480, 0.327, 0.397, -5.000, 0.513, -0.120, -0.012, -0.275, 0.013, 0.291, -0.599, -0.085, -0.391, 0.255, -0.346, -5.000, -0.698, 0.226, -0.031, -0.442, 0.001, 0.123, -2.618, -0.118, -0.135, 0.065, -0.887, -0.470, -0.385, 0.115, -0.780, -1.285, -0.538, -0.061, -0.624, -2.068, 0.058, -0.100, -1.045, -0.767, -0.608, -0.570, -0.907, -1.069, 0.021, 0.408, 0.175, -0.495, -0.483, -0.292, 0.317, -1.217, 0.331, -0.055, -0.425, -0.519, -0.104, 0.028, -0.582, -0.925, -0.446, 0.392, -0.185, -5.000, -1.119, -0.295, -1.167, -5.000, -0.858, -0.442, -0.772, -1.151, -0.830, 0.026, -0.487, -0.414, -0.408, -0.001, -0.554, -5.000, -1.085, -1.232, -0.427, -0.800, -1.663, -0.927, -0.457, -0.712, -0.499, -0.439, -1.227, -0.730, -0.888, -0.154, -1.115, -0.981, -1.198, -0.931, -0.483, -1.621, -0.978, -0.388, -1.119, -1.126, -1.435, -0.455, -1.247, -1.738, -0.780, -0.008, -0.621, -1.282, -1.026, -0.424, -0.411, -2.300, -0.297, -0.199, -0.365, -0.863, -0.896, -0.273, -0.718, -1.020, -0.261, 0.446, 0.134, -5.000, -0.553, 0.367, -0.388, -5.000, -0.290, 0.086, -0.789, -0.864, -0.943, -0.051, -0.388, -0.069, -0.402, 0.438, -0.010, -5.000, -1.300, 0.253, -0.302, -0.598, -0.278, 0.036, -0.617, -1.482, -0.141, -0.355, -0.253, -0.893, -0.491, 0.074, -0.797, -1.192, -0.944, 0.220, -0.491, -1.685, -0.239, 0.029, -0.423, -0.947, -0.511, 0.043, -0.718, -1.780, -0.201, 0.738, 0.073, -0.437, -0.448, 0.523, 0.342, -1.165, 0.131, 0.601, 0.422, -0.276, -0.100, 0.075, -0.078, -0.529, -0.346, 0.508, 0.185, -5.000, -0.810, 0.164, -0.225, -5.000, 0.370, 0.525, 0.072, -0.350, 0.249, 0.317, -0.297, 0.512, -0.514, -0.193, -0.137, -5.000, -0.542, -0.411, -1.008, -0.334, -0.317, -0.053, 0.766, -0.351, -0.362, -0.054, -0.825, -0.458, -0.399, -0.700, -0.834, -1.969, -1.034, -0.013, 0.058, -2.056, -0.360, -1.188, -0.873, -1.145, -0.550, -1.242, -0.833, -1.433, 0.097, 0.486, -0.734, -0.415, -0.397, 0.534, 0.232, -0.455, -0.008, 0.148, 0.178, 0.028, 0.047, -0.036, -0.772, -0.503, -0.009, 0.693, 0.073, -5.000, -0.390, 0.432, 0.135, -5.000, 0.520, 0.804, 0.023, -0.014, -0.021, 0.388, -0.505, 0.057, -0.262, 0.549, -0.083, -5.000, -0.479, 0.021, -0.110, -0.613, -0.238, 0.505, 0.018, 0.185, -0.063, -0.004, -0.594, -0.483, -0.253, 0.084, -0.935, -1.328, -0.968, -0.229, -0.918, -2.327, -0.382, -0.083, -0.858, -0.922, -1.186, -1.616, -1.403, -1.340, -0.700, 0.027, -1.093, -0.600, -0.727, -0.311, -0.901, -1.962, -0.650, -0.342, 0.021, -1.185, -0.811, -0.851, -1.551, -1.328, -0.355, 0.389, -0.225, -5.000, -0.790, 0.159, -1.279, -5.000, -0.321, 0.061, -0.828, -0.677, -0.570, -0.302, -0.581, -0.462, -0.694, 0.109, 0.026, -5.000, -1.046, 0.131, -0.125, -0.744, -1.405, -0.368, -1.023, -1.263, -0.468, -0.863, -1.650, -0.997, -0.317, 0.054, -1.130, -1.169, -1.128, -0.721, -0.750, -2.035, -0.556, -0.809, -1.404, -1.809, -1.208, -1.249, -1.528, -1.771, -0.518, 0.293, -0.572, -0.753, -0.696, -0.326, -0.221, -1.455, -0.538, -0.442, -0.448, -1.013, -0.529, -0.688, -1.087, -1.186, 0.422, 0.959, 0.548, -5.000, -0.097, 0.706, -0.165, -5.000, -0.022, 0.234, -0.247, -0.354, -0.004, 0.325, -0.155, 0.189, 0.161, 0.713, 0.358, -5.000, -0.540, 0.521, -0.174, 0.167, -0.184, 0.391, -0.562, -0.348, 0.407, 0.196, -0.557, -0.116, 0.154, 0.731, -0.397, -0.291, -0.207, 0.627, 0.207, -0.824, 0.374, 0.592, 0.108, -0.284, 0.147, 0.388, 0.167, -0.300, 0.361, 0.913, 0.208, 0.166, 0.110, 0.718, 0.642, -0.670, 0.541, 0.590, 0.721, 0.029, 0.459, 0.571, 0.387, 0.170, 1.120, 1.402, 1.228, -5.000, 0.545, 1.412, 0.985, -5.000, 0.992, 1.309, 1.003, 0.659, 1.004, 1.281, 0.834, 1.109, 0.546, 0.958, 0.570, -5.000, 0.041, 0.816, 0.694, 0.535, 0.368, 0.914, 0.134, 0.575, 0.653, 0.583, -0.136, 0.319, 0.597, 1.094, 0.426, 0.145, 0.431, 1.154, 1.148, 0.154, 0.813, 1.110, 0.436, 0.119, 0.587, 0.195, 0.399, 0.203, 0.921, 1.229, 0.734, 0.756, 0.814, 1.115, 1.169, 0.279, 0.817, 1.057, 0.797, 0.490, 0.840, 0.654, 0.092, 0.760, 0.509, 1.152, 0.584, -5.000, 0.052, 1.224, 0.305, -5.000, 0.327, 0.807, 0.301, 0.338, 0.201, 0.744, 0.021, 0.517, 0.239, 0.935, 0.210, -5.000, -0.441, 0.850, -0.321, -0.281, 0.123, 0.174, 0.333, -0.243, 0.309, 0.463, -0.620, 0.318, 0.016, 0.865, -0.253, -0.485, -0.082, 0.407, 0.487, -1.145, 0.168, 0.287, -0.118, -0.597, -0.115, -0.340, -0.817, -0.600, 0.122, 0.617, 0.014, -0.130, 0.147, 0.630, 0.198, -0.207, 0.082, 0.468, 0.328, -0.031, 0.424, 0.108, -0.249, -0.097, 0.168, 0.746, 0.388, -5.000, -0.568, 0.643, -0.097, -5.000, -0.208, -0.020, -0.705, -0.509, -0.220, 0.114, -0.344, -0.065, 0.123, 0.602, 0.294, -5.000, -0.876, 0.128, -0.034, -0.015, -0.355, -0.199, -0.555, -0.788, 0.439, -0.152, -0.511, -0.268, 0.266, 0.767, 0.068, -0.442, -0.363, 0.521, 0.509, -0.890, 0.089, 0.184, 0.088, -0.788, -0.333, -0.109, -0.412, -0.642, 0.226, 0.695, 0.106, -0.007, -0.065, 0.614, 0.671, -0.674, 0.304, 0.592, 0.439, -0.042, 0.070, 0.073, -0.207, -0.221, 0.096, 0.688, 0.287, -5.000, -0.710, 0.369, -0.055, -5.000, -0.176, 0.281, -0.607, -0.659, -0.234, 0.242, -0.214, 0.406, -0.165, 0.721, 0.372, -5.000, -0.721, -0.074, -1.296, 0.039, -0.176, 0.255, -0.551, -0.049, 0.307, 0.384, -0.108, -0.081, -0.134, 0.601, -0.340, -0.711, -0.688, 0.145, 0.231, -1.238, 0.095, 0.042, -0.548, -0.901, -0.155, -0.150, -0.180, -0.665, 0.039, 0.734, 0.139, -0.034, -0.149, 0.610, 0.140, -0.698, 0.404, 0.614, 0.641, -0.126, 0.276, 0.149, 0.194, 0.097, 0.696, 1.115, 1.133, -5.000, 0.351, 1.129, 0.898, -5.000, 0.891, 1.059, 0.668, 0.423, 0.737, 0.852, 0.796, 0.885, 0.294, 0.902, 0.675, -5.000, -0.214, 1.003, 0.215, 0.362, 0.420, 0.643, 0.577, 0.154, 0.479, 0.716, -0.135, 0.341, 0.283, 1.003, -0.040, -0.294, 0.104, 0.879, 0.856, -0.450, 0.411, 0.729, 0.021, -0.052, 0.101, -0.192, -0.093, 0.048, 0.466, 0.995, 0.702, 0.558, 0.761, 1.088, 1.024, 0.254, 0.483, 0.793, 0.667, 0.225, 0.567, -0.065, -0.312, 0.451, 0.771, 1.377, 1.010, -5.000, 0.076, 1.158, 0.444, -5.000, 0.766, 1.063, 0.413, 0.035, 0.456, 0.641, 0.464, 0.593, 0.447, 1.269, 0.883, -5.000, -0.086, 0.676, 0.287, 0.383, 0.305, 0.564, -0.031, -0.282, 0.863, 0.517, -0.035, 0.362, 0.175, 1.255, -0.108, 0.275, 0.290, 0.751, 1.029, -0.514, 0.335, 0.550, 0.924, -0.578, 0.814, 0.047, -0.570, 0.235, 0.464, 0.784, 0.226, 0.329, -0.017, 0.511, 1.027, -0.841, 0.298, 0.751, 0.356, -0.059, 0.741, 0.237, 0.086, 0.175, -0.707, 0.079, -0.250, -5.000, -1.163, 0.072, -0.401, -5.000, -0.923, -0.249, -1.156, -1.594, -1.007, -0.399, -0.719, -0.411, -0.716, -0.026, -0.053, -5.000, -1.905, -0.691, -1.163, -0.679, -1.336, -0.771, -0.660, -1.860, -0.239, -0.343, -0.932, -0.633, -0.753, -0.097, -0.921, -1.178, -0.872, -0.338, -0.979, -2.222, -1.049, -1.102, -1.261, -1.736, -1.113, -0.967, -0.610, -1.421, -0.794, 0.003, -0.504, -0.725, -0.334, -0.110, -0.467, -2.018, -0.519, -0.426, -0.674, -1.289, -0.549, -0.598, -0.909, -0.919, 0.322, 0.933, 0.713, -5.000, -0.122, 0.881, -0.132, -5.000, 0.082, 0.437, 0.017, -0.392, 0.179, 0.460, -0.216, 0.269, 0.149, 0.833, 0.428, -5.000, -0.047, 0.313, 0.089, -0.038, -0.050, 0.186, -0.301, -0.225, 0.328, 0.380, -0.254, -0.081, -0.171, 0.743, -0.129, -0.401, -0.204, 0.604, 0.696, -1.590, -0.023, 0.300, -0.097, -0.376, -0.174, 0.153, -0.081, -0.383, 0.294, 1.002, 0.362, 0.177, 0.240, 0.959, 0.639, -0.753, 0.630, 0.789, 0.669, 0.146, 0.552, 0.662, 0.345, 0.033, 0.629, 1.209, 0.942, -5.000, 0.200, 1.052, 0.474, -5.000, 0.712, 0.729, 0.402, 0.059, 0.549, 0.854, 0.450, 0.618, 0.468, 0.978, 0.643, -5.000, 0.166, 0.788, 0.452, 0.521, 0.647, 0.504, 0.535, 0.145, 0.521, 0.561, -0.038, 0.304, 0.102, 0.576, 0.074, -0.508, -0.084, 0.763, -0.070, -1.032, 0.104, 0.234, -0.176, -0.685, -0.613, -0.045, -0.390, -0.739, 0.787, 1.219, 0.826, 0.422, 0.458, 1.160, 0.977, -0.595, 0.711, 0.908, 0.586, -0.007, 0.698, 0.357, 0.032, 0.415, 0.424, 1.034, 0.499, -5.000, 0.322, 0.694, 0.096, -5.000, 0.769, 0.539, -0.017, 0.038, 0.410, 0.599, -0.004, 0.485, 0.356, 0.933, 0.451, -5.000, 0.325, 0.819, 0.441, 0.106, 0.554, 0.305, 0.239, -0.327, 0.506, 0.503, 0.040, 0.252, 0.448, 1.193, 0.064, -0.296, -0.018, 0.665, 0.178, -0.634, 0.526, 0.118, -0.161, -0.320, 0.355, 0.065, -0.425, -0.056, 0.423, 1.302, 0.653, 0.202, 0.071, 0.908, 0.643, -0.282, 0.699, 0.396, 0.075, -0.138, 0.597, 0.468, 0.064, -0.055, 0.213, 0.706, 0.378, -5.000, -0.388, 0.036, -0.097, -5.000, -0.308, -0.009, -0.432, -0.766, -0.233, -0.067, -0.447, -0.163, 0.395, 0.672, 0.411, -5.000, -0.396, -0.100, -0.141, -0.252, -0.096, 0.177, -0.165, -0.385, 0.296, -0.213, -0.153, -0.213, -0.160, 0.455, -0.157, -0.646, -0.398, -0.023, -0.570, -1.346, -0.331, -0.090, -0.199, -0.504, -0.394, -0.455, -0.138, -0.511, -0.177, 0.501, -0.116, -0.484, -0.275, 0.452, 0.342, -0.775, 0.049, 0.193, 0.134, -0.597, -0.129, 0.003, -0.236, -0.484, 0.227, 0.972, 0.540, -5.000, -0.154, 0.660, 0.091, -5.000, -0.130, 0.076, -0.237, -0.217, -0.320, 0.156, -0.300, 0.174, 0.082, 0.781, 0.336, -5.000, -0.616, 0.201, -0.524, -0.109, 0.143, 0.194, 0.108, -0.691, 0.466, 0.235, -0.288, -0.249, -0.087, 0.560, -0.111, -0.680, -0.372, 0.645, 0.153, -1.209, 0.294, 0.681, 0.056, -0.466, 0.089, 0.197, -0.273, -0.551, 0.275, 0.989, 0.384, 0.011, 0.002, 0.865, 0.916, -0.643, 0.555, 0.920, 0.782, 0.252, 0.475, 0.652, 0.392, 0.061, 0.280, 0.919, 0.600, -5.000, -0.305, 0.555, -0.135, -5.000, 0.205, 0.515, 0.119, -0.374, -0.028, 0.498, -0.142, 0.365, 0.061, 0.699, 0.067, -5.000, -0.439, 0.566, -0.115, -0.286, 0.570, 0.315, 0.255, -0.229, 0.119, 0.246, -0.472, -0.020, -0.222, 0.374, -0.734, -0.856, -0.486, 0.543, 0.275, -0.636, 0.027, 0.555, -0.399, -0.202, -0.131, -0.014, -0.545, -1.070, 0.419, 0.854, 0.199, -0.049, 0.237, 0.790, 0.856, -0.402, 0.357, 0.582, 0.470, -0.122, 0.430, 0.155, -0.314, -0.112, 0.127, 0.941, 0.342, -5.000, -0.258, 0.767, 0.127, -5.000, 0.516, 0.814, 0.266, -0.199, -0.056, 0.219, -0.395, -0.006, -0.013, 0.734, 0.261, -5.000, -0.334, 0.747, 0.231, -0.506, 0.347, 0.492, -0.193, -0.095, 0.028, -0.116, -0.845, -0.302, -0.060, 0.495, -0.555, -0.832, -0.368, 0.267, 0.089, -1.281, -0.084, 0.057, -0.486, -0.632, -0.350, -0.590, -1.316, -1.097, -0.098, 0.321, -0.423, -0.659, -0.095, 0.037, 0.265, -1.342, -0.387, -0.241, -0.400, -0.594, -0.227, -0.564, -1.076, -0.801, 0.033, 0.716, 0.385, -5.000, -0.297, 0.712, 0.084, -5.000, 0.075, 0.133, -0.480, -0.356, -0.155, 0.098, -0.441, -0.097, -0.009, 0.757, 0.272, -5.000, -0.388, 0.581, 0.177, -0.104, -0.523, -0.123, -0.498, -0.411, 0.137, 0.148, -0.585, -0.105, 0.025, 0.677, -0.377, -0.556, -0.383, 0.138, 0.203, -1.203, -0.015, -0.087, -0.323, -0.934, -0.561, -0.382, -0.450, -0.817, -0.075, 0.643, -0.045, -0.298, -0.152, 0.333, 0.413, -1.019, 0.062, 0.251, -0.103, -0.494, -0.280, -0.250, -0.663, -0.430 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_16(struct _training *tptr) {
  struct _training tinf = {
    0.495, 11, 4.350, { 0.927, 0.346, 1.727 }, { 0.536, -1.693, -0.455 }, 1, 
    { -0.935, -3.880, -1.668, -1.522, 0.104, -4.000, -0.471, -0.833, 1.567, 0.181, -2.214, -4.000, -0.710, 0.304, 1.218, -0.225, 1.095, -0.079, 1.844, 1.530, -0.351, -0.964, 1.483, -4.000, 2.091, -4.000, 1.116, 2.210 }, 
    {{ 0.166, -0.155, 0.035, -0.079},{ 0.323, -0.371, -0.262, 0.139},{ 0.225, -0.199, -0.329, 0.183},{ 0.191, -0.199, -0.371, 0.240},{ 0.302, -0.249, -0.298, 0.111},{ 0.313, -0.249, -0.375, 0.146},{ 0.321, -0.230, -0.357, 0.111},{ 0.402, -0.221, -0.361, -0.002},{ 0.421, -0.275, -0.401, 0.036},{ 0.408, -0.295, -0.435, 0.089},{ 0.418, -0.295, -0.282, -0.027},{ 0.263, -0.218, -0.302, 0.137},{ 0.287, -0.246, -0.371, 0.171},{ 0.254, -0.184, -0.295, 0.120},{ 0.137, -0.178, -0.275, 0.223},{ 0.215, -0.252, -0.252, 0.181},{ 0.254, -0.143, -0.259, 0.064},{ 0.240, -0.175, -0.302, 0.133},{ 0.242, -0.118, -0.308, 0.091},{ 0.252, -0.053, -0.265, -0.007},{ 0.269, -0.178, -0.298, 0.100},{ 0.318, -0.208, -0.230, 0.012},{ 0.242, -0.050, -0.288, 0.020},{ 0.250, -0.060, -0.312, 0.036},{ 0.211, -0.190, -0.190, 0.100},{ 0.233, -0.109, -0.193, 0.012},{ 0.205, -0.129, -0.278, 0.122},{ 0.304, -0.143, -0.308, 0.036},{ 0.272, -0.109, -0.329, 0.062},{ 0.234, -0.166, -0.240, 0.091},{ 0.217, -0.146, -0.275, 0.120},{ 0.259, -0.034, -0.308, -0.002} }, 
    {{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}} }, 
    0.000, { 0.166, 0.583, -0.691, -5.000, 0.149, 0.239, -0.650, -5.000, 0.172, 0.603, -0.043, -0.007, 0.666, -0.137, 0.236, -0.166, 0.549, 0.866, -0.073, -5.000, 0.332, -0.073, -0.269, -0.525, -0.593, 0.123, -0.313, -0.529, 0.281, 0.203, 0.120, -0.662, 0.132, 0.217, -0.420, 0.411, 0.490, 0.236, 0.100, -0.892, -0.634, 0.176, 0.094, -0.460, 0.267, 0.252, 0.513, 0.300, -0.266, 0.444, -0.853, -0.485, 0.118, 0.985, 0.284, -0.910, -0.129, 0.677, 0.251, -0.182, 0.243, 0.871, 0.899, -0.039, -0.136, 0.161, -1.255, -5.000, -0.321, -0.063, -1.536, -5.000, 0.419, 0.503, -0.341, 0.045, 0.872, -0.259, 0.285, -0.227, 0.473, 0.845, -0.228, -5.000, 0.893, 0.415, -0.024, -0.172, 0.075, 0.114, 0.108, -0.208, 0.613, 0.449, 0.293, -0.506, 0.736, 0.902, -0.308, 0.808, 0.644, 0.638, 0.412, -0.301, 0.246, 0.768, 0.566, 0.133, 0.763, 0.566, 0.798, 0.630, 0.402, 0.955, 0.046, 0.200, 0.520, 0.756, 0.509, -0.468, 0.067, 0.645, 0.266, 0.130, 0.906, 1.047, 1.219, 0.776, -0.868, -1.162, -1.764, -5.000, -1.721, -1.640, -1.647, -5.000, -0.645, -1.001, -1.437, -1.213, -1.061, -1.298, -1.520, -1.232, -0.881, -0.845, -1.359, -5.000, -1.057, -1.213, -1.782, -1.143, -1.246, -0.921, -0.846, -2.442, -0.725, -1.158, -1.548, -1.411, -1.178, -0.100, -1.523, -0.944, -1.345, -1.559, -2.126, -1.882, -1.346, -0.712, -1.108, -0.966, -1.151, -1.138, -0.879, -1.508, -1.090, -1.141, -1.718, -1.326, -1.531, -1.667, -2.005, -1.963, -1.574, -1.272, -1.932, -2.153, -1.366, -1.498, -1.184, -1.505, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.097, 0.532, -1.717, -5.000, -0.260, -0.158, -1.442, -5.000, 0.043, 0.540, -0.443, -0.295, 0.715, -0.246, 0.425, -0.493, 0.462, 0.873, -0.437, -5.000, -0.154, -0.626, -0.374, -0.886, -0.717, 0.031, -0.953, -1.363, -0.396, -0.092, -0.292, -1.072, 0.072, 0.215, -0.567, 0.341, -0.296, -0.230, -0.902, -1.022, -0.447, 0.178, -0.529, -0.862, -0.125, 0.206, 0.370, 0.235, -0.905, -0.399, -1.932, -1.070, -0.826, -0.166, -1.149, -1.875, -0.408, 0.585, -0.819, -0.434, -0.059, 0.409, 0.341, -0.494, -0.695, -0.663, -1.772, -5.000, -1.307, -0.783, -1.926, -5.000, 0.088, 0.316, -0.969, -0.405, 0.936, -0.236, 0.363, -0.519, 0.007, 0.242, -0.723, -5.000, 0.467, -0.302, -0.571, -0.547, -0.199, -0.134, -0.736, -0.617, 0.241, 0.510, 0.656, -0.655, 0.585, 0.786, -0.243, 0.814, 0.660, 0.550, 0.121, -0.001, 0.130, 0.597, -0.189, -0.324, 0.744, 1.001, 0.994, 0.970, -0.180, 0.293, -0.468, 0.070, -0.179, 0.147, -0.311, -0.733, -0.776, 0.011, -0.649, -0.715, 0.715, 1.038, 1.282, 0.833, -1.207, -1.542, -2.276, -5.000, -1.524, -1.619, -2.557, -5.000, -0.676, -0.380, -1.518, -1.087, -1.050, -1.580, -1.988, -1.534, -0.235, 0.008, -1.218, -5.000, -0.635, -1.469, -2.448, -1.542, -0.164, -0.560, -1.067, -1.053, -0.779, -0.543, -1.286, -1.883, -1.242, -1.173, -1.552, -1.370, -1.444, -1.150, -1.876, -2.045, -1.810, -0.523, -1.723, -1.533, -0.888, -1.078, -0.817, -1.307, -1.592, -1.523, -2.150, -1.552, -1.995, -1.602, -3.425, -2.185, -2.223, -1.207, -1.994, -1.738, -1.695, -1.117, -1.002, -1.946, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.464, 0.731, -0.625, -5.000, -0.248, 0.195, -1.417, -5.000, 0.329, 0.590, 0.196, -0.145, 0.936, 0.630, 0.729, -0.150, 0.886, 1.011, 0.042, -5.000, 0.325, 0.125, -0.274, -0.491, -0.325, 0.069, -0.162, -1.186, 0.327, 0.471, 0.388, -0.947, 0.749, 0.796, 0.235, 0.992, 0.292, 0.528, 0.032, -0.059, -0.034, 0.450, 0.012, -0.290, 0.421, 0.725, 0.910, 0.784, -0.187, 0.132, -0.680, -0.662, -0.604, 0.367, -0.072, -1.184, -1.035, -0.446, -1.498, -1.228, -0.176, 0.346, 0.525, -0.415, 0.263, 0.498, -2.015, -5.000, -0.585, 0.005, -1.851, -5.000, 0.524, 0.740, -0.353, 0.072, 1.270, 0.070, 0.876, -0.099, 0.793, 1.037, 0.321, -5.000, 0.573, 0.375, -0.349, -0.046, 0.190, 0.402, 0.118, -0.310, 0.555, 0.884, 0.756, -0.783, 0.922, 1.078, 0.137, 1.179, 0.534, 0.790, -0.023, 0.451, 0.181, 0.716, 0.140, 0.115, 1.140, 0.976, 1.257, 1.187, 0.705, 0.807, 0.165, 0.590, 0.252, 0.891, 0.508, 0.116, 0.111, 0.587, 0.082, -0.198, 0.847, 1.113, 1.170, 0.756, 0.294, 0.368, -1.336, -5.000, -0.111, -0.527, -1.152, -5.000, 0.048, 0.094, -0.659, -0.408, 0.260, -0.199, -0.300, -0.508, 0.199, 0.407, -0.460, -5.000, -0.328, -0.782, -1.144, -0.933, -0.957, -0.374, -1.036, -0.760, -0.066, 0.083, -0.175, -0.965, -0.018, 0.203, -0.791, -0.457, -0.632, -0.806, -0.986, -0.730, -0.710, -0.160, -0.778, -0.788, -0.315, -0.272, -0.006, -0.112, -0.159, -0.009, -0.971, -0.719, -0.734, -0.532, -1.811, -0.775, -0.812, -0.532, -1.174, -0.959, -0.500, -0.188, -0.131, -0.416, 0.470, 0.821, -1.016, -5.000, -0.051, 0.226, -0.712, -5.000, 0.028, 0.615, 0.029, -0.206, 0.478, 0.313, 0.243, -0.803, 0.441, 0.807, -0.114, -5.000, -0.071, -0.365, -0.854, -0.613, -0.890, -0.467, -0.900, -0.605, 0.098, -0.171, -0.558, -0.773, -0.107, 0.523, -0.235, 0.281, -0.467, 0.174, -0.493, -0.650, -0.571, -0.095, -0.665, -0.843, 0.063, 0.564, 0.687, 0.238, -0.301, 0.246, -0.671, -0.347, -0.695, 0.265, -0.155, -0.672, -0.802, -0.095, -0.974, -1.053, -0.221, 0.303, 0.340, -0.257, 0.433, 1.029, -1.007, -5.000, 0.436, 0.558, -0.611, -5.000, 0.992, 1.273, 0.624, 0.650, 1.275, 0.844, 0.861, 0.017, 1.255, 1.398, 0.654, -5.000, 1.083, 0.601, 0.055, 0.138, 0.329, 0.840, 0.179, -0.253, 0.879, 0.943, 0.611, -0.368, 1.164, 1.317, 0.612, 1.335, 0.973, 0.942, 0.827, 0.476, 0.913, 1.326, 0.666, 0.559, 0.910, 1.190, 1.223, 1.165, 0.294, 1.049, -0.150, 0.084, 0.240, 1.157, 0.365, -0.499, -0.470, 0.198, -0.429, -0.798, 0.138, 1.132, 0.586, 0.044, -0.632, -0.537, -1.459, -5.000, -0.975, -0.550, -1.323, -5.000, 0.102, 0.227, -0.652, -0.157, 0.687, -0.835, 0.494, -0.101, -0.063, 0.118, -0.733, -5.000, 0.098, -0.570, -0.941, -0.550, 0.152, 0.252, -0.086, -0.272, 0.132, 0.299, 0.398, -0.573, 0.263, 0.317, -0.593, 0.581, 0.200, -0.141, 0.228, -0.054, -0.095, 0.013, -0.285, -0.152, 0.716, 0.456, 0.570, 0.821, 0.060, 0.297, -0.404, -0.268, 0.284, 0.285, 0.250, -0.520, 0.062, 0.356, -0.162, -0.358, 0.495, 0.736, 0.862, 0.752, 0.326, 0.468, -2.352, -5.000, -0.208, -0.721, -1.240, -5.000, 0.217, 0.396, -0.388, -0.342, 0.256, -1.474, -0.540, -1.057, 0.492, 0.675, -0.083, -5.000, -0.085, -0.878, -0.884, -0.776, -0.155, 0.206, -0.692, -1.298, 0.223, 0.198, -0.156, -0.887, -0.381, -0.126, -1.019, -0.143, -0.776, -0.630, -0.982, -1.347, -0.102, 0.410, -0.222, -0.497, -0.187, 0.093, 0.237, 0.157, -0.252, -0.011, -1.381, -0.203, -0.657, -0.856, -1.424, -1.561, -1.184, -0.435, -1.474, -1.182, -0.193, 0.185, 0.178, -0.353, -0.029, 0.355, -1.184, -5.000, -0.403, -0.266, -1.148, -5.000, -0.367, -0.046, -0.623, -0.898, -0.272, -0.661, -1.002, -0.910, 0.145, 0.374, -0.450, -5.000, -0.376, -0.855, -1.403, -0.695, -0.929, -0.610, -0.941, -0.616, -0.141, -0.359, -1.066, -0.644, -0.836, -0.000, -0.732, -0.382, -0.827, -0.402, -1.097, -1.435, -0.925, -0.906, -1.053, -1.125, -0.335, -0.389, -0.079, -0.544, -0.277, 0.152, -0.643, -0.377, -0.514, -0.105, -0.744, -1.047, -0.720, -0.100, -0.956, -1.047, -0.185, 0.082, 0.147, -0.246, 0.554, 0.892, -0.503, -5.000, 0.739, 0.731, -0.146, -5.000, 0.841, 1.019, 0.631, 0.485, 1.310, 0.547, 0.610, 0.177, 0.989, 1.216, 0.526, -5.000, 0.884, 0.401, 0.190, -0.247, -0.125, 0.209, -0.162, -0.597, 0.709, 0.826, 0.461, -0.297, 0.608, 0.736, -0.309, 0.752, 0.573, 0.180, 0.049, -0.710, 0.676, 0.949, 0.609, -0.021, 0.303, 0.382, 0.429, 0.144, 0.018, 0.684, -0.958, -0.434, 0.561, 1.295, 0.822, -0.387, 0.021, 0.186, -0.085, -0.025, 0.697, 1.180, 0.856, 0.096, 0.064, 0.321, -1.328, -5.000, 0.053, 0.268, -1.240, -5.000, 1.082, 1.193, 0.321, 0.885, 1.353, -0.348, 0.887, 0.106, 0.784, 1.116, 0.297, -5.000, 1.208, 0.684, 0.514, 0.323, 0.392, 0.494, 0.447, -0.009, 1.016, 0.996, 0.750, -0.481, 0.976, 1.209, 0.228, 1.195, 0.885, 0.834, 0.487, -0.293, 0.860, 1.154, 0.849, 0.474, 1.167, 0.814, 0.997, 0.961, 0.797, 1.149, 0.235, 0.387, 0.813, 0.937, 0.758, -0.433, 0.179, 0.667, 0.257, 0.200, 1.050, 1.125, 1.186, 0.756, 0.188, 0.325, -1.567, -5.000, -0.130, -0.072, -1.259, -5.000, 0.205, 0.130, -0.525, -0.303, 0.712, -0.247, -1.209, -0.813, 0.222, 0.477, -0.088, -5.000, 0.183, -0.315, -0.620, -0.413, -0.893, -0.312, -0.739, -0.936, 0.392, -0.029, -0.355, -0.835, 0.484, 0.648, -0.198, 0.626, 0.013, 0.008, -0.391, -0.423, 0.406, 0.843, 0.436, 0.217, 0.267, 0.520, 0.442, 0.432, -0.458, -0.128, -0.848, -0.571, -0.202, 0.026, -0.549, -0.957, -1.313, -0.698, -1.426, -1.182, -0.451, -0.434, -0.280, -0.742, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.558, 1.038, -1.206, -5.000, 0.166, 0.535, -0.766, -5.000, 0.544, 0.854, 0.101, 0.145, 1.276, 0.761, 0.776, -0.132, 0.858, 1.211, 0.223, -5.000, 0.404, 0.211, 0.197, -0.489, -0.278, 0.244, -0.563, -0.794, 0.213, 0.663, 0.500, -0.597, 0.759, 1.050, 0.271, 1.094, 0.485, 0.419, 0.042, -0.169, 0.180, 0.701, -0.003, -0.147, 0.490, 0.819, 0.882, 0.761, -1.001, 0.055, -1.837, -1.086, -1.104, -0.324, -1.373, -1.652, 0.228, 0.620, -1.089, -0.333, -0.427, 0.719, 0.666, -0.212, -0.705, -0.509, -1.605, -5.000, -1.107, -0.836, -1.624, -5.000, 0.145, 0.480, -0.506, -0.269, 1.085, -0.341, -0.070, -0.209, 0.246, 0.345, -0.882, -5.000, 0.240, -0.172, -0.684, -0.644, -0.114, 0.050, -0.339, -0.568, 0.416, 0.651, 0.608, -0.525, 0.777, 0.734, -0.294, 1.010, 0.493, 0.256, -0.330, -0.046, 0.313, 0.608, -0.043, -0.210, 0.660, 0.572, 0.705, 0.953, 0.089, 0.418, -0.625, -0.194, -0.445, -0.148, -0.591, -0.857, -1.126, -0.752, -1.239, -1.383, 0.376, 0.372, 0.839, 0.341, -0.594, -0.227, -2.064, -5.000, -0.639, -1.044, -2.136, -5.000, -0.529, -0.547, -0.943, -0.600, 0.034, -0.650, -1.273, -1.212, -0.396, 0.108, -0.842, -5.000, -0.363, -0.696, -0.957, -1.108, -0.791, -0.187, -0.685, -0.942, -0.558, 0.052, -0.207, -0.915, 0.041, 0.092, -0.739, 0.249, -0.639, -0.806, -1.542, -0.890, -0.255, 0.041, -0.378, -0.636, -0.049, -0.070, 0.158, -0.003, -1.129, -0.826, -1.548, -1.454, -1.340, -1.135, -1.708, -1.753, -1.502, -1.870, -2.126, -1.752, -1.676, -1.625, -1.414, -1.160, 0.043, 0.392, -1.552, -5.000, -0.749, -0.497, -1.364, -5.000, -0.379, -0.050, -0.800, -0.702, 0.053, -0.210, -0.951, -1.132, 0.178, 0.362, -0.273, -5.000, -0.430, -0.539, -1.157, -0.772, -1.184, -0.721, -0.905, -1.431, -0.237, -0.420, -0.724, -0.720, 0.057, 0.749, -0.508, 0.226, -0.594, 0.047, -0.336, -0.718, -0.331, 0.128, -0.897, -0.852, -0.077, 0.182, 0.318, -0.040, -0.525, -0.356, -1.006, -0.637, -1.410, -1.148, -2.010, -1.922, -2.003, -1.603, -1.918, -1.617, -1.541, -0.989, -1.408, -0.405, -0.223, -0.244, -2.228, -5.000, -0.810, -0.439, -5.000, -5.000, -0.090, 0.204, -0.563, -0.543, 0.525, 0.107, 0.228, -0.355, 0.403, 0.350, -0.346, -5.000, -0.205, -0.602, -0.427, -0.895, -0.544, -0.194, -0.861, -1.027, -0.082, 0.067, 0.314, -0.801, 0.338, 0.482, 0.133, 0.594, -0.186, -0.030, -0.177, -0.375, -0.385, 0.064, -0.296, -0.622, 0.046, 0.349, 0.241, 0.351, -0.951, -0.467, -0.901, -0.654, -1.198, -0.372, -1.053, -0.839, -2.125, -1.328, -1.191, -1.755, -0.364, -0.108, 0.210, -0.643, -0.062, -0.070, -0.833, -5.000, -0.971, -0.380, -1.512, -5.000, 0.232, 0.613, -0.503, -0.120, 1.136, -0.431, 0.103, -0.049, 0.381, 0.642, -0.309, -5.000, 0.138, 0.138, -0.279, -0.804, -0.588, 0.135, -0.143, -0.610, 0.324, 0.650, 0.511, -0.922, 0.782, 0.880, -0.282, 1.067, 0.182, 0.275, -0.242, 0.111, 0.228, 0.539, 0.063, -0.368, 0.700, 0.567, 0.520, 0.849, 0.239, 0.514, -0.203, 0.020, -0.545, 0.297, 0.308, -0.416, -0.152, 0.127, -0.497, -0.401, 0.415, 0.752, 0.671, 0.208, -0.010, -0.067, -1.455, -5.000, -0.463, -0.530, -1.201, -5.000, -0.493, -0.383, -0.951, -0.626, 0.118, -0.166, -0.614, -0.897, 0.070, -0.242, -0.498, -5.000, -0.389, -0.813, -1.218, -0.921, -0.914, -0.347, -0.893, -0.908, -0.197, 0.023, -0.383, -0.438, 0.228, 0.343, -0.353, 0.006, -0.055, -0.223, -0.973, 0.006, -0.349, -0.113, -0.569, -0.532, 0.041, 0.421, 0.326, 0.297, -0.622, -0.027, -1.110, -0.670, -0.810, -0.305, -1.590, -0.385, -1.240, -0.891, -0.907, -1.035, -0.781, -0.599, -0.276, -0.397, -0.372, 0.115, -1.111, -5.000, -1.121, -0.520, -0.995, -5.000, -0.908, 0.194, -0.550, -0.624, -0.015, -0.079, -0.199, -0.509, -0.387, 0.124, -0.643, -5.000, -0.736, -0.946, -1.671, -0.850, -1.574, -0.889, -1.037, -1.378, -0.242, -0.493, -0.343, -0.782, -0.634, -0.172, -0.460, -0.203, -0.617, -0.421, -0.413, -0.935, -0.645, -0.352, -1.207, -1.119, -0.508, 0.076, 0.325, -0.258, -0.705, -0.072, -0.731, -0.882, -0.756, -0.497, -0.605, -0.870, -1.275, -0.913, -1.119, -1.077, -0.710, -0.309, -0.276, -0.563, -0.098, 0.876, -0.916, -5.000, -0.144, 0.304, -0.591, -5.000, 0.350, 0.912, 0.225, 0.096, 1.162, 0.649, 0.632, 0.055, 0.950, 1.155, 0.128, -5.000, 0.283, 0.098, -0.187, -0.439, -0.652, 0.067, -0.884, -0.834, 0.203, 0.368, 0.141, -0.598, 0.761, 0.964, 0.315, 0.958, 0.432, 0.555, 0.297, 0.004, 0.287, 0.804, -0.026, -0.108, 0.402, 0.752, 0.899, 0.573, -0.325, 0.516, -0.630, -0.354, -0.551, 0.240, 0.055, -0.981, -1.131, -0.828, -1.194, -1.035, -0.533, 0.277, -0.130, -0.660, -0.297, -0.019, -1.286, -5.000, -0.542, 0.072, -2.118, -5.000, 0.322, 0.578, -0.349, -0.113, 1.270, -0.311, 0.366, -0.230, 0.598, 0.781, -0.265, -5.000, 0.395, -0.037, -0.150, -0.626, 0.178, 0.387, -0.012, -0.151, 0.340, 0.632, 0.613, -0.738, 0.928, 1.040, 0.145, 1.024, 0.332, 0.737, 0.729, -0.003, 0.469, 0.705, 0.194, 0.080, 1.129, 0.726, 1.179, 1.017, 0.525, 0.919, 0.109, 0.324, 0.378, 0.790, 0.639, 0.025, 0.163, 0.464, 0.068, -0.205, 0.701, 0.992, 1.120, 0.587, 0.779, 1.041, -1.392, -5.000, 0.529, 0.373, -0.594, -5.000, 0.493, 0.703, -0.020, 0.174, 0.988, 0.265, 0.090, -0.017, 0.531, 0.549, 0.094, -5.000, 0.235, -0.425, -0.695, -0.647, -0.344, 0.042, -0.642, -0.626, 0.385, 0.387, -0.018, -0.640, 0.348, 0.637, -0.265, 0.341, 0.059, 0.196, -0.139, -0.409, -0.054, 0.619, 0.000, -0.436, 0.225, 0.573, 0.606, 0.294, -0.316, 0.325, -0.831, -0.536, -0.277, 0.046, -0.198, -0.809, -0.966, -0.356, -1.124, -1.147, -0.158, 0.218, 0.231, -0.103, -0.373, -0.289, -1.494, -5.000, -0.442, -0.566, -1.718, -5.000, -1.181, -0.621, -1.366, -1.131, -0.569, -0.770, -1.069, -0.837, -0.256, -0.266, -1.104, -5.000, -0.724, -1.007, -1.217, -0.962, -1.060, -1.020, -1.259, -1.503, -0.609, -0.809, -1.171, -0.917, -1.190, -0.758, -0.866, -0.840, -1.166, -0.674, -1.034, -0.917, -1.372, -1.119, -1.486, -1.237, -0.952, -0.944, -0.423, -0.731, -0.734, -0.794, -0.916, -1.041, -1.069, -0.356, -0.619, -1.012, -1.044, -0.947, -1.269, -1.351, -0.537, -0.549, -0.028, -0.522, 0.260, 0.764, -0.814, -5.000, 0.202, 0.485, -1.120, -5.000, 0.867, 0.983, 0.874, 0.386, 1.106, 0.294, 0.535, -0.294, 0.844, 1.107, 0.463, -5.000, 0.641, 0.223, -0.218, 0.006, -0.146, 0.270, -0.121, -0.734, 0.466, 0.710, 0.314, -0.577, 0.661, 0.642, 0.178, 0.943, 0.721, 0.400, -0.235, -0.321, 0.764, 1.090, 0.836, 0.337, 0.398, 0.498, 0.616, 0.559, -0.041, 0.487, -0.788, -0.615, 0.303, 0.870, 0.098, -0.529, -0.079, 0.556, -0.138, -0.175, 0.123, 0.789, 0.443, -0.098, -0.588, -0.036, -1.040, -5.000, -0.150, 0.404, -1.438, -5.000, 0.866, 0.907, -0.054, 0.637, 1.285, -0.719, 0.151, -0.210, 0.666, 1.016, 0.209, -5.000, 1.079, 0.727, 0.097, 0.238, 0.195, 0.598, 0.520, 0.118, 0.941, 1.066, 0.752, -0.470, 0.868, 1.204, 0.448, 1.290, 0.913, 0.808, 0.320, 0.300, 0.772, 1.130, 0.831, 0.483, 1.147, 0.980, 1.092, 1.225, 0.612, 0.973, 0.252, 0.503, 0.739, 0.891, 0.572, 0.106, 0.356, 0.794, 0.249, 0.245, 1.035, 1.191, 1.223, 1.117, 0.108, 0.341, -1.620, -5.000, -0.239, -0.256, -1.483, -5.000, 0.189, -0.073, -0.512, -0.313, 0.715, -0.580, -1.565, -1.102, 0.417, 0.612, -0.127, -5.000, 0.352, -0.299, -0.979, -0.586, -0.540, -0.588, -0.310, -0.754, 0.334, 0.255, -0.386, -1.260, 0.027, 0.383, -0.253, 0.336, -0.314, -0.080, -0.921, -0.546, 0.143, 0.710, 0.248, 0.151, 0.070, 0.443, 0.265, 0.098, -0.381, -0.095, -0.849, -0.669, -0.634, -0.278, -1.543, -1.033, -1.452, -0.644, -1.274, -1.665, -0.823, -0.634, -0.617, -0.973, 0.661, 0.864, -0.739, -5.000, 0.198, 0.445, -1.080, -5.000, 0.195, 0.536, -0.147, 0.004, 0.907, 0.361, -0.334, -0.683, 1.060, 1.152, 0.677, -5.000, 0.828, 0.113, -0.822, 0.320, -0.741, -0.236, -0.688, -0.807, 0.684, 0.356, -0.015, -1.010, 1.282, 1.568, 1.153, 1.508, 1.129, 1.343, 1.120, 0.903, 1.463, 1.595, 1.309, 1.322, 1.344, 1.598, 1.515, 1.194, 0.707, 1.083, -0.036, 0.362, 0.644, 0.691, 0.264, -0.599, -0.761, 0.126, -0.971, -0.643, 0.385, 0.632, 0.638, -0.099, 0.129, 0.667, -1.515, -5.000, -0.296, 0.334, -1.158, -5.000, 0.299, 0.565, 0.138, 0.037, 1.109, 0.276, 0.563, -0.362, 0.610, 0.860, 0.287, -5.000, 0.194, -0.234, -0.781, -0.334, 0.118, 0.125, -0.423, -0.897, 0.339, 0.711, 0.309, -0.655, 0.247, 0.537, -0.314, 0.804, -0.073, -0.206, -0.701, -0.626, 0.120, 0.250, -0.218, -0.154, 0.020, 0.339, 0.476, 0.320, -1.319, -0.661, -1.961, -1.017, -0.577, -0.030, -0.452, -1.666, -1.319, 0.005, -0.345, -0.801, -0.121, 0.508, 0.346, -0.309, -0.705, -0.436, -1.592, -5.000, -1.039, -0.491, -1.988, -5.000, 0.486, 0.721, -0.582, 0.389, 1.134, -0.596, 0.716, 0.290, 0.121, 0.468, -0.267, -5.000, 0.658, 0.218, -0.428, -0.355, 0.015, 0.365, -0.033, -0.341, 0.720, 0.728, 0.548, -0.529, 0.570, 0.831, -0.155, 1.226, 0.439, 0.322, -0.090, 0.222, 0.401, 0.688, 0.138, -0.027, 0.418, 0.499, 0.563, 0.888, 0.014, 0.269, -0.449, -0.083, -0.063, -0.041, -0.159, -0.475, -0.460, -0.009, -0.665, -0.546, 0.437, 0.484, 0.705, 0.667, -0.098, 0.404, -2.173, -5.000, -0.340, -0.602, -1.919, -5.000, -0.177, 0.158, -0.413, 0.140, -0.036, -0.762, -1.028, -1.773, -0.046, 0.371, -0.077, -5.000, 0.212, -0.564, -0.906, -0.741, 0.277, 0.297, -0.666, -0.406, 0.106, 0.136, -0.161, -0.921, -0.140, 0.353, -0.628, 0.425, -0.368, -0.289, -0.999, -0.567, -0.130, 0.334, 0.086, -0.332, -0.294, 0.176, 0.104, -0.068, -1.465, -0.537, -1.096, -0.515, -0.940, -0.919, -1.292, -1.030, -2.074, -1.107, -1.695, -1.097, -1.800, -1.011, -1.211, -0.850, -0.013, 0.247, -1.234, -5.000, -0.409, -0.524, -1.353, -5.000, -0.068, 0.117, -0.943, -0.243, 0.202, -0.228, -0.935, -1.420, 0.251, 0.346, -0.141, -5.000, 0.051, -0.636, -1.123, -0.639, -1.083, -0.448, -0.665, -0.588, 0.169, -0.123, -0.613, -0.713, -0.104, 0.305, -0.167, 0.383, -0.332, -0.235, -0.406, -0.621, -0.349, 0.036, -0.607, -0.477, -0.096, 0.195, -0.044, 0.026, -0.772, -0.659, -1.139, -0.771, -1.243, -1.194, -1.963, -1.345, -2.124, -1.258, -1.309, -1.641, -1.185, -0.703, -0.717, -1.138, 0.111, 0.547, -1.178, -5.000, -0.305, 0.103, -1.547, -5.000, 0.353, 0.556, 0.076, -0.085, 0.907, 0.420, 0.310, -0.360, 0.506, 0.757, -0.042, -5.000, 0.284, 0.173, -0.528, -0.369, -0.235, 0.046, -0.256, -0.463, 0.244, 0.411, -0.021, -0.912, 0.440, 0.688, -0.043, 0.993, 0.084, 0.240, -0.385, -0.120, -0.053, 0.364, -0.103, -0.269, 0.039, 0.545, 0.289, 0.218, -0.511, 0.111, -1.236, -0.535, -0.647, 0.073, -0.736, -1.209, -1.111, -0.643, -0.654, -1.243, -0.573, -0.000, -0.359, -0.582, -0.019, 0.460, -1.530, -5.000, -0.455, 0.354, -1.556, -5.000, 0.620, 0.870, -0.102, 0.427, 1.354, 0.003, 0.139, -0.224, 0.669, 1.071, 0.471, -5.000, 0.730, 0.620, 0.016, -0.046, 0.178, 0.616, 0.210, -0.189, 0.539, 0.981, 0.605, -0.748, 1.145, 1.292, 0.265, 1.374, 0.551, 0.638, -0.061, 0.234, 0.519, 0.815, 0.157, 0.119, 0.883, 0.787, 0.772, 0.792, 0.468, 0.795, -0.058, 0.275, 0.094, 0.578, 0.043, -0.381, -0.139, 0.323, -0.240, -0.408, 0.214, 0.934, 0.862, 0.426, 0.431, 0.500, -1.353, -5.000, -0.050, -0.268, -1.528, -5.000, 0.214, 0.301, -0.363, -0.272, 0.797, 0.360, -0.088, -0.581, 0.383, 0.489, -0.339, -5.000, -0.099, -0.586, -1.247, -1.262, -0.434, -0.075, -0.824, -0.658, 0.116, 0.195, -0.156, -1.015, 0.581, 0.804, -0.151, 0.385, -0.184, -0.162, -0.720, -0.039, -0.196, 0.188, -0.224, -0.459, 0.066, 0.302, 0.173, 0.018, -0.477, 0.063, -1.127, -0.585, -0.716, -0.530, -1.901, -0.823, -0.661, -0.679, -1.155, -1.311, -0.701, -0.543, -0.456, -0.704, 0.370, 0.419, -0.940, -5.000, -0.074, -0.118, -1.095, -5.000, -0.022, 0.320, -0.251, -0.355, 0.379, -0.017, -0.251, -0.911, 0.125, 0.353, -0.072, -5.000, -0.129, -0.366, -1.157, -0.775, -0.676, -0.189, -0.659, -0.926, -0.082, -0.162, -0.639, -0.852, -0.028, 0.465, -0.403, 0.205, -0.380, -0.060, -0.434, -0.645, -0.512, -0.382, -0.723, -0.743, -0.277, -0.083, 0.036, -0.365, -0.262, 0.038, -0.978, -0.535, -0.905, -0.364, -0.632, -1.166, -1.120, -0.786, -1.065, -1.142, -0.513, -0.348, -0.212, -0.483, 0.172, 0.835, -0.849, -5.000, 0.092, 0.314, -1.631, -5.000, 0.615, 0.795, 0.383, 0.299, 1.150, 0.294, 0.410, 0.120, 0.830, 1.095, 0.311, -5.000, 0.678, 0.221, -0.593, -0.105, -0.218, 0.078, -0.295, -0.455, 0.556, 0.790, 0.302, -0.581, 0.615, 0.761, 0.030, 1.076, 0.162, 0.100, -0.361, -0.332, 0.271, 0.658, 0.099, 0.130, 0.174, 0.492, 0.318, 0.265, -0.064, 0.407, -0.731, -0.216, -0.478, 0.272, -0.645, -0.728, -0.843, -0.766, -0.745, -0.937, -0.399, 0.169, -0.311, -0.508, -0.375, -0.032, -1.333, -5.000, -0.178, 0.169, -1.480, -5.000, 0.590, 0.757, -0.510, 0.453, 1.212, -0.450, 0.698, 0.133, 0.668, 0.856, 0.277, -5.000, 0.794, 0.305, -0.114, -0.067, 0.577, 0.860, 0.429, 0.338, 0.671, 0.847, 0.514, -0.723, 0.862, 0.904, 0.238, 1.257, 0.511, 0.096, 0.352, 0.170, 0.604, 0.771, 0.246, 0.228, 0.843, 0.572, 0.531, 0.835, 0.447, 0.704, -0.149, 0.039, 0.289, 0.700, 0.420, 0.032, 0.045, 0.410, -0.223, -0.217, 0.417, 0.878, 0.774, 0.513, 1.073, 1.135, -1.077, -5.000, 0.902, 0.783, -0.471, -5.000, 1.031, 0.966, 0.423, 0.861, 1.242, 0.383, 0.134, 0.109, 0.887, 0.856, 0.647, -5.000, 1.108, 0.330, -0.160, 0.284, 0.097, 0.587, -0.020, 0.072, 0.943, 0.813, 0.465, -0.612, 0.689, 0.884, 0.390, 0.996, 0.445, 0.406, 0.417, -0.015, 0.521, 0.882, 0.566, 0.287, 0.328, 0.565, 0.455, 0.480, 0.094, 0.205, -0.654, -0.379, 0.148, 0.340, -0.005, -0.422, -0.566, -0.271, -0.965, -1.059, -0.061, 0.126, -0.204, -0.219, 0.687, 0.839, -0.339, -5.000, 0.636, 0.678, -0.673, -5.000, 0.581, 0.786, 0.300, 0.591, 1.036, 0.559, 0.294, -0.144, 0.261, 0.575, 0.273, -5.000, 0.634, -0.036, -0.492, 0.088, -0.413, -0.088, -0.595, -0.290, 0.420, 0.355, 0.035, -0.512, 0.829, 1.169, 0.674, 1.065, 0.362, 0.625, 0.506, -0.030, 0.484, 0.800, 0.406, 0.106, 0.172, 0.812, 0.882, 0.523, -0.214, 0.341, -0.401, -0.380, -0.152, 0.236, 0.244, -0.772, -0.554, -0.250, -0.898, -0.821, -0.282, 0.066, 0.204, -0.268, 0.089, 0.438, -0.061, -5.000, -0.299, -0.241, -0.710, -5.000, 0.352, 0.528, 0.154, -0.038, 0.472, 0.204, 0.123, -0.303, 0.325, 0.454, -0.345, -5.000, 0.040, -0.485, -0.781, -0.547, -0.557, -0.211, -0.794, -0.900, 0.147, 0.348, -0.023, -0.655, 0.404, 0.255, -0.392, 0.718, -0.097, -0.354, -0.796, -0.814, 0.391, 0.697, -0.021, -0.060, 0.143, 0.142, 0.219, 0.271, -0.195, -0.329, -1.563, -0.621, -0.481, -0.132, -1.018, -0.993, -0.268, 0.254, -0.427, -0.228, 0.117, 0.381, 0.077, -0.259, -0.347, -0.048, -1.326, -5.000, -0.488, -0.411, -1.830, -5.000, 0.548, 0.794, -0.302, 0.483, 1.068, -0.276, 0.348, 0.215, 0.433, 0.707, -0.341, -5.000, 0.748, 0.450, -0.322, 0.035, 0.329, 0.593, 0.247, 0.177, 0.765, 0.927, 0.527, -0.442, 0.689, 0.877, -0.221, 0.978, 0.322, 0.299, -0.042, -0.317, 0.707, 1.039, 0.552, 0.235, 0.831, 0.487, 0.660, 0.878, 0.357, 0.754, -0.215, 0.296, 0.228, 0.572, 0.159, -0.471, -0.002, 0.441, 0.054, 0.068, 0.671, 0.986, 1.009, 0.641, -0.281, -0.276, -1.862, -5.000, -0.797, -1.027, -2.188, -5.000, -0.519, -0.540, -0.997, -0.552, 0.066, -1.007, -1.802, -0.623, -0.333, -0.374, -0.920, -5.000, -0.372, -0.948, -1.480, -1.077, -1.428, -0.718, -0.924, -1.265, -0.362, -0.347, -0.763, -0.786, -0.222, -0.080, -0.869, 0.107, -0.891, -0.893, -1.218, -0.773, -0.248, 0.265, -0.476, -0.230, -0.417, 0.026, -0.311, -0.205, -0.598, -0.540, -1.231, -0.712, -1.092, -0.985, -1.874, -1.465, -1.598, -1.315, -1.780, -1.409, -1.180, -0.891, -0.966, -1.013, 0.080, -0.051, -1.246, -5.000, -0.615, -0.632, -1.519, -5.000, -0.575, 0.015, -0.711, -0.505, 0.070, -0.544, -0.630, -0.575, 0.177, -0.233, -0.585, -5.000, -0.201, -0.872, -1.433, -0.682, -0.688, -0.832, -0.868, -1.101, -0.108, -0.290, -0.671, -0.544, 0.391, 0.519, -0.281, 0.807, 0.142, -0.014, -0.015, -0.159, 0.311, 0.584, 0.058, 0.341, 0.364, 0.461, 0.244, 0.469, -0.024, -0.076, -0.699, -0.559, -0.269, -0.403, -0.870, -0.860, -0.673, -0.427, -1.110, -0.860, -0.329, -0.206, -0.527, -0.444, 0.025, 0.237, -1.291, -5.000, -0.741, -0.314, -1.680, -5.000, -0.434, -0.054, -0.589, -0.613, 0.821, 0.409, 0.264, -0.266, 0.126, 0.267, -0.462, -5.000, -0.241, -0.571, -0.819, -0.770, -0.435, -0.400, -1.251, -1.124, -0.086, 0.429, -0.199, -0.805, 0.251, 0.586, -0.554, 0.676, -0.239, -0.439, -1.308, -0.649, -0.194, 0.115, -0.721, -0.377, -0.106, 0.177, 0.282, 0.238, -1.028, -0.863, -1.843, -0.981, -1.127, -0.562, -1.788, -1.499, -1.158, -0.914, -1.238, -0.207, -0.077, 0.221, 0.400, -0.129, -0.332, -0.286, -1.716, -5.000, -0.959, -0.601, -2.342, -5.000, 0.549, 0.841, -0.405, 0.293, 1.172, -0.481, 0.638, -0.195, 0.439, 0.569, -0.838, -5.000, 0.602, 0.161, -0.578, -0.259, 0.394, 0.677, -0.187, -0.292, 0.749, 0.990, 0.789, -0.135, 0.539, 0.613, -0.454, 1.175, 0.531, 0.289, -0.976, 0.285, 0.440, 0.688, 0.114, 0.111, 0.665, 0.866, 0.656, 1.042, 0.150, 0.646, -0.689, 0.186, -0.068, 0.325, -0.188, -0.452, -0.618, -0.098, -0.711, -0.848, 0.482, 0.863, 0.836, 0.478, 0.077, 0.079, -2.526, -5.000, -0.567, -0.564, -1.574, -5.000, 0.008, 0.393, -1.035, -0.227, 0.297, -0.578, -1.276, -0.789, 0.343, 0.552, -0.928, -5.000, -0.142, -0.823, -1.502, -1.509, -0.959, -0.477, -2.044, -0.857, -0.017, 0.233, -0.301, -0.958, 0.236, 0.158, -0.946, 0.451, -0.268, -0.128, -1.390, -0.424, -0.106, 0.646, -0.264, -0.240, -0.426, 0.394, 0.403, 0.091, -0.761, -0.301, -1.632, -1.216, -1.298, -0.879, -1.600, -1.711, -1.882, -1.520, -2.259, -3.896, -1.324, -0.924, -0.818, -0.704, -0.179, -0.026, -1.723, -5.000, -0.909, -0.999, -2.230, -5.000, -0.795, -0.325, -1.380, -1.110, -0.051, -0.725, -1.359, -1.546, -0.089, -0.302, -1.091, -5.000, -0.748, -1.122, -1.502, -1.288, -0.847, -1.078, -2.321, -1.111, -0.150, -0.727, -0.893, -0.511, -0.126, 0.089, -0.905, 0.144, -0.809, -0.590, -1.135, -0.924, -0.652, -0.233, -1.113, -1.010, -0.404, -0.255, -0.350, -0.548, -0.828, -0.764, -1.235, -0.594, -1.661, -1.654, -2.000, -1.433, -2.513, -1.099, -1.673, -1.647, -0.770, -0.737, -1.193, -0.786, -0.309, -0.395, -1.417, -5.000, -1.114, -1.425, -2.673, -5.000, -0.214, 0.184, -0.589, -0.415, 0.278, 0.123, 0.046, -0.468, -0.051, -0.524, -1.235, -5.000, -0.523, -0.780, -1.138, -1.176, -1.097, -0.209, -1.022, -0.897, 0.007, 0.002, -0.227, -0.929, 0.028, -0.024, -1.063, 0.399, -0.607, -0.736, -1.931, -1.272, -0.607, -0.157, -0.905, -0.817, -0.218, -0.112, -0.329, -0.046, -0.962, -0.528, -1.996, -1.077, -1.115, -0.976, -1.834, -1.648, -0.973, -0.828, -1.058, -1.308, -0.454, -0.249, -0.212, -0.760, -0.558, -0.272, -2.170, -5.000, -0.859, -0.605, -1.752, -5.000, 0.069, 0.416, -1.118, -0.261, 0.963, -0.278, -0.008, -0.158, 0.228, 0.396, -0.401, -5.000, 0.288, 0.049, -0.478, -0.469, -0.329, 0.408, -0.456, -0.325, 0.324, 0.685, -0.051, -0.744, 0.540, 0.711, -0.418, 0.940, 0.091, 0.073, -1.041, -0.242, 0.044, 0.303, -0.280, -0.538, 0.541, 0.402, 0.297, 0.401, -0.102, 0.184, -0.819, 0.028, -0.445, 0.048, -0.801, -1.050, -0.433, -0.012, -0.593, -0.714, 0.236, 0.476, 0.432, 0.117, -0.110, -0.356, -1.960, -5.000, -0.855, -1.309, -2.104, -5.000, -0.272, -0.363, -0.752, -0.527, 0.166, -0.501, -1.009, -0.949, -0.547, -0.587, -1.402, -5.000, -0.798, -1.233, -1.743, -1.212, -0.965, -0.698, -1.381, -1.246, -0.174, -0.145, -0.960, -0.849, 0.070, 0.244, -0.833, 0.026, -0.967, -1.117, -1.587, -0.947, -0.597, -0.399, -0.843, -0.623, -0.391, -0.351, -0.483, -0.160, -0.665, -0.485, -1.353, -0.897, -0.880, -1.295, -1.614, -1.196, -1.560, -1.516, -1.615, -1.514, -1.063, -1.037, -1.056, -0.881, -0.269, 0.061, -1.489, -5.000, -0.682, -0.921, -1.647, -5.000, -0.613, -0.091, -1.054, -0.871, -0.226, -0.508, -0.901, -1.176, -0.362, -0.052, -0.831, -5.000, -0.763, -1.250, -1.578, -0.966, -1.087, -0.677, -1.129, -1.524, -0.320, -0.419, -0.894, -1.028, -0.336, 0.019, -0.886, -0.006, -0.726, -0.609, -1.032, -0.878, -0.702, -0.486, -1.145, -1.013, -0.311, -0.150, 0.008, -0.393, -0.714, -0.189, -1.202, -0.460, -1.022, -1.120, -1.568, -1.520, -1.257, -1.172, -1.457, -1.378, -0.661, -0.776, -0.489, -0.686, 0.015, 0.575, -1.283, -5.000, -0.378, -0.279, -1.398, -5.000, 0.214, 0.663, -0.168, -0.063, 0.591, 0.470, 0.395, -0.038, 0.386, 0.561, -0.187, -5.000, 0.157, -0.032, -0.698, -0.592, -0.425, 0.164, -0.291, -0.388, 0.297, 0.482, -0.106, -0.253, 0.467, 0.591, -0.349, 0.844, -0.256, -0.176, -0.507, -0.526, -0.073, 0.629, -0.167, -0.090, -0.010, 0.415, 0.300, 0.354, -0.163, 0.130, -0.885, -0.148, -0.580, -0.090, -1.314, -1.151, -0.834, -0.585, -0.778, -0.686, -0.226, 0.249, -0.189, -0.307, -0.389, 0.014, -1.767, -5.000, -0.571, -0.018, -1.501, -5.000, 0.511, 0.843, -0.687, 0.165, 1.035, -0.218, 0.327, -0.169, 0.548, 0.819, -0.214, -5.000, 0.680, 0.379, -0.280, -0.107, 0.542, 0.846, 0.084, 0.224, 0.625, 0.855, 0.310, -0.419, 0.831, 0.982, 0.152, 1.101, 0.224, 0.295, 0.206, 0.300, 0.500, 0.910, 0.318, 0.291, 0.845, 0.846, 0.809, 0.862, 0.353, 0.773, -0.160, 0.125, 0.334, 0.699, 0.284, -0.269, 0.060, 0.620, -0.097, -0.091, 0.353, 0.763, 0.790, 0.475, 0.875, 1.153, -0.973, -5.000, 0.641, 0.544, -0.520, -5.000, 0.487, 0.848, -0.038, 0.600, 0.920, 0.345, 0.110, 0.466, 0.633, 0.656, 0.340, -5.000, 0.599, -0.065, -0.582, 0.100, -0.227, 0.329, -0.453, -0.523, 0.723, 0.732, 0.194, 0.140, 0.570, 0.869, 0.035, 0.980, 0.163, 0.551, 0.119, -0.161, 0.352, 0.849, 0.253, 0.122, 0.334, 0.705, 0.549, 0.534, 0.053, 0.344, -0.664, -0.366, -0.051, 0.414, -0.647, -0.481, -0.654, -0.151, -1.102, -0.527, -0.078, -0.073, -0.203, -0.406, 0.264, 0.612, -0.997, -5.000, 0.059, 0.233, -0.898, -5.000, 0.011, 0.277, -0.432, -0.163, 0.291, 0.420, -0.104, -0.415, -0.031, 0.154, -0.334, -5.000, -0.291, -0.650, -0.841, -0.513, -0.973, -0.174, -0.924, -0.594, 0.064, 0.000, -0.622, -0.374, 0.356, 0.927, -0.210, 0.499, 0.135, 0.482, -0.127, -0.340, -0.098, 0.237, -0.304, -0.349, 0.076, 0.357, 0.520, 0.172, -0.261, 0.101, -0.797, -0.375, -0.724, -0.209, -0.518, -0.797, -0.866, -0.469, -1.231, -0.918, -0.563, -0.263, -0.352, -0.327 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_17(struct _training *tptr) {
  struct _training tinf = {
    0.333, 11, 4.350, { 2.559, 0.279, 0.162 }, { 0.646, -1.061, -1.468 }, 1, 
    { -0.766, -0.243, -2.130, -1.116, -1.435, -4.000, -1.313, -4.000, 2.524, -1.694, -4.000, -4.000, -4.000, 0.875, 2.121, -0.448, 2.062, -4.000, 2.318, 1.886, -4.000, -4.000, 1.663, -4.000, 2.827, -4.000, -4.000, 2.913 }, 
    {{ -0.087, -0.649, -0.014, 0.284},{ 0.096, -0.894, -0.387, 0.303},{ 0.183, -0.494, -0.494, 0.172},{ 0.168, -0.419, -0.408, 0.144},{ 0.143, -0.294, -0.360, 0.117},{ 0.262, -0.537, -0.387, 0.066},{ 0.229, -0.408, -0.329, 0.048},{ 0.258, -0.453, -0.556, 0.096},{ 0.239, -0.550, -0.453, 0.116},{ 0.197, -0.636, -0.425, 0.174},{ 0.174, -0.519, -0.350, 0.148},{ 0.194, -0.334, -0.500, 0.117},{ 0.144, -0.339, -0.365, 0.132},{ 0.144, -0.329, -0.339, 0.120},{ 0.089, -0.270, -0.324, 0.151},{ 0.192, -0.414, -0.350, 0.099},{ 0.189, -0.397, -0.289, 0.078},{ 0.180, -0.299, -0.414, 0.096},{ 0.245, -0.397, -0.608, 0.107},{ 0.223, -0.537, -0.425, 0.122},{ 0.238, -0.324, -0.622, 0.096},{ 0.248, -0.392, -0.494, 0.073},{ 0.197, -0.260, -0.365, 0.048},{ 0.120, -0.119, -0.289, 0.052},{ 0.154, -0.214, -0.265, 0.045},{ 0.132, -0.214, -0.201, 0.045},{ 0.248, -0.334, -0.387, 0.020},{ 0.222, -0.228, -0.314, -0.012},{ 0.229, -0.289, -0.459, 0.050},{ 0.222, -0.299, -0.506, 0.076},{ 0.195, -0.408, -0.360, 0.098},{ 0.189, -0.365, -0.425, 0.111} }, 
    {{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}} }, 
    0.000, { 0.560, 1.205, -0.093, -5.000, 0.330, 1.242, -0.422, -5.000, 0.685, 1.346, 0.700, 0.701, 0.594, 1.034, -0.158, 0.564, -0.359, 0.240, -0.370, -5.000, -0.418, -0.409, -1.585, -0.779, -0.330, 0.277, -0.279, -0.434, 0.494, -0.024, -1.094, -0.224, 0.381, 1.139, 0.252, 0.442, -0.077, 0.238, -1.600, -1.330, -0.057, 0.035, -0.796, -0.680, 0.079, 0.093, 0.020, -0.651, 0.402, 1.022, -0.097, 0.075, 0.050, 0.802, -1.104, -0.299, 0.489, 1.060, 0.420, 0.164, 0.293, 0.805, 0.375, -0.176, 1.303, 1.578, 0.170, -5.000, 1.189, 1.500, 0.295, -5.000, 0.858, 1.436, 1.088, 1.020, 1.062, 1.321, 0.720, 1.089, 0.378, 0.758, 0.199, -5.000, 0.889, 1.094, 0.065, 0.421, 0.085, 0.244, 0.455, 0.228, 0.814, 0.103, -0.837, -0.117, 1.220, 1.673, 1.074, 1.348, 1.204, 1.507, 0.675, 0.619, 1.198, 1.188, 0.954, 0.870, 1.251, 1.357, 1.362, 0.394, 0.993, 1.547, 0.394, 0.942, 1.094, 1.246, 0.488, 0.678, 1.239, 1.376, 1.209, 0.910, 1.239, 1.467, 1.325, 0.706, -0.305, 0.426, -1.509, -5.000, -0.413, 0.232, -2.282, -5.000, -0.061, 0.754, -0.146, 0.132, -0.954, -0.586, -1.253, -0.989, -1.386, -0.378, -0.595, -5.000, -0.607, -0.662, -1.363, -0.846, -0.520, -0.073, -0.485, -0.959, -0.551, -1.148, -2.512, -1.913, -0.773, 0.271, -1.283, -0.350, -0.327, 0.181, -1.574, -0.959, -0.021, -0.430, -0.878, -0.480, -0.785, -1.019, -1.154, -1.540, -0.640, 0.081, -1.744, -0.890, -0.665, 0.609, -2.164, -1.404, 0.009, 0.732, 0.058, -0.379, -0.236, 0.270, -0.711, -1.560, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.143, 1.006, -0.248, -5.000, -0.201, 0.885, -1.559, -5.000, 0.715, 1.132, 0.604, 0.460, 0.695, 0.900, -0.239, 0.874, -0.828, 0.549, 0.427, -5.000, -0.711, -0.391, -1.263, -0.635, 0.247, 0.634, 0.180, -0.104, 1.041, 0.371, -0.753, 0.276, -0.243, 0.850, 0.035, 0.178, -0.473, -0.288, -2.544, -1.548, -0.483, -0.371, -1.218, -1.540, 0.051, -0.161, 0.028, -1.116, -0.317, 0.954, -0.811, -0.468, -0.475, 0.701, -1.690, -1.155, 0.527, 1.125, 0.614, -0.037, 0.360, 1.007, 0.949, -0.318, 1.207, 1.582, 0.226, -5.000, 0.906, 1.276, -0.051, -5.000, 0.808, 1.354, 0.925, 0.600, 0.685, 1.130, 0.687, 1.092, 0.301, 0.695, 0.394, -5.000, 0.514, 0.895, -0.325, -0.056, 0.732, 1.208, 0.861, 0.432, 0.963, 0.570, -0.252, 0.567, 1.071, 1.573, 1.341, 1.168, 1.008, 1.618, 0.383, 0.675, 0.796, 1.058, 0.831, 0.384, 1.162, 1.149, 1.332, 0.156, 0.462, 1.335, -0.163, 0.432, 0.902, 1.515, 0.305, 0.597, 1.026, 1.276, 1.237, 0.743, 1.119, 1.454, 1.394, 0.637, -0.332, 0.337, -2.009, -5.000, -0.676, -0.367, -1.738, -5.000, -0.913, 0.332, -0.983, -1.288, -1.055, -0.818, -2.332, -1.698, -0.966, 0.585, -0.634, -5.000, -0.379, -0.073, -1.123, -1.723, -0.467, 0.662, -0.124, -0.746, -0.641, -1.008, -1.521, -0.989, -0.826, -0.482, -2.057, -0.552, -0.612, -0.234, -5.000, -1.734, -1.647, -1.254, -1.401, -2.132, -1.220, -0.965, -1.745, -2.693, -1.311, -0.381, -2.177, -1.190, -0.908, -0.447, -2.276, -2.388, -1.747, -0.831, -0.974, -1.765, -0.245, -0.069, -1.217, -1.869, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.352, 0.927, -0.413, -5.000, -0.015, 1.074, -0.809, -5.000, 0.394, 0.949, 0.446, 0.148, 0.255, 0.729, 0.129, 0.516, -0.691, -0.696, -0.233, -5.000, -0.505, -0.173, -1.442, -0.346, -0.031, 0.598, 0.313, -0.327, 0.662, -0.264, -0.629, -0.440, 0.153, 0.768, 0.234, 0.572, -0.293, -0.097, -2.347, -0.976, 0.054, 0.077, -0.273, -0.533, 0.360, -0.052, 0.575, -0.256, -0.033, 0.827, -0.541, 0.129, 0.027, 0.922, -0.720, -0.052, 0.435, 0.923, 0.587, -0.331, 0.450, 0.950, 0.749, -0.127, 1.190, 1.451, 0.100, -5.000, 0.907, 1.093, -0.037, -5.000, 0.397, 1.166, 0.329, 0.519, 0.689, 0.807, 0.474, 1.006, 0.639, 0.939, 0.764, -5.000, 0.883, 1.104, 0.371, 0.610, 0.316, 1.093, 0.454, 0.414, 1.312, 0.493, 0.543, 0.760, 0.877, 1.380, 1.374, 1.298, 0.639, 1.200, 0.115, 0.369, 0.685, 0.909, -0.102, -0.011, 0.886, 0.727, 1.188, 0.406, 0.846, 1.381, 0.403, 1.008, 0.459, 1.503, 0.827, 0.659, 0.920, 1.281, 0.767, 0.382, 1.050, 1.358, 1.271, 0.568, 0.519, 0.861, -0.647, -5.000, 0.189, 0.924, -0.938, -5.000, 0.018, 0.451, -0.744, -0.267, -0.419, 0.027, -0.317, -0.076, -0.049, 0.570, 0.109, -5.000, 0.568, 0.640, -0.029, -0.217, 0.463, 0.918, -0.179, -0.337, 0.457, -0.023, -0.570, -0.201, 0.321, 1.011, 0.196, 0.284, -0.073, 0.702, -0.974, 0.205, 0.281, 0.174, -0.076, -0.372, 0.170, -0.203, 0.486, -0.127, 0.286, 1.012, -0.753, 0.015, -0.382, 0.907, -1.389, 0.146, 0.513, 0.957, 0.499, -0.320, 0.418, 0.768, 0.430, -0.608, 0.330, 0.901, -0.539, -5.000, -0.023, 0.747, -0.715, -5.000, -0.155, 0.828, -0.010, -0.193, -0.270, 0.364, -0.166, -0.003, 0.102, 0.541, 0.022, -5.000, -0.316, -0.126, -0.853, -0.731, 0.004, 0.366, -0.226, -0.879, 0.636, 0.200, -0.463, -0.301, 0.173, 0.626, 0.039, 0.299, 0.022, 0.436, -1.341, -0.564, 0.005, -0.028, -0.218, -0.104, 0.488, 0.338, 0.743, 0.164, 0.196, 0.879, -0.373, 0.301, -0.234, 0.895, -0.721, -0.446, 0.256, 0.693, 0.391, -0.471, 0.592, 0.972, 0.756, -0.234, 0.305, 0.962, -0.764, -5.000, -0.106, 0.997, -0.632, -5.000, 0.406, 1.104, 0.398, 0.254, 0.120, 0.536, -0.054, 0.230, -0.361, 0.316, -0.427, -5.000, -0.485, 0.117, -1.056, -0.643, 0.011, 0.665, 0.289, -0.213, 0.436, 0.191, -0.112, -0.011, 0.086, 0.780, -0.174, 0.187, -0.338, 0.044, -1.868, -1.039, -0.290, -0.040, -0.757, -0.535, 0.008, 0.088, 0.566, -0.388, 0.016, 0.744, -0.668, -0.377, -0.419, 0.331, -1.235, -0.286, -0.181, 0.578, 0.310, -0.099, 0.155, 0.623, 0.596, 0.016, 0.710, 1.190, -0.473, -5.000, 0.643, 1.187, -0.415, -5.000, 0.475, 1.094, 0.566, 0.590, 0.368, 0.669, 0.426, 0.648, 0.227, 0.538, 0.190, -5.000, 0.259, 0.689, -0.078, 0.115, 0.066, 0.423, 0.380, -0.275, 0.734, 0.282, 0.096, 0.233, 0.576, 1.296, 0.855, 0.878, 0.281, 1.200, 0.147, -0.244, 0.363, 0.542, 0.375, -0.113, 0.499, 0.371, 1.162, -0.312, 0.469, 1.146, -0.267, 0.521, 0.242, 0.972, -0.061, 0.265, 0.575, 0.721, 0.655, 0.195, 0.809, 1.152, 1.011, 0.385, -0.025, 0.645, -1.271, -5.000, -0.452, 0.691, -1.407, -5.000, 0.365, 1.084, 0.310, 0.204, -0.291, -0.207, -0.436, -0.223, -0.588, -0.098, -0.476, -5.000, -0.239, 0.324, -0.258, -0.555, -0.051, 0.725, 0.390, 0.059, 0.128, -0.379, -1.405, -0.624, -0.135, 0.100, -0.618, 0.108, -0.486, 0.022, -1.963, -0.739, -0.430, 0.017, -0.141, -0.422, -0.560, -0.668, -0.536, -0.975, -0.211, 0.566, -1.517, -0.435, -0.674, -0.251, -1.716, -1.599, -0.473, -0.231, -0.325, -0.533, -0.665, -0.488, -0.778, -1.374, 0.433, 1.024, -0.997, -5.000, 0.069, 0.889, -1.160, -5.000, 0.358, 0.972, 0.276, 0.261, 0.153, 0.680, -0.057, -0.112, -0.264, 0.237, -0.226, -5.000, -0.044, 0.061, -0.887, -0.173, -0.080, 0.403, -0.011, -0.155, 0.294, 0.067, -0.394, -0.233, 0.075, 0.846, -0.364, 0.402, -0.186, 0.140, -1.642, -0.888, -0.248, -0.369, -0.579, -0.359, 0.373, -0.247, -0.126, 0.036, 0.299, 1.012, -0.644, 0.130, 0.066, 0.719, -1.275, -0.283, 0.082, 0.771, -0.037, -0.377, 0.413, 0.919, 0.295, -0.075, -0.105, 0.682, -1.276, -5.000, -0.308, 0.625, -1.172, -5.000, -0.234, 0.748, -0.256, -0.146, -0.111, 0.044, -1.036, 0.007, -1.770, -0.863, -1.602, -5.000, -1.383, -1.372, -2.614, -1.951, -1.868, -1.360, -1.765, -2.102, -0.440, -1.218, -2.558, -1.184, -0.057, 0.755, -0.161, -0.249, -0.993, -0.636, -3.801, -2.166, -1.106, -0.608, -1.236, -2.269, -0.678, -0.823, -0.782, -1.514, -0.058, 0.655, -0.864, -0.407, -0.598, 0.359, -2.434, -1.050, 0.223, 0.573, 0.003, -0.545, -0.041, 0.586, 0.011, -0.422, 0.655, 1.143, -1.210, -5.000, 0.060, 0.736, -1.003, -5.000, -0.204, 0.758, -0.207, 0.179, 0.258, 0.513, -0.595, 0.654, -1.364, -0.083, -0.798, -5.000, 0.258, 0.375, -0.781, -0.356, -0.957, -0.537, -1.060, -1.427, 0.135, -0.671, -1.799, -1.056, 0.267, 1.226, 0.386, 0.246, 0.433, 0.789, -1.106, -0.940, -0.449, -0.127, -0.285, -0.984, 0.020, -0.025, 0.645, -0.848, 0.374, 1.196, -0.714, 0.341, 0.454, 0.436, -0.485, -0.007, 0.527, 0.929, 0.347, 0.463, 0.732, 0.848, 0.604, -0.076, 0.406, 1.185, -1.324, -5.000, 0.593, 1.122, -0.911, -5.000, 0.131, 0.994, -0.322, 0.055, -0.179, 0.047, -1.205, -0.348, -0.672, 0.175, -0.806, -5.000, 0.352, -0.076, -1.744, -0.483, -0.760, 0.010, -0.361, -0.902, -0.488, -1.150, -2.167, -1.618, 0.254, 0.990, -0.213, 0.589, 0.451, 0.633, -1.185, -0.381, 0.021, 0.208, -0.791, -0.302, -0.248, -0.673, -1.030, -1.357, -0.042, 0.774, -2.007, -0.268, -0.034, 0.826, -1.583, -0.500, 0.263, 0.846, -0.043, -0.108, 0.134, 0.349, -0.843, -1.444, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.586, 0.409, -0.649, -5.000, -0.468, 0.829, -1.460, -5.000, -0.019, 0.631, -0.181, -0.006, 0.451, 0.681, -0.207, 0.677, -1.299, -0.482, -0.689, -5.000, -0.808, -0.423, -1.738, -1.210, -0.810, -0.873, -0.383, -1.243, 0.168, -0.750, -1.342, -0.079, -0.145, 0.594, 0.329, -0.093, -0.853, -0.723, -2.864, -1.740, -1.488, -1.045, -2.066, -2.531, -0.549, -0.692, -0.621, -1.585, 0.115, 1.107, -0.284, -0.073, -0.285, 0.540, -1.495, -0.441, 0.127, 0.564, 0.353, -0.253, 0.398, 1.009, 0.465, -0.475, 0.486, 0.981, -0.314, -5.000, 0.285, 0.548, -0.293, -5.000, 0.027, 0.809, -0.051, -0.520, 0.048, 0.412, -0.251, 0.572, -0.608, -0.121, -0.546, -5.000, 0.067, 0.056, -0.719, -0.936, -0.692, -0.401, -0.479, -0.996, 0.247, -0.328, -0.852, -0.342, 0.289, 1.096, 0.768, 0.529, 0.127, 1.342, -1.385, -0.261, 0.110, -0.115, 0.241, -0.900, 0.595, 0.263, 0.960, -0.599, -0.123, 0.896, -0.484, 0.272, 0.378, 0.807, -0.450, -0.204, 0.095, 0.013, 0.014, -0.420, 0.594, 1.129, 0.280, -0.017, -0.558, 0.490, -1.648, -5.000, -0.660, 0.246, -2.743, -5.000, -1.572, -1.338, -1.495, -1.259, -1.058, -0.644, -1.005, -1.224, -2.008, -0.926, -1.363, -5.000, -1.354, -1.112, -3.151, -3.493, -1.136, -0.207, -0.242, -0.912, -0.712, -1.341, -2.307, -1.225, -0.565, 0.282, -1.009, -0.269, -1.133, 0.336, -1.752, -1.574, -1.442, -1.200, -1.354, -1.825, -0.620, -2.006, -2.238, -1.563, -0.880, 0.103, -1.460, -1.173, -0.815, -1.153, -1.551, -2.490, -1.343, -1.133, -2.088, -1.658, -0.548, -0.276, -1.524, -1.517, -0.443, 0.408, -1.505, -5.000, -0.440, 0.386, -1.600, -5.000, -0.556, 0.671, -0.301, -0.033, -0.473, -0.041, -0.470, -0.725, -0.869, -0.256, -0.170, -5.000, -0.998, -1.068, -2.127, -0.866, -0.374, -0.138, -0.060, -0.506, -0.104, -0.413, -1.956, -0.965, -0.154, 1.055, -0.401, -0.105, 0.018, 0.671, -0.935, -0.788, -0.139, -0.214, -0.952, -1.066, -0.319, -0.020, 0.500, -0.827, -1.224, -0.361, -1.856, -1.524, -1.814, -0.009, -1.978, -2.376, -0.977, -0.157, -0.320, -1.041, -1.378, -0.442, -0.536, -1.444, 0.053, 0.438, -0.948, -5.000, 0.023, 0.897, -2.582, -5.000, -0.056, 0.444, 0.021, -0.362, 0.076, 0.592, -0.803, 0.104, -1.054, -1.032, -0.903, -5.000, -1.417, -1.250, -0.766, -1.127, -1.018, -1.233, -1.040, -1.177, 0.092, -0.338, -1.583, -0.951, 0.549, 0.399, -0.114, 0.664, -0.289, -0.624, -1.912, -0.608, -0.389, -0.666, -0.961, -1.004, 0.229, -0.795, -0.485, -0.914, -0.123, 0.588, -0.893, -0.151, 0.010, 0.305, -0.813, -0.675, -0.224, -0.016, -0.271, -0.537, 0.086, 0.374, 0.105, -0.639, 0.566, 0.909, -1.333, -5.000, 0.153, 0.592, -1.007, -5.000, -0.464, 0.491, -0.048, -0.578, -0.129, 0.220, -0.115, -0.077, -0.520, -0.345, -0.423, -5.000, 0.353, 0.112, -0.666, -0.543, -1.299, -0.692, -0.142, -0.810, 0.313, -0.794, -1.018, -0.332, 0.928, 1.224, 0.823, 0.801, 0.486, 0.512, -0.900, -0.396, 0.426, 0.592, 0.486, -1.004, 0.629, 0.432, 0.740, 0.042, 0.639, 1.086, 0.371, 0.585, 0.258, 1.077, 0.034, 0.268, 0.542, 0.914, 0.227, -0.042, 0.728, 0.934, 0.753, 0.118, 0.012, 0.113, -0.966, -5.000, -0.153, -0.025, 0.048, -5.000, -0.148, -0.167, -1.029, -0.628, -0.622, -0.269, -0.595, -0.645, -0.860, 0.263, 0.056, -5.000, -0.027, 0.196, -0.692, -0.525, 0.325, -0.108, -1.072, -1.529, 0.443, -0.370, -1.156, -0.757, 0.444, 1.106, 0.378, 0.366, 0.285, 0.216, -0.849, 0.221, 0.005, -0.759, -0.586, -0.484, 0.085, -0.500, -0.850, -0.640, 0.023, 0.770, -0.906, -0.301, -0.314, 0.486, 0.022, 0.217, 0.425, 0.617, -0.234, -0.405, 0.008, 0.388, -0.080, -1.199, -0.364, 0.116, -1.314, -5.000, -0.954, 0.052, -1.045, -5.000, -0.872, -0.252, -1.121, -1.524, -1.141, -0.479, -0.927, -0.938, -1.025, -0.430, -0.970, -5.000, -0.577, -0.406, -1.561, -1.146, -1.335, 0.243, -0.951, -1.045, -0.449, -0.746, -1.179, -1.366, -0.501, -0.785, -1.741, -0.703, -1.477, -1.106, -0.537, -1.829, -0.975, -0.588, -0.986, -0.909, -0.373, -0.364, -0.533, -1.350, 0.014, 0.673, -0.430, -0.149, -0.661, 0.237, -0.790, -0.645, -0.232, -0.274, -0.543, -1.135, -0.053, 0.205, 0.059, -0.913, 0.443, 1.164, -0.665, -5.000, 0.540, 1.280, -0.515, -5.000, 0.692, 1.331, 0.778, 0.504, 0.580, 1.091, -0.126, 0.506, -0.748, -0.047, -0.026, -5.000, -0.258, -0.373, -1.553, -0.461, -0.197, 0.071, 0.234, -0.456, 0.595, 0.136, -0.847, -0.170, 0.693, 1.171, 0.617, 0.896, 0.196, 0.244, -1.081, -0.434, 0.003, -0.224, -1.038, -0.502, 0.591, 0.297, 0.474, 0.380, 0.110, 0.870, -0.488, -0.029, -0.041, 0.569, -1.098, -0.383, -0.104, 0.616, 0.354, -0.085, 0.209, 0.703, 0.052, -0.163, -0.166, 0.292, -1.446, -5.000, -0.927, 0.085, -1.993, -5.000, -0.366, 0.455, 0.025, -0.677, -0.142, -0.269, -0.411, -0.592, -0.635, -0.503, -0.817, -5.000, -0.854, -0.521, -0.455, -1.270, -1.251, -0.723, -0.866, -1.952, -0.442, -1.203, -1.061, -0.902, 0.413, 0.868, 0.292, 0.363, -0.646, 0.620, -1.816, -0.841, -0.252, -0.980, -0.349, -1.210, -0.006, -0.212, 0.323, -0.744, 0.076, 0.659, -1.296, -0.072, -0.092, 0.200, -0.990, -0.805, -0.362, -0.253, -0.364, -0.875, 0.266, 0.324, -0.054, -0.280, -0.581, 0.014, -2.299, -5.000, -0.750, 0.059, -0.970, -5.000, -0.238, 0.672, -0.373, -0.280, -0.676, -0.264, -1.247, -0.988, -1.143, -1.055, -0.838, -5.000, -1.194, -0.653, -0.637, -1.158, -0.718, 0.121, -1.007, -1.013, -0.898, -0.834, -2.005, -1.541, -0.990, -0.288, -0.739, -0.700, -1.109, -1.111, -2.109, -2.114, -1.117, -0.864, -1.495, -0.983, -1.393, -1.531, -1.591, -2.024, -0.813, 0.113, -1.709, -0.870, -0.963, -0.807, -1.596, -1.784, -0.920, -0.389, -0.835, -1.855, -1.071, -1.412, -1.558, -1.953, -0.217, 0.272, -1.803, -5.000, 0.073, 0.464, -1.556, -5.000, -0.266, 0.472, -0.797, -0.317, -0.369, 0.040, -1.057, -0.647, -1.138, -0.345, -1.000, -5.000, -0.855, -0.926, -1.659, -1.592, -1.367, -0.529, -1.561, -1.255, -0.802, -1.026, -1.979, -1.268, -0.734, 0.088, -1.020, -0.719, -0.717, -0.867, -3.530, -2.160, -1.320, -1.182, -1.497, -1.694, -0.542, -1.095, -1.349, -1.233, -0.225, 0.447, -1.048, -0.335, -0.356, -0.020, -1.795, -1.295, -0.239, 0.286, -0.232, -0.835, -0.066, 0.293, -0.526, -0.754, 0.299, 1.147, -0.401, -5.000, 0.212, 1.230, -0.848, -5.000, 0.808, 1.293, 0.709, 0.722, 0.577, 0.905, 0.006, 0.739, -1.107, -0.415, -0.539, -5.000, -1.696, -1.121, -3.138, -1.288, -0.149, -0.048, -0.444, -0.900, 0.458, -0.401, -1.633, -0.578, 0.005, 1.007, 0.363, 0.161, -0.381, -0.325, -1.956, -1.750, -0.570, -0.814, -1.774, -1.773, -0.142, -0.805, -0.003, -0.951, 0.115, 0.743, -0.358, -0.039, -0.669, 0.371, -1.248, -0.851, 0.079, 0.516, 0.084, -0.316, 0.175, 0.517, 0.109, -0.254, 1.176, 1.527, -0.172, -5.000, 1.246, 1.638, -0.169, -5.000, 0.613, 1.390, 0.932, 0.933, 1.167, 1.264, 0.709, 1.134, 0.290, 0.643, 0.128, -5.000, 0.769, 1.190, -1.106, 0.580, 0.275, 0.347, -0.214, -0.468, 1.097, 0.416, -0.417, 0.088, 0.980, 1.482, 0.914, 1.252, 1.218, 1.485, -1.765, 0.308, 0.541, 0.598, 0.507, -0.014, 1.040, 0.953, 1.352, -0.011, 0.698, 1.436, 0.226, 0.760, 1.156, 1.419, -0.101, 0.770, 1.204, 1.446, 1.012, 0.787, 1.286, 1.562, 1.380, 0.807, 0.316, 1.007, -1.134, -5.000, 0.614, 1.264, -1.593, -5.000, 0.517, 1.302, 0.347, 0.502, -0.080, 0.533, -1.129, -0.080, -0.914, 0.156, -0.419, -5.000, 0.257, 0.496, -0.775, -0.231, 0.593, 0.596, 0.269, -0.358, 0.125, -0.395, -2.328, -1.430, 0.220, 1.137, 0.096, 0.440, 0.474, 0.788, -2.260, 0.074, 0.461, 0.235, -0.543, -0.137, 0.044, -0.391, -0.236, -0.612, -0.206, 0.774, -0.793, -0.301, -0.315, 0.809, -1.765, -0.551, 0.444, 0.846, 0.875, -0.087, 0.490, 0.855, -0.024, -0.740, 0.531, 1.128, -0.672, -5.000, 0.259, 1.177, -0.743, -5.000, 0.472, 1.273, 0.408, 0.593, 0.255, 0.572, 0.218, 0.241, -0.206, 0.294, 0.120, -5.000, -0.015, 0.477, -1.239, 0.078, 0.297, 0.774, 0.436, 0.044, 0.572, 0.008, -0.879, -0.331, 0.322, 1.212, 0.569, 0.800, 0.337, 1.013, -1.636, 0.108, 0.123, 0.031, -0.131, -0.160, 0.232, 0.225, 1.005, -0.264, -0.040, 0.891, -0.786, -0.086, -0.617, 0.678, -1.354, -0.533, 0.457, 0.710, 0.269, 0.207, 0.153, 0.699, 0.632, -0.555, -0.327, 0.826, -0.839, -5.000, -0.323, 0.936, -1.883, -5.000, 0.243, 0.633, 0.034, -0.013, 0.423, 0.693, -0.311, 0.894, -1.392, -0.296, -0.142, -5.000, -1.302, -0.410, -2.046, -1.127, -0.212, 0.056, -0.440, -0.831, 0.742, -0.034, -1.201, 0.167, 0.020, 0.956, -0.107, 0.251, -0.728, -0.232, -1.934, -2.139, -0.967, -1.393, -1.833, -1.733, 0.029, -0.647, 0.365, -1.082, -0.199, 0.741, -0.965, -0.239, -0.213, 0.397, -1.841, -1.184, -0.065, 0.486, 0.402, -0.273, -0.237, 0.675, 0.305, -0.761, 0.705, 1.261, -0.244, -5.000, 0.835, 0.817, -0.742, -5.000, 0.138, 1.103, -0.103, 0.180, 0.765, 0.900, 0.653, 0.868, -0.082, 0.522, 0.186, -5.000, 0.744, 0.536, 0.234, -0.188, -0.030, -0.207, 0.135, -0.379, 0.925, 0.343, -0.816, 0.310, 0.867, 1.387, 0.966, 0.983, 0.494, 1.123, -1.711, -0.612, 0.677, 0.738, -0.115, -0.552, 0.849, 0.985, 1.046, -0.578, -0.168, 0.981, -0.653, -0.029, 0.558, 1.091, -0.379, -0.008, 0.558, 0.826, 0.459, -0.061, 0.757, 1.158, 0.622, 0.101, -0.946, -0.488, -3.131, -5.000, -1.460, -0.640, -5.000, -5.000, -2.445, -0.645, -1.180, -1.896, -2.028, -0.891, -1.732, -1.816, -2.182, -0.313, -2.230, -5.000, -0.471, -0.835, -1.089, -2.593, -1.889, -0.073, -5.000, -5.000, -1.305, -1.483, -2.110, -5.000, -1.305, -0.591, -2.332, -1.012, -2.098, -5.000, -1.609, -2.923, -1.515, -1.218, -0.961, -2.376, -1.180, -1.956, -2.616, -2.847, -1.763, -0.944, -2.107, -1.900, -1.385, -1.230, -0.723, -5.000, -1.679, -0.207, -1.720, -1.375, -1.072, -0.986, -2.458, -1.906, -0.864, 0.307, -1.947, -5.000, -0.930, 0.540, -1.746, -5.000, -0.727, 0.611, -0.428, -0.291, -0.959, -0.197, -0.649, -0.523, -1.410, -0.341, -0.207, -5.000, -1.476, -1.164, -2.153, -1.602, -0.594, -0.175, -0.868, -1.134, -0.022, -1.358, -1.951, -0.757, -0.987, 0.434, -0.119, -0.637, -1.578, -0.799, -2.747, -2.321, -0.685, -1.024, -1.167, -1.752, -0.626, -0.723, -0.144, -1.434, -1.811, -0.787, -2.231, -2.091, -2.082, -0.189, -1.944, -2.468, -1.279, -0.769, -0.557, -1.435, -1.146, -0.744, -0.569, -2.103, 0.079, 0.880, -0.593, -5.000, 0.078, 0.960, -1.193, -5.000, 0.029, 0.460, -0.048, 0.108, 0.158, 0.574, -0.270, 0.456, -0.876, -0.692, -0.286, -5.000, -0.340, 0.123, -0.835, -0.773, -0.491, -0.824, 0.071, -0.986, 0.736, -0.229, -1.298, -1.028, -0.351, 0.555, -0.028, 0.143, -1.155, -0.375, -3.342, -2.182, -0.813, -0.595, -0.779, -1.953, -0.566, -0.870, -0.728, -1.408, -0.253, 0.508, -0.602, -0.259, -0.437, 0.555, -1.749, -0.719, 0.012, 0.227, -0.153, -0.909, 0.162, 0.525, 0.154, -0.571, 0.088, 0.971, -1.041, -5.000, -0.177, 0.558, -0.952, -5.000, -0.891, -0.073, -1.335, -0.550, 0.164, 0.159, -0.416, 0.199, -0.873, -0.106, -0.504, -5.000, -0.211, 0.316, -0.518, -0.839, -1.218, 0.347, -0.887, -1.179, 0.464, -0.367, -0.666, -0.572, -0.447, 0.758, -0.361, -0.856, -0.753, 0.551, -1.791, -1.326, -1.657, -1.252, -0.843, -1.990, -0.952, -0.900, -0.356, -1.577, -0.054, 0.811, -0.687, -0.215, -0.468, 0.767, -1.184, -0.131, 0.046, 0.299, -0.500, -0.625, 0.286, 0.560, 0.509, -0.609, -0.329, 0.331, -1.213, -5.000, -0.540, 0.229, -2.546, -5.000, -0.675, -0.513, -0.874, -0.580, -0.537, -0.467, -0.570, -0.363, -1.588, -0.424, -0.558, -5.000, -0.180, -0.460, -1.963, -2.205, -0.137, -0.229, -1.112, -1.085, 0.035, -0.910, -1.088, -1.457, -0.267, 0.589, -0.298, -0.518, -0.377, -0.257, -1.775, -1.517, 0.020, -0.325, -1.005, -0.728, -0.633, -1.194, -0.417, -1.508, -0.684, 0.155, -1.432, -1.050, -0.838, -0.010, -1.810, -0.521, -0.171, -0.720, -0.229, -0.689, -0.175, 0.069, -0.701, -1.356, -0.460, 0.631, -0.723, -5.000, -0.690, 0.176, -3.083, -5.000, -0.578, 0.255, -0.760, -0.827, -0.585, -0.381, -0.093, -0.479, -1.225, -0.256, -0.416, -5.000, -1.176, -0.709, -1.529, -1.333, -0.466, 0.053, -0.692, -0.992, -0.550, -0.773, -1.484, -0.537, -1.344, -0.005, -0.738, -0.944, -1.381, -0.030, -1.354, -1.793, -0.835, -0.635, -1.495, -2.056, -1.106, -1.621, -0.730, -1.744, -1.156, -0.220, -1.562, -0.839, -1.704, -0.461, -1.882, -1.828, -1.073, -0.880, -0.929, -1.698, -0.592, -0.385, -0.146, -1.755, 0.237, 1.053, -0.581, -5.000, 0.214, 1.017, -1.589, -5.000, 0.580, 0.980, 0.409, 0.244, 0.321, 0.604, 0.098, 0.617, -0.738, 0.108, 0.198, -5.000, -0.490, -0.133, -2.213, -1.016, 0.004, 0.512, -0.069, -0.455, 0.548, 0.181, -0.450, -0.122, -0.100, 0.776, 0.163, 0.152, -0.978, -1.191, -2.909, -1.630, -0.673, -1.197, -1.308, -1.611, -0.327, -0.972, -0.761, -1.453, 0.088, 0.820, -0.273, 0.026, -0.317, 0.439, -2.015, -0.419, -0.145, 0.512, -0.003, -0.619, 0.149, 0.666, 0.302, -0.338, -0.016, 0.640, -0.999, -5.000, 0.134, 0.555, -1.884, -5.000, -0.037, 0.512, -0.795, -0.034, 0.192, 0.471, 0.324, 0.496, -0.554, -0.293, -0.261, -5.000, -0.604, 0.459, -1.091, -1.045, -0.442, 0.102, -0.412, -1.244, 0.325, -0.203, -0.554, -0.517, -0.450, 0.765, 0.284, 0.055, -0.221, 0.199, -1.218, -0.847, -0.498, -0.073, -1.142, -1.795, -0.479, -0.420, -0.027, -1.817, -0.232, 0.657, -1.194, -0.154, -0.338, 0.393, -0.987, -0.665, 0.022, 0.012, -0.705, -0.420, 0.309, 0.548, 0.463, -0.417, 0.484, 1.134, -0.509, -5.000, 0.856, 1.161, -0.525, -5.000, 0.795, 1.293, 0.620, 0.845, 0.273, 0.786, -0.514, 0.382, -0.566, 0.339, 0.104, -5.000, 0.453, 0.711, -0.835, -0.156, 0.449, 0.716, 0.711, -0.552, 0.684, 0.234, -0.635, -0.280, 0.297, 1.152, 0.166, 0.324, 0.307, 0.196, -0.440, -0.540, -0.081, -0.244, -0.732, -0.051, -0.180, -0.225, -0.155, -0.527, -0.290, 0.718, -1.308, -0.648, -0.121, 0.629, -3.111, -0.796, 0.323, 0.445, 0.151, -0.562, -0.208, 0.311, -0.393, -1.966, -0.251, 0.383, -1.476, -5.000, -0.524, 0.358, -1.784, -5.000, -0.154, 0.453, -0.173, -0.157, -0.419, -0.082, -0.743, -0.221, -1.703, -0.711, -0.953, -5.000, -1.361, -0.888, -1.199, -1.572, -0.559, -0.117, -0.288, -1.200, -0.512, -0.789, -1.521, -0.799, -0.853, 0.231, -0.522, -0.669, -2.004, -1.260, -3.055, -3.136, -1.651, -1.672, -1.963, -2.865, -1.586, -1.866, -1.163, -1.862, -0.987, -0.140, -1.781, -0.938, -1.461, -0.604, -2.035, -1.726, -0.937, -0.643, -0.707, -1.747, -1.179, -0.772, -0.988, -1.397, 0.211, 1.166, -0.387, -5.000, -0.256, 0.983, -0.862, -5.000, 0.330, 0.945, 0.290, 0.311, 0.334, 0.744, -0.003, 0.311, -0.803, -0.005, -0.728, -5.000, -1.375, -0.613, -1.838, -0.920, -0.376, -0.379, -0.548, -0.830, 0.347, -0.136, -0.904, -0.182, -0.017, 0.904, 0.058, 0.160, -0.739, -0.247, -1.534, -1.726, -0.429, -0.541, -1.136, -1.259, -0.315, -0.503, -0.191, -1.034, -0.063, 0.605, -0.567, -0.104, -0.660, -0.171, -1.904, -0.975, 0.028, 0.247, -0.213, -0.369, -0.149, 0.207, -0.047, -0.506, 1.115, 1.520, 0.006, -5.000, 0.759, 1.408, 0.066, -5.000, 0.693, 1.250, 0.504, 0.919, 0.928, 1.261, 0.752, 0.999, 0.441, 0.791, 0.065, -5.000, 0.659, 1.035, -0.064, 0.366, 0.470, 0.700, 0.297, 0.027, 1.018, 0.680, 0.158, 0.228, 0.730, 1.459, 0.806, 1.092, 0.894, 1.355, -0.287, 0.110, 0.537, 0.360, 0.150, -0.030, 0.890, 0.833, 1.250, -0.229, 0.601, 1.288, -0.130, 0.786, 0.612, 0.600, -0.480, 0.495, 0.881, 1.160, 0.830, 0.622, 0.957, 1.291, 1.218, 0.599, -0.405, 0.708, -1.608, -5.000, -0.584, 0.385, -1.966, -5.000, -0.286, 0.331, -0.521, -0.418, -0.636, -0.415, -1.073, -0.826, -1.105, -0.233, -1.218, -5.000, -0.514, -0.174, -1.558, -0.878, -0.175, -0.166, -0.214, -0.833, -0.539, -0.844, -1.779, -1.269, -0.707, 0.541, -0.708, -0.581, -0.748, 0.354, -2.160, -1.150, -0.718, -0.586, -0.978, -1.075, -0.998, -0.799, -0.646, -1.716, -0.917, 0.079, -1.818, -1.308, -1.032, -0.282, -2.656, -1.786, -0.572, -0.132, -0.441, -0.681, -0.553, -0.232, -0.953, -1.666, -0.037, 0.733, -1.198, -5.000, -0.678, 0.528, -1.428, -5.000, 0.019, 0.592, -0.211, -0.041, -0.221, 0.119, -0.361, -0.275, -0.381, 0.115, -0.320, -5.000, -0.669, 0.023, -1.224, -0.398, 0.014, -0.145, -0.553, -0.772, 0.068, -0.255, -1.017, -0.629, -0.013, 0.997, -0.073, 0.401, 0.234, 0.690, -1.584, -0.314, 0.119, -0.026, -0.244, -0.299, -0.090, 0.111, 0.587, -0.614, -0.248, 0.641, -0.857, -0.244, -0.595, 0.443, -1.264, -0.970, 0.022, 0.752, 0.077, 0.011, -0.192, 0.433, 0.078, -0.867, -0.241, 0.834, -0.644, -5.000, -0.374, 0.682, -1.440, -5.000, 0.124, 0.299, -0.351, -0.359, 0.315, 0.491, -0.359, 0.304, -1.379, -0.082, -0.018, -5.000, -0.903, -0.598, -1.643, -0.950, -0.327, -0.191, -0.773, -0.978, 0.758, -0.036, -0.590, 0.125, -0.389, 0.795, -0.303, 0.017, -0.777, -0.359, -1.943, -1.391, -0.881, -1.243, -1.668, -2.150, -0.255, -0.430, 0.205, -1.103, -0.376, 0.610, -0.923, -0.559, -0.604, 0.100, -1.903, -1.170, -0.051, -0.008, 0.081, -0.389, -0.026, 0.555, 0.351, -0.558, 0.748, 1.308, -0.001, -5.000, 0.606, 0.839, -0.975, -5.000, 0.422, 1.206, 0.493, 0.195, 0.632, 0.949, 0.435, 0.779, -0.130, 0.456, 0.090, -5.000, 0.005, 0.280, -0.860, 0.270, 0.539, 0.637, 0.201, -0.362, 1.141, 0.426, -0.589, 0.475, 0.666, 1.419, 0.980, 1.001, 0.940, 1.388, -0.624, 0.297, 0.570, 0.426, -0.078, -0.007, 0.878, 1.121, 1.349, -0.178, 0.138, 1.181, -0.180, 0.613, 0.595, 0.900, -0.676, 0.374, 0.570, 0.704, 0.698, 0.117, 0.945, 1.280, 1.179, 0.564, -0.668, -0.144, -2.204, -5.000, -1.534, -0.043, -1.489, -5.000, -1.329, -0.189, -2.198, -0.706, -1.128, -0.802, -1.488, -1.676, -1.406, -0.349, -1.460, -5.000, -1.043, -0.623, -1.061, -1.580, -0.396, -0.502, -0.442, -2.546, -0.404, -1.311, -1.905, -1.591, -0.825, 0.280, -1.488, -0.444, -1.151, -0.465, -1.859, -1.475, -0.286, -0.946, -1.055, -1.786, -1.083, -2.588, -1.532, -2.211, -1.390, -0.689, -1.989, -1.398, -1.561, -0.578, -2.029, -1.785, -0.753, -0.597, -1.385, -2.509, -0.755, -0.461, -1.433, -2.257, -0.273, 0.468, -1.630, -5.000, -0.594, 0.405, -1.873, -5.000, -0.366, 0.596, -0.708, -0.555, -0.274, 0.406, -0.587, -0.434, -0.633, -0.384, -0.466, -5.000, -1.129, -0.713, -1.779, -1.014, -0.442, -0.430, -0.725, -1.537, 0.137, -0.376, -1.243, -0.642, -0.358, 0.648, -0.146, -0.158, -0.390, 0.550, -1.808, -0.491, -0.399, -0.581, -1.046, -0.945, -0.144, 0.167, 0.423, -0.808, -1.025, -0.136, -1.607, -1.455, -1.745, -0.062, -2.275, -1.994, -1.032, -0.286, -0.573, -1.223, -0.692, -0.234, -0.519, -1.151, 0.245, 0.984, -0.347, -5.000, -0.005, 1.088, -0.916, -5.000, 0.292, 0.478, 0.214, -0.078, 0.481, 0.890, 0.027, 0.525, -0.633, 0.051, 0.188, -5.000, -0.673, -0.168, -1.382, -0.340, -0.047, 0.337, 0.178, -1.210, 1.089, 0.311, -0.609, -0.050, -0.030, 0.809, 0.144, 0.545, -0.607, -0.115, -2.093, -1.174, -0.280, -0.406, -0.900, -1.004, -0.016, -0.870, 0.122, -1.024, 0.013, 0.793, -0.508, 0.292, -0.066, 0.677, -1.108, -0.114, 0.011, 0.232, 0.348, -0.174, 0.260, 0.729, 0.261, -0.266, 0.875, 1.441, 0.194, -5.000, 0.719, 1.072, -0.011, -5.000, -0.021, 0.753, -0.225, 0.090, 0.409, 0.859, 0.391, 0.678, 0.135, 0.702, 0.606, -5.000, 0.274, 0.770, -0.211, 0.168, -0.170, 1.038, -0.440, -0.543, 1.130, 0.255, -0.150, 0.266, 0.681, 1.302, 1.012, 0.921, 0.089, 1.068, -0.302, -0.387, 0.109, 0.247, -0.566, -0.727, 0.303, 0.027, 0.537, -0.762, 0.195, 1.271, 0.054, 0.593, 0.201, 1.367, -0.055, 0.161, 0.540, 1.028, 0.230, -0.111, 0.592, 1.222, 0.933, 0.036, 0.519, 1.025, -0.487, -5.000, 0.304, 0.805, -0.926, -5.000, 0.021, 0.435, -0.305, -0.105, 0.200, 0.186, -0.352, 0.142, -0.166, 0.632, 0.048, -5.000, 0.457, 0.572, -0.487, -0.629, 0.503, 0.340, -0.712, -0.644, 0.887, 0.228, -0.499, -0.129, 0.449, 1.335, 0.872, 0.590, 0.233, 0.624, -1.351, 0.050, 0.293, -0.377, -0.416, -0.510, 0.253, -0.171, 0.233, -0.277, 0.262, 0.982, -0.102, 0.087, -0.071, 0.658, -1.012, 0.249, 0.470, 0.657, 0.221, -0.529, 0.392, 0.676, 0.212, -0.987, 0.011, 0.775, -0.996, -5.000, -0.480, 0.294, -0.791, -5.000, -0.476, 0.008, -0.872, -0.636, -0.326, 0.184, -0.273, -0.061, -0.737, 0.021, 0.202, -5.000, -0.794, -0.463, -1.540, -0.826, -0.292, 0.150, -0.928, -0.995, 0.241, -0.307, -0.841, -0.645, -0.769, 0.422, -0.291, -0.306, -0.976, 0.032, -1.894, -1.782, -0.607, -0.820, -0.649, -1.010, -0.439, -0.868, 0.263, -1.611, -0.242, 0.464, -0.636, 0.071, -0.706, 0.322, -0.867, -0.721, -0.409, -0.295, -0.650, -1.438, 0.095, 0.445, 0.283, -1.092, 0.329, 1.086, -0.397, -5.000, 0.186, 1.108, -0.785, -5.000, 0.552, 0.994, 0.298, 0.203, 0.421, 0.876, -0.137, 0.264, -0.393, 0.387, 0.271, -5.000, -0.387, 0.035, -1.184, -0.632, 0.157, 0.519, -0.097, -0.498, 0.641, 0.353, -0.299, -0.009, 0.157, 0.978, 0.034, 0.232, -0.292, 0.083, -2.101, -1.076, -0.379, -0.432, -1.394, -1.086, -0.130, -0.404, -0.381, -0.819, 0.172, 0.904, -0.263, 0.036, -0.033, 0.532, -1.644, -0.422, 0.174, 0.602, 0.149, -0.173, 0.142, 0.624, 0.299, -0.357, 0.802, 1.277, -0.425, -5.000, 0.596, 1.104, -0.724, -5.000, 0.617, 1.165, 0.403, 0.550, 0.631, 1.030, 0.456, 0.774, 0.167, 0.469, 0.323, -5.000, 0.272, 0.864, -0.341, 0.220, 0.472, 0.734, 0.372, -0.216, 0.940, 0.425, -0.073, 0.042, 0.759, 1.420, 0.801, 0.893, 0.600, 1.085, -0.507, -0.080, 0.601, 0.359, -0.354, -0.204, 0.699, 0.617, 0.881, -0.168, 0.590, 1.278, -0.224, 0.548, 0.367, 1.117, -0.421, 0.128, 0.638, 0.790, 0.490, 0.062, 0.771, 1.149, 0.808, 0.305, 0.503, 1.307, -0.561, -5.000, 0.578, 1.358, -0.523, -5.000, 0.757, 1.333, 0.512, 0.630, 0.325, 0.709, -0.311, 0.239, -0.148, 0.612, 0.269, -5.000, 0.700, 1.019, -0.414, 0.112, 0.565, 0.886, 0.566, 0.114, 0.692, 0.158, -0.518, -0.274, 0.249, 1.166, -0.102, 0.418, 0.347, 0.832, -1.619, -0.395, 0.538, 0.277, -0.608, -0.011, -0.111, 0.023, -0.160, -1.052, 0.011, 0.906, -1.016, -0.257, -0.079, 0.848, -1.341, -0.387, 0.285, 0.619, 0.158, -0.291, -0.155, 0.249, -0.543, -1.423, -0.144, 0.700, -1.227, -5.000, -0.291, 0.673, -1.199, -5.000, -0.025, 0.711, -0.028, -0.125, -0.175, 0.279, -0.586, -0.404, -0.891, 0.052, -0.416, -5.000, -0.633, -0.304, -1.389, -0.739, -0.309, -0.036, -0.370, -0.717, 0.034, -0.476, -0.902, -0.593, -0.505, 0.700, -0.650, -0.189, -0.794, -0.042, -1.615, -1.425, -1.153, -0.722, -1.109, -1.510, -0.854, -0.906, -0.840, -1.268, -0.635, 0.286, -1.057, -0.763, -0.773, 0.066, -1.647, -1.194, -0.657, -0.357, -0.952, -1.178, -0.750, -0.455, -0.848, -1.232 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_18(struct _training *tptr) {
  struct _training tinf = {
    0.354, 11, 4.350, { 2.344, 0.336, 0.320 }, { 0.621, -0.460, -1.470 }, 0, 
    { -0.119, -0.757, -0.812, -1.046, -0.328, -0.398, -0.398, -4.000, 0.756, 0.026, 0.010, -4.000, -0.654, 0.393, 0.724, -0.398, 0.729, 0.330, 0.717, 1.148, -0.025, -1.091, 0.264, -0.720, 1.226, 1.585, -0.124, 1.298 }, 
    {{ 0.080, -0.175, -0.418, 0.175},{ 0.228, -0.155, -0.579, 0.062},{ 0.124, -0.177, -0.372, 0.120},{ 0.149, -0.166, -0.203, 0.024},{ 0.119, 0.026, -0.324, 0.011},{ 0.170, -0.144, -0.432, 0.077},{ 0.122, -0.251, -0.344, 0.141},{ 0.145, -0.119, -0.302, 0.047},{ 0.052, -0.085, -0.254, 0.108},{ 0.060, -0.119, -0.144, 0.070},{ 0.168, 0.016, -0.289, -0.056},{ 0.283, -0.302, -0.636, 0.070},{ 0.225, -0.186, -0.677, 0.105},{ 0.278, -0.302, -0.710, 0.095},{ 0.127, -0.407, -0.735, 0.287},{ 0.052, -0.432, -0.735, 0.354},{ -0.003, -0.257, -0.604, 0.319},{ 0.002, -0.447, -0.254, 0.276},{ 0.101, -0.175, -0.270, 0.105},{ 0.237, -0.034, -0.372, -0.082},{ 0.337, -0.169, -0.421, -0.136},{ 0.290, -0.227, -0.358, -0.062},{ 0.278, -0.054, -0.429, -0.107},{ 0.237, -0.072, -0.425, -0.040},{ 0.121, 0.044, -0.183, -0.064},{ 0.110, 0.067, -0.251, -0.032},{ 0.094, 0.037, -0.295, 0.020},{ 0.117, 0.007, -0.221, -0.019},{ 0.099, 0.014, -0.389, 0.063},{ 0.059, -0.057, -0.257, 0.089},{ 0.124, -0.044, -0.318, 0.041},{ 0.119, 0.075, -0.276, -0.038} }, 
    {{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 0.790, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 2.167, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}} }, 
    -0.243, { 0.475, 0.816, 0.006, -5.000, 0.273, 0.525, -0.910, -5.000, 0.118, 0.720, 0.199, 0.055, 0.534, 0.607, 0.111, 0.325, 0.637, 0.801, -0.109, -5.000, 0.108, 0.295, -1.385, -0.319, -0.408, 0.352, -0.166, -0.101, 0.446, 0.561, -0.265, 0.124, 0.066, 0.446, -0.368, -0.048, -0.195, 0.277, -1.175, -1.131, -0.541, 0.265, -0.213, -0.611, -0.250, 0.251, -0.454, -0.122, 0.160, 0.715, -0.334, 0.038, 0.203, 0.752, -1.238, -0.678, 0.402, 0.934, 0.585, 0.154, 0.250, 0.689, 0.183, 0.104, 0.590, 0.830, 0.497, -5.000, 0.420, 0.738, -0.831, -5.000, 0.411, 1.078, 0.974, 0.415, 0.897, 0.990, 0.444, 0.836, 0.939, 1.094, -0.244, -5.000, 0.667, 0.574, -1.287, 0.083, 0.431, 0.846, 0.479, 0.316, 0.462, 0.557, -0.383, 0.391, 0.761, 1.333, 0.402, 0.696, 0.412, 0.808, -0.696, -0.442, 0.187, 0.769, 0.552, 0.136, 0.262, 0.830, 0.455, 0.585, 0.763, 1.187, 0.117, 0.658, 0.798, 1.044, -0.601, -0.069, 0.894, 1.225, 0.939, 0.537, 0.728, 1.024, 0.307, 0.591, 0.474, 0.740, 0.111, -5.000, 0.485, 0.660, -1.209, -5.000, 0.680, 1.096, 0.407, 0.372, 0.333, 0.364, -0.168, 0.167, 0.312, 0.669, -0.413, -5.000, 0.163, 0.374, -1.806, -0.405, -0.216, 0.760, 0.106, -0.145, 0.142, 0.112, -1.121, -0.349, -0.391, 0.049, -1.189, -0.800, -0.645, -0.031, -2.030, -1.009, -0.542, 0.101, -0.326, -0.890, -0.730, 0.149, -1.051, -0.736, 0.327, 0.602, -0.930, -0.019, -0.145, 0.691, -2.028, -1.187, 0.113, 0.827, -0.119, -0.035, 0.178, 0.564, -0.410, -0.412, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.125, 0.530, 0.074, -5.000, 0.149, 0.478, -1.440, -5.000, -0.240, 0.497, 0.027, -0.175, 0.501, 0.599, 0.114, 0.441, 0.435, 0.730, -0.172, -5.000, 0.045, -0.008, -1.936, -0.266, -0.428, 0.550, 0.245, -0.009, 0.317, 0.499, -0.097, 0.117, 0.074, 0.309, 0.006, -0.081, -0.310, 0.202, -1.553, -1.442, -0.577, 0.282, -0.452, -0.794, -0.135, 0.207, -0.291, -0.049, 0.056, 0.677, -0.174, 0.055, 0.065, 0.765, -1.023, -0.889, 0.511, 1.092, 0.593, 0.069, 0.285, 0.739, 0.126, 0.112, 0.357, 0.791, 0.426, -5.000, 0.311, 0.820, -1.297, -5.000, 0.664, 1.219, 0.796, 0.232, 0.962, 0.960, 0.504, 0.847, 0.698, 0.819, -0.549, -5.000, 0.668, 0.450, -0.921, 0.476, 0.578, 1.126, 0.750, 0.192, 0.703, 0.734, -0.042, 0.496, 0.802, 1.057, 0.883, 0.930, 0.670, 0.915, -0.477, -0.359, 0.484, 1.036, 0.521, -0.071, 0.366, 0.785, 0.524, 0.944, 0.514, 1.034, 0.348, 0.495, 0.697, 1.171, -0.333, -0.276, 0.974, 1.233, 0.895, 0.428, 0.480, 0.849, 0.200, 0.617, -0.991, -0.510, -0.989, -5.000, -1.159, -1.062, -1.560, -5.000, -0.579, -0.162, -0.786, -0.998, -0.916, -1.039, -1.634, -0.918, -0.863, -0.801, -1.943, -5.000, -0.974, -1.446, -1.622, -1.020, -0.361, -0.710, -0.469, -1.814, -0.488, -1.184, -1.211, -1.007, -1.589, -0.861, -0.593, -2.231, -1.243, -1.839, -5.000, -2.151, -0.381, -0.449, -1.211, -1.471, -1.252, -1.403, -0.589, -1.517, -1.192, 0.026, -1.467, -1.300, -1.863, -0.122, -1.919, -3.421, -1.080, -0.308, -1.470, -1.163, -1.164, -0.693, -1.470, -1.684, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.123, 0.476, 0.022, -5.000, 0.049, 0.585, -0.809, -5.000, 0.207, 0.567, 0.195, -0.011, 0.517, 0.694, -0.041, 0.173, 0.586, 0.761, 0.092, -5.000, 0.074, 0.331, -1.140, -0.018, 0.136, 0.431, 0.253, -0.286, 0.613, 0.536, -0.409, 0.008, 0.286, 0.403, -0.291, 0.497, -0.194, 0.500, -1.500, -0.886, 0.161, 0.464, 0.070, -0.207, -0.215, 0.483, 0.001, 0.031, 0.037, 0.545, -0.442, 0.129, -0.110, 0.939, -1.045, -0.654, 0.437, 0.819, 0.370, 0.032, -0.011, 0.698, 0.016, -0.001, 0.639, 1.137, 0.817, -5.000, 0.739, 0.973, -1.604, -5.000, 0.561, 1.075, 0.693, 0.319, 1.097, 1.122, 0.561, 0.797, 0.903, 1.226, 0.074, -5.000, 0.872, 0.921, -0.780, 0.396, 0.455, 0.836, 0.141, 0.439, 0.721, 0.723, -0.144, 0.702, 0.740, 1.326, 1.034, 1.136, 0.537, 1.162, -0.095, -0.553, 0.551, 1.046, 0.648, 0.224, 0.400, 0.979, 0.378, 0.849, 0.641, 1.158, 0.752, 0.870, 0.806, 1.354, -0.037, 0.212, 0.927, 1.217, 0.769, 0.504, 0.752, 1.118, 0.465, 0.653, 0.539, 0.803, 0.217, -5.000, 0.716, 0.839, -0.507, -5.000, 0.593, 0.588, 0.447, 0.155, 0.628, 0.691, -0.017, 0.547, 0.450, 0.726, -0.321, -5.000, 0.355, 0.517, -1.645, -0.011, 0.332, 0.677, 0.226, -0.005, 0.569, 0.610, -0.639, 0.231, 0.279, 0.823, -0.083, -0.038, -0.230, 0.441, -1.538, -0.213, 0.117, 0.574, 0.050, -0.489, -0.194, 0.331, -0.819, -0.054, 0.565, 1.132, 0.108, 0.315, 0.086, 1.055, -1.293, -0.079, 0.290, 0.619, 0.119, -0.060, 0.307, 0.721, -0.233, -0.265, -0.090, 0.422, -0.162, -5.000, -0.119, 0.214, -1.407, -5.000, 0.022, 0.541, 0.317, -0.246, 0.179, 0.384, -0.072, -0.059, 0.140, 0.384, -0.203, -5.000, -0.265, 0.078, -1.070, -0.076, -0.181, 0.468, 0.268, -0.076, 0.482, 0.596, -0.055, 0.190, -0.025, 0.337, -0.634, 0.057, -0.490, 0.251, -1.818, -0.979, -0.114, 0.181, -0.254, -0.517, 0.011, 0.222, -0.321, -0.130, -0.002, 0.449, -0.411, 0.007, -0.449, 0.532, -0.979, -1.030, -0.036, 0.494, 0.020, -0.326, 0.225, 0.552, -0.010, -0.305, 0.606, 0.954, 0.259, -5.000, 0.531, 1.021, -0.602, -5.000, 0.702, 1.149, 0.662, 0.538, 0.673, 0.881, 0.343, 0.524, 0.699, 0.989, -0.088, -5.000, 0.325, 0.591, -1.666, 0.188, 0.318, 0.836, 0.571, 0.121, 0.624, 0.665, -0.193, 0.178, 0.436, 0.901, 0.010, 0.488, 0.135, 0.541, -1.390, -1.207, 0.091, 0.677, 0.159, -0.153, 0.032, 0.505, -0.102, 0.369, 0.282, 0.949, -0.389, 0.086, 0.187, 0.927, -1.092, -0.689, 0.229, 0.701, 0.109, -0.210, 0.213, 0.661, -0.108, 0.105, 0.621, 0.835, 0.411, -5.000, 0.551, 0.891, -0.610, -5.000, 0.751, 1.165, 0.763, 0.423, 0.829, 0.929, 0.551, 0.667, 0.736, 0.888, -0.856, -5.000, 0.139, 0.312, -1.524, 0.051, 0.098, 0.685, 0.214, 0.020, 0.310, 0.413, -0.728, -0.012, 0.668, 1.153, 0.597, 0.750, 0.320, 0.768, -0.654, -0.480, 0.070, 0.811, 0.670, -0.027, 0.172, 0.560, -0.009, 0.830, 0.624, 1.186, 0.258, 0.583, 0.600, 1.205, -0.047, -0.405, 0.754, 1.098, 0.526, 0.294, 0.538, 0.948, 0.060, 0.446, 0.427, 0.785, -0.158, -5.000, 0.395, 0.693, -0.765, -5.000, 0.262, 0.912, 0.055, 0.109, 0.293, 0.532, -0.419, 0.020, 0.285, 0.657, -0.788, -5.000, -0.055, 0.194, -1.591, -0.111, -0.241, 0.630, -0.247, -0.124, 0.257, 0.372, -0.894, -0.065, -0.076, 0.408, -1.083, -0.429, -0.120, 0.050, -1.904, -1.099, -0.230, 0.170, -0.294, -0.495, -0.258, 0.284, -0.538, -0.055, 0.127, 0.777, -0.799, -0.055, 0.173, 0.496, -1.397, -1.086, -0.119, 0.319, -0.457, -0.352, 0.177, 0.388, -0.546, -0.184, 0.452, 0.879, 0.039, -5.000, 0.522, 0.831, -0.586, -5.000, 0.354, 1.030, 0.471, 0.171, 0.322, 0.605, -0.138, 0.135, 0.428, 0.892, -0.140, -5.000, 0.323, 0.625, -1.555, 0.291, 0.004, 0.910, 0.315, 0.064, 0.455, 0.512, -0.251, 0.223, 0.245, 0.824, -0.404, 0.181, -0.020, 0.425, -1.248, -1.107, -0.038, 0.534, -0.263, -0.274, 0.058, 0.271, -0.350, 0.095, 0.344, 0.845, -0.378, 0.164, 0.132, 0.794, -1.019, -1.019, 0.072, 0.737, -0.183, -0.324, 0.329, 0.640, -0.026, -0.061, 0.425, 0.827, 0.147, -5.000, 0.271, 0.667, -0.876, -5.000, 0.255, 0.750, 0.348, 0.196, 0.811, 0.734, 0.223, 0.618, 0.625, 0.768, -0.296, -5.000, 0.189, 0.273, -1.513, -0.205, -0.357, 0.596, -0.181, -0.246, 0.354, 0.500, -0.443, 0.111, 0.339, 0.657, -0.337, 0.340, 0.153, 0.387, -1.029, -0.899, 0.168, 0.395, 0.011, -0.311, -0.058, 0.563, -0.223, 0.139, 0.567, 1.058, -0.066, 0.546, 0.543, 1.015, -0.796, -0.583, 0.889, 1.184, 0.795, 0.427, 0.610, 1.039, 0.477, 0.525, 0.754, 1.005, 0.503, -5.000, 0.487, 0.820, -0.680, -5.000, 0.670, 1.100, 1.126, 0.484, 1.066, 1.048, 0.515, 0.893, 0.899, 0.994, -0.376, -5.000, 0.735, 0.474, -1.067, 0.223, 0.290, 0.605, 0.270, -0.015, 0.455, 0.423, -0.687, 0.182, 1.116, 1.383, 0.629, 1.155, 0.859, 0.852, -0.364, -0.223, 0.592, 0.841, 0.748, 0.628, 0.778, 0.928, 0.337, 0.851, 0.977, 1.334, 0.357, 0.920, 0.896, 1.167, -0.171, 0.055, 0.984, 1.329, 1.111, 0.650, 0.976, 1.166, 0.464, 0.754, 0.127, 0.382, -0.160, -5.000, 0.139, 0.431, -1.156, -5.000, 0.310, 0.596, 0.025, 0.144, 0.155, 0.035, -0.776, 0.025, -0.259, 0.386, -1.099, -5.000, -0.283, -0.077, -5.000, -0.830, -0.704, 0.133, -0.488, -0.616, -0.363, -0.606, -1.702, -0.762, -1.141, -0.216, -2.206, -1.518, -0.407, -0.569, -2.297, -1.936, -1.532, -0.615, -0.772, -0.783, -1.285, -0.887, -1.703, -1.105, 0.042, 0.431, -1.432, -0.229, -0.167, 0.416, -1.750, -2.057, -0.263, 0.305, -0.656, -0.551, -0.085, 0.007, -0.858, -0.841, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.047, 0.484, -0.082, -5.000, -0.031, 0.239, -1.775, -5.000, -0.506, 0.509, -0.274, -0.419, 0.452, 0.423, -0.387, 0.299, 0.388, 0.639, -0.362, -5.000, 0.120, -0.190, -1.898, -0.578, -0.297, 0.480, -0.168, -0.583, 0.057, 0.321, -0.537, -0.087, 0.218, 0.608, -0.341, 0.114, -0.765, -0.039, -2.538, -2.161, -0.593, 0.293, -0.674, -1.207, -0.711, 0.147, -0.498, -0.075, 0.155, 0.862, 0.059, 0.363, 0.230, 0.723, -0.912, -0.872, 0.489, 1.085, 0.500, -0.111, 0.249, 0.766, 0.163, -0.067, 0.178, 0.388, 0.081, -5.000, 0.018, 0.599, -1.443, -5.000, 0.683, 1.041, 0.701, 0.420, 0.484, 0.637, 0.004, 0.398, 0.484, 0.483, -0.665, -5.000, 0.501, -0.001, -0.598, -0.255, 0.074, 0.544, 0.882, -0.199, 0.331, 0.239, -0.964, -0.382, 0.309, 1.080, 0.107, 0.189, 0.353, 0.632, -0.543, -1.264, -0.130, 0.077, 0.412, -0.550, 0.075, 0.508, -0.071, 0.206, 0.251, 0.691, -0.009, 0.092, 0.333, 0.928, -1.898, -0.749, 0.552, 0.959, 0.763, 0.211, 0.043, 0.502, -0.232, 0.150, -1.545, -1.454, -1.516, -5.000, -0.805, -0.973, -2.077, -5.000, -1.233, -0.586, -2.340, -1.678, -2.220, -1.887, -0.560, -1.634, -1.270, -0.713, -1.603, -5.000, -1.709, -1.338, -0.641, -1.990, -1.645, 0.232, -0.366, -1.344, -1.016, -1.622, -1.800, -1.652, -2.143, -1.052, -2.439, -1.632, -1.352, -0.811, -0.473, -2.257, -2.614, -1.320, -0.844, -1.518, -2.594, -5.000, -1.701, -1.418, -1.805, -1.064, -1.384, -2.038, -1.251, -0.568, -1.207, -2.550, -1.056, -1.572, -1.554, -1.418, -1.395, -1.132, -1.734, -1.907, -0.036, 0.526, -0.310, -5.000, -0.010, 0.579, -1.467, -5.000, -0.042, 0.670, 0.075, -0.134, -0.079, 0.254, -0.362, -0.050, 0.224, 0.673, -0.631, -5.000, -0.500, 0.029, -1.077, -0.187, 0.241, 0.879, 0.493, 0.086, 0.190, 0.136, -0.400, -0.525, -0.610, 0.371, -0.884, -0.632, -0.944, 0.179, -2.514, -1.956, -0.663, -0.251, -0.941, -1.296, -1.158, -0.761, -1.295, -0.337, -0.219, 0.670, -0.792, -0.256, -0.173, 0.560, -1.062, -1.486, -0.125, 0.620, 0.348, -0.331, -0.521, 0.213, -0.819, -0.439, -0.107, 0.173, -0.353, -5.000, -0.240, 0.309, -1.087, -5.000, -0.096, 0.451, 0.153, -0.306, 0.127, 0.363, -0.641, -0.366, -0.008, 0.486, -0.517, -5.000, -0.221, 0.020, -2.186, -0.344, -0.486, 0.638, -0.109, -0.584, -0.190, -0.084, -0.917, -0.963, 0.217, 0.083, -0.100, 0.419, -0.128, 0.447, 0.916, -1.695, -0.257, 0.046, -0.394, -0.723, -0.312, 0.288, -0.933, -0.276, -0.126, 0.525, -0.186, 0.034, 0.001, 0.591, -0.477, -0.863, 0.204, 0.394, 0.124, -0.392, -0.121, 0.377, -0.390, -0.445, 0.568, 0.939, 0.528, -5.000, 0.551, 1.035, -0.944, -5.000, 0.498, 0.956, 0.334, 0.167, 0.851, 0.763, 0.362, 0.600, 0.679, 0.972, -0.256, -5.000, 0.219, 0.566, -1.109, 0.334, -0.020, 0.874, -0.098, -0.087, 0.265, 0.567, -0.687, 0.012, 0.795, 1.348, 0.565, 1.115, 1.086, 0.987, -5.000, 0.059, 0.447, 0.213, 0.255, 0.439, 0.448, 1.002, 0.447, 0.708, 0.729, 1.223, 0.597, 0.894, 0.824, 1.343, -1.527, -0.276, 0.858, 1.138, 0.432, 0.364, 0.543, 0.994, 0.308, 0.466, 0.536, 0.674, -0.107, -5.000, 0.295, 0.612, -5.000, -5.000, 0.309, 0.203, 0.166, 0.041, 0.542, 0.414, -0.436, 0.125, 0.203, 0.441, 0.032, -5.000, 0.301, 0.039, 0.152, 0.014, -0.269, 0.508, 0.275, -0.013, 0.131, 0.462, -1.863, -0.101, 0.092, 0.436, -0.423, -0.512, -0.610, 0.416, -1.109, -0.205, -0.428, -0.175, -0.329, -0.498, -0.392, -0.411, -1.502, -0.146, 0.422, 1.081, 0.247, 0.191, 0.141, 0.829, -1.493, -0.128, 0.213, 0.420, -0.046, -0.144, 0.250, 0.642, -0.283, -0.427, -0.232, 0.364, -0.366, -5.000, -0.494, -0.088, -1.261, -5.000, -0.532, 0.551, -0.020, -0.417, -0.021, 0.387, -0.217, -0.160, 0.009, 0.159, -1.031, -5.000, -0.414, -0.350, -1.709, -0.396, -0.757, 0.148, -0.573, -0.749, 0.035, -0.053, -0.905, -0.093, -0.084, 0.234, -0.124, 0.057, -0.161, 0.633, -2.330, -1.134, -0.565, 0.003, -0.191, -0.486, -0.100, 0.083, -0.152, -0.329, -0.212, 0.399, -0.765, -0.109, -0.237, 0.482, -0.481, -1.961, -0.135, 0.092, -0.166, -0.814, -0.060, 0.176, -0.183, -0.614, 0.422, 0.717, 0.031, -5.000, 0.428, 0.868, -1.052, -5.000, 0.520, 1.006, 0.483, 0.386, 0.399, 0.600, -0.210, 0.182, 0.214, 0.497, -0.508, -5.000, -0.051, 0.116, -1.928, -0.195, -0.390, 0.493, 0.206, -0.214, 0.256, 0.168, -1.009, -0.207, 0.597, 0.745, 0.122, 0.547, 0.135, 0.171, -1.286, -0.917, 0.227, 0.481, -0.240, -0.341, -0.123, 0.381, -0.433, 0.371, 0.077, 0.679, -0.462, 0.066, -0.003, 0.674, -1.572, -0.897, 0.100, 0.610, -0.303, -0.439, -0.032, 0.432, -0.288, -0.089, 0.486, 0.723, 0.155, -5.000, 0.381, 0.507, -1.007, -5.000, 0.379, 1.009, 0.533, 0.255, 0.566, 0.651, 0.030, 0.334, 0.380, 0.602, -0.918, -5.000, -0.167, -0.337, -1.233, -0.335, -0.328, 0.446, 0.018, -0.635, -0.261, -0.105, -0.990, -0.496, 0.667, 1.032, 0.322, 0.750, 0.015, 0.412, -0.785, -1.125, 0.015, 0.473, 0.581, 0.025, 0.173, 0.558, 0.241, 0.745, 0.631, 1.059, -0.087, 0.579, 0.442, 0.811, -0.023, -0.659, 0.524, 1.008, 0.393, -0.006, 0.375, 0.572, -0.308, 0.152, -0.021, 0.410, -0.872, -5.000, -0.135, -0.126, -2.043, -5.000, -0.489, 0.559, -0.813, -0.493, -0.263, -0.239, -0.766, -0.392, -0.259, 0.229, -1.338, -5.000, -0.512, -0.468, -1.726, -1.095, -0.959, 0.069, -1.197, -0.727, -0.523, -0.184, -1.190, -0.871, -0.683, -0.164, -1.064, -0.828, -1.026, -0.950, -1.642, -1.484, -1.108, -0.765, -1.475, -1.098, -1.212, -0.638, -1.181, -0.650, -0.172, 0.437, -1.290, -0.453, -0.161, -0.086, -1.805, -1.727, -0.329, -0.098, -1.045, -0.805, -0.232, -0.275, -0.845, -0.798, 0.165, 0.541, -0.272, -5.000, -0.033, 0.401, -1.570, -5.000, 0.012, 0.749, -0.134, -0.164, 0.089, 0.129, -0.448, -0.155, 0.114, 0.531, -0.820, -5.000, -0.098, 0.059, -1.692, -0.266, -0.224, 0.654, 0.127, -0.116, -0.208, 0.213, -0.713, -0.242, -0.188, 0.351, -0.551, 0.010, -0.642, -0.094, -1.723, -1.680, -0.489, 0.279, -0.205, -0.485, -0.391, -0.243, -0.635, -0.218, 0.077, 0.675, -0.695, -0.127, -0.157, 0.583, -1.079, -1.600, -0.115, 0.393, -0.893, -0.578, -0.028, 0.226, -0.544, -0.325, 0.236, 0.660, 0.078, -5.000, -0.069, 0.393, -0.678, -5.000, 0.052, 0.464, 0.129, -0.056, 0.358, 0.390, 0.072, 0.253, 0.412, 0.692, -0.191, -5.000, -0.076, -0.205, -1.149, -0.283, -0.615, 0.129, -0.187, -0.584, 0.228, 0.170, -0.340, -0.103, -0.121, 0.330, -0.747, -0.113, -0.534, -0.394, -1.989, -1.537, -0.781, -0.200, -0.340, -1.161, -0.690, -0.301, -0.797, -0.427, -0.027, 0.526, -0.667, 0.094, -0.158, 0.496, -1.154, -1.061, 0.151, 0.444, 0.075, -0.291, 0.196, 0.565, -0.111, -0.001, 0.531, 0.826, 0.439, -5.000, 0.220, 0.665, -0.299, -5.000, 0.629, 1.028, 0.954, 0.329, 1.020, 0.881, 0.566, 0.766, 0.801, 0.899, -0.484, -5.000, 0.352, 0.124, -2.203, 0.043, 0.608, 0.519, 0.488, 0.332, 0.415, 0.387, -0.679, 0.182, 0.348, 1.016, 0.579, 0.811, 0.348, 1.048, -0.549, -0.967, 0.016, 0.748, 0.683, 0.078, 0.242, 0.897, 0.211, 0.675, 0.653, 1.072, 0.250, 0.591, 0.643, 1.217, -0.129, -0.180, 0.785, 1.064, 0.998, 0.307, 0.850, 1.089, 0.389, 0.688, -0.172, 0.124, -0.716, -5.000, 0.004, 0.534, -2.101, -5.000, 0.167, 0.503, -0.354, -0.361, -0.235, -0.044, -0.733, -0.457, -0.105, 0.491, -1.012, -5.000, -0.514, 0.077, -0.978, -0.416, -0.484, 0.321, -0.834, -0.351, 0.014, -0.359, -1.487, -0.673, -0.919, -0.158, -1.657, -0.849, -1.235, -0.382, -1.379, -1.635, -1.168, -0.062, -0.483, -0.977, -1.438, -0.722, -1.030, -1.018, -0.236, 0.469, -0.766, -0.472, -0.337, 0.641, -1.229, -0.805, -0.096, 0.700, -0.431, -0.607, 0.066, 0.447, -0.441, -0.432, 0.250, 0.612, -0.309, -5.000, -0.019, 0.520, -1.916, -5.000, -0.008, 0.614, 0.046, -0.177, -0.015, 0.108, -0.074, -0.143, 0.377, 0.638, -0.327, -5.000, -0.356, -0.074, -1.309, -0.235, -0.370, 0.460, -0.606, -0.529, 0.170, 0.377, -0.292, -0.245, -0.082, 0.436, -0.690, -0.351, -0.813, -0.076, -1.317, -1.625, -0.806, 0.166, -0.313, -0.923, -0.362, -0.024, -0.330, -0.123, 0.096, 0.886, -0.892, -0.120, -0.381, 0.731, -1.460, -1.268, 0.071, 0.742, 0.030, -0.477, 0.376, 0.722, -0.017, -0.072, -0.204, 0.218, -0.394, -5.000, -0.454, 0.098, -1.799, -5.000, -0.226, 0.360, -0.274, -0.297, 0.156, 0.437, -0.015, 0.286, 0.077, 0.304, -0.413, -5.000, -0.780, -0.130, -2.310, -0.722, 0.198, 0.575, -0.237, -0.690, 0.302, 0.231, -0.623, -0.348, -0.654, -0.002, -1.077, -0.605, -0.966, -0.942, -1.611, -2.493, -1.246, -0.727, -1.095, -1.642, -1.415, -0.093, -1.123, -0.996, -0.573, -0.055, -0.962, -0.512, -0.641, 0.477, -0.925, -1.432, -0.082, 0.244, -0.237, -0.978, -0.426, 0.047, -0.689, -0.724, -0.021, 0.219, 0.207, -5.000, -0.619, 0.211, -1.278, -5.000, 0.055, 1.008, 0.370, -0.130, 0.783, 0.692, 0.466, 0.712, 0.249, 0.397, -0.295, -5.000, -0.034, -0.038, -1.622, -0.378, 0.135, 0.753, 0.626, 0.740, 0.307, -0.062, -0.220, 0.040, 0.535, 0.910, 0.411, 0.531, 0.088, 0.326, -1.396, -0.922, -0.448, 0.472, 0.148, -0.547, -0.289, 0.515, -0.411, 0.531, 0.211, 0.644, -0.137, 0.125, 0.148, 0.614, -0.616, -0.551, 0.312, 0.808, 0.323, -0.113, -0.029, 0.544, -0.051, 0.229, -1.489, -0.839, -2.024, -5.000, -1.844, -1.409, -1.287, -5.000, -1.274, -1.016, -1.867, -0.825, -1.197, -1.983, -1.581, -1.206, -1.510, -1.879, -1.358, -5.000, -0.882, -0.416, -1.364, -5.000, -1.290, -5.000, -0.461, -2.096, -0.969, -2.077, -2.352, -0.802, -1.628, -0.594, -2.711, -1.776, -2.048, -1.217, -5.000, -2.082, -1.831, -0.216, -1.086, -1.647, -2.371, -2.284, -2.297, -1.128, -1.352, -0.787, -1.894, -1.952, -1.440, -1.384, -2.253, -2.808, -1.642, -1.504, -0.890, -1.242, -1.545, -2.096, -1.671, -1.599, -1.006, -0.359, -1.151, -5.000, -0.961, -0.650, -5.000, -5.000, -1.163, -0.328, -0.861, -0.987, -1.125, -0.839, -1.070, -1.097, -0.775, 0.034, -1.565, -5.000, -2.315, -1.081, -5.000, -1.295, -0.649, -0.205, -0.586, -0.642, -0.765, -0.636, -1.029, -1.302, -1.651, -1.127, -2.073, -1.937, -2.512, -1.597, -5.000, -2.683, -2.062, -1.910, -1.992, -2.160, -1.837, -1.006, -1.853, -1.878, -1.454, -0.586, -1.936, -1.629, -2.140, -0.780, -2.002, -1.956, -1.368, -0.315, -0.843, -1.141, -1.277, -0.683, -1.288, -1.407, -0.386, -0.151, -0.391, -5.000, -0.516, -0.003, -1.551, -5.000, -0.074, 0.542, -0.172, -0.376, 0.079, 0.285, -0.277, -0.058, -0.061, 0.483, -0.294, -5.000, -0.701, -0.364, -1.591, -1.056, -0.186, -0.084, 0.061, -0.286, 0.072, 0.187, -0.669, -0.546, -0.820, -0.614, -0.337, -0.415, -1.953, -0.722, -2.636, -2.407, -1.580, -0.133, -1.286, -1.280, -0.689, -0.451, -1.096, -0.590, -0.623, 0.036, -0.672, -0.525, -0.856, 0.226, -2.172, -1.689, -0.180, 0.101, 0.167, -0.510, -0.444, 0.222, -0.581, -0.556, 0.087, 0.625, 0.350, -5.000, -0.016, 0.753, -1.487, -5.000, -0.085, 0.559, 0.197, 0.030, 0.561, 0.788, 0.217, 0.492, 0.436, 0.920, -0.411, -5.000, 0.221, 0.307, -0.277, -0.370, 0.507, 0.393, -0.064, 0.153, 0.405, 0.178, 0.183, -0.083, 0.134, 0.894, 0.183, 0.455, -0.379, 0.170, -2.057, -1.210, -0.516, -0.110, -0.827, -0.517, -0.446, 0.247, -0.078, 0.287, -0.003, 0.946, -0.235, 0.042, -0.084, 0.899, -1.162, -1.378, 0.204, 0.812, -0.432, -0.333, 0.047, 0.705, -0.592, -0.102, -0.054, 0.385, -0.455, -5.000, -0.132, 0.352, -0.756, -5.000, 0.085, 0.151, -0.012, -0.433, 0.156, 0.434, -0.542, 0.120, -0.175, 0.429, -0.705, -5.000, -0.368, 0.155, -1.283, -0.748, -0.540, -0.010, 0.049, -0.347, 0.078, 0.077, -1.214, -0.448, -0.329, 0.439, -1.192, -0.702, -0.622, 0.159, -0.926, -0.871, -0.504, -0.067, -0.364, -0.950, -0.649, 0.341, -1.194, -0.546, -0.025, 0.687, -0.482, -0.428, -0.782, 0.684, -1.484, -0.804, -0.376, -0.056, -0.409, -0.714, 0.022, 0.365, -0.928, -0.767, -0.810, -0.122, -0.787, -5.000, -0.894, -0.354, -1.926, -5.000, -0.647, -0.062, -0.678, -0.801, -0.538, -0.292, -0.282, -0.360, -0.569, 0.567, -0.626, -5.000, -1.157, -0.785, -1.403, -0.852, -0.845, 0.167, -0.220, -0.480, -0.408, -0.105, -0.821, -0.519, -0.711, 0.156, -0.952, -0.502, -1.513, -0.298, -1.239, -1.548, -0.850, -0.491, -1.134, -1.285, -1.029, -0.367, -0.871, -0.890, -0.653, 0.230, -1.295, -0.827, -1.217, -0.143, -2.144, -1.904, -0.689, -0.174, -0.622, -0.920, -0.376, 0.058, -0.612, -0.705, 0.023, 0.310, -0.559, -5.000, -0.378, 0.323, -1.635, -5.000, 0.088, 0.248, -0.133, -0.102, 0.001, 0.142, -0.258, -0.079, 0.177, 0.605, -0.623, -5.000, -0.834, -0.538, -1.692, -0.991, -0.226, 0.675, 0.034, -0.335, -0.007, 0.250, -0.520, -0.181, -0.622, 0.187, -1.017, -0.376, -0.997, -0.718, -2.313, -2.234, -1.339, -0.514, -1.109, -1.550, -1.058, -0.519, -1.008, -0.550, -0.562, 0.282, -1.173, -0.813, -0.737, 0.134, -2.007, -1.550, -0.658, -0.089, -0.581, -0.990, -0.485, -0.080, -0.903, -0.783, 0.210, 0.480, 0.221, -5.000, 0.160, 0.502, -1.133, -5.000, 0.158, 0.493, 0.150, 0.153, 0.516, 0.585, 0.134, 0.378, 0.436, 0.541, -0.095, -5.000, -0.279, -0.224, -0.950, -0.529, -0.287, 0.323, -0.071, -0.127, 0.022, 0.299, -1.193, -0.445, 0.071, 0.824, 0.017, 0.278, -0.296, 0.216, -2.315, -1.774, -0.257, 0.100, -0.078, -0.607, -0.513, -0.107, -0.772, -0.081, -0.017, 0.691, -0.584, -0.015, -0.098, 0.900, -0.342, -0.552, 0.250, 0.535, 0.166, -0.375, 0.066, 0.321, -0.434, 0.007, -0.243, 0.012, -0.612, -5.000, -0.276, -0.029, -1.358, -5.000, 0.003, 0.189, -0.582, -0.446, -0.375, -0.197, -0.605, -0.221, -0.482, 0.375, -0.805, -5.000, -0.443, -0.720, -2.174, -0.829, -0.461, -0.033, -0.713, -0.541, -0.306, 0.106, -0.830, -0.443, -0.832, -0.019, -1.209, -1.042, -1.268, -0.896, -1.584, -1.840, -0.720, -0.441, -0.848, -1.318, -1.184, -0.574, -0.897, -1.138, -0.617, -0.177, -1.249, -0.986, -0.933, -0.142, -1.835, -2.012, -0.509, -0.433, -1.006, -1.078, -0.502, -0.259, -0.847, -0.827, 0.032, 0.405, -0.389, -5.000, 0.060, 0.529, -0.357, -5.000, -0.033, 0.521, 0.099, -0.140, 0.007, 0.027, -0.148, -0.028, 0.265, 0.799, -0.472, -5.000, -0.222, 0.154, -1.945, -0.251, -0.018, 0.670, 0.191, 0.053, 0.357, 0.427, -0.295, -0.068, -0.200, 0.555, -0.666, -0.170, -0.634, -0.005, -1.852, -1.798, -0.543, -0.064, -0.301, -0.856, -0.564, -0.209, -0.948, -0.216, -0.207, 0.611, -1.038, -0.475, -0.315, 0.673, -1.214, -1.133, -0.249, 0.094, -0.548, -0.899, -0.347, 0.005, -0.545, -0.673, 0.126, 0.528, -0.087, -5.000, 0.032, 0.400, -1.752, -5.000, 0.066, 0.571, 0.298, 0.028, 0.502, 0.583, 0.104, 0.308, 0.370, 0.621, -0.248, -5.000, -0.141, -0.086, -2.096, -0.315, -0.191, 0.238, 0.064, -0.216, 0.322, 0.548, -0.328, -0.039, -0.039, 0.340, -0.632, 0.004, -0.322, -0.097, -1.911, -1.667, -0.342, -0.149, -0.305, -0.651, -0.504, 0.087, -0.570, -0.169, 0.143, 0.567, -0.479, 0.247, -0.003, 0.505, -1.048, -0.903, 0.288, 0.544, 0.311, -0.154, 0.212, 0.627, 0.067, 0.067, 0.730, 0.941, 0.614, -5.000, 0.579, 0.846, -0.741, -5.000, 0.719, 1.161, 1.036, 0.511, 1.148, 1.116, 0.624, 0.936, 0.964, 1.039, -0.721, -5.000, 0.705, 0.698, -1.271, 0.291, 0.257, 1.050, 0.683, 0.235, 0.651, 0.748, -0.488, 0.467, 0.885, 1.304, 0.712, 0.991, 0.723, 0.951, -0.736, -0.327, 0.544, 1.028, 0.791, 0.302, 0.470, 0.973, 0.184, 0.835, 0.681, 1.166, 0.167, 0.832, 0.824, 1.107, -0.247, 0.036, 0.952, 1.271, 0.944, 0.519, 0.902, 1.124, 0.302, 0.693, -0.185, 0.190, -0.772, -5.000, -0.041, 0.551, -0.724, -5.000, 0.061, 0.492, -0.162, -0.346, -0.128, -0.083, -0.709, -0.372, -0.292, 0.296, -1.265, -5.000, -0.074, 0.150, -2.930, -0.638, -0.525, 0.188, -0.802, -0.928, -0.067, -0.140, -1.680, -0.429, -1.037, -0.309, -1.440, -1.227, -0.990, 0.041, -2.281, -1.639, -0.967, -0.386, -0.646, -1.116, -1.183, -0.696, -1.304, -1.037, -0.461, 0.256, -0.634, -0.608, -0.403, 0.649, -1.595, -1.373, -0.212, 0.454, -0.574, -0.732, -0.168, 0.143, -0.815, -0.863, 0.213, 0.583, -0.358, -5.000, 0.139, 0.630, -1.303, -5.000, 0.147, 0.708, 0.074, -0.146, 0.161, 0.340, -0.250, -0.081, 0.266, 0.654, -0.520, -5.000, -0.028, 0.251, -1.876, -0.084, 0.019, 0.674, 0.222, -0.262, 0.378, 0.499, -0.317, -0.034, -0.125, 0.450, -0.817, -0.125, -0.562, 0.375, -1.619, -1.279, -0.486, 0.367, -0.136, -0.556, -0.575, -0.051, -0.590, -0.053, -0.088, 0.619, -0.675, -0.079, -0.196, 0.856, -1.401, -0.869, 0.133, 0.727, -0.031, -0.344, 0.052, 0.455, -0.238, -0.201, -0.002, 0.449, -0.275, -5.000, -0.168, 0.407, -1.465, -5.000, -0.000, 0.371, 0.214, -0.115, 0.457, 0.647, 0.086, 0.366, 0.340, 0.564, -0.500, -5.000, -0.063, -0.042, -2.025, -0.400, -0.471, 0.517, -0.158, -0.642, 0.610, 0.597, -0.303, 0.227, -0.168, 0.228, -0.498, -0.465, -0.635, 0.081, -2.320, -1.707, -0.871, -0.013, -0.604, -1.067, -0.480, 0.013, -0.842, -0.477, -0.054, 0.492, -0.588, -0.145, -0.100, 0.704, -1.986, -1.062, 0.179, 0.531, 0.067, -0.308, 0.061, 0.508, -0.241, -0.261, 0.678, 0.889, 0.739, -5.000, 0.377, 0.799, -0.989, -5.000, 0.977, 1.172, 0.826, 0.474, 1.136, 1.136, 0.686, 1.051, 0.886, 1.074, -0.268, -5.000, 0.914, 0.653, -1.170, 0.468, 0.693, 0.952, 0.694, 0.368, 0.745, 0.600, -0.041, 0.532, 0.983, 1.164, 0.842, 1.121, 0.798, 0.988, -0.651, 0.125, 0.339, 0.860, 0.754, 0.115, 0.197, 0.853, 0.353, 0.998, 0.670, 1.168, 0.298, 0.759, 0.704, 1.064, -0.737, 0.031, 0.926, 1.189, 0.774, 0.419, 0.531, 0.974, 0.291, 0.646, -1.074, -0.820, -1.437, -5.000, -0.824, -0.845, -0.315, -5.000, -1.065, -0.538, -1.302, -1.080, -1.024, -1.154, -1.213, -0.822, -0.601, -0.191, -1.789, -5.000, -0.779, -0.992, -1.604, -0.649, -1.341, -0.442, -0.951, -0.980, -0.789, -1.349, -1.551, -0.766, -1.182, -0.159, -1.524, -1.700, -1.926, -0.784, -1.630, -1.560, -1.164, -0.516, -1.050, -1.531, -1.515, -1.050, -1.803, -1.727, -1.141, -0.789, -1.115, -1.403, -0.785, -0.448, -1.220, -1.989, -1.269, -0.619, -1.246, -1.369, -1.076, -0.615, -1.150, -1.574, -0.631, -0.329, -1.649, -5.000, -0.780, -0.205, -1.990, -5.000, -0.925, -0.257, -0.994, -0.647, -0.893, -0.360, -1.248, -0.774, -0.779, -0.074, -1.134, -5.000, -0.894, -0.787, -1.993, -1.321, -0.931, -0.209, -1.146, -0.749, -0.550, 0.131, -1.339, -0.874, -1.104, -0.236, -1.159, -1.195, -1.523, -0.519, -1.779, -1.819, -1.914, -1.736, -1.021, -1.796, -1.191, -0.884, -1.755, -0.853, -0.885, -0.218, -0.881, -0.984, -1.114, -0.214, -1.928, -1.363, -0.855, -0.064, -0.823, -1.129, -0.797, -0.415, -1.148, -1.157, 0.133, 0.597, 0.082, -5.000, 0.081, 0.504, -1.531, -5.000, 0.148, 0.621, 0.191, -0.050, 0.635, 0.681, 0.140, 0.187, 0.553, 0.962, 0.104, -5.000, 0.163, 0.485, -0.663, 0.148, 0.188, 0.608, 0.380, -0.218, 0.615, 0.655, -0.285, 0.239, 0.114, 0.392, -0.012, 0.485, -0.369, 0.369, -1.539, -1.403, -0.371, 0.283, -0.248, -0.425, -0.370, 0.182, -0.626, -0.057, 0.041, 0.716, -0.372, 0.241, -0.149, 0.890, -0.813, -0.852, 0.237, 0.649, 0.195, -0.154, -0.003, 0.654, -0.225, -0.109, 0.624, 1.060, 0.834, -5.000, 0.719, 1.065, -0.721, -5.000, 0.517, 0.990, 0.505, 0.256, 1.145, 1.057, 0.488, 0.818, 0.956, 1.322, 0.252, -5.000, 0.985, 0.860, -0.744, 0.655, 0.271, 0.741, 0.488, 0.268, 0.858, 0.813, -0.058, 0.696, 0.614, 1.181, 0.609, 0.972, 0.247, 1.081, -1.083, -0.849, 0.072, 0.764, 0.197, 0.084, 0.326, 0.746, -0.265, 0.691, 0.435, 1.107, 0.272, 0.662, 0.407, 1.300, -0.939, -0.468, 0.565, 0.983, 0.522, 0.289, 0.517, 1.040, -0.012, 0.358, 0.138, 0.570, -0.136, -5.000, 0.399, 0.601, -1.217, -5.000, 0.239, 0.492, 0.153, -0.227, 0.408, 0.562, -0.124, 0.254, 0.272, 0.742, -0.627, -5.000, 0.366, 0.751, -1.596, -0.205, -0.101, 0.296, 0.106, -0.080, 0.340, 0.539, -0.283, -0.001, -0.186, 0.763, -0.448, -0.285, -0.523, 0.119, -1.102, -0.800, -0.730, -0.180, -0.472, -0.716, -0.497, -0.054, -0.531, -0.657, 0.124, 0.970, -0.192, -0.058, -0.403, 0.762, -2.149, -0.715, -0.251, 0.050, -0.461, -0.544, -0.248, 0.320, -0.539, -0.610, -0.237, 0.155, -0.488, -5.000, -0.351, 0.135, -2.121, -5.000, -0.229, 0.381, 0.062, -0.459, -0.057, 0.319, -0.293, -0.078, -0.151, 0.449, -0.674, -5.000, -0.496, -0.071, -2.024, -0.466, -0.597, 0.418, -0.088, -0.532, 0.171, 0.556, -0.239, -0.106, -0.366, 0.341, -0.814, -0.178, -0.731, -0.006, -1.520, -1.282, -0.564, 0.007, -0.615, -0.754, -0.423, -0.137, -0.839, -0.459, -0.334, 0.347, -0.769, -0.349, -0.588, 0.544, -1.409, -1.416, -0.417, 0.178, -0.420, -0.734, -0.176, 0.187, -0.458, -0.564, 0.368, 0.681, 0.127, -5.000, 0.139, 0.630, -0.905, -5.000, 0.267, 0.802, 0.258, 0.106, 0.591, 0.749, 0.213, 0.405, 0.548, 0.800, -0.220, -5.000, -0.024, 0.192, -2.143, -0.242, -0.069, 0.763, 0.340, 0.274, 0.523, 0.632, -0.080, 0.251, 0.160, 0.659, -0.329, 0.248, -0.425, -0.074, -1.905, -1.498, -0.639, -0.323, -0.573, -0.728, -0.388, 0.004, -0.826, -0.031, -0.069, 0.657, -0.683, -0.001, -0.232, 0.521, -1.527, -1.080, -0.148, 0.254, -0.305, -0.603, -0.099, 0.353, -0.252, -0.295, 0.598, 0.888, 0.567, -5.000, 0.485, 0.796, -0.527, -5.000, 0.558, 0.974, 0.691, 0.514, 0.914, 0.990, 0.706, 0.794, 0.781, 1.001, -0.496, -5.000, 0.493, 0.340, -0.722, 0.172, 0.044, 0.733, 0.280, 0.051, 0.470, 0.529, -0.491, -0.011, 0.675, 1.223, 0.564, 0.750, 0.053, 0.637, -1.427, -1.012, -0.183, 0.360, 0.469, -0.104, 0.200, 0.521, -0.244, 0.543, 0.521, 1.178, -0.040, 0.567, 0.417, 1.015, -0.153, -0.451, 0.625, 0.943, 0.601, 0.167, 0.459, 0.761, -0.055, 0.261, 0.156, 0.545, -0.186, -5.000, 0.216, 0.499, -1.389, -5.000, 0.112, 0.545, -0.063, -0.141, 0.123, 0.172, -0.328, 0.116, 0.071, 0.626, -0.437, -5.000, -0.103, 0.028, -1.630, -0.118, -0.118, 0.570, -0.122, -0.181, 0.410, 0.259, -0.478, 0.116, -0.605, 0.046, -1.003, -0.709, -0.765, -0.257, -1.550, -1.894, -0.639, -0.135, -0.248, -0.756, -0.740, -0.414, -1.168, -0.782, -0.335, 0.369, -1.035, -0.364, -0.307, 0.445, -1.364, -1.222, -0.608, 0.040, -0.679, -0.689, -0.301, -0.078, -0.755, -0.621, -0.027, 0.390, -0.410, -5.000, 0.055, 0.578, -1.207, -5.000, 0.122, 0.772, 0.248, -0.114, 0.072, 0.248, -0.141, -0.030, 0.146, 0.650, -0.285, -5.000, -0.051, 0.066, -1.454, -0.168, -0.050, 0.835, 0.200, -0.044, 0.253, 0.437, -0.160, 0.073, -0.326, 0.437, -0.759, -0.299, -0.608, 0.028, -1.577, -1.550, -0.590, 0.162, -0.329, -0.786, -0.612, -0.290, -0.925, -0.330, -0.347, 0.375, -0.834, -0.385, -0.265, 0.441, -1.071, -1.266, -0.224, 0.232, -0.523, -0.860, -0.367, 0.020, -0.748, -0.778 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_19(struct _training *tptr) {
  struct _training tinf = {
    0.722, 11, 4.350, { 0.876, 0.090, 2.034 }, { 1.053, -0.729, -1.887 }, 1, 
    { -1.233, -1.616, -1.115, -1.202, -0.611, -4.000, -0.388, -4.000, -0.048, -0.622, -1.580, -4.000, -0.311, 0.202, -0.185, 1.560, 1.217, -1.142, 1.793, 1.186, 0.751, 1.592, 2.790, 2.321, 2.141, 0.392, 3.274, 2.552 }, 
    {{ -0.655, -0.294, 0.470, -0.541},{ 0.058, -0.387, 0.219, 0.129},{ 0.356, 0.031, -0.131, -0.212},{ 0.430, -0.092, -0.104, -0.055},{ 0.400, -0.128, -0.032, -0.103},{ 0.221, -0.149, 0.072, -0.084},{ 0.339, -0.201, 0.014, 0.032},{ 0.254, -0.135, 0.046, -0.088},{ 0.162, -0.151, 0.112, -0.128},{ 0.181, -0.195, 0.064, 0.085},{ 0.229, -0.120, 0.038, -0.068},{ 0.069, -0.132, 0.128, -0.111},{ 0.153, -0.153, 0.051, 0.067},{ 0.109, -0.093, 0.057, -0.037},{ 0.076, -0.133, 0.105, -0.043},{ 0.130, -0.152, 0.037, 0.121},{ 0.159, -0.052, 0.007, -0.059},{ 0.074, -0.111, 0.098, -0.073},{ 0.177, -0.163, 0.022, 0.132},{ 0.144, -0.059, 0.014, -0.046},{ 0.045, -0.086, 0.088, -0.072},{ 0.142, -0.141, 0.007, 0.157},{ 0.112, -0.060, -0.010, 0.057},{ -0.003, -0.061, 0.030, 0.075},{ 0.171, -0.160, -0.017, 0.216},{ 0.072, -0.050, 0.019, 0.003},{ -0.032, -0.056, 0.092, -0.081},{ 0.132, -0.138, 0.028, 0.113},{ 0.105, -0.040, 0.001, -0.011},{ 0.090, -0.123, 0.084, -0.023},{ 0.263, -0.146, -0.020, 0.099},{ 0.142, -0.052, -0.008, 0.000} }, 
    {{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}} }, 
    0.000, { -0.157, 0.067, -0.033, -5.000, -0.601, -0.220, -0.646, -5.000, -0.229, -0.221, -0.070, -0.393, 0.230, 0.237, 0.180, 0.781, 0.578, 0.416, 0.196, -5.000, -0.307, -0.226, -0.376, -0.043, 0.180, 0.033, -0.212, -0.271, 0.839, 0.426, 0.615, 0.224, 0.739, 0.769, 0.378, 0.760, 0.559, 0.719, 0.672, 0.373, 0.862, 0.934, 0.295, 0.607, 0.740, 0.884, 0.903, 0.873, 0.090, -0.152, -0.943, 0.852, -0.477, 0.138, -0.055, -0.188, 0.233, 0.412, -0.335, 0.660, -0.175, -0.149, -0.129, -0.262, 0.121, -1.093, -1.541, -5.000, -0.258, -1.376, -1.812, -5.000, -0.349, -1.161, -1.593, -0.535, -0.220, -1.583, -0.188, -0.434, 1.048, 0.338, -0.173, -5.000, 0.062, -0.255, -0.205, 0.456, 0.222, 0.043, -0.170, -0.032, 0.997, 0.080, 0.510, 0.467, 0.853, 0.222, -0.147, 1.015, 0.485, -0.170, -0.026, 0.135, 0.883, 0.491, 0.284, 0.480, 1.000, 0.020, 0.442, 0.787, 0.088, -1.266, -1.293, 0.012, -0.068, -0.932, -0.543, -0.673, -0.806, -1.315, -1.255, -0.860, -0.055, -1.361, -1.156, -0.380, 0.268, -0.624, -1.238, -5.000, -0.436, -1.195, -2.022, -5.000, -0.348, -0.646, -1.252, -0.406, -0.250, -1.313, -2.395, -0.611, 0.435, -0.031, -0.447, -5.000, -0.548, -1.208, -1.550, -0.062, -0.162, -0.880, -1.277, -0.161, 0.630, 0.351, 0.229, 0.175, 0.065, -0.435, -1.230, 0.604, -0.039, -1.302, -1.395, -0.549, 0.472, -0.130, -0.734, -0.006, 0.494, -0.714, -0.600, 0.090, -0.061, -1.308, -2.068, -0.160, -0.314, -1.603, -1.496, -0.531, -0.415, -1.728, -1.966, -0.773, -0.137, -1.458, -1.846, -0.195, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.794, -0.495, -0.358, -5.000, -2.038, -1.808, -2.359, -5.000, -1.922, -2.043, -2.126, -2.008, 0.283, -0.705, -0.262, -0.092, -0.464, -0.315, -0.509, -5.000, -1.731, -1.583, -1.999, -2.212, -1.667, -1.572, -1.723, -1.892, 0.273, -0.250, 0.152, -0.167, -0.424, -0.371, -0.557, -0.517, -1.184, -0.769, -0.894, -1.402, -1.276, -1.229, -1.779, -1.531, -0.229, -0.351, -0.014, -0.288, -0.527, -1.337, -1.925, -0.773, -2.251, -2.448, -2.604, -2.777, -0.007, -0.084, -0.373, -0.120, 0.208, -0.113, -0.836, -0.129, -0.333, -0.909, -1.720, -5.000, -1.612, -1.742, -2.490, -5.000, -1.065, -1.802, -2.340, -1.671, 0.058, -0.989, -0.454, 0.255, 0.539, 0.103, -0.398, -5.000, -0.942, -0.609, -1.141, -0.467, -0.518, -0.473, -1.033, -0.670, 0.603, -0.152, -0.263, 0.066, 0.289, 0.084, -0.670, 0.271, -0.605, -0.517, -1.153, -1.059, 0.149, -0.032, -0.742, -0.318, 0.703, -0.124, -0.008, 0.507, -0.463, -1.659, -1.610, -0.376, -1.284, -1.681, -2.016, -1.699, -2.110, -2.339, -2.731, -2.472, -0.372, -1.772, -1.301, -0.962, -0.170, -0.882, -1.559, -5.000, -2.200, -2.098, -2.497, -5.000, -1.336, -1.881, -2.376, -1.906, -0.634, -1.470, -2.088, -1.194, -0.211, -0.722, -1.224, -5.000, -2.125, -2.018, -2.357, -1.943, -1.567, -1.621, -2.109, -1.886, 0.329, -0.511, -0.233, 0.048, -0.570, -1.121, -1.879, -0.406, -1.696, -1.715, -2.038, -1.980, -0.922, -1.187, -1.629, -1.183, -0.510, -1.042, -1.479, -0.543, -0.589, -1.961, -2.276, -0.574, -2.165, -2.433, -2.538, -2.531, -2.125, -2.416, -2.729, -2.266, -1.005, -2.014, -2.340, -1.259, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.116, -0.197, -0.860, -5.000, -2.000, -1.450, -2.272, -5.000, -1.675, -1.613, -2.242, -1.913, -0.485, -0.332, 0.223, -0.246, 0.205, 0.054, 0.043, -5.000, -1.639, -1.070, -1.411, -1.677, -1.105, -1.070, -1.580, -1.817, 0.493, 0.067, 0.333, 0.038, -0.067, 0.128, -0.464, 0.531, -0.914, -0.317, -0.838, -1.357, -0.573, -0.708, -1.119, -1.102, 0.030, 0.014, 0.285, -0.083, -0.434, -1.233, -0.743, 0.056, -1.966, -1.243, -2.041, -1.864, -2.439, -1.766, -1.915, -2.634, -1.766, -0.633, -2.064, -0.188, -0.160, -0.492, -1.352, -5.000, -1.809, -1.378, -2.515, -5.000, -1.485, -2.016, -2.637, -2.155, 0.062, -0.748, -0.184, -1.054, 0.441, 0.458, 0.091, -5.000, -1.575, -0.850, -1.383, -1.304, -1.006, -0.714, -1.287, -1.459, 0.668, 0.098, 0.082, -0.159, -0.131, -0.114, -0.644, 0.201, -1.061, -0.855, -1.447, -1.797, -0.209, -0.340, -0.960, -0.921, 0.463, -0.243, -0.181, 0.283, -0.182, -1.234, -1.384, -0.453, -1.433, -1.759, -1.808, -1.852, -1.292, -1.881, -2.087, -1.848, -0.203, -1.002, -0.840, -0.556, -0.241, -1.163, -1.578, -5.000, -2.409, -2.081, -2.519, -5.000, -1.827, -2.012, -2.297, -2.485, -0.993, -1.617, -1.811, -0.479, -0.221, -1.097, -1.535, -5.000, -2.316, -2.061, -2.265, -2.347, -1.788, -1.872, -1.936, -2.150, -0.031, -0.613, -0.932, -0.398, -0.783, -1.254, -1.719, -0.279, -1.505, -1.763, -2.262, -2.153, -1.005, -1.227, -1.221, -1.124, -0.856, -1.273, -1.465, -0.894, -0.482, -1.535, -1.797, -0.623, -2.217, -2.312, -2.600, -2.112, -2.224, -2.209, -2.679, -2.517, -0.865, -1.806, -2.144, -1.016, -0.537, -0.171, -0.448, -5.000, -2.341, -1.776, -2.386, -5.000, -2.036, -1.830, -2.265, -2.322, -0.477, -0.887, -1.266, -0.634, -0.553, -0.107, -0.379, -5.000, -1.928, -1.670, -1.852, -1.911, -1.480, -1.288, -1.580, -1.730, -0.045, -0.230, 0.108, 0.060, -0.693, -0.334, -0.741, -0.070, -1.389, -1.253, -1.510, -1.969, -1.092, -0.674, -1.440, -1.453, -0.446, -0.181, 0.091, -0.290, -0.297, -1.006, -0.802, -0.516, -1.553, -1.532, -1.931, -2.200, -2.042, -2.056, -2.332, -2.373, -0.646, -1.081, -0.490, -0.544, 0.226, -0.025, -0.129, -5.000, -0.485, -0.274, -0.659, -5.000, -0.237, -0.845, -0.521, -0.398, -0.129, -0.019, 0.025, -1.127, 0.696, 0.262, -0.556, -5.000, -0.455, 0.017, -0.289, 0.269, -0.174, 0.274, -0.420, -0.237, 0.806, 0.673, 0.728, 0.246, 0.366, 0.457, -0.237, 0.682, -0.283, 0.484, 0.062, -0.453, 0.148, 0.466, -0.317, 0.089, 0.259, 0.341, 0.380, 0.349, -0.080, -0.396, -0.763, -0.668, 0.719, -0.013, -0.674, -0.732, 0.083, -0.822, -0.640, -0.773, 0.719, 0.329, 0.647, 0.382, -0.013, -1.149, -1.439, -5.000, -0.683, -1.385, -2.125, -5.000, -0.387, -1.363, -1.740, -1.441, 0.323, -1.602, 0.339, -0.668, 0.478, -0.587, -0.723, -5.000, -0.513, -0.644, -0.670, -0.229, -0.122, -0.453, -0.891, -0.193, 0.068, -0.480, -0.484, 0.373, 0.448, -0.218, -0.687, 0.510, -0.322, -0.593, -1.165, -0.409, 0.209, -0.118, -0.570, -0.043, 0.204, -0.569, -0.467, 0.215, -0.594, -1.613, -1.325, 0.277, -0.565, -1.315, -1.223, -0.543, -0.478, -1.611, -1.411, -1.386, -5.000, -1.598, -1.081, -1.127, -0.055, -0.721, -1.639, -5.000, -0.907, -1.357, -2.209, -5.000, 0.177, -1.281, -1.411, -0.594, -5.000, -1.183, -1.436, -1.073, -0.120, -0.440, -0.790, -5.000, -0.427, -1.232, -1.983, -0.645, -0.152, -1.119, -1.507, -0.529, -0.113, -0.025, -0.525, 0.536, -0.039, -0.826, -1.475, 0.354, -0.468, -1.376, -1.895, -1.101, -0.522, -0.945, -1.071, -0.581, -0.317, -0.746, -1.224, -0.445, -0.114, -1.166, -1.334, 0.448, -0.297, -1.568, -1.640, -0.792, -0.589, -1.729, -1.888, -1.179, 0.237, -1.572, -2.027, -0.095, 0.660, 0.010, -0.763, -5.000, -1.035, -0.700, -0.065, -5.000, -0.129, -0.358, -0.501, -0.224, -0.748, -0.129, -0.149, -0.129, 0.529, -0.039, -0.224, -5.000, -0.270, -0.268, -0.928, -0.303, -0.516, -0.171, -0.784, -0.227, -0.460, 0.127, 0.005, 0.489, 0.291, 0.156, -0.370, 0.344, -0.190, -0.301, -0.702, -0.060, 0.047, 0.103, -0.323, -0.453, 0.488, -0.064, 0.629, 0.071, 0.100, 0.094, -0.971, 0.693, -0.460, -0.445, -0.295, -0.184, -0.651, 0.079, -0.003, -0.485, -1.515, -1.361, 0.271, 0.025, 0.437, 0.123, 0.075, -5.000, -0.253, 0.524, -0.170, -5.000, -0.020, 0.053, -0.326, -0.555, 0.039, 0.129, 0.112, 0.112, 1.207, 1.253, 0.993, -5.000, -0.573, 0.406, -0.004, 0.434, 0.287, 0.656, 0.236, -0.278, 0.839, 0.843, 1.360, -0.326, 1.521, 1.558, 1.297, 1.610, 1.210, 1.553, 1.477, 1.076, 1.507, 1.567, 1.401, 1.414, 1.545, 1.502, 1.524, 1.567, 0.719, -0.189, 0.017, 0.242, 0.157, 0.526, 0.464, -0.049, -0.544, 0.223, 0.032, 0.733, 0.621, -0.360, -0.108, 0.159, 0.242, 0.075, -0.639, -5.000, -0.156, -0.530, -1.085, -5.000, 0.008, -0.335, -1.319, -0.524, 0.470, -0.963, 0.175, -0.035, 1.211, 1.133, 0.788, -5.000, -0.112, 0.610, 0.708, 1.015, 0.643, 0.869, 0.598, 0.234, 1.072, 0.997, 1.250, 0.309, 1.253, 1.082, 0.934, 1.388, 0.670, 0.605, 0.794, 0.560, 1.182, 0.952, 1.000, 0.944, 1.337, 0.841, 0.859, 1.206, 0.291, -0.583, -0.300, 0.457, 0.414, -0.165, 0.355, -0.237, -0.271, -0.631, -0.515, -0.241, -0.011, -0.962, -0.547, 0.061, 0.674, 0.255, -0.342, -5.000, -0.258, -0.046, -0.766, -5.000, 0.170, 0.239, -0.954, -0.285, 0.130, -0.446, -0.952, -0.080, 1.235, 0.551, 0.061, -5.000, -0.204, 0.115, 0.119, 1.028, 0.479, 0.158, 0.221, 0.538, 1.155, 0.503, 0.795, 0.443, 1.003, 0.416, -0.050, 1.162, 0.227, 0.121, 0.060, 0.017, 0.981, 0.675, 0.203, 0.392, 1.028, 0.250, 0.530, 0.834, 0.660, -0.878, -1.089, 0.486, 0.389, -0.523, -0.361, -0.275, 0.144, -0.462, -0.492, -0.063, 0.443, -0.759, -0.680, -0.013, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.153, -0.153, -0.479, -5.000, -1.912, -1.305, -1.872, -5.000, -1.988, -1.719, -2.181, -2.093, -0.206, -0.131, -0.516, -0.318, -0.507, -0.084, -0.351, -5.000, -1.419, -0.928, -1.250, -1.643, -1.363, -1.125, -1.415, -1.600, -0.173, -0.325, 0.256, -0.485, -0.493, -0.064, -0.636, -0.458, -1.017, -0.300, -0.397, -1.133, -0.823, -0.598, -1.235, -1.331, -0.285, -0.188, 0.135, -0.319, -0.247, -1.245, -0.799, -0.640, -1.614, -1.754, -1.864, -2.378, -0.111, -0.454, -0.100, -0.262, 0.385, -0.086, -0.010, 0.253, -0.087, -0.170, -1.314, -5.000, -1.286, -0.978, -2.047, -5.000, -1.146, -1.464, -2.039, -1.382, 0.004, -0.894, -0.218, 0.083, 0.618, 0.711, 0.277, -5.000, -0.775, -0.346, -0.439, -0.127, -0.312, -0.014, -0.557, -0.546, 0.803, 0.390, 0.665, -0.041, 0.495, 0.645, 0.056, 0.602, -0.426, -0.041, -0.599, -0.805, 0.187, 0.214, -0.343, -0.239, 0.795, 0.141, 0.357, 0.701, -0.286, -1.016, -1.296, -0.479, -1.334, -1.001, -1.341, -1.396, -2.237, -2.026, -2.175, -2.277, -0.169, -1.531, -1.259, -0.216, 0.070, 0.184, -0.788, -5.000, -1.631, -1.002, -1.689, -5.000, -1.121, -0.834, -1.774, -1.308, -0.172, -0.151, -1.305, -0.229, 0.551, 0.686, -0.000, -5.000, -1.432, -0.556, -0.943, -0.400, -0.942, -0.405, -0.902, -1.063, 0.612, 0.370, 0.905, -0.110, 0.470, 0.633, -0.274, 0.963, -0.563, 0.005, -0.452, -0.911, 0.190, 0.304, -0.514, -0.202, 0.297, 0.093, -0.339, 0.593, -0.294, -1.380, -1.582, -0.032, -1.592, -1.634, -1.755, -1.908, -1.929, -1.937, -2.267, -2.213, -0.976, -1.610, -1.469, -0.480, 0.505, 0.760, 0.086, -5.000, -1.699, -0.800, -1.792, -5.000, -1.431, -1.028, -1.820, -1.561, -0.019, 0.239, -0.508, -0.262, 0.683, 0.985, 0.826, -5.000, -1.389, -0.780, -0.979, -0.549, -0.924, -0.185, -0.522, -0.983, 0.350, 0.576, 1.240, 0.039, 0.149, 1.109, 0.609, 0.958, -0.587, 0.531, -0.087, -1.338, 0.025, 0.493, -0.367, -0.359, 0.336, 0.813, 1.022, 0.774, -0.616, -0.082, -0.581, -0.029, -0.907, -1.070, -1.413, -1.639, -1.206, -1.354, -1.957, -1.854, -0.421, -0.852, -0.613, -0.475, 0.007, 0.163, -0.619, -5.000, -1.570, -0.468, -1.604, -5.000, -1.632, -1.165, -2.153, -2.180, 0.137, -0.465, -0.157, -0.021, 0.626, 0.824, 0.513, -5.000, -1.107, -0.143, -0.446, -0.523, -0.384, -0.070, -0.583, -0.913, 0.508, 0.462, 1.034, -0.384, 0.686, 0.989, 0.738, 1.155, -0.451, 0.626, 0.164, -0.595, 0.340, 0.447, -0.029, -0.150, 0.668, 0.725, 0.845, 0.774, -0.349, -0.562, -0.281, 0.257, -1.403, -0.235, -0.635, -1.864, -1.932, -1.648, -1.657, -2.255, -0.881, -0.995, -0.547, 0.014, 0.214, 0.029, -0.890, -5.000, -1.232, -0.492, -1.838, -5.000, -1.080, -1.258, -2.336, -2.004, 0.333, -0.839, -0.153, 0.105, 0.852, 0.992, 0.647, -5.000, -0.878, 0.178, -0.077, -0.068, -0.051, 0.245, -0.268, -0.549, 0.749, 0.644, 1.095, -0.288, 0.759, 1.073, 0.713, 1.044, -0.216, 0.535, 0.045, -0.515, 0.523, 0.570, 0.032, 0.000, 0.919, 0.674, 0.833, 0.912, -0.162, -0.670, -0.654, 0.120, -0.515, -0.360, -0.617, -0.898, -1.120, -1.337, -1.654, -1.694, -0.147, -1.107, -0.906, -0.287, 0.161, 0.264, -0.895, -5.000, -1.581, -0.655, -1.661, -5.000, -0.973, -0.735, -1.635, -1.557, 0.036, -0.127, -1.589, -0.405, 0.460, 0.352, -0.203, -5.000, -1.251, -0.528, -0.802, -0.830, -0.532, -0.373, -0.703, -1.123, 0.254, 0.349, 0.861, -0.447, 0.837, 0.742, -0.065, 0.952, -0.449, -0.190, -0.663, -0.975, 0.448, 0.259, -0.458, -0.160, 0.710, 0.271, 0.052, 0.610, 0.302, -0.107, -0.472, 0.688, -0.984, -0.654, -1.068, -1.374, -0.744, -0.667, -1.278, -1.628, 0.298, -0.299, -0.497, -0.218, 0.077, 0.397, -0.535, -5.000, -1.854, -0.881, -1.965, -5.000, -1.518, -1.533, -2.243, -2.016, -0.249, -0.263, -0.540, -0.070, 0.347, 0.717, 0.328, -5.000, -1.328, -0.681, -0.808, -0.689, -0.729, -0.479, -0.841, -1.190, 0.029, 0.159, 0.873, -0.464, -0.190, 0.552, 0.187, 0.392, -0.931, 0.102, -0.506, -1.181, -0.118, 0.125, -0.407, -0.630, 0.113, 0.500, 0.824, 0.235, -0.336, -0.110, -0.213, 0.085, -1.223, -0.114, -0.816, -1.483, -1.732, -1.041, -1.686, -1.962, -0.419, -0.350, -0.183, -0.435, 0.405, 0.433, -0.234, -5.000, -0.080, 0.271, -0.378, -5.000, 0.034, -0.390, -0.547, -0.170, 0.025, -0.180, 0.105, 0.291, 1.035, 1.056, 0.761, -5.000, -0.419, 0.572, 0.754, 0.450, 0.367, 0.625, 0.228, 0.103, 0.796, 0.828, 1.330, -0.206, 1.085, 1.083, 0.733, 1.138, 0.095, 1.118, 0.694, 0.246, 0.702, 0.833, 0.179, 0.391, 0.998, 0.843, 0.868, 0.971, 0.233, 0.090, 0.177, 0.719, -0.046, 0.640, 0.200, -0.193, -0.451, -0.556, -0.799, -0.827, -0.335, 0.148, -0.289, 0.220, 0.128, 0.053, -0.630, -5.000, -0.246, -0.003, -1.095, -5.000, -0.256, -0.824, -1.468, -0.747, 0.061, -0.972, -0.465, -0.442, 0.900, 0.906, 0.607, -5.000, -0.543, 0.476, 0.535, 0.456, 0.488, 0.572, 0.243, 0.144, 0.714, 0.797, 1.215, -0.089, 1.051, 1.103, 0.649, 1.092, 0.204, 0.562, 0.137, 0.263, 0.793, 0.771, 0.317, 0.440, 1.101, 0.790, 0.748, 1.116, 0.864, 0.348, 0.366, 1.233, 0.407, 0.090, -0.396, 0.388, -0.126, -0.733, -0.974, -0.453, 0.188, -0.638, -0.536, 0.395, 1.278, 1.191, 0.559, -5.000, 0.389, 0.690, -0.096, -5.000, 0.742, 0.803, -0.435, 0.336, 0.598, 0.293, -0.714, 0.463, 1.433, 1.321, 0.834, -5.000, 0.336, 1.014, 0.986, 1.206, 1.221, 1.191, 0.890, 1.042, 1.406, 1.366, 1.426, 0.636, 1.443, 1.227, 0.738, 1.557, 1.044, 0.870, 0.371, 0.879, 1.474, 1.254, 0.691, 1.199, 1.449, 1.118, 0.803, 1.375, 1.267, 0.583, 0.563, 1.535, 0.682, 0.633, 0.066, 0.457, 0.473, 0.237, -0.325, -0.008, 0.804, -0.044, -0.438, 0.348, -0.001, 0.168, 0.185, -5.000, -1.078, -0.351, -0.485, -5.000, -0.256, 0.202, -0.539, -0.587, -0.688, -0.269, 0.119, -0.640, -0.246, 0.710, 0.625, -5.000, -0.761, -0.213, 0.126, -0.432, -0.298, 0.119, -0.063, -0.422, -0.675, -0.048, 0.757, -0.477, -0.548, -0.307, -0.068, -0.156, -1.153, -0.418, -0.682, -0.671, -0.502, -0.442, -0.584, -0.810, -0.685, -0.599, -0.094, -0.628, -0.012, 0.208, -0.352, 0.307, -0.630, 0.159, -0.337, -0.598, -0.024, -0.113, -0.568, -0.496, 0.185, -0.015, 0.048, -0.416, 0.019, 0.327, -0.267, -5.000, -0.523, -0.023, -0.835, -5.000, -0.785, -0.284, -0.965, -0.529, 0.223, -0.029, 0.159, 0.208, 1.068, 1.170, 0.909, -5.000, -0.704, 0.196, -0.144, 0.496, -0.090, 0.146, -0.124, -0.399, 0.878, 0.705, 1.247, -0.108, 1.371, 1.438, 1.198, 1.574, 0.739, 1.386, 1.201, 0.531, 1.335, 1.433, 1.048, 1.129, 1.455, 1.481, 1.495, 1.484, 0.511, -0.411, -0.224, 0.463, -0.262, 0.130, -0.256, -0.827, 0.313, 0.437, -0.045, 0.088, 0.326, 0.119, 0.334, -0.303, 0.123, -0.894, -1.543, -5.000, -0.543, -0.798, -1.668, -5.000, -0.351, -0.928, -1.827, -1.094, 0.280, -1.373, 0.228, 0.148, 1.400, 1.048, 0.578, -5.000, 0.103, 0.602, 0.601, 1.192, 0.816, 0.783, 0.587, 0.535, 1.264, 1.017, 1.269, 0.353, 1.308, 0.898, 0.693, 1.464, 0.889, 0.684, 0.660, 0.677, 1.268, 1.015, 0.944, 1.041, 1.409, 0.931, 1.059, 1.362, 0.545, -0.716, -0.746, 0.491, 0.316, -0.271, -0.156, -0.143, -0.352, -1.154, -1.062, -0.731, -0.078, -1.109, -0.774, 0.274, 0.404, 0.043, -1.264, -5.000, -0.631, -0.414, -1.587, -5.000, -0.215, -0.484, -1.526, -0.841, -0.432, -1.140, -2.154, -1.101, 1.215, 0.644, -0.077, -5.000, -0.525, 0.086, -0.163, 0.688, 0.451, 0.261, -0.019, 0.407, 1.237, 0.837, 1.138, 0.505, 1.023, 0.587, -0.107, 1.315, 0.440, 0.196, -0.247, 0.124, 0.952, 0.687, -0.180, 0.358, 1.042, 0.420, 0.106, 0.997, 0.213, -0.875, -1.298, 0.364, -0.242, -0.877, -1.119, -0.775, -0.649, -1.341, -1.536, -0.984, 0.008, -1.084, -1.400, -0.162, 0.365, 0.972, 0.253, -5.000, -0.861, 0.726, -0.692, -5.000, -0.041, 0.071, -0.850, -0.564, 0.332, 0.597, -0.187, -0.303, 1.213, 1.362, 1.046, -5.000, -0.446, 0.709, 0.361, 0.881, 0.658, 0.681, 0.207, 0.153, 1.031, 0.989, 1.397, 0.009, 1.617, 1.671, 1.540, 1.686, 1.549, 1.597, 1.503, 1.299, 1.615, 1.635, 1.433, 1.510, 1.650, 1.678, 1.667, 1.675, 0.832, 0.752, 0.714, 0.984, 1.091, 1.163, 0.839, 0.521, 0.323, 0.566, -0.015, -0.092, 0.268, 0.259, 0.473, 0.593, 0.053, -0.051, -0.336, -5.000, -1.643, -0.864, -1.882, -5.000, -1.315, -1.388, -1.938, -1.835, 0.167, -0.245, -0.358, 0.054, 0.985, 0.671, 0.518, -5.000, -1.123, -0.529, -0.686, -0.696, -0.586, -0.243, -0.744, -1.161, 0.776, 0.260, 0.909, -0.247, 0.253, 0.759, 0.361, 0.674, -0.661, 0.275, -0.163, -0.752, -0.064, -0.410, -0.560, -0.639, 0.375, 0.387, 0.769, 0.429, -0.471, -1.423, -1.204, -0.262, -1.703, -1.707, -1.459, -1.829, -0.333, -0.024, -0.380, -0.129, 0.277, -0.410, -0.029, -0.074, 0.046, -0.393, -1.275, -5.000, -0.890, -1.002, -1.843, -5.000, -0.860, -1.156, -2.051, -1.159, 0.078, -1.192, 0.006, 0.155, 1.263, 0.912, 0.286, -5.000, -0.622, -0.159, -0.089, 0.565, 0.201, 0.438, -0.146, 0.086, 1.178, 0.549, 0.854, 0.003, 0.992, 0.743, 0.301, 1.043, 0.177, 0.280, -0.036, -0.323, 0.730, 0.462, 0.089, 0.363, 1.259, 0.586, 0.821, 1.041, -0.262, -1.399, -1.326, -0.173, -0.844, -0.896, -1.154, -1.283, -1.664, -2.209, -2.163, -1.699, -0.236, -1.470, -1.320, -0.164, 0.520, 0.186, -0.975, -5.000, -1.353, -0.878, -1.617, -5.000, -0.961, -0.632, -1.534, -1.018, 0.039, -0.357, -1.588, -0.158, 0.853, 0.517, 0.006, -5.000, -1.191, -0.537, -0.557, -0.021, -0.543, -0.193, -0.433, -0.602, 0.863, 0.563, 1.204, 0.184, 0.606, 0.387, -0.283, 1.023, -0.351, -0.127, -0.435, -0.890, 0.439, 0.346, -0.401, -0.123, 0.691, 0.324, -0.073, 0.817, -0.356, -1.503, -1.752, -0.044, -1.489, -1.592, -1.502, -1.788, -1.658, -1.846, -2.221, -2.142, -0.403, -1.537, -1.559, -0.497, -0.416, 0.003, -0.673, -5.000, -1.604, -1.452, -2.114, -5.000, -1.781, -1.395, -1.785, -1.853, -0.100, -0.562, -0.975, 0.055, 0.148, 0.360, -0.107, -5.000, -1.474, -1.181, -1.320, -0.982, -1.025, -0.563, -1.233, -1.157, 0.119, 0.130, 0.659, -0.251, -0.352, 0.488, 0.135, 0.518, -1.105, -0.337, -0.883, -1.455, -0.359, 0.107, -1.006, -0.710, 0.089, 0.503, 0.778, 0.500, -0.384, -0.761, -0.595, -0.404, -1.298, -1.209, -1.566, -1.410, -1.529, -1.709, -1.962, -2.018, -0.628, -0.930, -0.510, -0.335, 0.283, 0.239, -0.589, -5.000, -1.181, -0.190, -1.305, -5.000, -1.371, -0.827, -1.763, -1.855, -0.296, -0.656, 0.145, 0.223, 0.976, 1.073, 0.753, -5.000, -0.747, 0.121, 0.044, 0.109, -0.122, 0.286, -0.204, -0.654, 0.917, 0.773, 1.283, -0.175, 1.009, 1.254, 0.886, 1.379, -0.144, 1.049, 0.664, -0.045, 0.766, 0.922, 0.497, 0.440, 1.143, 1.160, 1.331, 1.212, -0.022, -0.448, -0.602, 0.450, -1.182, -0.131, -0.514, -1.466, -1.589, -1.289, -1.589, -2.256, 0.084, 0.118, -0.204, -0.314, 0.304, 0.018, -0.750, -5.000, -0.994, -0.203, -1.406, -5.000, -0.764, -0.791, -2.083, -1.570, 0.528, -0.974, 0.161, -0.085, 1.190, 1.050, 0.676, -5.000, -0.522, 0.401, 0.337, 0.361, 0.304, 0.527, 0.138, -0.161, 1.024, 0.840, 1.308, -0.061, 0.996, 1.002, 0.675, 1.144, 0.160, 0.644, 0.366, -0.176, 0.853, 0.779, 0.388, 0.426, 1.267, 0.954, 1.152, 1.208, 0.115, -0.596, -0.678, 0.463, -0.365, -0.688, -0.435, -0.635, -0.904, -0.950, -1.192, -1.180, 0.083, -0.806, -0.745, 0.111, 0.352, 0.220, -1.051, -5.000, -1.348, -0.547, -1.656, -5.000, -0.821, -0.630, -1.519, -1.271, 0.235, -0.232, -1.330, -0.216, 0.744, 0.460, 0.006, -5.000, -1.027, -0.302, -0.481, -0.517, -0.254, -0.062, -0.418, -0.779, 0.405, 0.584, 1.093, -0.284, 0.824, 0.809, 0.031, 0.904, 0.007, 0.222, -0.189, -0.502, 0.746, 0.620, -0.135, 0.226, 0.968, 0.606, 0.353, 0.856, 0.187, -0.125, -0.666, 0.525, -0.849, -0.556, -0.920, -1.369, -0.605, -0.512, -1.143, -1.223, 0.470, -0.186, -0.338, 0.057, 0.208, 0.228, -0.453, -5.000, -1.625, -0.540, -1.853, -5.000, -1.405, -1.036, -1.680, -1.572, 0.400, -0.622, -1.132, 0.270, 0.776, 0.810, 0.446, -5.000, -1.079, -0.406, -0.455, -0.192, -0.417, -0.121, -0.317, -0.781, 0.400, 0.322, 1.032, -0.332, 0.318, 0.885, 0.419, 0.811, -0.445, 0.583, 0.095, -0.625, 0.421, 0.621, 0.140, -0.009, 0.608, 0.955, 1.208, 0.734, 0.089, -0.017, -0.613, 0.371, -1.031, -0.071, -0.590, -1.049, -1.234, -0.626, -1.116, -1.640, 0.040, -0.215, -0.083, -0.299, 0.308, 0.400, -0.033, -5.000, -0.122, 0.196, -0.695, -5.000, -0.232, -0.267, -0.699, -0.927, 0.104, 0.030, 0.472, -0.798, 1.169, 1.347, 1.010, -5.000, -0.024, 0.786, 0.868, 0.775, 0.607, 0.850, 0.410, 0.313, 0.889, 1.024, 1.429, -0.019, 1.273, 1.394, 1.044, 1.402, 0.292, 1.342, 0.976, 0.317, 1.061, 1.062, 0.461, 0.755, 1.214, 1.262, 1.323, 1.221, 0.523, 0.277, 0.295, 0.603, -0.259, 0.531, 0.353, -0.211, -0.589, -0.789, -0.950, -1.114, 0.259, 0.155, 0.439, 0.135, 0.465, -0.498, -0.898, -5.000, -0.397, -0.431, -1.543, -5.000, -0.424, -0.817, -1.822, -1.044, -0.267, -1.315, -0.222, -0.230, 1.333, 0.934, 0.441, -5.000, -0.206, 0.401, 0.486, 0.833, 0.816, 0.681, 0.286, 0.451, 1.132, 0.821, 1.181, 0.110, 1.211, 0.904, 0.482, 1.231, 0.539, 0.569, 0.241, 0.428, 1.087, 0.781, 0.420, 0.699, 1.305, 0.891, 0.811, 1.215, 0.763, -0.452, -0.155, 0.842, 0.212, -0.276, -0.399, -0.055, -0.200, -0.749, -0.871, -0.587, 0.319, -0.775, -0.991, 0.067, 1.104, 0.668, 0.068, -5.000, 0.102, 0.328, -0.689, -5.000, 0.418, 0.461, -0.945, -0.135, 0.460, -0.355, -1.117, -0.123, 1.445, 0.923, 0.315, -5.000, 0.346, 0.653, 0.589, 1.045, 1.033, 0.884, 0.322, 0.796, 1.361, 1.056, 1.221, 0.531, 1.419, 0.892, 0.356, 1.536, 0.922, 0.464, 0.038, 0.453, 1.357, 0.820, 0.216, 1.013, 1.426, 0.786, 0.473, 1.249, 1.018, -0.300, -0.375, 1.266, 0.427, -0.152, -0.571, -0.236, 0.038, -0.426, -0.872, -0.210, 0.722, -0.487, -0.857, 0.272, 0.513, 0.556, 0.133, -5.000, -0.112, 0.642, -0.339, -5.000, -0.262, 0.100, -0.826, -0.668, 0.279, -0.108, -0.262, -0.113, 1.282, 1.107, 0.546, -5.000, -0.024, 0.663, 0.529, 1.002, 0.925, 0.892, 0.561, 0.647, 1.108, 1.010, 1.269, 0.257, 1.168, 1.365, 1.107, 1.379, 0.504, 1.152, 0.987, 0.454, 1.075, 1.092, 0.692, 0.804, 1.115, 1.333, 1.335, 1.084, 0.423, 0.707, 0.040, 0.813, 0.121, 0.743, 0.508, 0.051, -0.012, 0.175, -0.198, -0.152, 0.482, 0.170, 0.688, 0.039, -0.276, -0.029, -0.771, -5.000, -0.469, -0.709, -0.589, -5.000, 0.087, -0.421, -0.485, -0.740, -0.525, -0.262, -0.445, 0.208, 0.440, 0.253, -0.020, -5.000, -0.232, -0.400, -0.442, -0.347, -0.148, -0.162, -0.283, -0.508, 0.561, 0.647, 0.315, 0.326, 0.590, 0.650, 0.370, 0.313, 0.533, 0.799, 0.812, 0.145, 0.740, 0.918, 0.510, 0.544, 0.763, 0.876, 1.018, 0.862, -0.002, -0.280, -0.558, 0.719, -0.413, -0.337, -0.024, -0.157, -0.380, -0.352, -0.085, -0.080, 0.259, -0.485, -0.335, -0.175, -0.187, -1.558, -1.767, -5.000, -0.816, -1.718, -2.392, -5.000, -0.884, -1.850, -2.509, -1.552, -0.323, -1.554, -0.080, -0.996, 0.498, -0.379, -0.890, -5.000, -0.366, -0.761, -1.005, 0.243, -0.220, -0.694, -1.003, -0.421, 0.645, -0.155, -0.474, 0.149, 0.444, -0.490, -0.842, 0.587, 0.321, -0.765, -0.955, -0.148, 0.527, -0.174, -0.303, 0.010, 0.643, -0.641, -0.560, 0.335, -0.376, -1.415, -1.515, -0.722, -0.380, -1.293, -1.099, -0.512, -0.688, -1.675, -1.618, -1.187, 0.140, -1.089, -1.052, -0.103, -0.687, -1.560, -1.954, -5.000, -0.816, -1.440, -2.161, -5.000, -0.529, -1.598, -1.906, -1.034, -0.393, -1.675, -1.759, -0.510, 0.074, -0.645, -1.149, -5.000, -0.650, -1.068, -1.460, -0.348, -0.315, -0.812, -0.990, -0.272, 0.609, -0.268, -0.259, 0.330, 0.218, -0.553, -1.098, 0.431, 0.053, -0.682, -1.023, -0.462, 0.558, -0.118, -0.708, -0.095, 0.336, -0.553, -0.939, -0.079, -0.915, -1.576, -1.542, -0.581, -0.342, -1.431, -1.493, -0.836, -0.734, -1.302, -1.620, -0.826, -0.411, -1.510, -1.914, -0.606, -0.534, 0.042, 0.123, -5.000, 0.013, -0.058, -0.586, -5.000, -0.164, -0.230, -0.857, -0.615, -0.149, -0.207, -1.179, -1.127, 0.270, 0.621, 0.355, -5.000, -0.325, 0.064, -0.285, 0.431, 0.404, 0.263, -0.072, -0.046, 0.781, 0.544, 0.814, 0.443, 0.860, 1.154, 0.771, 0.564, 1.177, 1.176, 1.137, 0.719, 1.363, 1.316, 0.950, 0.927, 1.181, 1.234, 1.120, 1.215, -0.380, 0.345, -0.157, 1.258, 0.322, 0.663, 0.497, -1.179, 0.264, 0.112, 0.112, -0.505, -0.055, 0.366, -0.366, -0.021, -0.262, -0.348, -1.123, -5.000, -1.778, -1.859, -2.280, -5.000, -1.650, -1.471, -2.068, -1.316, 0.063, -0.237, -0.534, 0.598, 0.154, 0.024, 0.048, -5.000, -1.482, -1.183, -1.518, -1.504, -1.130, -0.805, -1.462, -1.472, 0.590, 0.108, 0.363, 0.115, -0.062, 0.235, -0.097, 0.317, -0.871, -0.244, -0.647, -1.102, -0.631, -0.742, -1.355, -1.200, 0.050, -0.175, 0.089, 0.292, -0.337, -0.834, -0.251, -0.323, -1.873, -2.085, -2.455, -2.171, 0.134, 0.073, -0.111, 0.088, 0.408, -0.380, 0.044, 0.100, -0.362, -1.264, -1.902, -5.000, -1.806, -1.558, -2.400, -5.000, -1.378, -1.728, -2.591, -1.550, -0.757, -1.447, 0.025, -0.198, 0.484, -0.233, -0.745, -5.000, -1.095, -0.784, -1.226, -0.442, -0.454, -0.550, -1.303, -0.494, 0.396, -0.169, -0.399, 0.287, 0.360, -0.211, -0.776, 0.143, -0.504, -0.471, -0.952, -0.898, 0.174, -0.281, -0.767, -0.341, 0.670, -0.385, -0.304, 0.358, -0.288, -1.618, -1.575, -0.166, -1.047, -1.344, -1.689, -1.623, -1.808, -2.075, -2.192, -2.094, -0.796, -1.431, -1.456, -0.416, -0.211, -0.789, -1.673, -5.000, -1.965, -1.741, -2.169, -5.000, -1.306, -1.480, -2.203, -1.297, -0.330, -1.373, -1.786, -0.999, 0.167, -0.258, -0.867, -5.000, -1.708, -1.208, -1.523, -1.049, -1.032, -1.027, -1.510, -1.150, 0.450, -0.070, 0.376, 0.265, -0.069, -0.490, -1.293, 0.292, -0.927, -0.857, -1.303, -1.584, -0.035, -0.253, -0.955, -0.572, 0.250, -0.485, -0.738, 0.119, -0.575, -1.751, -1.874, -0.415, -1.875, -1.905, -2.074, -2.181, -1.640, -2.126, -2.469, -2.137, -0.801, -1.937, -1.776, -0.875, -0.389, -0.305, -1.060, -5.000, -1.700, -1.967, -2.450, -5.000, -1.705, -1.638, -2.153, -2.223, -0.164, -0.837, -1.799, -0.568, -0.325, -0.412, -0.570, -5.000, -1.711, -1.498, -2.027, -1.875, -1.242, -0.955, -1.582, -1.454, -0.179, -0.065, -0.352, 0.122, -0.534, -0.234, -0.526, -0.520, -1.373, -0.761, -1.423, -1.838, -0.729, -0.253, -1.146, -1.112, -0.138, -0.071, 0.084, 0.125, -0.603, -0.814, -1.195, 0.100, -1.908, -1.457, -1.984, -1.702, -1.750, -1.835, -2.147, -1.887, -0.606, -0.872, -0.837, -0.401, -0.145, -0.573, -0.906, -5.000, -2.010, -2.243, -2.531, -5.000, -1.685, -1.842, -2.078, -1.604, -0.634, -0.902, -0.144, -0.485, 0.174, -0.030, -0.326, -5.000, -1.727, -1.335, -1.872, -1.780, -1.437, -1.258, -1.789, -1.995, 0.526, 0.151, 0.307, 0.160, 0.187, 0.043, -0.459, 0.778, -0.901, -0.734, -1.068, -1.255, -0.617, -0.662, -0.996, -1.119, 0.472, -0.056, 0.176, 0.351, -0.668, -0.952, -0.509, -5.000, -1.878, -2.039, -2.279, -2.217, -1.778, -1.474, -1.359, -2.187, -0.518, -0.405, -0.340, -0.659, -0.418, -1.590, -2.244, -5.000, -1.853, -2.051, -2.741, -5.000, -1.901, -2.145, -2.710, -2.490, -0.402, -0.812, -0.029, 0.003, 0.273, -0.132, -0.644, -5.000, -1.424, -1.182, -1.487, -1.110, -0.889, -1.071, -1.591, -1.542, 0.272, -0.317, -0.711, 0.032, -0.158, -0.798, -1.294, 0.158, -1.051, -1.305, -1.788, -1.758, -0.532, -0.741, -1.287, -1.033, 0.162, -0.745, -0.767, -0.043, -0.783, -1.514, -1.657, 0.065, -1.193, -1.753, -1.946, -1.615, -1.716, -2.045, -2.380, -1.748, -0.599, -1.229, -0.922, -0.470, -0.464, -1.256, -2.126, -5.000, -1.996, -2.325, -2.711, -5.000, -1.731, -1.956, -2.222, -2.057, -0.802, -1.607, -2.411, -0.564, -0.234, -0.845, -0.984, -5.000, -1.772, -1.726, -2.081, -2.041, -1.544, -1.719, -2.010, -2.118, -0.007, -0.381, -0.612, -0.171, -0.339, -1.267, -1.821, 0.012, -1.444, -1.600, -2.196, -2.009, -0.607, -0.861, -1.161, -0.851, -0.272, -1.060, -1.306, -0.467, -0.581, -1.656, -1.815, -0.678, -2.260, -2.129, -2.413, -2.082, -1.959, -1.946, -2.129, -2.088, -0.566, -1.871, -1.769, -0.902, -0.485, -0.744, -1.423, -5.000, -2.420, -2.048, -2.690, -5.000, -1.911, -2.067, -2.405, -2.232, -0.847, -1.766, -1.961, -1.166, -0.026, -0.582, -0.851, -5.000, -1.908, -1.584, -2.184, -2.132, -1.642, -1.549, -2.070, -2.456, 0.162, -0.164, -0.546, 0.352, -0.767, -0.424, -0.827, 0.138, -1.572, -1.371, -1.817, -1.809, -1.145, -0.753, -1.227, -1.300, -0.362, -0.574, -0.204, -0.311, -0.700, -0.981, -0.933, -0.485, -1.558, -1.360, -1.930, -1.919, -1.761, -1.822, -2.605, -2.227, 0.001, -0.646, -0.583, -0.226, 0.398, -0.208, -0.275, -5.000, -0.150, -0.389, -0.704, -5.000, -0.285, -0.250, -0.552, -0.421, 0.719, 0.171, 0.208, -0.695, 0.528, 0.258, -0.137, -5.000, -0.088, -0.331, -0.545, -0.180, 0.353, -0.015, -0.534, -0.343, 0.862, 0.550, 0.337, 0.287, 0.609, 0.345, 0.208, 0.294, -0.061, 0.360, 0.107, 0.025, 0.476, 0.094, -0.437, 0.147, 0.632, 0.266, 0.194, 0.329, -0.118, 0.132, -0.112, -1.179, -0.955, -0.427, -0.538, -0.945, -0.220, -0.625, -0.516, -0.527, 0.286, -0.262, -0.198, 0.408, -0.209, -1.455, -1.529, -5.000, -1.127, -1.936, -2.190, -5.000, -1.114, -1.992, -2.400, -1.788, -0.293, -1.435, -0.085, -0.352, 0.571, -0.519, -0.891, -5.000, -0.452, -0.672, -0.996, -0.289, -0.386, -0.829, -0.991, -0.644, 0.421, -0.452, -0.800, 0.293, 0.175, -0.897, -1.314, -0.079, -0.450, -1.049, -1.489, -0.830, -0.005, -0.695, -0.794, -0.518, 0.250, -0.869, -0.842, -0.054, -0.001, -1.475, -1.340, 0.297, -0.373, -1.242, -1.314, -0.760, -0.808, -1.527, -1.609, -1.057, -0.434, -1.391, -1.229, -0.514, 0.138, -1.114, -1.181, -5.000, -0.409, -1.408, -1.621, -5.000, -0.226, -0.944, -1.561, -1.096, 0.047, -1.894, -1.916, -0.763, 0.548, -0.819, -0.991, -5.000, -0.432, -0.993, -1.276, -0.234, -0.241, -0.758, -1.355, -0.375, 0.699, -0.459, -0.475, -0.017, 0.274, -0.944, -1.370, 0.597, -0.161, -1.142, -1.518, -0.997, 0.176, -0.760, -0.756, -0.330, 0.514, -1.220, -1.020, -0.293, -0.256, -1.188, -1.537, 0.219, -0.194, -1.433, -1.530, -1.624, -0.480, -1.213, -1.837, -0.657, 0.060, -1.423, -1.442, -0.301, -0.234, -0.352, -0.380, -5.000, -0.416, -0.439, -1.009, -5.000, -0.469, -0.056, -0.525, -0.455, -0.129, 0.047, -0.303, -0.581, -0.120, -0.189, -0.951, -5.000, -0.362, -0.515, -0.597, -0.328, -0.010, -0.485, -0.746, -0.317, 0.640, 0.202, -0.257, -0.122, 0.325, 0.359, 0.029, 0.588, -0.256, 0.065, -0.504, -0.575, 0.181, 0.241, -0.301, -0.014, 0.051, 0.090, 0.487, 0.021, -0.113, -0.211, -0.188, 0.131, -0.088, -0.190, -0.179, -0.074, -0.514, -0.776, -1.065, -0.314, 0.360, -0.141, -0.033, 0.105 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_20(struct _training *tptr) {
  struct _training tinf = {
    0.563, 11, 4.350, { 0.527, 0.145, 2.328 }, { -0.144, -0.510, 0.724 }, 0, 
    { -1.080, -3.003, -0.904, -0.526, -0.853, -4.000, -0.133, 1.123, 1.348, -4.000, -0.876, -4.000, -0.355, -0.135, 1.997, -4.000, 0.339, 0.914, -4.000, 1.482, 0.825, -4.000, -0.011, 1.081, 1.307, 0.336, 1.469, 1.025 }, 
    {{ -0.287, 0.103, -0.092, 0.201},{ -0.387, 0.292, -0.147, 0.060},{ -0.050, 0.347, -0.475, 0.002},{ 0.040, 0.168, -0.460, 0.182},{ 0.034, 0.047, -0.200, 0.128},{ 0.005, 0.041, -0.366, 0.290},{ 0.062, 0.045, -0.295, 0.186},{ 0.112, 0.043, -0.326, 0.169},{ 0.025, 0.056, -0.282, 0.196},{ 0.225, -0.139, -0.343, 0.254},{ 0.189, -0.067, -0.139, 0.043},{ 0.166, -0.126, -0.116, 0.106},{ 0.211, -0.147, -0.131, 0.096},{ 0.156, -0.118, -0.077, 0.068},{ 0.079, -0.062, -0.085, 0.096},{ 0.151, -0.103, -0.090, 0.071},{ 0.109, -0.007, -0.077, -0.010},{ 0.122, 0.039, -0.134, -0.019},{ 0.130, 0.009, -0.118, -0.007},{ 0.125, -0.024, -0.121, 0.043},{ -0.004, 0.002, -0.033, 0.043},{ 0.045, -0.045, -0.031, 0.048},{ 0.043, -0.057, 0.023, -0.001},{ 0.074, -0.189, 0.025, 0.106},{ 0.028, -0.180, -0.005, 0.174},{ 0.143, -0.085, 0.004, -0.057},{ 0.128, -0.072, -0.121, 0.096},{ 0.338, -0.231, -0.208, 0.101},{ 0.216, -0.123, -0.177, 0.112},{ 0.251, -0.231, -0.261, 0.244},{ 0.244, -0.211, -0.353, 0.301},{ 0.213, -0.155, -0.208, 0.174} }, 
    {{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -0.699, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -1.417, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -0.876, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -1.941, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -1.731, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -0.209, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -1.696, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 0.989, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 2.267, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 0.468, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -0.237, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 0.450, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 1.653, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 0.444, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 2.595, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 1.888, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -0.933, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 0.272, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 0.569, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -2.171, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -1.779, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -1.484, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -0.563, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -1.199, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 2.956, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 2.080, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}} }, 
    -3.227, { 0.394, 0.303, -0.796, -5.000, 0.000, -0.455, -1.852, -5.000, -0.066, 0.475, -0.145, -0.108, 0.588, 0.635, 0.281, -0.148, 0.699, 0.764, -0.173, -5.000, 0.442, 0.175, -0.391, -0.537, 0.115, 0.289, -0.608, -0.065, 0.403, 0.801, 0.479, 0.068, 0.167, 0.467, -0.297, 0.470, 0.237, 0.338, -0.864, -0.819, 0.043, 0.420, -0.355, -0.100, 0.335, 0.645, 0.523, 0.600, -0.207, -0.041, -1.070, -0.449, -0.539, 0.060, -1.212, -1.090, 0.287, 0.391, -0.323, -0.085, 0.691, 0.791, 0.478, 0.152, 0.112, -0.312, -1.221, -5.000, -0.100, -0.608, -1.991, -5.000, 0.287, 0.094, -0.968, -0.411, 0.691, -0.134, 0.220, -0.254, 0.487, 0.159, -0.945, -5.000, 0.609, -0.203, -0.860, -0.540, 0.292, 0.542, -0.047, -0.096, 0.295, 0.476, 0.262, -0.014, -0.138, 0.049, -0.792, 0.504, 0.376, -0.165, -0.697, -0.663, 0.431, -0.015, 0.058, -0.090, 0.431, -0.096, 0.129, 0.592, 0.004, 0.152, -0.824, -0.644, -0.272, -0.084, -0.741, -1.804, -0.207, -0.107, -0.646, -0.466, 0.713, 0.492, 0.194, 0.108, -0.463, -0.876, -2.058, -5.000, -0.843, -1.712, -3.692, -5.000, -1.063, -1.041, -1.710, -1.552, -0.245, -1.457, -1.409, -1.185, -0.364, -0.570, -1.236, -5.000, -0.598, -1.218, -2.220, -1.518, -1.462, -0.388, -1.284, -1.188, -0.336, -0.178, -1.193, -0.546, -0.444, -0.327, -1.153, -0.652, -0.812, -0.789, -2.134, -2.024, -0.836, -0.502, -0.726, -0.903, -0.900, -0.244, -0.540, -0.317, -0.701, -1.064, -1.718, -1.521, -1.435, -1.710, -2.589, -2.269, -1.336, -1.371, -2.075, -1.593, -0.667, -1.109, -1.247, -1.190, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.041, 0.120, -1.043, -5.000, -0.757, -1.033, -1.734, -5.000, -0.728, 0.045, -1.013, -0.843, 0.538, 0.127, 0.116, -0.558, 0.296, 0.219, -0.413, -5.000, -0.051, -0.646, -1.506, -1.090, -0.801, -0.057, -1.005, -0.745, 0.147, 0.523, -0.087, -0.520, 0.130, 0.300, -0.303, 0.316, -0.374, -0.062, -1.197, -0.960, -0.318, 0.140, -0.781, -0.504, 0.342, 0.612, 0.538, 0.675, -0.798, -0.567, -1.262, -0.514, -0.879, -0.284, -1.591, -1.781, -0.109, 0.323, -0.733, -0.351, 0.402, 0.935, 0.340, 0.180, -0.189, -0.575, -1.853, -5.000, -1.160, -1.241, -2.396, -5.000, -0.247, -0.449, -1.309, -1.380, 0.515, -0.334, -0.274, -1.203, 0.292, -0.205, -0.766, -5.000, -0.170, -0.458, -1.015, -0.734, 0.219, 0.195, -0.167, -0.137, 0.381, 0.425, 0.209, -0.038, 0.417, 0.298, -0.018, 0.766, 0.318, -0.284, -1.051, -0.257, 0.141, -0.123, -0.279, -0.338, 0.278, 0.341, 0.296, 0.671, -0.420, 0.080, -0.748, -0.186, -0.884, -0.633, -1.437, -1.670, -0.426, -0.412, -0.836, -0.806, 0.425, 0.328, 0.144, -0.581, -1.107, -2.149, -2.749, -5.000, -2.153, -2.374, -3.048, -5.000, -1.914, -1.154, -2.548, -1.819, -0.599, -1.925, -1.937, -1.709, -1.853, -1.442, -2.368, -5.000, -1.298, -1.789, -2.882, -2.489, -1.415, -1.171, -1.839, -0.808, -0.658, -1.190, -1.325, -1.499, -1.547, -1.160, -1.689, -0.989, -1.636, -1.733, -2.452, -2.176, -1.417, -1.200, -1.224, -1.258, -1.132, -1.437, -1.181, -0.624, -1.413, -1.443, -2.747, -1.800, -1.909, -2.225, -4.673, -3.339, -2.081, -1.924, -2.685, -1.943, -1.313, -1.419, -1.779, -2.037, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.226, 0.212, -0.650, -5.000, -0.457, -0.269, -1.663, -5.000, -0.223, 0.123, -0.623, -0.575, 0.768, 0.598, 0.198, -0.478, 0.661, 0.527, -0.215, -5.000, -0.063, -0.380, -1.525, -0.788, -0.637, -0.207, -0.567, -0.660, 0.379, 0.608, 0.195, -0.606, 0.355, 0.703, 0.258, 0.723, -0.050, 0.502, -0.641, -0.667, -0.181, 0.151, -0.396, -0.466, 0.010, 0.917, 0.536, 0.736, -0.416, -0.339, -1.518, -0.418, -1.116, -0.481, -1.750, -1.695, -0.465, -0.212, -0.887, -0.963, -0.230, 0.714, 0.186, -0.269, 0.254, 0.200, -1.269, -5.000, -0.398, -0.647, -2.352, -5.000, -0.036, 0.146, -0.992, -0.702, 1.094, 0.659, 0.556, -0.279, 0.696, 0.474, -0.213, -5.000, 0.147, -0.198, -1.496, -0.689, -0.371, 0.424, -0.578, -0.441, 0.563, 0.919, 0.573, 0.027, 0.691, 0.782, 0.584, 1.081, 0.289, 0.170, -0.554, -0.245, 0.227, 0.461, -0.115, -0.010, 0.580, 0.831, 0.915, 1.091, 0.014, 0.517, -0.212, 0.389, -0.119, -0.002, -0.736, -0.747, 0.091, 0.369, -0.583, -0.515, 0.663, 1.106, 0.875, 0.426, -0.409, -0.999, -1.810, -5.000, -0.937, -1.139, -2.220, -5.000, -0.658, -0.756, -1.289, -1.296, 0.562, -0.776, -0.468, -1.253, -0.010, -0.153, -1.239, -5.000, -0.573, -0.969, -2.153, -1.263, -0.725, -0.448, -1.167, -1.184, 0.069, 0.228, -0.371, -0.717, -0.059, 0.418, -0.492, -0.470, -0.876, -0.698, -1.922, -1.032, -0.928, -0.560, -0.894, -1.042, -0.543, -0.146, -0.376, 0.174, -0.453, -0.067, -0.910, -0.672, -1.172, -1.136, -2.237, -1.648, -0.991, -1.003, -1.405, -1.576, -0.249, -0.285, -0.680, -0.806, -0.236, 0.046, -1.185, -5.000, -0.937, -0.511, -1.750, -5.000, -0.544, -0.065, -1.148, -1.182, 0.197, 0.127, -0.520, -1.204, -0.165, 0.224, -0.638, -5.000, -0.628, -0.726, -1.608, -1.233, -0.997, -0.337, -1.428, -1.093, -0.069, 0.356, -0.238, -0.731, -0.205, 0.182, -0.789, -0.222, -1.300, -0.569, -1.631, -1.511, -1.095, -0.259, -1.026, -1.219, -0.382, 0.476, 0.317, -0.269, -0.910, -0.384, -0.891, -0.731, -1.631, -1.243, -2.447, -2.121, -1.545, -0.551, -1.280, -1.394, -0.338, 0.224, -0.119, -0.816, 0.672, 0.647, 0.043, -5.000, 0.389, 0.325, -1.058, -5.000, 0.660, 1.023, 0.359, 0.355, 1.234, 1.017, 1.009, 0.220, 1.318, 1.388, 0.956, -5.000, 1.258, 0.639, -0.284, 0.644, 0.609, 0.929, 0.649, 0.528, 1.177, 1.272, 1.113, 0.465, 1.126, 1.285, 0.666, 1.277, 1.047, 1.090, 0.179, 0.073, 0.745, 1.053, 0.720, 0.585, 1.003, 1.303, 1.077, 1.319, 0.196, 0.881, -0.095, 0.334, -0.045, 0.789, -0.693, -0.532, 0.322, 0.817, 0.162, 0.082, 0.682, 1.213, 0.629, 0.379, 0.169, -0.630, -1.089, -5.000, -0.291, -0.379, -1.718, -5.000, 0.422, 0.473, -0.667, -0.022, 0.919, -0.044, 0.637, -0.303, 0.460, 0.351, -0.498, -5.000, 0.314, -0.372, -1.151, -0.238, 0.326, 0.529, -0.280, -0.073, 0.516, 0.674, 0.319, 0.001, 0.420, 0.468, -0.078, 0.807, 0.141, 0.084, -0.777, -0.432, 0.148, 0.310, 0.056, 0.005, 0.441, 0.292, 0.248, 1.074, -0.028, 0.708, -0.551, 0.039, 0.014, 0.252, -0.682, -0.706, 0.471, 0.461, -0.447, 0.115, 0.808, 0.897, 0.282, 0.444, 0.153, -0.113, -1.244, -5.000, -0.533, -0.771, -3.082, -5.000, 0.065, 0.294, -0.815, -0.463, 0.960, 0.203, 0.123, -0.965, 0.829, 0.934, -0.191, -5.000, 0.326, -0.243, -1.105, -0.500, 0.009, 0.392, -0.657, -0.182, 0.502, 0.864, 0.348, -0.339, 0.651, 0.983, 0.100, 0.848, 0.214, 0.255, -0.760, -0.890, 0.269, 0.843, 0.060, -0.128, 0.253, 0.949, 0.569, 0.793, 0.063, 0.747, -0.397, 0.317, -0.520, -0.294, -1.469, -1.152, -0.276, 0.213, -0.701, -0.620, 0.353, 0.717, 0.225, 0.138, -0.119, 0.062, -0.822, -5.000, -0.639, -0.555, -1.487, -5.000, -0.401, -0.372, -0.872, -0.556, 0.010, -0.274, -0.938, -0.728, -0.154, 0.139, -1.013, -5.000, -0.887, -0.753, -1.694, -1.526, -1.110, -0.417, -0.748, -1.186, -0.448, 0.234, -0.555, -0.353, -0.369, 0.070, -0.631, -0.159, -0.815, -0.645, -1.356, -1.305, -0.989, -0.334, -1.149, -1.236, -0.695, -0.148, -0.356, -0.492, -0.521, 0.275, -0.544, -0.103, -0.864, -0.510, -1.108, -1.031, -0.570, -0.158, -0.730, -1.085, -0.364, 0.052, -0.451, -0.339, 0.723, 0.748, -0.328, -5.000, 0.341, 0.208, -1.158, -5.000, 0.371, 0.942, 0.170, 0.112, 1.230, 0.987, 0.844, -0.006, 1.190, 1.332, 0.499, -5.000, 1.036, 0.765, -0.436, 0.308, 0.084, 0.661, 0.404, 0.071, 0.776, 1.130, 0.986, 0.394, 0.797, 1.124, 0.274, 1.198, 0.856, 0.932, -0.301, -0.257, 0.700, 1.020, 0.635, 0.523, 0.853, 1.174, 0.812, 1.117, -0.003, 0.618, -0.496, 0.282, 0.548, 1.049, -0.303, -0.820, 0.740, 0.976, 0.009, 0.340, 1.045, 1.259, 0.854, 0.594, 0.640, 0.327, -0.813, -5.000, 0.571, 0.000, -1.361, -5.000, 0.716, 0.739, -0.046, -0.136, 1.339, 0.629, 0.915, 0.119, 1.212, 1.117, 0.047, -5.000, 1.350, 0.780, 0.010, 0.592, 0.802, 1.092, 0.838, 0.512, 1.081, 1.198, 1.011, 0.531, 1.135, 1.290, 0.615, 1.316, 1.169, 0.868, -0.010, 0.051, 0.937, 0.979, 0.911, 0.722, 1.037, 0.986, 0.861, 1.193, 0.316, 0.849, -0.100, 0.276, 0.415, 0.711, -0.117, -0.736, 0.719, 0.765, 0.141, 0.006, 1.040, 1.248, 0.899, 0.487, -0.166, -0.530, -1.530, -5.000, -0.377, -0.718, -2.527, -5.000, -0.255, -0.091, -1.246, -0.800, 0.647, -0.466, -0.600, -0.884, 0.539, 0.550, -0.413, -5.000, 0.573, -0.292, -1.794, -0.363, -0.063, 0.622, -0.312, -0.290, 0.571, 0.662, 0.056, -0.467, 0.094, 0.512, -0.650, 0.350, 0.024, -0.060, -1.423, -1.092, -0.042, 0.199, -0.060, -0.332, -0.092, 0.225, -0.161, 0.522, -0.765, -0.167, -1.539, -0.783, -0.422, -0.618, -2.202, -2.444, -0.492, -0.363, -1.561, -1.258, -0.328, -0.014, -0.870, -0.970, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.443, 0.537, -0.688, -5.000, -0.087, 0.115, -1.158, -5.000, -0.096, 0.519, -0.556, -0.434, 1.070, 0.798, 0.669, -0.273, 1.089, 1.240, 0.554, -5.000, 0.815, 0.404, -0.278, -0.062, -0.058, 0.514, -0.024, -0.186, 0.710, 1.064, 0.727, -0.033, 0.810, 1.265, 0.524, 1.263, 0.539, 0.952, 0.062, 0.098, 0.317, 0.889, 0.224, 0.143, 0.834, 1.238, 0.988, 1.095, 0.076, 0.668, -0.152, 0.531, -0.038, 0.818, -0.522, -0.759, 0.434, 0.850, 0.050, 0.283, 0.830, 1.348, 1.079, 0.648, 0.044, -0.485, -1.445, -5.000, -0.809, -0.629, -1.842, -5.000, -0.311, -0.005, -0.996, -1.006, 0.664, -0.154, -0.036, -0.892, 0.775, 0.587, -0.322, -5.000, 0.585, 0.140, -0.350, -0.385, 0.415, 0.505, 0.021, -0.103, 0.688, 0.830, 0.575, 0.051, 0.660, 0.802, -0.105, 0.889, 0.603, 0.321, -0.547, -0.178, 0.343, 0.484, 0.010, -0.095, 0.398, 0.198, 0.096, 0.772, -0.352, 0.233, -0.641, -0.106, -0.576, -0.292, -1.139, -1.194, -0.330, -0.165, -0.671, -0.576, 0.268, 0.423, 0.077, -0.078, -0.754, -1.079, -1.851, -5.000, -1.146, -1.635, -2.694, -5.000, -1.184, -0.862, -1.635, -1.172, -0.026, -1.106, -0.942, -1.312, -0.088, -0.078, -1.199, -5.000, -0.400, -0.943, -1.950, -1.283, -0.872, -0.254, -0.841, -0.483, -0.343, -0.211, -0.518, -0.878, -0.649, -0.171, -0.915, -0.100, -0.775, -0.553, -1.225, -1.241, -0.739, -0.084, -0.450, -0.502, -0.521, -0.398, -0.655, 0.228, -0.942, -0.867, -1.706, -1.418, -1.814, -1.323, -2.519, -1.783, -1.523, -1.158, -1.854, -1.511, -0.607, -1.241, -1.446, -0.906, 0.459, 0.229, -0.821, -5.000, -0.354, -0.375, -1.483, -5.000, -0.461, -0.079, -0.821, -0.721, 0.187, -0.424, -0.620, -1.072, 0.884, 1.028, -0.020, -5.000, 0.303, -0.096, -1.067, -0.323, -0.493, 0.050, -0.405, -0.638, 0.172, 0.435, -0.201, -0.781, 0.352, 0.799, -0.255, 0.321, -0.394, -0.185, -1.302, -1.509, -0.801, -0.378, -0.597, -0.899, -0.179, 0.277, 0.138, 0.305, -0.386, 0.318, -0.527, -0.257, -0.971, -0.566, -1.586, -1.316, -0.620, -0.408, -0.579, -0.866, -0.129, 0.212, 0.010, -0.571, 0.138, 0.208, -1.045, -5.000, -0.571, -0.304, -1.307, -5.000, -0.391, 0.029, -0.613, -0.779, 0.731, 0.496, 0.258, -0.346, 0.975, 0.943, 0.286, -5.000, 0.091, -0.067, -0.731, -0.550, -0.533, -0.130, -0.694, -0.972, 0.493, 0.762, 0.303, -0.673, 0.428, 1.078, 0.393, 0.694, -0.167, 0.484, -1.082, -0.736, -0.087, 0.218, -0.114, -0.595, 0.173, 0.564, 0.365, 0.573, -0.545, -0.058, -0.977, -0.330, -1.392, -0.298, -1.668, -1.344, -0.775, -0.434, -0.819, -1.153, 0.002, 0.681, -0.016, -0.548, 0.288, 0.416, -0.838, -5.000, -0.479, -0.372, -1.807, -5.000, -0.353, 0.223, -0.774, -0.607, 1.144, 0.530, 0.504, -0.429, 0.954, 1.091, 0.363, -5.000, 0.437, 0.151, -0.924, -0.248, -0.127, 0.581, -0.234, -0.475, 0.695, 1.096, 0.786, 0.046, 0.922, 1.190, 0.624, 1.107, 0.585, 0.649, -0.215, -0.864, 0.270, 0.680, -0.003, 0.164, 0.552, 0.913, 0.911, 1.048, 0.446, 0.777, -0.087, 0.466, 0.095, 0.251, -0.522, -0.795, 0.137, 0.592, -0.323, -0.318, 0.574, 1.120, 0.970, 0.235, -0.333, -0.247, -1.672, -5.000, -0.650, -1.019, -2.078, -5.000, -0.479, -0.365, -1.067, -1.391, 0.748, -0.067, -0.400, -1.062, 0.703, 0.722, -0.449, -5.000, 0.076, -0.026, -1.198, -1.028, -0.172, -0.172, -0.300, -1.055, 0.227, 0.701, 0.199, -0.626, 0.663, 1.157, -0.080, 0.468, -0.131, -0.124, -1.617, -0.722, -0.464, -0.385, -0.493, -0.841, -0.263, 0.343, -0.259, 0.129, -0.121, 0.836, -0.457, -0.228, -0.598, -0.404, -1.241, -0.994, -0.658, -0.512, -0.895, -1.417, -0.083, 0.219, -0.455, -0.657, 0.113, 0.377, -1.218, -5.000, -0.726, -0.395, -1.223, -5.000, -0.675, -0.232, -0.720, -0.739, 0.312, 0.218, -0.111, -0.652, 0.289, 0.865, -0.439, -5.000, -0.469, -0.606, -0.980, -0.834, -1.007, -0.258, -0.902, -1.139, -0.214, 0.482, -0.350, -0.528, -0.153, 0.570, -0.214, 0.204, -0.932, -0.238, -1.012, -1.361, -0.822, -0.126, -0.801, -1.085, -0.324, 0.467, 0.162, -0.255, -0.106, 0.172, -0.390, -0.538, -1.204, -0.685, -1.227, -2.149, -1.032, -0.434, -1.499, -1.430, -0.457, 0.323, -0.311, -0.599, 0.483, 0.769, -0.181, -5.000, 0.294, 0.232, -0.715, -5.000, 0.349, 0.815, -0.184, 0.265, 1.088, 0.789, 0.858, -0.013, 1.148, 1.309, 0.814, -5.000, 0.912, 0.335, -0.351, 0.359, -0.067, 0.407, 0.315, 0.165, 0.767, 0.876, 0.699, 0.207, 0.941, 1.238, 0.689, 1.087, 0.594, 0.876, 0.150, -0.212, 0.135, 0.776, 0.181, 0.224, 0.520, 1.015, 0.796, 0.959, -0.295, 0.533, -0.206, 0.069, -0.703, 0.147, -0.395, -1.042, -0.280, 0.296, -0.416, -0.338, -0.013, 0.759, 0.443, 0.009, 0.648, 0.347, -0.580, -5.000, 0.121, 0.222, -1.225, -5.000, 0.549, 0.739, 0.127, -0.060, 1.239, 0.787, 0.914, -0.052, 1.164, 1.083, 0.461, -5.000, 0.836, 0.313, -0.199, 0.044, 0.613, 0.860, 0.566, 0.236, 0.917, 1.029, 0.952, 0.209, 1.202, 1.369, 0.661, 1.280, 0.927, 0.850, -0.439, -0.050, 0.644, 0.800, 0.527, 0.369, 0.828, 0.965, 0.837, 1.364, 0.624, 1.166, 0.309, 0.744, 0.474, 0.805, -0.055, -0.461, 0.762, 0.946, 0.405, 0.390, 0.952, 1.255, 0.998, 0.631, 0.510, -0.168, -0.428, -5.000, -0.166, -0.145, -2.413, -5.000, 0.174, 0.544, -0.577, -0.134, 1.130, 0.126, 0.325, -0.560, 1.050, 1.277, 0.415, -5.000, 0.768, 0.393, -0.576, -0.002, 0.319, 0.804, 0.091, -0.087, 0.742, 1.089, 0.764, -0.192, 0.630, 1.186, 0.280, 0.899, 0.259, 0.412, -0.500, -0.660, 0.064, 0.707, 0.366, -0.352, 0.002, 0.787, 0.458, 0.755, -0.170, 0.882, -0.371, 0.262, -0.230, 0.279, -1.038, -1.385, 0.280, 0.560, -0.341, -0.450, 0.645, 0.711, 0.339, 0.233, 0.270, -0.301, -1.286, -5.000, -0.746, -0.307, -1.624, -5.000, -0.495, 0.008, -1.022, -0.483, 0.205, -0.190, -0.383, -0.868, -0.191, 0.452, -0.299, -5.000, -0.816, -0.318, -0.861, -0.798, -0.818, 0.183, -0.534, -1.027, -0.344, 0.320, -0.254, -0.423, -0.171, 0.716, -0.804, -0.307, -0.787, -0.257, -0.872, -1.500, -0.782, -0.214, -0.579, -0.936, -0.752, -0.080, -0.430, -0.461, -0.036, 0.592, -0.090, -0.351, -0.408, 0.058, -0.720, -0.809, -0.344, 0.156, -0.822, -0.767, -0.001, 0.483, -0.004, -0.407, 0.293, 0.083, -0.766, -5.000, 0.338, 0.207, -0.981, -5.000, 0.360, 0.783, -0.268, 0.085, 1.008, 0.573, 0.671, -0.222, 0.738, 0.946, 0.220, -5.000, 0.812, 0.148, -0.902, 0.305, -0.009, 0.151, 0.238, -0.419, 0.673, 0.819, 0.427, 0.172, 0.169, 0.661, -0.222, 0.814, 0.530, 0.772, -0.456, -0.271, 0.769, 0.817, 0.529, 0.267, 0.379, 0.641, 0.098, 0.862, -0.096, -0.038, -0.822, -0.339, -0.319, 0.461, -0.895, -0.635, 0.648, 0.499, -0.577, -0.264, 0.540, 0.827, 0.034, 0.093, 0.558, 0.200, -0.714, -5.000, 0.637, 0.350, -1.264, -5.000, 0.800, 0.761, 0.354, 0.455, 1.289, 0.684, 1.089, 0.260, 1.167, 0.965, 0.379, -5.000, 1.320, 0.664, 0.089, 0.964, 1.077, 1.271, 0.926, 0.732, 1.186, 1.196, 1.023, 0.672, 0.954, 1.060, 0.609, 1.424, 1.237, 0.997, -0.024, 0.539, 0.969, 1.075, 1.092, 0.760, 0.882, 0.973, 0.794, 1.382, 0.313, 0.657, -0.612, -0.004, 0.446, 0.524, -0.293, -0.978, 0.859, 0.577, -0.206, 0.121, 1.043, 1.189, 0.533, 0.478, -0.335, -0.780, -1.544, -5.000, -0.206, -0.633, -1.844, -5.000, 0.036, 0.032, -0.895, -0.748, 0.661, -0.339, -0.141, -0.578, 0.514, 0.481, -0.458, -5.000, 0.640, -0.318, -1.266, 0.066, 0.240, 0.574, -0.191, -0.748, 0.846, 0.742, -0.036, -0.209, -0.209, 0.318, -0.451, 0.439, -0.013, 0.320, -1.071, -0.720, 0.179, 0.306, -0.050, -0.389, -0.031, 0.364, -0.142, 0.604, -0.537, -0.072, -0.991, -0.713, -1.664, -0.753, -1.475, -1.436, -0.328, -0.602, -1.384, -1.026, 0.021, -0.131, -0.870, -0.873, 0.687, 0.349, -0.915, -5.000, 0.245, -0.101, -1.023, -5.000, -0.060, 0.572, -0.322, -0.300, 0.902, 0.339, 0.122, -0.595, 1.234, 1.346, 0.606, -5.000, 1.087, 0.416, -0.119, 0.818, 0.268, 0.811, 0.312, -0.038, 0.931, 1.069, 0.381, -0.184, 1.062, 1.196, 0.401, 1.125, 1.014, 0.959, 0.208, -0.122, 0.995, 1.084, 0.777, 0.405, 1.198, 1.193, 1.075, 1.271, 0.102, 0.706, -0.310, -0.012, 0.040, 0.290, -0.616, -1.092, 0.396, 0.621, -0.244, -0.293, 0.733, 0.967, 0.330, 0.159, 0.169, -0.016, -0.873, -5.000, -0.380, -0.244, -1.575, -5.000, -0.041, 0.257, -0.183, -0.326, 0.923, 0.467, 0.315, -0.691, 0.843, 0.709, 0.121, -5.000, 0.627, 0.275, -0.354, 0.099, -0.005, 0.273, 0.055, -0.361, 0.754, 1.000, 0.581, 0.072, 0.316, 0.621, -0.127, 0.868, 0.139, 0.476, -0.634, -0.039, 0.047, 0.370, 0.081, -0.094, 0.017, 0.702, 0.214, 0.621, -0.774, -0.490, -1.477, -0.664, -0.451, 0.190, -0.949, -1.078, 0.036, 0.156, -0.685, -0.510, 0.154, 0.654, 0.068, -0.052, 0.242, -0.289, -0.991, -5.000, -0.543, -0.419, -1.756, -5.000, 0.207, 0.299, -0.467, -0.331, 0.989, 0.166, 0.721, -0.155, 0.734, 0.521, -0.194, -5.000, 0.682, 0.171, -0.136, 0.103, 0.631, 0.817, 0.272, 0.318, 1.032, 0.858, 0.866, 0.374, 0.695, 0.798, 0.357, 1.163, 0.604, 0.338, -0.174, 0.415, 0.571, 0.700, 0.255, 0.352, 0.457, 0.655, 0.529, 1.229, -0.319, 0.058, -0.883, -0.249, -0.820, -0.286, -1.275, -1.076, 0.195, 0.154, -0.947, -0.418, 0.336, 0.585, 0.292, 0.135, -0.594, -0.881, -2.034, -5.000, -1.151, -1.696, -2.337, -5.000, -0.721, -0.704, -1.368, -0.680, 0.031, -1.109, -0.945, -0.704, -0.156, -0.469, -1.129, -5.000, -0.282, -0.889, -1.429, -0.994, -0.847, -0.222, -0.643, -0.323, -0.091, 0.063, -0.325, -0.217, -0.926, -0.348, -1.124, -0.220, -0.989, -0.703, -1.615, -1.121, -0.545, -0.124, -0.473, -0.321, -0.371, -0.450, -0.509, 0.092, -2.228, -1.289, -1.904, -1.742, -2.563, -1.912, -2.510, -2.418, -1.821, -1.647, -2.596, -1.912, -1.204, -1.199, -1.856, -1.644, -0.110, -0.269, -0.899, -5.000, -0.369, -0.989, -1.600, -5.000, -0.655, -0.605, -1.083, -0.941, 0.089, -1.160, -0.902, -1.444, 0.278, 0.342, -1.010, -5.000, -0.021, -0.861, -1.206, -0.695, -0.885, -0.461, -0.715, -0.677, -0.237, 0.150, -0.422, -0.578, -0.261, 0.279, -0.514, 0.083, -0.692, -0.634, -0.934, -0.938, -0.788, -0.593, -0.981, -0.834, -0.770, 0.022, -0.457, 0.053, -1.041, -0.617, -2.028, -1.161, -1.458, -1.231, -2.078, -1.696, -1.133, -1.300, -1.613, -1.382, -0.797, -0.492, -1.120, -0.739, 0.241, 0.173, -0.735, -5.000, -0.320, -0.181, -1.741, -5.000, -0.232, 0.229, -0.670, -0.539, 0.697, 0.608, 0.268, -0.364, 0.757, 0.625, -0.112, -5.000, -0.108, 0.248, -0.809, -0.193, -0.532, -0.242, -0.546, -0.693, 0.391, 0.985, 0.354, -0.360, -0.099, 0.523, -0.189, 0.561, -0.167, 0.556, -0.525, -0.414, -0.058, 0.121, -0.304, -0.435, -0.224, 0.649, 0.189, 0.753, -0.862, -0.472, -1.626, -0.740, -1.113, -0.413, -2.223, -1.507, -0.656, -0.343, -0.883, -0.873, -0.230, 0.497, -0.173, -0.112, 0.243, -0.040, -1.042, -5.000, -0.323, -0.258, -1.868, -5.000, -0.032, 0.363, -0.701, -0.356, 0.990, 0.492, 0.668, -0.320, 0.776, 0.773, -0.127, -5.000, 0.500, 0.263, -0.672, 0.063, 0.100, 0.659, -0.345, -0.226, 0.857, 1.031, 0.742, 0.164, 0.528, 0.867, 0.104, 1.100, 0.423, 0.632, -0.258, 0.263, 0.225, 0.590, -0.001, -0.006, 0.387, 0.733, 0.618, 1.188, -0.563, 0.373, -0.885, 0.056, -0.613, -0.137, -1.048, -1.513, 0.067, 0.253, -0.866, -0.387, 0.578, 0.735, 0.352, 0.097, -0.218, -0.401, -1.949, -5.000, -0.796, -0.809, -2.241, -5.000, -0.242, -0.115, -0.904, -0.780, 0.771, 0.290, 0.095, -0.795, 0.448, 0.591, -0.708, -5.000, 0.237, -0.075, -1.242, -0.529, -0.152, 0.173, -0.061, -0.615, 0.365, 0.738, 0.172, -0.466, 0.263, 0.907, -0.202, 0.184, -0.029, 0.184, -1.671, -0.198, -0.241, 0.071, -0.278, -0.622, -0.071, 0.756, 0.053, 0.594, -0.250, 0.437, -0.845, -0.456, -0.892, -0.556, -1.571, -0.837, -0.475, -0.733, -1.093, -1.433, 0.060, 0.221, -0.594, -0.618, -0.110, -0.013, -1.166, -5.000, -0.466, -0.579, -1.959, -5.000, -0.984, -0.023, -0.954, -0.680, 0.222, -0.038, -0.196, -0.982, 0.275, 0.692, -0.432, -5.000, -0.548, -0.467, -1.137, -0.399, -0.984, -0.206, -0.882, -0.888, 0.021, 0.524, -0.052, -0.326, -0.419, 0.157, -0.633, 0.074, -0.945, -0.073, -1.074, -1.491, -0.677, -0.217, -0.857, -1.030, -0.628, 0.379, 0.217, -0.097, -0.187, -0.303, -1.035, -0.650, -1.456, -0.926, -1.690, -1.458, -1.625, -0.317, -1.297, -1.467, -0.464, 0.379, -0.161, -0.495, 0.353, 0.266, -0.271, -5.000, 0.173, 0.110, -0.956, -5.000, 0.220, 0.467, -0.018, -0.081, 0.811, 0.706, 0.461, -0.378, 1.032, 1.034, 0.119, -5.000, 0.788, -0.015, -0.531, 0.181, -0.230, 0.365, -0.208, -0.167, 0.470, 0.855, 0.339, 0.115, 0.321, 0.937, -0.119, 0.724, 0.038, 0.495, -0.757, -0.563, -0.010, 0.327, -0.060, -0.141, 0.017, 0.575, 0.132, 0.742, -0.370, 0.240, -0.641, -0.248, -0.618, -0.112, -1.059, -1.407, -0.543, -0.296, -0.819, -0.411, -0.215, 0.519, -0.139, -0.182, 0.590, 0.126, -0.644, -5.000, 0.143, 0.405, -1.082, -5.000, 0.588, 0.744, -0.115, 0.195, 1.061, 0.579, 1.097, 0.030, 0.933, 0.995, 0.217, -5.000, 0.834, 0.363, -0.563, 0.470, 0.785, 0.929, 0.504, 0.293, 0.841, 1.048, 0.791, 0.137, 0.626, 1.036, 0.102, 1.220, 0.634, 0.732, -0.086, -0.079, 0.540, 0.769, 0.391, 0.394, 0.350, 0.760, 0.376, 1.324, -0.039, 0.737, -0.573, 0.196, -0.051, 0.581, -0.550, -0.896, 0.421, 0.670, -0.282, 0.250, 0.709, 1.025, 0.468, 0.655, 0.189, 0.047, -0.734, -5.000, -0.072, -0.144, -1.886, -5.000, 0.285, 0.648, -0.612, 0.162, 0.971, -0.041, 0.567, -0.226, 0.753, 0.959, 0.090, -5.000, 0.832, 0.321, -0.629, 0.361, 0.419, 0.869, -0.098, 0.071, 0.758, 0.997, 0.620, -0.096, 0.046, 0.796, -0.178, 0.744, 0.113, 0.446, -0.822, -0.368, 0.082, 0.711, 0.127, 0.036, -0.147, 0.736, 0.089, 0.724, -0.627, 0.326, -0.938, -0.341, -0.465, 0.072, -1.299, -1.104, -0.113, 0.231, -0.938, -0.204, 0.231, 0.484, -0.340, -0.324, 0.677, 0.540, 0.321, -5.000, 0.344, 0.525, -0.578, -5.000, 0.580, 0.823, 0.122, 0.458, 1.164, 0.690, 0.682, -0.069, 1.309, 1.355, 0.840, -5.000, 1.112, 0.762, -0.034, 0.729, 0.611, 0.906, 0.496, 0.308, 0.857, 1.288, 0.779, 0.309, 0.729, 1.283, 0.653, 1.016, 0.476, 0.661, -0.195, -0.370, 0.314, 0.557, 0.476, 0.048, 0.168, 0.767, 0.653, 0.888, 0.151, 0.796, 0.090, 0.176, -0.051, 0.420, -0.227, -0.887, 0.298, 0.673, -0.134, -0.042, 0.278, 0.962, 0.309, 0.104, 0.032, -0.446, -0.760, -5.000, -0.292, -0.395, -1.412, -5.000, -0.541, -0.161, -1.228, -0.428, 0.490, 0.321, -0.036, -0.601, 0.245, 0.284, -0.471, -5.000, 0.251, -0.379, -0.776, -0.249, -0.288, -0.942, -0.858, -0.667, 0.161, 0.410, -0.076, 0.223, -0.190, 0.299, -1.032, 0.182, -0.041, -0.025, -0.914, -0.351, -0.584, -0.096, -0.295, -0.605, -0.307, -0.047, -0.288, 0.020, -0.419, -0.610, -1.170, -0.589, -0.420, -0.202, -1.556, -0.967, 0.025, -0.499, -0.925, -0.663, -0.252, 0.158, -0.669, -0.332, 0.088, -0.406, -1.486, -5.000, -0.075, -0.581, -2.076, -5.000, -0.065, 0.068, -0.621, -0.635, 0.971, 0.176, 0.186, -0.099, 0.808, 0.528, -0.628, -5.000, 1.017, 0.455, -0.373, 0.501, 0.681, 0.691, 0.308, -0.163, 0.738, 0.791, 0.342, 0.486, 0.684, 1.004, 0.028, 1.049, 0.857, 0.575, -0.449, -0.241, 0.787, 0.433, 0.357, -0.028, 0.383, 0.635, 0.021, 0.677, -0.135, 0.326, -0.927, -0.049, 0.224, 0.578, -0.561, -1.160, 0.325, 0.201, -0.469, -0.187, 0.386, 0.944, 0.258, -0.071, -0.352, -1.301, -1.843, -5.000, -0.956, -1.471, -2.483, -5.000, -0.515, -1.014, -1.587, -0.920, 0.002, -1.525, -1.060, -1.536, -0.135, 0.087, -1.071, -5.000, 0.094, -0.612, -1.759, -0.778, -0.333, -0.245, -1.057, -1.064, 0.015, 0.112, -0.741, -0.519, -0.680, -0.018, -1.132, -0.087, -0.538, -0.485, -1.439, -0.942, -0.879, -0.566, -0.916, -0.815, -0.828, -0.483, -0.902, -0.227, -0.938, -0.502, -1.527, -1.509, -1.540, -0.813, -2.097, -1.666, -0.681, -1.263, -1.905, -1.872, -0.764, -0.737, -1.648, -1.463, 0.052, -0.405, -1.386, -5.000, -0.331, -0.732, -1.754, -5.000, -0.247, -0.244, -0.739, -0.854, 0.022, -0.502, -0.770, -0.682, 0.577, 0.507, -0.600, -5.000, 0.671, -0.338, -1.181, -0.257, -0.079, 0.336, -0.393, -0.599, 0.336, 0.490, -0.241, -0.091, 0.045, 0.482, -0.790, 0.374, 0.003, -0.138, -1.164, -0.904, -0.390, -0.091, -0.715, -0.916, 0.032, -0.108, -0.385, 0.079, -0.502, -0.054, -0.905, -0.552, -0.633, -0.726, -1.449, -1.587, -0.354, -0.532, -0.890, -1.058, -0.083, -0.133, -0.849, -0.572, -0.618, -0.607, -1.613, -5.000, -0.950, -0.860, -1.693, -5.000, -0.697, -0.122, -0.694, -1.293, 0.307, 0.298, -0.124, -0.052, 0.348, 0.302, -1.047, -5.000, 0.171, -0.467, -1.351, -0.671, -0.885, -0.568, -0.855, -1.008, 0.328, 0.365, 0.096, -0.471, -0.267, 0.186, -0.853, 0.244, -0.224, -0.180, -1.598, -1.371, -0.574, -0.276, -0.789, -1.019, -0.580, 0.303, -0.607, -0.074, -0.663, -0.860, -1.827, -0.854, -0.726, -0.380, -2.384, -2.026, -0.348, -0.395, -1.220, -0.726, 0.090, 0.237, -0.155, -0.465, -0.110, -0.341, -1.635, -5.000, -0.755, -0.861, -2.037, -5.000, -0.447, -0.309, -1.075, -1.441, 0.714, -0.009, -0.063, -0.604, 0.711, 0.440, -0.524, -5.000, 0.673, -0.079, -0.517, -0.162, 0.200, 0.332, -0.154, -0.139, 0.826, 0.553, 0.524, 0.238, 0.399, 0.676, -0.403, 0.848, 0.454, 0.272, -0.670, 0.095, 0.187, 0.301, -0.137, 0.156, 0.208, 0.342, 0.211, 0.534, -0.384, 0.158, -0.956, -0.097, -0.278, -0.157, -1.186, -1.620, -0.243, -0.103, -0.936, -0.508, 0.469, 0.586, 0.261, -0.225, -1.025, -1.765, -2.427, -5.000, -1.601, -2.207, -3.135, -5.000, -1.162, -1.213, -2.054, -2.109, -0.444, -1.283, -1.252, -1.988, -0.379, -0.393, -1.428, -5.000, -0.285, -1.087, -1.928, -1.622, -1.293, -0.479, -0.872, -1.174, -0.067, 0.002, -0.916, -0.700, -1.235, -0.609, -1.685, -0.772, -1.390, -0.909, -2.092, -1.696, -1.093, -0.643, -0.840, -1.012, -0.993, -1.063, -0.808, -0.315, -1.483, -0.974, -2.370, -1.476, -1.554, -2.161, -3.098, -1.943, -2.014, -2.084, -2.228, -3.168, -1.135, -1.244, -1.873, -2.370, -0.764, -0.929, -1.565, -5.000, -1.275, -1.334, -2.494, -5.000, -1.587, -1.284, -1.905, -1.296, -1.049, -1.595, -1.546, -1.604, -0.116, -0.378, -1.373, -5.000, -0.647, -1.285, -1.752, -1.169, -1.216, -1.186, -1.327, -1.339, -0.556, -0.087, -1.013, -0.880, -0.670, -0.523, -1.404, -0.813, -1.320, -1.322, -1.749, -1.907, -1.363, -1.506, -1.837, -1.793, -0.965, -1.146, -1.509, -0.997, -1.568, -1.424, -1.367, -1.553, -1.742, -1.719, -2.602, -2.132, -2.307, -1.820, -1.859, -1.624, -0.273, -0.701, -1.436, -0.994, -0.141, -0.068, -0.740, -5.000, -0.851, -0.508, -2.265, -5.000, -0.457, 0.003, -0.389, -0.702, 0.646, 0.523, 0.145, -0.159, 0.566, 0.788, -0.319, -5.000, 0.351, -0.125, -0.898, -0.550, -0.391, 0.015, -0.690, -1.070, 0.539, 0.901, 0.366, -0.108, 0.016, 0.668, -0.275, 0.625, -0.346, 0.235, -1.437, -0.967, -0.314, -0.119, -0.413, -0.567, -0.374, 0.342, 0.009, 0.363, -0.838, -0.596, -1.646, -0.804, -1.493, -0.353, -2.038, -1.650, -0.555, -0.279, -0.881, -0.954, -0.089, 0.669, -0.122, -0.285, -0.127, -0.370, -1.420, -5.000, -0.495, -0.994, -2.318, -5.000, -0.404, -0.063, -1.288, -1.080, 0.970, 0.135, 0.373, -0.344, 0.672, 0.606, -0.471, -5.000, 0.586, 0.118, -1.036, -0.114, 0.027, 0.506, -0.380, -0.419, 0.715, 0.879, 0.537, 0.360, 0.233, 0.694, -0.404, 0.818, 0.131, 0.064, -0.923, -0.789, -0.052, 0.297, -0.655, -0.279, 0.054, 0.119, -0.103, 0.789, -0.284, 0.245, -0.916, -0.343, -0.610, -0.035, -1.256, -1.436, 0.040, 0.008, -1.056, -0.413, 0.346, 0.709, 0.326, -0.100, -0.827, -1.453, -2.808, -5.000, -1.047, -1.516, -2.966, -5.000, -0.930, -0.893, -1.607, -1.101, 0.062, -1.194, -0.799, -1.005, 0.002, -0.102, -1.318, -5.000, 0.001, -0.557, -1.742, -1.026, -0.358, -0.273, -0.763, -0.892, 0.142, 0.513, -0.371, -0.415, -0.484, 0.209, -1.132, -0.406, -0.678, -0.846, -2.132, -1.073, -1.095, -0.642, -1.222, -1.115, -0.763, -0.731, -1.273, -0.110, -0.880, -0.164, -1.585, -1.285, -1.292, -1.380, -2.307, -1.683, -1.093, -1.554, -1.845, -1.767, -0.687, -0.759, -1.552, -1.307, -0.201, -0.404, -1.137, -5.000, -0.935, -1.102, -2.007, -5.000, -0.988, -0.535, -1.547, -1.552, -0.068, -0.832, -1.163, -1.115, 0.145, 0.560, -0.970, -5.000, -0.208, -0.594, -1.343, -0.843, -1.049, -0.294, -1.239, -1.108, 0.248, 0.460, -0.149, -0.166, -0.490, -0.058, -0.816, -0.318, -1.024, -0.546, -1.293, -1.804, -1.098, -0.629, -1.306, -1.353, -0.536, -0.136, -0.470, -0.317, -0.361, -0.254, -1.425, -0.693, -1.175, -1.045, -2.180, -1.489, -1.665, -0.895, -1.679, -1.808, -0.469, -0.176, -0.529, -0.794, 0.236, 0.557, -0.096, -5.000, 0.212, 0.100, -0.617, -5.000, 0.196, 0.196, -0.461, -0.080, 0.626, 0.613, 0.343, 0.113, 1.110, 1.231, 0.258, -5.000, 0.917, 0.078, -0.620, 0.145, 0.235, 0.480, -0.109, -0.091, 0.732, 0.756, 0.731, 0.458, 0.379, 1.053, 0.225, 0.762, 0.315, 0.471, -0.676, -0.378, 0.093, 0.502, -0.121, -0.243, 0.254, 0.495, 0.169, 0.439, -0.173, 0.452, -1.041, 0.035, -0.296, 0.245, -1.124, -0.994, -0.318, 0.156, -0.200, -0.130, 0.023, 0.549, 0.032, -0.109, 0.552, 0.177, -1.009, -5.000, 0.243, -0.084, -1.251, -5.000, 0.497, 0.751, -0.068, 0.001, 1.146, 0.601, 0.896, -0.126, 1.115, 1.100, 0.304, -5.000, 1.091, 0.456, -0.322, 0.525, 0.540, 1.003, 0.512, 0.362, 1.023, 1.107, 0.871, 0.357, 0.714, 1.008, -0.088, 1.064, 0.602, 0.559, -0.666, -0.124, 0.515, 0.758, 0.180, 0.063, 0.512, 0.804, 0.418, 0.997, 0.307, 0.985, -0.271, 0.311, 0.317, 0.735, -0.429, -0.556, 0.375, 0.778, 0.224, 0.255, 0.831, 1.054, 0.657, 0.361, -0.089, -0.685, -1.577, -5.000, -0.405, -0.531, -1.721, -5.000, -0.096, 0.278, -1.148, -0.235, 0.615, -0.488, -0.098, -0.178, 0.670, 0.853, -0.258, -5.000, 0.730, 0.079, -1.016, 0.056, 0.305, 0.787, -0.054, -0.025, 0.779, 0.837, 0.518, 0.221, 0.046, 0.578, -0.507, 0.550, 0.002, 0.080, -1.243, -0.832, -0.224, 0.425, -0.457, -0.427, -0.243, 0.221, -0.296, 0.240, -0.625, 0.172, -0.824, -0.319, -0.326, 0.003, -1.586, -1.520, -0.313, -0.073, -1.063, -0.766, -0.008, -0.210, -0.596, -0.458, -0.033, -0.384, -0.253, -5.000, -0.398, -0.270, -1.467, -5.000, -0.230, 0.036, -0.851, -0.673, 0.027, -0.462, -0.470, -0.284, 0.540, 0.783, 0.105, -5.000, 0.439, 0.046, -0.542, -0.107, -0.355, 0.192, -0.524, -0.116, 0.240, 0.510, -0.026, 0.073, -0.015, 0.436, -0.410, 0.211, -0.448, -0.333, -0.965, -1.155, -0.804, -0.356, -0.156, -0.787, -0.325, -0.296, -0.182, -0.101, -0.352, 0.022, -0.769, -0.376, -0.434, -0.255, -1.022, -0.883, -0.299, -0.266, -0.705, -0.586, -0.639, -0.033, -0.376, -0.453 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_21(struct _training *tptr) {
  struct _training tinf = {
    0.489, 11, 4.350, { 1.481, 0.251, 1.268 }, { 0.758, -1.272, -2.316 }, 0, 
    { -0.064, -1.467, -1.562, -1.742, -0.002, 0.276, -1.043, -4.000, -4.000, 0.333, -1.862, -4.000, -1.025, -0.173, -4.000, 0.789, 0.907, -4.000, -0.576, 1.086, -0.450, 0.351, 2.094, -4.000, 1.803, 0.977, 2.771, 2.299 }, 
    {{ -0.261, -0.425, 0.280, 0.225},{ -0.062, -0.338, 0.188, 0.128},{ 0.479, -0.428, -0.269, -0.056},{ 0.419, -0.524, -0.214, 0.052},{ 0.421, -0.314, -0.204, -0.092},{ 0.334, -0.447, -0.094, 0.034},{ 0.398, -0.514, -0.164, 0.040},{ 0.313, -0.282, -0.105, -0.038},{ 0.309, -0.287, -0.157, 0.016},{ 0.277, -0.428, -0.041, 0.052},{ 0.277, -0.344, -0.199, 0.125},{ 0.138, -0.236, -0.116, 0.146},{ 0.196, -0.194, -0.100, 0.043},{ 0.153, -0.206, -0.159, 0.143},{ 0.098, -0.209, -0.094, 0.151},{ 0.140, -0.314, -0.090, 0.174},{ 0.174, -0.248, -0.147, 0.142},{ 0.100, -0.045, -0.206, 0.110},{ 0.143, -0.256, -0.178, 0.197},{ 0.142, -0.127, -0.047, 0.006},{ -0.016, -0.066, -0.005, 0.079},{ 0.145, -0.173, -0.136, 0.112},{ 0.163, -0.054, -0.231, 0.068},{ 0.041, -0.136, -0.138, 0.185},{ 0.084, -0.064, -0.161, 0.108},{ 0.132, -0.079, -0.175, 0.082},{ 0.003, -0.092, 0.009, 0.070},{ 0.075, -0.134, -0.100, 0.125},{ 0.072, -0.025, -0.168, 0.093},{ 0.047, -0.060, -0.201, 0.168},{ 0.077, -0.072, -0.171, 0.128},{ 0.133, -0.049, -0.182, 0.061} }, 
    {{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { 0.853, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { 1.026, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 2.026, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 2.415, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { 1.419, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}} }, 
    -0.172, { 0.324, 0.587, -0.339, -5.000, -0.000, 0.306, -0.533, -5.000, 0.184, 0.494, -0.025, -0.017, 0.096, 0.370, 0.165, -0.106, 0.258, 0.410, 0.339, -5.000, -0.190, 0.009, -0.457, 0.004, -0.009, 0.347, 0.093, -0.135, 0.535, 0.391, 0.531, -0.147, 0.352, 0.487, -0.017, 0.665, 0.184, 0.312, -0.110, -0.455, 0.662, 0.872, 0.525, 0.359, 0.530, 0.507, 0.652, 0.285, 0.207, 0.519, 0.136, 0.523, 0.222, 0.325, 0.218, -0.362, 0.266, 0.818, 0.709, 0.454, 0.662, 0.559, 0.930, 0.506, 0.490, 0.767, -1.052, -5.000, -0.224, 0.542, -1.037, -5.000, 0.133, 0.189, -0.894, -0.349, 0.855, 0.737, 0.558, 0.233, 0.680, 0.767, 0.515, -5.000, 0.320, 0.382, 0.151, 0.341, 0.408, 0.659, 0.333, 0.163, 0.671, 0.820, 0.825, -0.074, 0.523, 0.878, 0.130, 0.668, 0.299, 0.511, 0.120, -0.169, 0.544, 0.655, 0.184, 0.181, 0.758, 0.742, 0.837, 0.459, 0.649, 0.853, 0.333, 0.793, 0.502, 0.719, 0.729, 0.122, 0.316, 0.604, 0.397, 0.085, 0.863, 0.784, 1.201, 0.701, -0.246, -0.086, -0.817, -5.000, -1.058, -0.646, -1.252, -5.000, -0.279, -0.318, -0.885, -0.245, -0.248, -0.215, -1.055, -0.461, -0.192, -0.092, -0.298, -5.000, -0.878, -0.781, -1.177, -0.936, -0.393, -0.187, -0.482, -0.616, 0.121, 0.023, -0.018, -0.550, -0.656, -0.638, -1.121, -0.770, -0.733, -0.244, -1.314, -1.079, -0.253, -0.094, -0.541, -0.650, -0.599, -0.542, -0.709, -1.073, -0.609, -0.484, -0.831, -0.673, -0.863, -0.929, -1.115, -1.056, -0.690, -0.290, -0.816, -0.759, -0.362, -0.655, -0.716, -0.925, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.346, -0.136, -0.832, -5.000, -0.632, -0.285, -1.174, -5.000, -0.408, -0.040, -0.831, -0.440, -0.246, 0.105, -0.647, -0.381, -0.657, -0.279, -0.268, -5.000, -0.925, -0.657, -1.096, -0.596, -0.597, -0.133, -0.579, -0.940, -0.096, 0.076, 0.247, -0.346, -0.138, 0.244, -0.232, -0.056, -0.575, 0.078, -0.323, -0.973, -0.116, 0.008, -0.796, -0.595, 0.120, 0.238, 0.412, -0.119, -0.853, -0.716, -1.155, -0.717, -1.281, -0.767, -1.225, -1.469, 0.157, 0.514, 0.436, -0.024, -0.188, 0.030, 0.121, -0.106, 0.435, 0.566, -1.132, -5.000, -0.281, 0.518, -1.049, -5.000, 0.065, 0.194, -0.873, -0.363, 0.657, 0.739, 0.554, 0.261, 0.410, 0.588, 0.122, -5.000, -0.008, 0.406, -0.176, 0.307, 0.029, 0.435, 0.079, -0.216, 0.645, 0.527, 0.612, 0.074, 0.427, 0.693, 0.004, 0.491, 0.156, 0.519, -0.146, -0.231, 0.338, 0.478, 0.116, -0.139, 0.606, 0.579, 0.905, 0.461, -0.161, 0.141, -0.287, 0.139, -0.319, 0.147, -0.194, -0.992, -0.813, -0.518, -0.693, -0.884, 0.309, 0.524, 1.168, 0.348, -0.203, -0.090, -1.049, -5.000, -0.864, -0.639, -1.072, -5.000, -0.413, -0.308, -1.228, -0.736, -0.290, -0.257, -1.270, -0.601, -0.378, -0.328, -0.478, -5.000, -0.717, -0.571, -1.140, -1.061, -1.010, -0.544, -1.109, -1.489, 0.009, -0.157, -0.068, -0.498, -0.988, -0.697, -1.295, -1.057, -0.717, -0.784, -1.522, -1.822, -0.408, -0.259, -0.942, -0.857, -0.596, -0.785, -0.967, -1.172, -0.836, -0.848, -1.231, -1.155, -1.214, -1.024, -1.142, -1.607, -1.430, -1.072, -1.601, -1.704, -0.535, -0.614, -0.502, -0.951, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.112, 0.289, -0.569, -5.000, -0.344, 0.108, -0.781, -5.000, -0.215, -0.210, -0.736, -0.484, 0.059, -0.117, -0.244, -0.319, 0.134, 0.400, 0.150, -5.000, -0.349, 0.051, -0.459, -0.196, -0.058, 0.072, -0.177, -0.677, 0.020, 0.180, 0.227, -0.537, -0.002, 0.467, -0.061, -0.025, -0.537, 0.297, -0.541, -1.032, -0.052, 0.140, -0.321, -0.389, 0.098, 0.082, 0.333, -0.334, -0.021, 0.374, -0.241, 0.235, -0.387, 0.062, -0.316, -0.685, -0.385, -0.156, -0.379, -0.534, 0.286, 0.266, 0.569, 0.030, 0.211, 0.412, -1.161, -5.000, -0.591, 0.202, -0.946, -5.000, -0.166, -0.155, -1.229, -0.559, 0.508, 0.656, 0.117, -0.181, 0.246, 0.654, 0.342, -5.000, -0.266, 0.408, -0.107, 0.102, -0.135, 0.319, -0.262, -0.427, 0.360, 0.513, 0.590, -0.455, 0.146, 0.753, -0.330, 0.047, -0.157, 0.434, -0.196, -0.827, 0.217, 0.398, -0.382, -0.347, 0.499, 0.557, 0.655, -0.117, 0.363, 0.527, -0.041, 0.358, -0.034, 0.312, -0.125, -0.698, -0.389, 0.064, -0.354, -0.601, 0.489, 0.435, 0.919, 0.174, -0.488, -0.176, -0.953, -5.000, -1.309, -0.236, -1.426, -5.000, -0.744, -0.774, -0.987, -1.010, -0.814, -0.552, -0.954, -0.936, -0.504, -0.279, -0.662, -5.000, -0.825, -0.423, -0.945, -1.104, -0.740, -0.384, -0.914, -1.248, -0.676, -0.120, -0.262, -0.926, -0.699, -0.243, -1.108, -0.889, -0.866, -0.390, -0.795, -1.362, -0.723, -0.505, -0.828, -0.911, -0.755, -0.158, -0.755, -0.781, -0.304, -0.047, -0.423, -0.303, -0.822, -0.453, -0.712, -1.188, -0.713, -0.374, -0.839, -0.702, -0.162, -0.422, -0.282, -0.878, -0.128, 0.191, -0.536, -5.000, -1.141, -0.311, -1.211, -5.000, -0.646, -0.333, -0.755, -0.899, -0.788, -0.380, -1.076, -1.090, -0.040, 0.374, 0.096, -5.000, -0.918, -0.517, -1.208, -0.630, -0.281, -0.246, -0.642, -0.961, -0.186, -0.215, -0.204, -0.637, -0.350, 0.014, -0.600, -0.419, -0.672, -0.042, -0.610, -0.862, -0.231, -0.105, -0.620, -0.572, -0.253, 0.108, 0.058, -0.566, -0.365, 0.093, -0.485, -0.050, -0.771, -0.044, -0.404, -1.106, -0.640, -0.254, -0.426, -0.685, -0.133, -0.011, 0.119, -0.467, 0.261, 0.437, -0.418, -5.000, -0.205, 0.158, -0.479, -5.000, -0.235, -0.036, -0.784, -0.477, -0.276, -0.075, -0.257, -0.208, 0.093, 0.528, 0.293, -5.000, -0.140, 0.065, -0.297, -0.262, -0.209, 0.200, -0.337, -0.662, 0.025, 0.176, 0.330, -0.396, 0.117, 0.351, -0.006, 0.322, -0.271, 0.405, -0.162, -0.769, 0.449, 0.301, -0.492, -0.048, 0.117, 0.286, 0.210, -0.307, 0.040, 0.536, -0.022, 0.298, -0.439, 0.307, -0.212, -0.523, -0.245, 0.130, -0.621, -0.552, 0.089, 0.194, 0.650, 0.038, 0.404, 0.410, -0.674, -5.000, -0.536, 0.103, -0.631, -5.000, -0.006, -0.137, -0.817, -0.379, -0.026, 0.280, 0.724, -0.081, 0.307, 0.624, 0.398, -5.000, -0.095, 0.416, -0.125, -0.059, 0.132, 0.429, 0.041, -0.260, 0.254, 0.527, 0.578, -0.228, 0.156, 0.401, -0.446, 0.177, -0.514, 0.370, -0.411, -0.934, -0.185, 0.244, -0.130, -0.103, 0.221, 0.220, 0.175, -0.295, 0.283, 0.524, 0.151, 0.410, 0.117, 0.389, -0.069, -0.370, -0.098, 0.357, 0.044, -0.390, 0.416, 0.337, 0.606, 0.146, -0.085, 0.075, -0.570, -5.000, -0.453, -0.372, -1.286, -5.000, -0.470, -0.272, -0.398, -0.415, -0.403, -0.147, -0.847, -0.350, -0.104, 0.097, -0.250, -5.000, -1.054, -0.454, -1.518, -0.595, -0.393, -0.322, -0.670, -0.630, -0.095, -0.181, -0.163, -0.270, -0.446, -0.740, -1.400, -0.483, -1.204, -0.700, -1.566, -2.113, -0.529, -0.693, -0.627, -0.747, -0.511, -1.016, -1.353, -1.108, -0.441, -0.418, -0.474, -0.657, -0.957, -0.778, -1.282, -1.279, -0.884, -0.700, -0.975, -0.588, -0.172, -0.728, -0.799, -0.774, -0.128, 0.300, -0.416, -5.000, -1.049, -0.231, -0.923, -5.000, -0.556, -0.277, -0.366, -0.662, -0.509, -0.402, -0.428, -0.333, -0.065, 0.301, 0.086, -5.000, -0.593, -0.350, -0.679, -0.675, -0.171, -0.002, -0.412, -0.478, -0.141, 0.004, -0.100, -0.337, -0.506, -0.263, -1.026, -0.446, -1.113, -0.676, -0.911, -1.262, -0.461, -0.464, -0.655, -0.799, -0.837, -0.345, -0.472, -0.655, -0.333, 0.042, -0.686, -0.144, -0.368, -0.237, -0.413, -0.878, -0.621, -0.371, -0.666, -0.729, -0.378, -0.301, -0.390, -0.440, 0.109, 0.596, -0.249, -5.000, -0.013, 0.345, -0.497, -5.000, 0.016, 0.341, -0.212, -0.433, 0.095, 0.240, -0.230, 0.017, 0.032, 0.523, 0.188, -5.000, -0.392, -0.145, -0.571, -0.090, -0.328, -0.008, -0.320, -0.496, 0.282, 0.181, 0.188, -0.234, 0.564, 0.770, 0.283, 0.810, 0.268, 0.472, 0.394, -0.251, 0.561, 0.624, 0.463, -0.010, 0.739, 0.645, 0.743, 0.262, 0.088, 0.325, 0.070, 0.445, -0.012, 0.320, 0.208, -0.378, 0.485, 0.053, 0.361, -0.007, 0.378, 0.598, 0.763, 0.184, 0.885, 1.009, -0.576, -5.000, 0.201, 0.668, -0.444, -5.000, 0.252, 0.430, -0.415, -0.039, 0.534, 0.522, 0.523, 0.420, 0.692, 0.948, 0.586, -5.000, 0.480, 0.349, 0.177, 0.370, 0.214, 0.542, 0.083, -0.138, 0.759, 0.717, 0.826, -0.125, 0.815, 0.933, 0.339, 0.765, 0.344, 0.724, 0.388, -0.109, 0.472, 0.700, 0.273, 0.356, 0.814, 0.837, 0.871, 0.515, 0.412, 0.921, 0.358, 0.848, 0.644, 0.766, 0.845, 0.083, 0.162, 0.438, 0.379, -0.074, 0.579, 0.682, 0.972, 0.654, 0.397, 0.679, -0.210, -5.000, -0.194, 0.345, -0.679, -5.000, 0.456, 0.545, -0.257, 0.246, 0.318, 0.407, -0.164, -0.110, 0.279, 0.645, 0.331, -5.000, -0.041, 0.079, -0.352, 0.244, 0.279, 0.526, 0.021, -0.068, 0.665, 0.539, 0.638, 0.243, 0.291, 0.449, 0.125, 0.359, 0.055, 0.538, 0.436, -0.280, 0.538, 0.700, 0.158, 0.090, 0.274, 0.260, 0.212, -0.042, 0.134, 0.489, -0.070, 0.256, 0.037, 0.412, 0.331, -0.567, -0.110, 0.207, 0.141, -0.160, 0.381, 0.328, 0.322, -0.162, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.561, -0.136, -0.942, -5.000, -0.690, -0.218, -0.866, -5.000, -0.612, -0.139, -0.558, -0.698, -0.450, -0.056, 0.050, -0.298, -0.715, -0.146, -0.458, -5.000, -0.894, -0.473, -0.832, -0.650, -0.763, -0.246, -0.730, -0.890, -0.195, -0.142, 0.011, -0.536, -0.005, 0.589, -0.156, 0.276, -0.294, 0.209, -0.236, -0.987, 0.027, 0.199, -0.693, -0.180, 0.199, 0.461, 0.320, -0.081, -1.051, -0.987, -0.929, -1.375, -0.808, -0.693, -0.913, -1.096, -0.817, -0.103, -0.663, -1.356, -0.162, -0.295, -0.198, -0.495, 0.527, 0.750, -0.700, -5.000, -0.213, 0.514, -1.081, -5.000, -0.192, -0.023, -0.805, -0.516, 0.397, 0.421, 0.757, 0.200, 0.236, 0.696, 0.247, -5.000, -0.049, 0.393, -0.189, 0.288, -0.376, 0.104, -0.143, -0.496, 0.618, 0.463, 0.550, -0.071, 0.288, 0.646, 0.005, 0.411, 0.115, 0.515, -0.402, -0.446, 0.131, 0.390, 0.026, -0.252, 0.500, 0.635, 0.914, 0.389, -0.592, -0.039, -0.563, -0.143, -0.582, 0.232, -0.229, -0.427, -1.488, -1.078, -0.897, -1.747, -0.029, -0.052, 0.976, -0.005, -0.134, 0.350, -0.772, -5.000, -0.879, -0.192, -0.882, -5.000, -0.063, -0.104, -0.934, -0.766, -0.299, -0.063, -0.673, -0.700, -0.285, 0.178, -0.281, -5.000, -0.877, -0.536, -1.048, -0.833, -0.802, -0.506, -0.943, -1.171, 0.025, -0.012, -0.201, -0.385, -0.148, 0.255, -0.424, -0.139, -0.487, -0.249, -0.795, -0.943, -0.127, 0.067, -0.551, -0.668, -0.148, -0.089, -0.339, -0.602, -0.523, -0.260, -0.903, -0.797, -0.880, -0.535, -0.684, -1.487, -1.583, -0.689, -1.320, -1.797, -0.521, -0.467, -0.320, -0.896, 0.241, 0.290, -0.229, -5.000, -0.900, 0.018, -0.695, -5.000, -0.144, -0.040, -0.455, -0.549, -0.291, -0.118, -0.850, -0.572, 0.243, 0.742, 0.228, -5.000, -0.708, -0.128, -0.861, -0.204, -0.516, 0.012, -0.528, -0.754, 0.088, -0.104, -0.112, -0.374, 0.179, 0.752, 0.118, 0.481, -0.023, 0.244, -0.047, -0.754, 0.163, 0.098, 0.114, -0.238, 0.001, 0.338, 0.321, -0.009, -0.663, -0.052, -0.778, -0.412, -0.825, -0.422, -0.521, -1.126, -1.497, -0.992, -0.970, -1.332, -0.817, -0.479, -0.652, -0.862, -0.052, 0.225, -0.853, -5.000, -0.363, 0.315, -0.688, -5.000, -0.060, -0.084, -0.492, -0.556, -0.078, 0.065, -0.245, -0.582, -0.029, 0.390, 0.062, -5.000, -0.684, 0.086, -0.352, -0.147, -0.155, 0.172, -0.100, -0.751, -0.036, 0.237, 0.225, -0.576, 0.244, 0.623, 0.133, 0.474, -0.270, 0.312, -0.235, -0.494, 0.033, 0.390, -0.248, -0.066, 0.257, 0.344, 0.081, -0.172, -0.024, 0.604, 0.048, 0.506, -0.291, 0.412, 0.156, -0.457, -0.271, 0.211, -0.284, -0.644, 0.181, 0.216, 0.650, 0.331, 0.410, 0.681, -1.177, -5.000, -0.485, 0.529, -0.870, -5.000, -0.042, -0.049, -1.205, -0.554, 0.545, 0.354, 0.560, -0.204, 0.588, 0.878, 0.615, -5.000, 0.045, 0.471, -0.088, 0.186, 0.007, 0.396, -0.203, -0.596, 0.423, 0.584, 0.558, -0.583, 0.646, 0.981, 0.466, 0.721, 0.167, 0.902, 0.005, -0.294, 0.415, 0.674, 0.144, -0.008, 0.699, 0.791, 0.840, 0.349, 0.465, 0.772, 0.236, 0.639, 0.140, 0.609, 0.200, -0.329, -0.129, 0.299, -0.265, -0.558, 0.498, 0.515, 0.924, 0.249, 0.114, 0.292, -0.732, -5.000, -0.552, 0.217, -1.034, -5.000, -0.127, -0.218, -0.715, -0.660, -0.411, -0.134, -0.972, -1.077, 0.131, 0.467, 0.125, -5.000, -0.323, 0.178, -0.524, -0.563, -0.184, -0.139, -0.420, -0.675, -0.051, 0.203, 0.155, -0.642, 0.200, 0.705, -0.223, -0.174, -0.387, 0.339, -0.263, -0.784, 0.081, 0.108, -0.463, -0.486, -0.075, 0.146, -0.406, -0.365, 0.241, 0.562, -0.110, 0.051, -0.244, 0.360, 0.066, -0.550, -0.099, 0.140, -0.043, -0.258, 0.296, 0.235, 0.228, -0.559, -0.174, 0.292, -0.531, -5.000, -1.484, -0.231, -1.071, -5.000, -0.406, -0.186, -0.899, -0.847, -0.838, -0.230, -1.021, -1.218, 0.012, 0.592, 0.292, -5.000, -0.967, -0.192, -0.863, -0.456, -0.389, -0.191, -0.578, -0.894, -0.229, -0.226, -0.363, -0.900, -0.193, 0.295, -0.331, 0.078, -0.673, -0.029, -0.455, -1.210, -0.288, -0.056, -0.367, -0.618, -0.384, 0.116, 0.203, -0.781, -0.359, 0.275, -0.441, 0.029, -0.721, 0.109, -0.336, -0.894, -0.598, -0.217, -0.296, -0.614, -0.251, -0.010, 0.221, -0.530, 0.380, 0.651, -0.399, -5.000, 0.005, 0.381, -0.348, -5.000, -0.333, 0.041, -0.555, -0.531, -0.456, -0.270, -0.493, -0.349, 0.181, 0.665, 0.616, -5.000, -0.156, 0.250, -0.414, -0.050, -0.220, 0.434, -0.055, -0.486, 0.315, 0.375, 0.478, -0.275, 0.444, 0.590, 0.107, 0.323, -0.053, 0.622, -0.017, -0.580, 0.564, 0.609, -0.043, 0.046, 0.517, 0.635, 0.503, 0.150, 0.250, 0.782, 0.246, 0.667, -0.246, 0.604, 0.008, -0.491, -0.486, 0.102, -0.500, -0.847, 0.367, 0.392, 0.735, 0.306, 0.474, 0.776, -0.816, -5.000, -0.292, 0.402, -0.343, -5.000, -0.187, -0.040, -0.969, -0.492, 0.087, 0.146, -0.010, 0.053, 0.562, 0.897, 0.511, -5.000, 0.167, 0.457, 0.273, 0.181, 0.295, 0.528, -0.057, -0.351, 0.410, 0.726, 0.733, -0.514, 0.293, 0.679, -0.286, 0.052, -0.157, 0.529, -0.051, -0.571, 0.153, 0.501, -0.148, -0.043, 0.473, 0.709, 0.479, 0.087, 0.725, 0.931, 0.484, 0.875, 0.316, 0.889, 0.443, -0.085, -0.072, 0.492, 0.016, -0.125, 0.636, 0.665, 0.873, 0.567, 0.788, 1.024, 0.100, -5.000, 0.247, 0.782, -0.156, -5.000, 0.561, 0.616, 0.166, 0.299, 0.379, 0.654, -0.179, -0.194, 0.511, 0.900, 0.398, -5.000, 0.010, 0.577, -0.007, 0.196, 0.453, 0.772, 0.198, -0.072, 0.579, 0.841, 0.710, 0.090, 0.446, 0.707, 0.016, 0.409, 0.037, 0.431, 0.051, -0.572, 0.355, 0.569, 0.011, -0.082, 0.032, 0.211, 0.165, -0.240, 0.604, 0.946, 0.258, 0.732, 0.259, 0.637, 0.615, -0.391, -0.112, 0.514, 0.250, 0.055, 0.749, 0.525, 0.569, 0.246, -0.152, 0.350, -0.294, -5.000, -0.884, 0.097, -0.679, -5.000, -0.293, 0.018, -0.622, -0.450, -0.665, -0.178, -0.685, -0.759, -0.141, 0.554, 0.331, -5.000, -0.742, 0.103, -0.541, -0.611, -0.156, 0.221, -0.491, -0.668, -0.378, 0.101, -0.104, -0.693, -0.940, -0.170, -0.998, -0.838, -1.370, -0.565, -1.054, -1.153, -0.751, -0.212, -0.708, -0.819, -1.335, -0.623, -0.606, -1.292, -0.344, 0.089, -0.726, -0.242, -0.943, -0.069, -0.323, -1.275, -0.743, -0.047, -0.459, -0.738, -0.537, -0.191, -0.253, -0.576, 0.310, 0.562, -0.296, -5.000, -0.100, 0.198, -0.260, -5.000, -0.097, 0.309, -0.191, -0.254, 0.019, 0.278, 0.209, -0.266, 0.010, 0.529, 0.375, -5.000, -0.440, -0.328, -0.314, 0.134, -0.448, 0.165, -0.050, -0.346, 0.348, 0.344, 0.392, -0.259, 0.358, 0.433, 0.056, 0.576, 0.032, 0.520, 0.170, -0.215, 0.653, 0.820, 0.500, 0.513, 0.636, 0.695, 0.589, 0.352, 0.142, 0.356, 0.054, 0.584, 0.009, 0.382, 0.170, -0.529, -0.002, 0.404, 0.285, 0.264, 0.741, 0.559, 0.749, 0.412, 0.564, 0.870, -0.641, -5.000, -0.018, 0.659, -0.577, -5.000, 0.209, 0.343, -0.536, -0.008, 0.526, 0.682, 0.906, 0.314, 0.718, 0.809, 0.582, -5.000, 0.397, 0.577, 0.238, 0.558, 0.184, 0.539, 0.248, 0.013, 0.852, 0.751, 0.822, 0.072, 0.566, 0.754, 0.171, 0.752, 0.438, 0.583, 0.183, -0.181, 0.549, 0.656, 0.306, 0.277, 0.765, 0.712, 0.888, 0.544, 0.547, 0.796, 0.236, 0.789, 0.327, 0.778, 0.642, 0.111, 0.034, 0.444, 0.277, -0.103, 0.778, 0.821, 1.052, 0.757, 0.044, 0.323, -0.740, -5.000, -0.672, 0.097, -0.843, -5.000, -0.259, -0.190, -0.523, -0.271, -0.242, 0.127, -0.604, -0.419, 0.046, 0.519, 0.025, -5.000, -0.447, 0.242, -0.672, -0.204, 0.180, 0.411, -0.165, -0.260, 0.440, 0.557, 0.488, -0.228, -0.117, 0.240, -0.230, -0.082, -0.208, 0.206, -0.090, -0.691, 0.030, 0.233, -0.048, -0.456, 0.042, 0.159, -0.080, -0.370, -0.356, 0.181, -0.428, -0.068, -0.198, 0.089, -0.431, -0.830, -0.287, -0.038, -0.354, -0.496, 0.207, 0.057, -0.215, -0.170, 0.260, 0.446, -0.347, -5.000, -0.581, 0.263, -0.627, -5.000, -0.309, 0.156, -0.603, -0.237, -0.040, -0.028, -1.188, -0.623, 0.408, 0.759, 0.223, -5.000, -0.651, 0.223, -0.516, 0.201, -0.504, -0.156, -0.571, -0.532, 0.407, 0.393, 0.139, -0.234, 0.964, 1.057, 0.638, 0.806, 0.598, 0.883, 0.749, -0.144, 1.150, 0.961, 0.690, 0.637, 1.052, 1.038, 1.023, 0.647, 0.431, 0.627, 0.166, 0.462, 0.353, 0.406, 0.227, -0.329, -0.294, 0.002, 0.125, -0.258, 0.372, 0.112, 0.266, 0.115, -0.111, 0.281, -0.449, -5.000, -0.574, -0.009, -0.824, -5.000, -0.348, -0.221, -0.852, -0.873, 0.163, 0.182, 0.636, -0.098, -0.370, 0.154, 0.059, -5.000, -0.688, -0.172, -0.793, -0.350, -0.480, -0.220, -0.492, -0.809, 0.091, 0.125, 0.361, -0.280, 0.017, 0.524, 0.083, 0.357, -0.406, 0.323, -0.416, -0.838, -0.098, -0.162, -0.779, -0.490, 0.308, 0.426, 0.466, 0.002, -0.364, -0.286, -0.518, -0.223, -0.446, -0.462, -0.727, -1.038, -0.529, -0.162, -0.103, -1.096, -0.022, 0.216, 0.119, -0.212, 0.579, 0.824, -0.656, -5.000, -0.068, 0.462, -0.456, -5.000, 0.129, 0.330, -0.540, -0.196, 0.735, 0.688, 0.829, 0.661, 0.139, 0.526, 0.128, -5.000, -0.038, 0.110, -0.092, 0.164, -0.117, 0.350, 0.139, -0.289, 0.837, 0.635, 0.562, 0.153, 0.589, 0.899, 0.331, 0.651, 0.355, 0.644, -0.154, -0.241, 0.362, 0.599, 0.258, 0.019, 0.763, 0.771, 0.888, 0.641, 0.038, 0.366, -0.164, 0.222, -0.159, 0.281, -0.142, -0.435, -1.037, -0.430, -0.617, -1.077, 0.330, 0.386, 1.129, 0.270, -0.025, 0.254, -0.603, -5.000, -0.997, -0.109, -0.877, -5.000, -0.278, -0.048, -0.492, -0.553, -0.065, 0.128, -0.571, -0.374, -0.373, 0.335, -0.100, -5.000, -0.764, -0.098, -0.718, -0.729, -0.654, -0.069, -0.854, -0.965, 0.274, 0.220, 0.237, -0.248, -0.113, 0.273, -0.130, -0.178, -0.561, -0.043, -0.693, -0.977, 0.057, 0.345, -0.512, -0.298, 0.170, -0.064, -0.251, -0.288, -0.451, -0.168, -0.612, -0.470, -0.492, -0.387, -0.593, -1.318, -1.102, -0.534, -0.625, -1.183, 0.218, 0.174, 0.263, -0.495, -0.506, -0.247, -0.898, -5.000, -1.422, -0.191, -1.303, -5.000, -0.973, -0.513, -1.177, -0.989, -0.868, -0.525, -1.155, -0.900, -0.425, 0.024, -0.328, -5.000, -0.934, -0.552, -1.187, -1.029, -0.559, -0.576, -0.468, -1.228, -0.334, -0.366, -0.455, -0.610, -0.539, -0.117, -0.738, -0.226, -0.954, -0.392, -0.914, -1.211, -0.525, -0.286, -0.920, -0.837, -0.324, -0.148, -0.167, -0.602, -0.578, -0.420, -0.640, -0.720, -0.650, -0.697, -0.809, -1.336, -1.149, -1.218, -1.226, -1.296, -0.904, -0.672, -0.456, -0.672, 0.376, 0.656, -0.315, -5.000, -0.136, 0.414, -0.404, -5.000, 0.057, 0.342, -0.688, -0.309, 0.136, 0.440, 0.060, -0.017, 0.134, 0.541, 0.328, -5.000, -0.166, 0.136, -0.287, 0.063, -0.018, 0.442, 0.059, -0.242, 0.375, 0.561, 0.529, -0.104, 0.258, 0.504, -0.039, 0.453, -0.280, 0.477, -0.126, -0.446, 0.035, 0.319, -0.399, -0.245, 0.425, 0.482, 0.421, 0.238, 0.244, 0.578, -0.016, 0.567, -0.203, 0.358, 0.244, -0.237, -0.094, 0.267, -0.120, -0.251, 0.776, 0.652, 0.891, 0.622, 0.557, 0.824, -0.585, -5.000, -0.329, 0.502, -0.535, -5.000, 0.081, 0.292, -0.669, -0.380, 0.569, 0.422, 0.957, 0.243, 0.316, 0.677, 0.461, -5.000, -0.262, 0.534, -0.090, 0.128, 0.083, 0.560, -0.324, -0.393, 0.642, 0.600, 0.786, -0.344, 0.349, 0.685, 0.227, 0.420, -0.121, 0.536, -0.248, -0.339, 0.186, 0.397, -0.068, -0.208, 0.720, 0.699, 0.635, 0.193, 0.492, 0.667, 0.210, 0.578, 0.120, 0.494, 0.201, -0.292, -0.080, 0.383, -0.033, -0.382, 0.812, 0.804, 1.046, 0.607, -0.113, 0.248, -0.557, -5.000, -0.584, -0.164, -1.291, -5.000, -0.241, -0.470, -0.800, -0.454, -0.222, -0.127, -0.470, -0.644, 0.009, 0.265, -0.072, -5.000, -0.531, -0.121, -0.890, -0.609, -0.189, -0.297, -0.519, -0.665, 0.087, 0.181, 0.306, -0.664, 0.110, 0.381, 0.030, -0.211, -0.231, 0.189, -0.478, -0.734, -0.033, -0.124, -0.520, -0.697, -0.036, 0.071, -0.114, -0.373, 0.085, 0.377, -0.194, 0.137, -0.157, 0.257, -0.348, -0.725, -0.199, 0.072, -0.335, -0.257, 0.208, 0.238, 0.287, -0.172, -0.065, 0.377, -0.560, -5.000, -1.074, -0.262, -0.985, -5.000, -0.529, -0.051, -0.541, -0.627, -0.361, -0.239, -0.621, -0.589, -0.016, 0.423, 0.117, -5.000, -0.745, -0.435, -0.940, -0.488, -0.335, -0.282, -0.506, -0.627, 0.132, 0.030, -0.239, -0.570, -0.146, 0.177, -0.203, -0.156, -0.740, 0.061, -0.476, -0.884, -0.196, -0.067, -0.289, -0.610, 0.008, 0.162, 0.202, -0.421, -0.298, 0.250, -0.452, 0.020, -0.596, -0.038, -0.236, -0.819, -0.389, -0.159, -0.289, -0.522, 0.040, 0.256, 0.445, -0.170, 0.480, 0.646, -0.254, -5.000, 0.048, 0.430, -0.273, -5.000, -0.002, 0.300, -0.712, -0.440, -0.208, 0.194, 0.054, -0.395, 0.351, 0.877, 0.481, -5.000, 0.133, 0.511, -0.048, 0.264, -0.023, 0.544, 0.001, -0.157, 0.469, 0.705, 0.615, -0.073, 0.530, 0.491, 0.141, 0.517, -0.027, 0.526, -0.039, -0.580, 0.649, 0.435, -0.305, 0.073, 0.513, 0.573, 0.383, 0.069, 0.418, 0.829, 0.432, 0.730, -0.055, 0.656, 0.316, -0.205, 0.186, 0.545, -0.178, -0.308, 0.823, 0.818, 1.061, 0.674, 0.567, 0.686, -0.373, -5.000, -0.011, 0.519, -0.853, -5.000, 0.128, 0.171, -0.538, -0.048, 0.257, 0.386, 0.233, 0.030, 0.511, 0.748, 0.403, -5.000, 0.318, 0.738, 0.183, 0.460, 0.412, 0.693, 0.211, -0.124, 0.478, 0.864, 0.721, -0.057, 0.450, 0.749, 0.100, 0.409, -0.010, 0.591, -0.077, -0.563, 0.277, 0.432, -0.024, -0.205, 0.575, 0.612, 0.382, 0.219, 0.805, 0.972, 0.537, 0.851, 0.584, 0.768, 0.598, 0.058, 0.262, 0.596, 0.145, 0.020, 0.960, 0.909, 0.916, 0.734, 0.684, 0.830, 0.101, -5.000, -0.038, 0.599, -0.308, -5.000, 0.464, 0.481, -0.126, 0.184, 0.306, 0.508, -0.193, -0.244, 0.417, 0.759, 0.393, -5.000, -0.047, 0.645, -0.132, 0.205, 0.489, 0.707, 0.124, 0.160, 0.630, 0.890, 0.727, 0.280, 0.394, 0.665, -0.049, 0.450, 0.019, 0.502, -0.060, -0.391, 0.380, 0.416, -0.137, -0.067, 0.184, 0.333, -0.056, -0.145, 0.478, 0.656, 0.248, 0.604, 0.239, 0.643, 0.385, -0.420, 0.062, 0.366, 0.037, 0.055, 0.852, 0.570, 0.555, 0.351, 0.280, 0.511, -0.263, -5.000, -0.763, 0.155, -0.443, -5.000, 0.064, 0.292, -0.600, -0.150, -0.213, -0.001, -0.476, -0.461, 0.246, 0.678, 0.209, -5.000, -0.383, 0.263, -0.435, -0.132, 0.026, 0.322, -0.019, -0.130, 0.231, 0.532, 0.275, -0.266, 0.167, 0.345, -0.072, 0.305, -0.362, 0.057, -0.347, -0.828, 0.038, 0.021, -0.292, -0.430, -0.181, -0.081, 0.004, -0.424, 0.109, 0.467, -0.001, 0.220, -0.161, 0.075, 0.096, -0.648, -0.480, -0.108, -0.222, -0.477, 0.026, 0.021, 0.214, -0.289, 0.087, 0.251, -0.264, -5.000, -0.255, -0.125, -0.602, -5.000, 0.043, 0.441, -0.223, -0.020, -0.014, 0.290, 0.056, -0.039, -0.056, 0.296, 0.159, -5.000, -0.363, -0.263, -0.477, -0.079, -0.346, 0.033, -0.121, -0.248, 0.391, 0.233, 0.218, -0.060, 0.291, 0.414, 0.281, 0.636, -0.118, 0.231, -0.042, -0.349, 0.873, 0.849, 0.368, 0.589, 0.716, 0.751, 0.759, 0.354, 0.097, 0.287, -0.010, 0.345, -0.056, 0.060, -0.091, -0.258, 0.295, 0.874, 0.554, 0.143, 0.484, 0.412, 0.626, 0.246, 0.541, 0.773, -0.900, -5.000, -0.132, 0.369, -0.966, -5.000, -0.056, -0.080, -0.982, -0.237, 0.597, 0.499, 0.436, 0.362, 0.694, 0.871, 0.424, -5.000, 0.377, 0.438, -0.061, 0.489, 0.129, 0.625, 0.290, 0.138, 0.640, 0.761, 0.640, 0.008, 0.519, 0.658, 0.193, 0.652, 0.190, 0.450, -0.132, -0.138, 0.604, 0.624, 0.361, 0.254, 0.809, 0.804, 0.825, 0.518, 0.496, 0.690, 0.226, 0.707, 0.432, 0.589, 0.518, 0.007, 0.150, 0.366, 0.174, -0.111, 0.601, 0.624, 0.933, 0.643, -0.052, 0.228, -0.671, -5.000, -0.560, -0.079, -1.291, -5.000, -0.194, 0.012, -0.478, -0.162, 0.039, 0.259, -1.052, -0.271, 0.037, 0.488, -0.018, -5.000, -0.628, 0.013, -0.503, -0.314, -0.122, 0.082, -0.315, -0.269, 0.350, 0.575, 0.299, 0.020, -0.117, 0.156, -0.462, -0.039, -0.182, 0.123, -0.560, -0.696, 0.342, 0.225, -0.193, -0.147, 0.021, 0.059, -0.242, -0.405, -0.228, 0.002, -0.471, -0.120, -0.221, -0.069, -0.288, -0.666, -0.548, 0.093, -0.261, -0.384, 0.205, 0.064, -0.124, -0.176, 0.158, 0.265, -0.755, -5.000, -0.580, -0.059, -0.937, -5.000, -0.306, 0.031, -0.832, -0.468, -0.142, -0.429, -0.987, -0.429, 0.419, 0.866, 0.237, -5.000, -0.324, 0.194, -0.420, -0.055, -0.029, 0.258, -0.222, -0.308, 0.431, 0.651, 0.096, -0.092, 0.847, 0.979, 0.475, 0.760, 0.475, 0.584, 0.264, -0.144, 1.172, 1.033, 0.900, 0.827, 0.945, 1.159, 0.928, 0.524, 0.323, 0.520, -0.270, 0.321, 0.256, 0.195, 0.019, -0.422, -0.156, -0.070, -0.154, -0.478, 0.291, -0.078, -0.085, 0.134, -0.203, 0.104, -0.560, -5.000, -0.331, -0.027, -0.772, -5.000, -0.423, -0.101, -0.462, -0.522, 0.083, 0.326, -0.821, -0.051, -0.327, 0.128, 0.135, -5.000, -0.625, -0.262, -0.751, -0.862, -0.853, -0.137, -0.644, -0.980, 0.267, 0.176, 0.258, -0.251, 0.132, 0.647, 0.032, 0.401, -0.283, 0.263, -0.255, -0.522, -0.197, -0.061, -1.008, -0.748, 0.358, 0.538, 0.470, 0.164, -0.335, -0.268, -0.571, -0.071, -0.504, -0.428, -0.695, -1.199, -0.147, 0.030, 0.282, -0.179, -0.153, 0.106, -0.000, 0.182, 0.377, 0.634, -0.880, -5.000, -0.345, 0.325, -0.876, -5.000, 0.089, 0.183, -0.506, -0.145, 0.354, 0.436, 0.436, 0.279, 0.208, 0.519, 0.165, -5.000, -0.330, 0.159, -0.363, 0.258, -0.065, 0.375, -0.024, -0.230, 0.698, 0.620, 0.655, 0.392, 0.372, 0.624, 0.108, 0.469, 0.154, 0.422, -0.242, -0.088, 0.433, 0.607, 0.131, -0.016, 0.797, 0.842, 1.032, 0.722, -0.133, 0.345, -0.301, 0.107, -0.009, 0.395, 0.033, -0.513, -0.658, -0.370, -0.205, -1.189, 0.489, 0.548, 1.079, 0.472, 0.229, 0.540, -0.523, -5.000, -0.315, 0.205, -0.941, -5.000, -0.039, 0.236, -0.634, -0.211, 0.239, 0.323, -0.652, 0.098, -0.049, 0.471, 0.061, -5.000, -0.552, 0.004, -0.590, -0.569, -0.375, 0.039, -0.686, -0.618, 0.374, 0.413, 0.437, 0.176, 0.155, 0.439, -0.354, 0.040, -0.050, 0.007, -0.510, -1.037, 0.316, 0.394, -0.093, -0.053, 0.344, 0.198, -0.144, -0.223, -0.019, 0.294, -0.369, -0.231, -0.438, -0.124, -0.303, -1.023, -0.241, 0.081, -0.631, -0.863, 0.428, 0.357, 0.308, -0.192, -0.398, -0.429, -1.165, -5.000, -1.035, -0.649, -1.445, -5.000, -1.286, -0.586, -1.480, -0.948, -0.664, -0.615, -1.301, -0.704, -0.602, -0.066, -0.481, -5.000, -1.063, -0.535, -1.216, -0.977, -0.747, -0.536, -0.603, -0.839, -0.213, 0.003, -0.410, -0.482, -0.447, -0.171, -0.393, -0.263, -0.741, -0.568, -1.072, -1.050, -0.275, -0.223, -0.645, -0.798, -0.141, 0.194, 0.053, -0.507, -0.561, -0.606, -0.893, -0.643, -0.740, -0.538, -0.954, -1.103, -1.217, -0.963, -1.401, -1.232, -0.448, -0.685, -0.377, -0.806, -0.452, -0.253, -0.970, -5.000, -0.794, -0.434, -1.454, -5.000, -0.487, -0.288, -0.684, -0.898, -0.180, -0.246, -0.090, -0.194, -0.245, 0.028, -0.171, -5.000, -0.588, -0.327, -1.055, -0.400, -0.282, -0.190, -0.523, -0.334, 0.257, 0.278, 0.241, -0.236, -0.173, -0.022, -0.181, -0.180, -0.332, -0.255, -0.566, -0.950, -0.275, -0.074, -0.431, -0.425, 0.161, 0.195, 0.020, -0.046, -0.288, 0.060, -0.350, -0.065, -0.500, -0.264, -0.254, -1.013, -0.587, 0.158, -0.316, -0.789, 0.270, 0.390, 0.573, 0.124, 0.208, 0.474, -1.233, -5.000, -0.500, 0.181, -1.007, -5.000, -0.360, -0.088, -0.750, -0.589, 0.343, 0.417, 0.282, 0.172, 0.409, 0.762, 0.274, -5.000, -0.348, 0.325, -0.471, 0.013, -0.158, 0.412, -0.265, -0.348, 0.445, 0.728, 0.495, -0.013, 0.078, 0.493, -0.068, -0.001, -0.169, 0.187, -0.545, -0.600, 0.075, 0.346, -0.353, -0.306, 0.513, 0.610, 0.545, -0.033, 0.133, 0.444, -0.070, 0.251, -0.354, 0.090, -0.204, -0.642, -0.479, -0.202, -0.504, -0.504, 0.455, 0.430, 0.880, 0.286, -0.109, 0.022, -0.858, -5.000, -0.649, -0.255, -1.085, -5.000, -0.245, -0.491, -1.070, -0.735, -0.362, -0.415, -0.728, -0.666, 0.103, 0.244, -0.192, -5.000, -0.625, -0.191, -0.703, -0.794, -0.181, -0.203, -0.709, -0.610, 0.181, 0.328, 0.194, -0.415, 0.067, 0.409, -0.452, -0.494, -0.375, 0.088, -0.468, -0.609, 0.002, -0.279, -0.462, -0.381, -0.117, 0.061, -0.296, -0.309, 0.207, 0.483, -0.164, -0.124, -0.210, 0.177, -0.168, -0.403, -0.083, -0.101, -0.343, -0.425, 0.403, 0.189, 0.237, -0.214, -0.302, -0.054, -0.792, -5.000, -1.213, -0.786, -1.379, -5.000, -0.473, -0.260, -0.911, -0.669, -0.698, -0.545, -1.203, -1.011, -0.236, 0.452, -0.225, -5.000, -0.682, -0.523, -1.351, -0.629, -1.023, -0.453, -0.708, -0.734, -0.126, -0.252, -0.410, -0.458, -0.395, 0.130, -0.319, -0.227, -0.790, -0.298, -0.649, -1.155, -0.273, -0.073, -0.340, -0.610, -0.173, 0.267, 0.147, -0.400, -0.488, -0.114, -0.603, -0.534, -0.561, -0.196, -0.411, -1.230, -0.689, -0.413, -0.537, -0.797, -0.267, -0.169, -0.080, -0.505, 0.367, 0.740, -0.486, -5.000, 0.050, 0.404, -0.491, -5.000, -0.020, 0.410, -0.189, -0.171, -0.097, 0.208, -0.385, 0.007, 0.435, 0.831, 0.604, -5.000, 0.049, 0.393, -0.219, 0.015, 0.238, 0.548, 0.159, -0.039, 0.461, 0.609, 0.563, -0.083, 0.428, 0.529, 0.044, 0.500, -0.045, 0.492, -0.041, -0.566, 0.780, 0.605, -0.114, 0.099, 0.678, 0.637, 0.495, 0.133, 0.421, 0.841, 0.367, 0.379, 0.218, 0.660, 0.275, -0.264, 0.233, 0.623, 0.190, 0.106, 0.618, 0.773, 0.875, 0.475, 0.340, 0.491, -1.163, -5.000, -0.113, 0.012, -0.886, -5.000, -0.184, -0.145, -0.477, -0.453, 0.009, 0.429, -0.075, 0.217, 0.746, 0.918, 0.423, -5.000, 0.196, 0.519, -0.082, 0.125, 0.350, 0.606, 0.105, 0.131, 0.542, 0.801, 0.727, -0.029, 0.162, 0.427, -0.060, 0.156, -0.008, 0.414, -0.402, -0.679, 0.145, 0.377, -0.240, 0.076, 0.521, 0.676, 0.284, 0.140, 0.562, 0.666, 0.223, 0.644, 0.166, 0.547, 0.170, -0.086, 0.055, 0.358, 0.029, -0.090, 0.636, 0.655, 0.891, 0.431, 0.769, 1.019, 0.099, -5.000, 0.319, 0.659, -0.271, -5.000, 0.785, 0.571, -0.147, 0.373, 0.362, 0.559, -0.245, -0.106, 0.736, 0.935, 0.540, -5.000, 0.243, 0.634, -0.079, 0.289, 0.774, 0.901, 0.372, 0.385, 0.796, 0.997, 0.917, 0.304, 0.479, 0.711, -0.096, 0.425, 0.228, 0.610, 0.005, -0.431, 0.426, 0.586, -0.167, 0.026, 0.287, 0.256, 0.036, -0.131, 0.706, 0.942, 0.354, 0.669, 0.403, 0.736, 0.483, -0.248, 0.152, 0.579, 0.083, 0.188, 0.849, 0.631, 0.644, 0.451, 0.282, 0.466, -0.412, -5.000, -0.493, 0.048, -0.683, -5.000, 0.055, 0.280, -0.365, -0.158, -0.221, -0.005, -0.473, -0.481, 0.399, 0.725, 0.292, -5.000, -0.278, 0.298, -0.334, -0.114, 0.226, 0.474, 0.074, -0.154, 0.268, 0.466, 0.318, -0.146, 0.290, 0.419, -0.041, 0.167, -0.218, 0.074, -0.479, -0.775, 0.195, 0.044, -0.075, -0.367, 0.033, 0.337, 0.050, -0.247, 0.183, 0.507, -0.051, 0.102, -0.080, 0.286, 0.009, -0.760, -0.224, 0.010, -0.244, -0.500, 0.069, 0.059, 0.001, -0.142 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_22(struct _training *tptr) {
  struct _training tinf = {
    0.283, 11, 4.350, { 2.623, 0.276, 0.101 }, { 0.419, -0.669, -1.189 }, 1, 
    { -2.099, -2.337, -2.067, -1.140, -1.610, -1.830, -0.463, 1.461, -1.342, -2.169, -0.124, -4.000, 0.598, -0.108, 1.928, 0.646, 1.766, 1.957, -0.993, 2.090, 1.326, 0.464, 2.334, 0.646, 2.669, 2.460, 1.919, 2.755 }, 
    {{ -0.013, -0.536, -0.616, 0.306},{ 0.240, -0.484, -0.488, 0.032},{ 0.276, 0.363, -1.198, -0.242},{ 0.239, 0.154, -1.052, -0.082},{ 0.240, 0.058, -0.799, -0.081},{ 0.207, -0.079, -0.841, 0.024},{ 0.212, -0.146, -0.754, 0.026},{ 0.243, -0.212, -0.597, -0.023},{ 0.219, -0.322, -0.586, 0.038},{ 0.251, -0.232, -0.699, -0.005},{ 0.236, -0.322, -0.667, 0.034},{ 0.246, -0.277, -0.635, 0.003},{ 0.227, -0.297, -0.620, 0.028},{ 0.230, -0.160, -0.590, -0.025},{ 0.279, -0.267, -0.675, -0.037},{ 0.188, -0.197, -0.518, 0.024},{ 0.237, -0.108, -0.586, -0.054},{ 0.222, -0.101, -0.687, -0.014},{ 0.202, -0.157, -0.683, 0.029},{ 0.215, -0.141, -0.651, 0.001},{ 0.191, -0.038, -0.557, -0.028},{ 0.215, -0.057, -0.635, -0.033},{ 0.194, -0.106, -0.651, 0.015},{ 0.201, -0.088, -0.579, -0.016},{ 0.247, -0.095, -0.575, -0.074},{ 0.196, -0.066, -0.582, -0.018},{ 0.195, -0.059, -0.522, -0.033},{ 0.192, -0.044, -0.568, -0.023},{ 0.167, 0.012, -0.561, -0.018},{ 0.188, 0.020, -0.543, -0.050},{ 0.151, -0.061, -0.593, 0.036},{ 0.127, 0.014, -0.471, 0.007} }, 
    {{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}} }, 
    0.000, { 0.574, 1.194, 0.275, -5.000, 0.078, 0.969, -0.567, -5.000, 0.361, 0.923, 0.190, 0.340, 0.547, 0.807, -0.215, 0.543, 0.050, 0.390, -0.873, -5.000, -0.999, 0.611, -1.597, -0.282, -0.132, 0.439, 0.002, -0.181, 0.568, 0.170, -1.129, -0.149, 0.146, 0.770, -0.492, -0.400, -0.143, 0.528, -0.339, -0.572, -0.546, 0.216, -0.330, -0.945, -0.782, -0.520, -0.846, -0.788, 0.605, 1.286, 0.043, 0.065, 0.423, 1.204, 0.170, -0.133, 0.602, 1.117, 0.764, 0.353, 0.097, 0.909, 0.372, 0.102, 1.238, 1.548, 0.910, -5.000, 1.126, 1.524, 0.591, -5.000, 1.285, 1.550, 1.420, 1.223, 1.206, 1.451, 0.735, 1.167, 0.920, 1.200, 0.064, -5.000, 0.325, 0.918, -0.437, 0.284, 0.696, 0.982, 0.851, 0.363, 0.859, 0.480, -0.886, 0.049, 0.997, 1.434, 0.636, 0.716, 0.924, 1.203, 0.347, 0.610, 0.371, 0.637, 0.423, 0.451, 0.423, 0.532, 0.410, 0.500, 1.204, 1.590, 0.804, 0.876, 1.268, 1.324, 0.991, 0.941, 1.017, 1.260, 0.902, 0.666, 0.959, 1.238, 0.667, 0.824, 0.487, 1.017, 0.313, -5.000, 0.571, 1.188, -0.112, -5.000, 0.428, 0.890, 0.384, 0.322, 0.307, 0.580, -0.521, 0.016, 0.141, 0.632, -0.301, -5.000, -0.191, 0.400, -1.124, -0.154, -0.017, 0.441, -0.584, -0.740, 0.306, -0.271, -1.290, -0.548, -0.263, 0.493, -1.068, -0.956, -0.284, 0.451, -0.692, -0.771, -0.152, 0.176, -0.809, -0.573, -0.925, -0.719, -1.469, -0.784, 0.483, 1.168, -0.460, -0.253, 0.482, 1.278, 0.229, -0.104, 0.891, 1.381, 0.680, 0.728, 0.336, 0.899, 0.136, -0.183, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.062, 1.097, 0.337, -5.000, -0.272, 0.908, -1.018, -5.000, 0.544, 1.045, 0.690, 0.490, 0.730, 1.048, 0.146, 0.855, -0.259, 0.667, -0.315, -5.000, -1.477, -0.158, -2.398, -0.680, 0.167, 0.438, 0.158, -0.441, 0.773, 0.321, -0.800, 0.128, -0.532, 0.492, -0.242, -1.036, -1.132, -0.069, -0.850, -1.417, -1.462, -0.188, -1.263, -1.432, -1.347, -0.911, -1.329, -1.157, 0.269, 1.181, 0.006, -0.298, -0.212, 0.826, -0.029, -0.628, 0.568, 1.257, 0.678, 0.281, -0.374, 0.816, 0.266, -0.171, 0.679, 1.456, 1.083, -5.000, 0.521, 1.219, 0.427, -5.000, 1.292, 1.566, 1.418, 1.206, 1.265, 1.498, 1.061, 1.253, 0.968, 1.132, 0.418, -5.000, 0.082, 0.772, -1.276, 0.805, 0.810, 1.463, 0.951, 0.488, 1.196, 0.862, -0.377, 0.376, 0.825, 1.283, 0.679, 0.575, 0.312, 1.468, -0.030, 0.404, 0.081, 0.948, 0.270, 0.269, 0.536, 0.944, 0.364, 0.698, 0.934, 1.448, 0.780, 0.631, 0.989, 1.541, 0.802, 0.781, 1.009, 1.252, 0.717, 0.584, 0.743, 1.273, 0.808, 0.948, -0.007, 0.652, -0.077, -5.000, -0.314, 0.357, -0.794, -5.000, -0.005, 0.413, 0.395, -0.002, -0.415, 0.452, -1.431, -0.571, -0.443, 0.103, -1.470, -5.000, -0.637, -0.172, -5.000, -0.549, -5.000, 0.201, -0.689, -0.506, 0.069, -0.122, -1.753, -0.319, -0.860, 0.518, -1.848, -0.905, -0.101, -1.047, -1.341, -0.698, -0.348, -0.570, 0.352, -0.979, -1.060, -1.140, -0.971, -1.124, -0.371, 0.485, -0.511, -0.730, -0.612, 0.374, 1.454, -0.618, 0.395, -0.053, -0.685, -0.061, -0.275, 0.124, -0.323, -1.066, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.338, 1.087, 0.387, -5.000, 0.329, 1.199, -0.379, -5.000, 0.400, 0.876, 0.689, 0.177, 0.622, 0.913, -0.056, 0.502, 0.007, 0.258, -0.351, -5.000, -0.706, 0.217, -0.748, -0.095, -0.101, 0.652, 0.445, -0.484, 0.957, 0.340, -0.697, 0.150, 0.117, 0.612, -0.185, -0.333, -0.289, 0.617, -0.905, -0.770, -0.258, 0.277, -0.672, -0.773, -0.623, 0.049, -0.639, -0.440, 0.424, 1.074, 0.194, 0.228, 0.346, 1.072, 0.353, 0.019, 0.618, 0.982, 0.495, 0.091, 0.268, 0.927, 0.627, 0.224, 0.782, 1.355, 0.772, -5.000, 0.839, 1.471, -0.164, -5.000, 1.061, 1.375, 1.067, 0.747, 0.914, 1.209, 0.249, 0.920, 0.715, 1.208, 0.293, -5.000, 0.280, 1.261, 0.236, 0.727, 0.565, 1.131, 0.510, 0.401, 1.085, 0.856, -0.721, 0.307, 0.628, 0.871, 0.605, 0.323, 0.497, 0.965, 0.601, 0.049, 0.192, 0.679, 0.016, -0.026, 0.612, 0.626, 0.241, 0.262, 0.918, 1.358, 0.779, 0.789, 0.990, 1.310, 1.059, 0.763, 0.832, 0.902, 0.119, 0.256, 0.786, 1.046, 0.711, 0.697, 0.651, 0.951, 0.467, -5.000, 0.813, 1.304, 0.098, -5.000, 0.684, 0.854, 0.025, 0.413, 0.634, 0.828, -0.227, 0.463, 0.328, 0.723, -0.213, -5.000, -0.078, 0.512, -1.693, 0.178, 0.235, 0.734, -0.343, -0.085, 0.687, 0.643, -0.936, -0.060, 0.208, 0.976, -0.059, -0.565, -0.265, 0.736, -0.805, -0.227, -0.166, -0.226, -0.938, -0.888, -0.560, -0.215, -1.038, -0.057, 0.468, 1.171, 0.073, 0.115, 0.213, 0.706, 0.264, 0.021, 0.459, 0.471, -0.618, -0.423, 0.284, 0.563, -0.033, -0.415, 0.271, 0.816, 0.309, -5.000, 0.018, 0.833, -0.821, -5.000, 0.247, 0.709, 0.090, -0.470, 0.320, 0.626, -0.315, 0.131, 0.057, 0.664, -0.231, -5.000, -0.762, 0.330, -1.666, 0.058, -0.282, 0.438, -0.408, -1.056, 0.700, 0.614, -1.018, -0.191, -0.339, 0.628, -0.538, -0.560, -0.786, 0.256, -0.531, -0.766, -0.300, 0.131, -0.315, -0.645, -0.786, -0.387, -1.111, -0.236, 0.142, 0.910, -0.017, -0.008, 0.129, 0.721, 0.383, -0.384, 0.012, 0.497, -0.117, -0.468, -0.030, 0.583, -0.070, -0.253, 0.433, 1.214, 0.246, -5.000, 0.560, 1.184, -0.276, -5.000, 0.327, 0.788, 0.529, 0.124, 0.463, 0.762, -0.496, 0.343, 0.023, 0.518, -0.698, -5.000, -0.832, 0.434, -1.409, -0.229, -0.459, 0.423, -0.141, -0.571, 0.498, -0.143, -1.662, -0.334, 0.190, 0.792, -0.419, -0.336, 0.029, 0.721, -0.668, -0.620, -0.026, 0.499, -0.619, -0.420, -0.703, -0.319, -0.998, -0.809, 0.575, 1.197, 0.001, 0.116, 0.538, 1.157, 0.187, -0.012, 0.719, 1.133, 0.606, 0.314, 0.168, 0.908, 0.439, 0.095, 0.748, 1.274, 0.575, -5.000, 0.840, 1.260, 0.195, -5.000, 0.944, 1.357, 1.032, 0.839, 0.811, 1.155, 0.032, 0.808, 0.491, 0.814, -0.342, -5.000, 0.184, 1.153, -0.287, 0.471, 0.649, 0.982, 0.158, -0.175, 0.542, 0.398, -1.546, -0.252, 0.563, 1.029, 0.498, 0.224, 0.777, 0.956, 0.250, 0.537, 0.444, 0.914, 0.074, 0.349, -0.269, 0.057, 0.018, 0.204, 0.960, 1.404, 0.548, 0.686, 0.934, 1.228, 0.540, 0.481, 0.963, 1.082, 0.535, 0.593, 0.502, 1.012, 0.328, 0.479, 0.108, 0.635, -0.637, -5.000, 0.281, 1.044, -0.468, -5.000, 0.192, 0.619, -0.094, -0.257, -0.005, 0.267, -1.341, -0.529, -0.358, 0.054, -1.077, -5.000, -0.522, 0.346, -1.234, -0.615, -0.473, 0.133, -0.676, -0.649, 0.063, -0.238, -2.554, -0.644, -0.712, -0.347, -1.913, -1.545, -0.967, 0.076, -1.680, -1.272, -0.335, 0.237, -1.239, -0.473, -1.509, -1.177, -1.719, -1.324, -0.335, 0.334, -1.556, -1.061, -0.243, 0.149, -1.047, -1.038, -0.135, 0.351, -0.721, -0.513, -0.790, -0.205, -1.255, -1.259, 0.533, 1.177, 0.357, -5.000, 0.563, 1.182, -0.061, -5.000, 0.557, 0.921, 0.119, -0.106, 0.431, 0.734, -0.535, 0.081, 0.140, 0.722, -0.320, -5.000, -0.479, 0.676, -1.176, 0.102, 0.290, 0.649, -0.390, -0.935, 0.469, 0.305, -1.222, -0.220, 0.135, 0.733, -0.575, -0.402, 0.062, 0.478, -0.493, -0.780, 0.302, 0.709, -0.508, -0.229, -0.551, -0.206, -1.473, -0.341, 0.453, 1.092, -0.241, -0.080, 0.401, 0.695, -0.178, -0.276, 0.571, 0.946, -0.001, -0.075, 0.058, 0.637, -0.055, -0.195, 0.208, 1.020, 0.077, -5.000, -0.150, 0.795, -0.830, -5.000, 0.373, 0.882, 0.436, 0.439, 0.210, 0.552, -0.711, 0.247, -0.651, -0.089, -1.339, -5.000, -1.540, -0.238, -2.026, -0.917, -0.376, -0.198, -0.626, -0.659, -0.052, -0.581, -1.531, -0.801, -0.289, 0.431, -0.889, -0.943, -0.413, 0.360, -1.242, -0.940, -1.013, -0.109, -0.632, -0.878, -0.940, -0.587, -1.637, -1.296, 0.466, 1.255, -0.463, -0.229, 0.294, 1.150, -0.053, -0.413, 0.628, 1.113, 0.760, 0.289, 0.079, 0.901, 0.405, -0.019, 0.781, 1.285, 0.238, -5.000, 0.786, 1.214, 0.024, -5.000, 1.047, 1.414, 1.408, 1.131, 0.869, 1.117, 0.171, 0.769, 0.074, 0.435, -0.852, -5.000, -0.353, 0.477, -1.360, -0.570, 0.170, 0.151, 0.477, -0.071, 0.180, -0.325, -1.631, -0.552, 0.674, 1.135, -0.568, 0.298, 0.288, 0.701, -0.144, 0.241, 0.285, 0.865, 0.144, 0.531, 0.378, -0.072, -0.086, 0.122, 0.966, 1.512, 0.183, 0.565, 0.950, 1.279, 0.061, 0.588, 0.877, 1.075, 0.572, 0.738, 0.695, 0.992, 0.005, 0.418, -0.091, 0.563, -0.409, -5.000, 0.393, 0.815, -0.462, -5.000, 0.089, 0.635, 0.174, 0.174, -0.309, -0.097, -1.369, -0.599, -0.469, -0.037, -1.411, -5.000, -0.657, -0.175, -1.638, -1.065, -0.587, 0.528, -0.680, -1.060, -0.516, -0.684, -1.898, -1.055, -1.007, -0.419, -1.693, -2.239, -1.216, -0.392, -1.218, -1.457, -1.325, -0.061, -0.517, -0.826, -1.731, -0.969, -2.091, -1.471, -0.154, 0.608, -1.143, -0.978, 0.294, 0.824, 0.241, -0.504, 0.405, 0.922, 0.188, 0.422, -0.319, 0.270, -0.538, -0.650, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.717, 0.296, -0.752, -5.000, -0.943, 0.034, -1.152, -5.000, -0.335, 0.290, -0.065, -0.332, -0.316, 0.166, -0.802, -0.009, -1.306, -0.437, -1.338, -5.000, -1.236, -0.929, -2.191, -1.277, -1.414, -0.549, 0.109, -1.666, -0.371, -0.668, -1.322, -0.929, -1.603, -0.784, -1.725, -2.054, -1.958, -0.951, -1.571, -1.827, -2.202, -1.283, -1.976, -1.886, -1.778, -1.648, -0.962, -2.637, -0.530, 0.757, -0.953, -1.141, -1.061, 0.175, -0.751, -1.346, -0.351, 0.731, 0.010, -0.283, -1.198, 0.086, -0.617, -1.165, 0.233, 1.052, 0.352, -5.000, 0.077, 0.745, -0.144, -5.000, 0.807, 1.346, 0.980, 0.862, 0.800, 1.151, 0.327, 0.922, 0.127, 0.814, -0.070, -5.000, -0.539, 0.160, -1.465, -0.339, 0.420, 0.987, -0.094, 0.352, 0.495, 0.239, -0.747, -0.005, 0.009, 0.492, 0.327, -0.222, -1.227, 1.145, -0.794, -0.079, -0.503, 0.383, -0.837, 0.227, 0.007, 0.343, -0.326, 0.256, 0.247, 0.949, -0.081, -0.131, 0.260, 1.140, -0.336, -0.008, 0.556, 0.902, 0.164, 0.379, -0.030, 0.632, 0.179, 0.218, -1.150, -0.367, -0.867, -5.000, -1.441, -0.295, -2.034, -5.000, -0.134, -0.629, -0.930, 0.180, -1.390, -0.784, -0.991, -1.178, -1.737, -0.729, -2.095, -5.000, -1.935, -1.405, -1.540, -3.051, -0.528, -1.155, 0.262, -0.352, -1.574, -0.359, -1.833, -1.614, -2.446, -1.170, -1.017, -1.900, -2.180, -5.000, -0.431, -3.101, -1.956, 0.310, -0.020, -1.976, -2.794, -0.731, -1.087, -3.734, -1.312, 0.106, -1.013, -1.114, -1.051, -0.189, 0.090, -2.080, -1.120, -0.261, -0.921, -1.619, -1.162, -0.326, -0.583, -1.510, -0.109, 0.522, 0.024, -5.000, -0.666, 0.594, -1.044, -5.000, -0.048, 0.443, -0.331, -0.526, -0.495, -0.019, -1.036, -0.478, -0.321, 0.500, -0.464, -5.000, -1.366, -0.202, -1.494, -0.726, -0.079, -0.036, -0.237, -0.616, -0.071, -0.144, -1.406, -0.849, -0.198, 0.650, -0.897, -1.098, -1.139, 0.187, -0.101, -1.442, -0.726, -0.045, -0.665, -1.152, -1.676, -0.622, -1.951, -1.312, 0.193, 0.902, -0.488, -0.473, -0.242, 0.708, -0.440, -1.175, 0.117, 0.722, 0.470, -0.085, -0.427, 0.306, -0.399, -0.403, 0.017, 0.824, 0.275, -5.000, -0.178, 0.846, -1.155, -5.000, -0.191, 0.371, 0.094, -0.136, -0.138, 0.455, -0.726, 0.280, -0.611, -0.346, -0.968, -5.000, -1.301, -0.103, -1.109, -0.457, -1.530, 0.886, -0.315, -1.590, 0.090, -0.026, -0.975, -0.176, 0.008, -0.528, -1.309, -1.175, 0.073, -0.247, -5.000, -1.101, -1.109, -0.640, -1.540, -0.730, -0.481, -2.446, -1.443, -1.098, 0.156, 0.843, -0.243, -0.311, 0.161, 0.774, -1.396, -0.585, 0.497, 0.738, 0.018, 0.046, 0.068, 0.411, 0.409, -0.141, 0.450, 1.230, 0.914, -5.000, 0.281, 1.243, 0.308, -5.000, 0.912, 1.316, 0.746, 0.754, 0.627, 0.989, -0.010, 0.648, -0.050, 0.348, -0.066, -5.000, -0.515, 0.340, -0.431, -0.063, -0.515, 0.479, 0.262, 0.364, 0.612, 0.088, -0.679, -0.235, 0.327, 0.187, -1.008, -0.261, -0.144, 0.924, -0.703, 0.090, -0.144, 0.663, 0.505, -0.030, -0.462, 0.064, -0.837, 0.647, 0.701, 1.177, 0.727, 0.602, 0.625, 0.795, 1.134, 0.571, 0.683, 0.983, -0.067, 0.403, 0.592, 0.751, 0.568, 0.256, 0.101, 0.293, -0.301, -5.000, 0.510, 0.271, 0.349, -5.000, 0.054, 0.109, 0.022, 0.053, 0.381, -0.190, -0.356, -0.119, 0.305, 0.217, 0.085, -5.000, -0.629, 0.501, -5.000, -0.489, -0.036, 0.794, -0.559, -0.125, 0.395, -0.045, -1.127, -0.719, -0.490, 0.111, -2.025, -0.980, 0.058, -0.010, -0.837, -0.000, -0.425, -0.816, -1.465, -0.072, -0.814, -2.446, -0.821, -0.405, -0.031, 0.392, -0.932, -0.379, -0.083, 0.648, -0.415, -0.661, 0.327, 0.342, -0.744, -0.565, 0.073, 0.136, -0.335, -0.691, -0.658, 0.231, -0.559, -5.000, -0.830, 0.503, 0.801, -5.000, -1.132, -0.434, -0.351, -0.473, -0.583, 0.052, -0.700, -0.631, -0.360, 0.064, -0.239, -5.000, -0.172, 0.209, -1.848, -0.750, -0.506, -0.837, -5.000, -1.200, 0.106, -0.824, -1.155, -0.517, -0.475, 0.749, -1.242, -1.022, -0.144, -0.525, -1.396, -1.956, -0.484, -0.877, -1.060, -1.971, -1.638, 0.144, -1.423, -1.740, -0.453, 0.434, -0.549, -0.821, -0.346, -0.051, -0.462, -0.667, -0.283, -0.084, -0.180, -0.650, -0.580, -0.673, -0.543, -0.896, 0.306, 1.142, 0.446, -5.000, 0.518, 1.264, -0.326, -5.000, 0.356, 0.905, 0.559, 0.337, 0.416, 0.699, -0.809, 0.320, -0.312, 0.289, -1.151, -5.000, -1.015, 0.224, -1.848, -0.200, -0.414, -0.108, 0.058, -1.004, 0.290, -0.674, -1.677, -0.575, 0.242, 0.756, -0.186, -0.408, -0.129, 0.779, -0.805, -0.334, -0.070, 0.715, -0.913, -0.256, -0.669, -0.116, -1.241, -0.737, 0.503, 1.149, 0.125, 0.028, 0.487, 1.215, 0.508, 0.066, 0.800, 1.283, 0.521, 0.638, 0.194, 0.968, 0.543, 0.250, 0.068, 0.852, -0.083, -5.000, 0.248, 0.888, -0.261, -5.000, 0.638, 1.014, 0.566, 0.404, 0.173, 0.625, -0.772, 0.013, -0.420, -0.054, -0.882, -5.000, -0.401, 0.144, -0.772, -0.690, -0.123, 0.172, -1.097, -1.155, -0.142, -0.231, -1.725, -0.827, 0.066, 0.078, -0.144, -1.374, -0.292, 0.217, -0.315, -0.936, -0.724, 0.592, -0.302, -0.293, -0.225, -1.080, -1.524, -0.513, 0.535, 0.978, 0.264, -0.048, 0.616, 0.986, -0.462, -0.127, 0.461, 0.560, -0.076, 0.135, -0.021, 0.268, -0.402, -0.275, -0.992, 0.023, -0.994, -5.000, -0.540, 0.258, -1.155, -5.000, -0.799, 0.071, -0.764, -0.512, -0.793, -0.630, -1.665, -1.286, -1.247, -0.736, -1.307, -5.000, -1.234, -0.789, -1.396, -1.324, -1.019, -0.165, -0.668, -0.931, -0.996, -1.082, -2.721, -1.190, -1.643, -1.127, -2.416, -2.720, -1.582, -1.335, -2.368, -2.129, -1.168, -0.340, -2.540, -1.624, -1.969, -1.902, -2.772, -2.780, -1.103, -0.632, -2.135, -1.746, -1.186, -0.346, -1.438, -1.737, -1.452, -0.481, -2.255, -0.925, -1.441, -1.043, -2.143, -2.190, -0.201, 0.611, -0.308, -5.000, -0.133, 0.653, -0.624, -5.000, -0.028, 0.412, -0.376, -0.478, -0.233, 0.036, -1.141, -0.457, -0.837, -0.047, -0.767, -5.000, -0.896, -0.208, -0.681, -1.092, -0.204, 0.506, -1.075, -0.860, -0.244, -0.431, -1.773, -0.900, -0.787, 0.034, -1.370, -1.545, -0.986, -0.259, -1.149, -1.557, -0.862, -0.464, -1.107, -1.525, -1.484, -1.260, -1.368, -1.561, -0.272, 0.502, -1.046, -0.905, -0.584, -0.105, -0.130, -1.250, -0.111, 0.288, -1.253, -0.654, -0.675, -0.248, -0.898, -0.871, -0.000, 0.904, -0.272, -5.000, -0.496, 0.649, -0.621, -5.000, -0.116, 0.260, -0.169, -0.210, 0.022, 0.367, -0.665, 0.144, -0.613, 0.165, -1.439, -5.000, -1.824, -0.664, -1.356, -1.367, -0.471, 0.080, -0.201, -0.539, 0.168, -0.153, -1.581, -0.767, -0.588, 0.280, -1.319, -0.998, -1.054, -0.292, -3.200, -1.309, -1.112, -0.457, -1.044, -1.791, -1.430, -0.749, -1.827, -0.949, -0.063, 0.757, -0.802, -0.716, -0.503, 0.459, -1.008, -1.025, 0.117, 0.666, 0.295, -0.362, -0.528, 0.345, -0.378, -0.627, 0.686, 1.143, 0.075, -5.000, 0.722, 1.390, -0.107, -5.000, 0.832, 1.390, 1.071, 0.826, 0.863, 1.203, 0.176, 0.962, 0.446, 0.747, -0.552, -5.000, -0.010, 0.652, -1.060, 0.068, 0.341, 0.550, 0.057, 0.064, 0.362, 0.148, -0.969, -0.303, -0.222, 0.683, -0.291, 0.260, 0.432, 0.819, 0.837, -0.415, 0.070, 0.195, -0.196, -0.333, 0.064, -0.837, -0.659, 0.195, 0.632, 1.067, 0.079, 0.277, 0.828, 1.011, 0.598, 0.455, 0.636, 0.708, 0.319, 0.275, 0.241, 0.747, -0.090, 0.353, -0.499, 0.275, -0.881, -5.000, -0.171, 0.683, -1.740, -5.000, -0.807, -0.040, -0.055, -0.602, -0.503, 0.049, -1.397, -0.786, -0.898, -0.297, -1.204, -5.000, -1.537, -0.430, -2.818, -1.521, -1.291, -0.940, -1.389, -0.240, -0.657, -0.198, -2.189, -0.903, -1.160, -0.444, -1.830, -1.855, -1.238, -0.708, -1.431, -1.490, -0.236, -0.232, -0.794, -1.167, -1.998, -1.741, -2.208, -1.909, -0.421, 0.555, -0.991, -0.904, -0.360, 0.883, 0.303, -0.454, 0.282, 0.655, -0.609, -0.326, -0.518, -0.123, -1.130, -1.177, -0.530, 0.316, -0.654, -5.000, -0.887, 0.358, -1.188, -5.000, -0.883, -0.100, -0.780, -1.033, -0.690, -0.299, -1.494, -0.852, -0.726, -0.005, -1.146, -5.000, -1.831, -0.149, -0.964, -1.038, -1.151, -0.020, 0.114, -1.420, -0.357, -0.269, -1.483, -1.190, -1.195, 0.146, -1.011, -1.396, -1.528, -0.471, -0.811, -1.986, -1.322, -0.580, -1.488, -1.492, -2.472, -1.616, -2.288, -1.901, -0.519, 0.402, -1.517, -0.988, -1.045, 0.039, -1.385, -1.328, -0.636, 0.151, -0.147, -0.575, -1.110, -0.326, -1.222, -1.327, -0.498, 0.586, -0.376, -5.000, -1.220, 0.377, -0.777, -5.000, -0.443, 0.148, -0.229, -0.453, -0.127, 0.354, -0.377, 0.253, -0.831, -0.101, -1.298, -5.000, -2.011, -0.685, -2.654, -1.189, -0.335, 0.170, 0.026, -0.315, 0.047, -0.395, -1.187, -0.738, -1.041, 0.231, -1.200, -1.588, -2.096, -0.520, -1.935, -1.975, -1.421, -0.689, -1.148, -2.351, -1.360, -0.580, -1.804, -1.682, -0.477, 0.708, -0.873, -1.267, -0.943, 0.261, -0.715, -1.322, -0.400, 0.404, -0.116, -0.731, -0.977, -0.228, -0.621, -1.088, 0.202, 1.059, 0.311, -5.000, -0.088, 0.887, -0.184, -5.000, 0.554, 1.154, 0.946, 0.652, 0.624, 1.120, 0.392, 0.927, 0.285, 0.909, -0.003, -5.000, -0.907, 0.298, -1.914, -0.093, 0.527, 0.683, 0.390, 0.347, 0.648, -0.189, -1.159, -0.270, -0.289, 0.967, 0.535, -0.505, -0.179, 0.694, 0.221, -0.043, -0.397, 0.624, 0.182, -0.367, 0.130, 0.090, -0.703, -0.230, 0.067, 0.993, -0.168, -0.380, -0.077, 1.124, -0.101, -0.024, 0.310, 0.547, -0.104, -0.078, 0.003, 0.528, -0.263, 0.266, -0.763, -0.516, -0.653, -5.000, -1.149, 0.034, 0.262, -5.000, -1.332, -0.447, -0.324, 0.098, -0.742, -0.357, -1.052, -0.272, -0.885, -1.019, -0.696, -5.000, -3.387, -0.968, -5.000, -2.228, -1.060, -0.010, -0.462, 0.201, -0.778, 0.669, -3.027, -0.336, -1.613, -0.355, -0.857, -1.227, -1.860, 0.042, -0.396, -2.541, -0.117, -1.514, -1.093, -3.316, -2.013, -1.610, -0.787, -2.201, -0.764, 0.064, -1.176, -0.664, -0.640, -0.431, 0.039, -1.322, 0.167, 0.438, -0.549, 0.003, -0.489, -0.144, -0.791, -1.290, -0.875, 0.105, -0.682, -5.000, -1.026, 0.031, -1.389, -5.000, -1.117, -0.401, -0.516, -1.378, -0.702, -0.272, -1.091, -0.787, -1.120, -0.152, -0.892, -5.000, -1.726, -0.090, -2.530, -1.412, -0.492, -0.447, -0.917, -0.875, -0.317, -0.646, -1.720, -1.133, -1.759, 0.071, -0.829, -1.860, -2.547, -1.008, -2.373, -1.922, -1.320, -0.052, -1.613, -2.447, -2.325, -2.284, -1.805, -2.151, -0.772, 0.199, -1.102, -1.147, -1.074, 0.258, -0.405, -1.139, -0.581, -0.119, -0.445, -1.416, -1.152, -0.494, -1.199, -1.513, -0.211, 0.743, -0.095, -5.000, -0.491, 0.648, -0.926, -5.000, -0.202, 0.156, -0.131, -0.343, 0.062, 0.460, -0.705, 0.116, -0.766, 0.432, -0.675, -5.000, -1.874, -0.482, -1.431, -1.590, -1.189, 0.080, 0.216, 0.006, 0.192, -0.326, -0.867, -0.680, -1.114, -0.331, -1.946, -1.301, -1.646, -0.409, -1.242, -2.164, -1.079, -0.777, -0.851, -1.894, -1.658, -0.872, -1.351, -1.248, -0.511, 0.543, -0.944, -1.117, -0.842, 0.358, -0.450, -0.962, -0.149, 0.350, -0.252, -0.751, -0.870, 0.188, -0.490, -1.073, 0.097, 0.967, 0.240, -5.000, 0.192, 0.990, -0.274, -5.000, 0.420, 0.974, 0.375, 0.300, 0.451, 0.882, -0.086, 0.486, 0.180, 0.874, -0.131, -5.000, -0.765, 0.818, 0.501, -0.166, 0.611, 0.705, -0.122, -0.131, 0.627, 0.627, -0.437, -0.406, -0.476, -0.010, -0.425, -0.749, -0.580, 0.362, -0.462, -0.304, -0.784, -0.535, -1.420, -1.985, -0.662, -0.125, -2.071, -0.328, 0.208, 0.970, -0.078, -0.282, 0.276, 1.057, 0.931, -0.237, 0.175, 0.400, -0.367, -0.219, 0.078, 0.178, -0.054, -0.387, -0.177, 0.391, -0.208, -5.000, -0.417, 0.253, -1.871, -5.000, -0.442, -0.156, -0.986, -0.541, -0.448, -0.031, -1.223, -0.350, -0.685, 0.449, -0.288, -5.000, -1.253, -0.794, -1.109, -0.732, -0.075, -0.052, -1.405, -0.339, -0.226, -0.334, -2.161, -0.678, -1.195, -0.470, -1.561, -1.598, -1.307, -0.791, -0.759, -2.173, -1.070, -0.338, -1.360, -1.539, -1.419, -1.109, -1.771, -1.257, -0.357, 0.323, -0.703, -0.969, -0.576, 0.062, -0.850, -0.670, -0.392, -0.629, -0.991, -1.545, -0.670, -0.215, -1.113, -1.393, -0.541, 0.227, -0.285, -5.000, -1.073, 0.098, -0.462, -5.000, -0.730, -0.064, -0.951, -0.906, -0.376, 0.209, -0.525, -0.371, -1.108, 0.188, -0.291, -5.000, -1.838, -0.019, -0.289, -1.420, -1.404, -0.189, -0.663, -1.679, -0.303, -0.039, -1.429, -0.947, -1.544, -0.335, -1.172, -1.636, -2.050, -0.369, -1.666, -2.113, -1.212, -0.441, -1.526, -1.600, -2.101, -1.628, -1.611, -2.158, -0.706, 0.006, -1.451, -1.192, -1.101, 0.189, -0.678, -1.680, -0.879, -0.004, -0.692, -1.253, -1.077, -0.229, -0.899, -1.324, -0.848, 0.254, -0.862, -5.000, -0.914, 0.180, -1.112, -5.000, -0.644, -0.164, -0.751, -0.893, -0.862, -0.262, -1.259, -0.684, -1.128, -0.394, -1.731, -5.000, -2.442, -0.601, -3.246, -1.747, -1.234, 0.064, -0.648, -2.080, -0.644, -0.422, -2.520, -1.536, -1.736, -0.430, -2.271, -2.222, -2.024, -0.981, -3.586, -2.529, -2.002, -1.060, -0.919, -2.323, -1.896, -1.255, -1.591, -2.545, -0.963, -0.004, -1.669, -1.702, -1.277, -0.226, -1.450, -1.673, -0.882, -0.044, -0.616, -1.334, -1.272, -0.673, -1.114, -1.639, -0.365, 0.163, -0.855, -5.000, -0.409, 0.448, -1.448, -5.000, -0.454, 0.023, -0.355, -0.415, -0.312, 0.011, -1.180, -0.201, -0.497, 0.027, -1.175, -5.000, -0.530, 0.176, 0.111, -1.039, -0.755, -0.761, -0.477, -1.925, -0.601, -0.207, -2.681, -1.099, -1.410, -0.308, -1.403, -0.794, -1.548, 0.501, 1.198, -1.837, 0.020, -1.026, 0.012, -1.572, -1.053, -0.965, -1.322, -0.957, -0.430, 0.252, -1.569, -1.377, -1.101, 0.239, 0.165, -0.917, -0.361, -0.226, -0.784, -0.629, -0.993, -0.687, -1.751, -1.047, -1.162, -0.459, -1.781, -5.000, -0.678, 0.298, -0.293, -5.000, -1.114, -0.130, -1.008, -1.349, -1.134, -0.983, -1.862, -1.061, -1.348, -0.610, -1.465, -5.000, -1.687, -1.566, -0.222, -0.832, -1.920, -0.682, -0.903, -1.416, -0.808, -0.375, -2.377, -1.818, -1.667, -1.238, -1.821, -2.250, -2.710, -1.365, -0.805, -1.451, -1.507, -0.894, -1.828, -2.111, -2.515, -1.369, -2.029, -2.130, -1.263, -0.460, -1.726, -1.773, -1.207, -0.348, -1.445, -2.441, -1.049, -1.060, -0.664, -1.759, -1.439, -1.079, -2.239, -1.950, -0.723, 0.124, -0.820, -5.000, -0.774, 0.384, -1.033, -5.000, -0.774, -0.002, -0.630, -0.937, -0.743, -0.146, -1.148, -0.717, -1.234, -0.275, -1.060, -5.000, -1.761, -0.343, -1.471, -1.131, -2.089, -0.137, -0.418, -2.167, -0.454, -0.227, -2.157, -1.250, -1.547, -0.271, -1.445, -1.946, -1.811, -0.835, -1.255, -2.119, -1.296, -0.612, -1.627, -1.580, -2.121, -2.261, -2.193, -1.781, -0.811, 0.087, -1.485, -1.487, -1.174, -0.083, -0.665, -1.414, -0.973, -0.140, -0.514, -1.305, -1.439, -0.627, -1.508, -1.369, 0.537, 1.228, 0.264, -5.000, 0.194, 1.012, -0.284, -5.000, 0.352, 0.773, 0.294, 0.201, 0.554, 0.843, -0.236, 0.481, 0.052, 0.609, -0.635, -5.000, -1.053, 0.193, -1.380, -0.168, -0.234, 0.248, 0.111, -0.353, 0.653, 0.368, -0.704, -0.028, 0.162, 0.782, -0.330, -0.184, -0.088, 0.510, -0.632, -0.742, -0.173, 0.281, -0.445, -0.786, -0.642, -0.272, -0.735, -0.660, 0.518, 1.177, -0.095, -0.017, 0.434, 0.896, -0.036, -0.146, 0.658, 1.012, 0.683, 0.223, 0.095, 0.808, 0.226, 0.124, 1.192, 1.497, 0.953, -5.000, 1.036, 1.529, 0.613, -5.000, 1.279, 1.532, 1.334, 1.130, 1.237, 1.490, 0.770, 1.264, 1.059, 1.250, 0.457, -5.000, 0.292, 0.966, -0.167, 0.619, 0.958, 1.327, 0.825, -0.053, 0.984, 0.805, -0.960, 0.283, 0.805, 1.444, 0.727, 0.876, 0.835, 1.310, 0.077, 0.665, 0.297, 0.983, 0.670, 0.460, 0.741, 0.550, 0.003, 0.702, 1.094, 1.502, 0.881, 0.941, 1.218, 1.245, 0.779, 0.990, 0.943, 1.140, 0.623, 0.741, 0.914, 1.160, 0.585, 0.913, 0.124, 0.804, -0.095, -5.000, 0.145, 0.943, 0.067, -5.000, -0.053, 0.455, -0.146, -0.288, -0.174, 0.187, -1.199, -0.394, -0.281, 0.452, -0.754, -5.000, -0.639, 0.347, -1.332, -0.507, 0.099, 0.264, -0.794, -1.008, 0.054, -0.140, -1.881, -0.795, -0.740, 0.135, -1.286, -1.523, -0.887, 0.123, -1.039, -1.186, -0.301, 0.116, -1.076, -1.077, -1.392, -0.651, -1.746, -1.479, -0.027, 0.885, -0.614, -0.570, 0.082, 1.085, -0.170, -0.275, 0.410, 0.965, 0.094, 0.034, -0.284, 0.362, -0.637, -0.992, 0.121, 0.830, -0.008, -5.000, -0.192, 0.803, -0.295, -5.000, -0.336, 0.240, -0.281, -0.806, -0.111, 0.252, -0.909, -0.302, -0.118, 0.582, -0.385, -5.000, -1.247, 0.362, -1.113, -0.541, -0.406, 0.000, -0.560, -0.896, 0.239, 0.147, -1.786, -0.497, -0.329, 0.709, -0.752, -0.913, -0.831, 0.159, -0.636, -1.333, -0.349, 0.589, -0.172, -0.577, -1.526, -0.586, -1.814, -1.379, 0.112, 1.003, -0.651, -0.452, -0.163, 0.703, -0.457, -0.726, 0.073, 0.790, 0.352, -0.117, -0.517, 0.335, -0.686, -0.622, 0.242, 1.077, 0.335, -5.000, -0.144, 0.945, -0.626, -5.000, 0.272, 0.665, 0.528, 0.175, 0.563, 0.888, -0.024, 0.700, -0.020, 0.502, -0.354, -5.000, -1.371, -0.480, -2.718, -0.367, -0.010, 0.408, -0.309, 0.358, 0.854, 0.487, -0.693, -0.023, -0.222, 0.731, -0.610, -0.819, -0.666, 0.296, -0.944, -1.196, -0.887, 0.092, -0.396, -1.022, -0.932, -0.341, -1.062, -0.835, 0.328, 1.122, -0.232, -0.273, -0.097, 0.806, 0.000, -0.667, 0.576, 0.961, 0.505, 0.196, -0.219, 0.682, 0.089, -0.154, 0.899, 1.412, 1.045, -5.000, 0.606, 0.940, 0.642, -5.000, 1.151, 1.442, 1.164, 1.091, 1.138, 1.394, 0.974, 1.207, 0.899, 1.127, 0.596, -5.000, -0.482, 0.351, -0.243, 0.285, 0.874, 0.659, 0.817, 0.389, 1.040, 0.604, -0.409, 0.270, 0.715, 1.249, 0.844, 0.366, 0.457, 1.273, -0.549, 0.300, 0.690, 0.941, 0.646, 0.622, 0.852, 0.872, 0.492, 0.807, 0.917, 1.372, 0.874, 0.680, 0.902, 1.345, 0.573, 0.613, 0.937, 1.173, 0.594, 0.603, 0.643, 1.014, 0.507, 0.836, 0.373, 0.876, 0.227, -5.000, 0.491, 0.557, 0.410, -5.000, -0.055, 0.520, 0.064, 0.446, 0.204, 0.479, -1.145, -0.233, 0.034, 0.565, 0.205, -5.000, -0.472, 0.347, -0.131, -0.375, 0.550, 0.886, 0.725, 0.307, 0.505, -0.335, -1.223, -0.446, -0.538, 0.161, -0.452, -1.539, -0.604, 0.051, -0.179, -1.045, -0.568, 0.381, -0.391, -0.614, -0.621, -1.008, -1.690, -0.895, 0.126, 1.182, 0.279, -0.345, -0.113, 1.296, 0.080, -0.144, 0.573, 0.530, 0.378, 0.047, 0.224, 0.612, -0.245, -0.713, -0.125, 0.697, -0.052, -5.000, -0.561, 0.627, -0.490, -5.000, -0.536, 0.344, -0.363, -1.030, 0.015, 0.461, -0.892, -0.184, -0.346, 0.364, -0.318, -5.000, -1.100, -0.095, -1.738, -0.904, -0.383, 0.501, -0.907, -1.426, 0.337, 0.252, -1.087, -0.388, -0.453, 0.267, -0.724, -1.171, -1.211, 0.229, -1.486, -1.373, -0.831, 0.344, -0.832, -1.118, -1.451, -0.543, -1.672, -1.339, -0.005, 0.747, -0.409, -0.415, -0.366, 0.414, -0.329, -0.661, -0.042, 0.625, 0.003, -0.627, -0.394, 0.281, -0.620, -0.741, 0.517, 1.126, 0.433, -5.000, 0.306, 1.126, -0.010, -5.000, 0.434, 0.745, 0.432, 0.216, 0.572, 0.924, -0.143, 0.509, 0.276, 0.599, 0.027, -5.000, -0.702, 0.381, -0.152, -0.040, -0.390, 0.459, 0.248, -0.170, 0.939, 0.454, -1.119, 0.129, 0.115, 0.770, -0.308, -0.341, -0.324, 0.244, 0.219, -0.640, -0.524, 0.226, -0.993, -0.890, -0.900, -0.261, -0.950, -0.812, 0.354, 1.083, -0.053, 0.031, 0.393, 1.023, -0.221, -0.145, 0.396, 0.751, 0.243, -0.174, 0.037, 0.865, 0.239, -0.033, 0.813, 1.363, 0.822, -5.000, 0.852, 1.456, 0.432, -5.000, 0.973, 1.280, 0.794, 0.694, 0.841, 1.181, 0.336, 0.875, 0.839, 1.327, 0.576, -5.000, 0.391, 1.211, -0.109, 0.556, 0.661, 1.051, 0.305, 0.453, 1.088, 1.065, -0.434, 0.451, 0.592, 1.105, 0.429, 0.324, 0.438, 1.042, 0.262, 0.073, 0.220, 0.555, -0.489, -0.225, 0.381, 0.191, -0.653, 0.235, 0.834, 1.387, 0.698, 0.678, 0.815, 1.229, 0.683, 0.498, 0.557, 0.782, 0.084, 0.068, 0.598, 0.994, 0.438, 0.432, 0.535, 1.024, 0.285, -5.000, 0.769, 1.269, -0.172, -5.000, 0.456, 0.587, -0.212, -0.045, 0.579, 0.685, -0.359, 0.280, 0.414, 0.806, -0.136, -5.000, -0.170, 0.860, -1.034, 0.114, 0.054, 0.656, -0.415, -0.588, 0.703, 0.535, -0.873, 0.096, 0.060, 0.910, -0.467, -0.692, -0.451, 0.752, -0.825, -0.274, 0.014, -0.107, -0.868, -0.814, -0.419, -0.130, -0.856, -0.424, 0.372, 1.130, -0.093, -0.078, 0.187, 0.760, -0.563, -0.048, 0.254, 0.157, -0.804, -0.409, 0.060, 0.320, -0.405, -0.593, 0.265, 0.781, 0.341, -5.000, 0.193, 0.652, -0.360, -5.000, 0.085, 0.349, -0.295, -0.623, 0.192, 0.653, -0.324, 0.049, 0.012, 0.640, 0.125, -5.000, -1.180, 0.390, -0.763, -0.122, -0.928, 0.621, -1.084, -1.677, 0.685, 0.569, -0.827, -0.158, -0.279, 0.696, -0.488, -0.577, -0.657, 0.332, -0.213, -1.229, -0.532, 0.055, -1.114, -0.823, -1.061, -0.746, -1.186, -1.168, 0.115, 0.891, -0.501, -0.173, -0.074, 0.744, 0.220, -0.560, -0.120, 0.280, -0.351, -0.813, -0.302, 0.400, -0.243, -0.633, 0.052, 0.872, -0.118, -5.000, -0.196, 0.795, -0.396, -5.000, 0.011, 0.496, 0.083, -0.092, 0.067, 0.467, -0.721, 0.001, -0.204, 0.437, -0.439, -5.000, -1.152, 0.115, -1.762, -0.495, -0.189, -0.092, -0.154, -0.420, 0.413, 0.043, -0.867, -0.213, -0.530, 0.228, -0.844, -1.172, -0.863, 0.071, -1.263, -1.331, -0.895, -0.161, -1.161, -1.239, -1.130, -0.550, -1.134, -1.341, 0.008, 0.848, -0.610, -0.572, -0.132, 0.722, 0.058, -0.593, 0.135, 0.694, 0.140, -0.290, -0.359, 0.459, -0.258, -0.537, 0.623, 1.218, 0.452, -5.000, 0.556, 1.118, -0.175, -5.000, 0.685, 1.108, 0.719, 0.530, 0.689, 1.103, 0.028, 0.693, 0.693, 1.055, 0.345, -5.000, 0.037, 1.075, -0.657, 0.227, 0.480, 1.095, 0.516, 0.186, 0.590, 0.705, -1.266, -0.002, 0.492, 0.954, 0.096, 0.019, 0.166, 1.014, -0.877, -0.171, 0.390, 0.796, 0.446, 0.020, -0.026, -0.362, -0.440, -0.141, 0.630, 1.203, 0.291, 0.110, 0.493, 1.143, 0.701, 0.179, 0.599, 0.814, 0.240, 0.174, 0.214, 0.804, 0.012, 0.044, 0.247, 1.020, -0.037, -5.000, 0.473, 1.166, 0.045, -5.000, 0.027, 0.572, 0.046, -0.214, 0.101, 0.521, -0.850, -0.067, -0.060, 0.648, -0.548, -5.000, -0.373, 0.596, -1.790, -0.119, -0.259, 0.235, -0.264, -0.969, 0.514, 0.275, -1.297, -0.284, -0.890, 0.105, -1.416, -1.196, -1.026, 0.351, -1.823, -0.896, -0.456, 0.324, -1.279, -0.686, -1.682, -1.091, -1.543, -1.725, -0.025, 0.582, -1.062, -0.759, -0.118, 0.902, -0.680, -0.641, -0.007, 0.435, -0.412, -0.415, -0.694, -0.008, -1.190, -1.336, 0.031, 0.862, 0.007, -5.000, -0.113, 0.780, -0.575, -5.000, -0.109, 0.322, -0.373, -0.775, -0.083, 0.421, -0.793, -0.273, -0.180, 0.661, -0.256, -5.000, -0.941, 0.310, -0.786, -0.150, -0.669, -0.000, -0.694, -1.329, 0.356, 0.299, -1.208, -0.313, -0.406, 0.505, -0.835, -1.125, -0.772, 0.214, -0.943, -1.300, -0.409, 0.376, -0.502, -0.675, -1.660, -0.797, -1.919, -1.171, -0.106, 0.704, -0.748, -0.631, -0.163, 0.520, -0.160, -0.891, -0.219, 0.352, -0.260, -0.726, -0.706, -0.061, -1.025, -0.757 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_23(struct _training *tptr) {
  struct _training tinf = {
    0.608, 11, 4.350, { 0.533, 0.117, 2.351 }, { 0.750, -0.635, -0.218 }, 1, 
    { -2.811, -4.000, -1.542, -1.149, -4.000, -0.716, -0.260, -1.755, -0.113, -0.469, 0.388, -4.000, 0.007, -0.582, 0.608, 0.399, 1.188, 1.067, -0.604, 2.065, 1.916, 0.611, 2.490, 1.413, 2.761, 2.914, -4.000, 3.507 }, 
    {{ 0.244, -0.069, -0.186, 0.088},{ 0.227, -0.231, -0.078, 0.168},{ 0.490, 0.244, -0.823, -0.210},{ 0.349, 0.185, -0.565, -0.066},{ 0.321, 0.091, -0.370, -0.046},{ 0.293, -0.019, -0.356, 0.143},{ 0.242, -0.045, -0.339, 0.216},{ 0.254, -0.103, -0.246, 0.184},{ 0.252, -0.180, -0.255, 0.277},{ 0.325, -0.294, -0.224, 0.281},{ 0.355, -0.172, -0.275, 0.177},{ 0.394, -0.271, -0.284, 0.240},{ 0.349, -0.248, -0.231, 0.219},{ 0.366, -0.134, -0.298, 0.143},{ 0.323, -0.130, -0.210, 0.098},{ 0.332, -0.112, -0.222, 0.078},{ 0.325, -0.045, -0.305, 0.090},{ 0.259, -0.107, -0.210, 0.145},{ 0.250, -0.107, -0.280, 0.225},{ 0.291, -0.101, -0.235, 0.129},{ 0.203, -0.053, -0.154, 0.073},{ 0.219, -0.112, -0.201, 0.186},{ 0.236, -0.007, -0.205, 0.032},{ 0.206, -0.007, -0.334, 0.201},{ 0.159, -0.088, -0.220, 0.236},{ 0.131, -0.045, -0.216, 0.208},{ 0.136, -0.031, -0.214, 0.184},{ 0.131, -0.082, -0.216, 0.250},{ 0.145, 0.026, -0.275, 0.163},{ 0.131, -0.029, -0.164, 0.131},{ 0.154, -0.036, -0.231, 0.190},{ 0.203, -0.013, -0.201, 0.075} }, 
    {{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}} }, 
    0.000, { 0.026, 0.329, -0.183, -5.000, -0.538, -0.515, -0.887, -5.000, -0.396, -0.685, -0.976, -0.874, 0.002, 0.109, 0.187, -0.003, 0.593, 0.829, 0.253, -5.000, -0.637, -0.103, -0.265, -0.573, -0.440, -0.007, -0.346, -0.889, 0.432, 0.643, 0.965, 0.561, 0.386, 0.601, -0.016, 0.588, -0.005, 0.277, 0.294, -0.291, 0.410, 0.688, 0.249, -0.173, 0.792, 0.304, 0.480, 0.084, 0.065, 0.092, -0.467, 0.302, -0.316, -0.261, -0.669, -0.728, 0.171, -0.013, -0.098, -0.519, 0.292, 0.256, 0.228, 0.166, 0.424, 0.720, -0.403, -5.000, -0.255, -0.245, -1.117, -5.000, -0.356, -0.602, -1.452, -0.875, 0.286, -0.073, 0.124, 0.054, 1.020, 1.287, 0.491, -5.000, 0.233, 0.630, 0.764, 0.430, 0.496, 0.706, 0.235, 0.163, 1.059, 1.177, 1.115, 0.741, 0.908, 0.966, 0.111, 1.130, 0.431, 0.215, 0.478, 0.039, 0.838, 0.793, 0.322, 0.367, 1.210, 0.561, 0.580, 0.734, 0.211, 0.187, -0.519, 0.639, -0.029, -0.247, -0.029, -0.199, -0.161, -0.212, -0.738, -0.573, 0.796, 0.071, 0.036, 0.604, 0.080, 0.092, -0.752, -5.000, -0.786, -0.866, -1.039, -5.000, -0.602, -0.982, -1.432, -0.916, -0.529, -0.710, -1.375, -0.528, 0.220, 0.227, -0.167, -5.000, -0.520, -0.788, -0.729, -0.447, -0.410, -0.124, -0.457, -0.274, 0.535, 0.419, 0.479, 0.230, 0.019, -0.479, -0.654, 0.005, -0.356, -0.794, -0.629, -0.778, -0.031, 0.029, -0.398, -0.394, 0.311, -0.167, -0.310, -0.048, -0.661, -0.986, -1.270, -0.709, -0.446, -1.098, -1.040, -0.711, -0.810, -0.983, -1.179, -0.907, -0.112, -0.749, -0.966, -0.584, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.516, -0.282, -1.005, -5.000, -1.000, -1.492, -2.214, -5.000, -1.692, -1.359, -1.554, -1.820, -0.001, 0.012, 0.039, -0.431, -0.183, 0.174, -0.322, -5.000, -1.078, -1.000, -0.867, -1.388, -1.208, -0.908, -1.455, -1.564, -0.030, 0.090, 0.145, 0.059, -0.493, 0.105, -0.254, -0.187, -0.847, -0.734, -0.845, -1.406, -0.474, -0.338, -1.091, -0.870, 0.161, -0.200, 0.010, -0.526, -0.509, -0.749, -1.280, -0.693, -1.178, -1.428, -1.700, -1.465, -0.509, -0.484, -0.535, -0.391, 0.058, -0.065, -0.340, 0.107, -0.331, -0.065, -1.161, -5.000, -1.173, -1.245, -2.028, -5.000, -1.007, -1.260, -2.213, -1.739, -0.037, -0.361, 0.039, -0.182, 0.182, 0.663, -0.128, -5.000, -0.521, -0.333, -0.480, -0.507, -0.571, -0.439, -0.764, -0.575, 0.581, 0.392, 0.502, 0.214, 0.115, 0.332, -0.374, 0.461, -0.690, -0.577, -1.087, -1.138, -0.032, -0.063, -0.757, -0.693, 0.643, 0.122, 0.071, 0.084, -0.547, -0.688, -1.705, -0.593, -1.150, -1.558, -1.650, -1.477, -1.227, -1.538, -2.353, -1.717, -0.425, -1.047, -0.571, -0.476, -0.588, -0.625, -1.894, -5.000, -1.905, -1.689, -2.176, -5.000, -1.410, -1.709, -2.617, -1.418, -0.985, -1.555, -1.175, -1.791, -0.415, -0.337, -0.940, -5.000, -1.296, -1.499, -1.610, -1.627, -1.161, -1.046, -1.581, -1.107, 0.143, 0.023, -0.065, -0.351, -0.712, -0.747, -1.793, -0.891, -1.384, -1.291, -1.810, -1.461, -0.971, -0.877, -1.577, -1.104, -0.445, -0.648, -0.831, -0.562, -1.854, -2.041, -2.604, -1.179, -1.479, -2.355, -2.746, -2.427, -2.491, -2.009, -2.787, -2.114, -0.405, -1.718, -2.430, -1.362, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.447, -0.117, -1.166, -5.000, -1.169, -1.360, -1.787, -5.000, -1.494, -1.403, -1.648, -1.266, -0.217, -0.091, -0.582, -0.627, -0.122, 0.486, -0.121, -5.000, -1.151, -0.835, -1.025, -1.384, -0.877, -0.613, -1.164, -1.416, 0.188, 0.171, 0.229, -0.066, -0.464, 0.053, -0.375, 0.316, -0.766, -0.335, -0.850, -1.155, -0.390, -0.516, -0.874, -0.784, -0.186, -0.151, -0.204, -0.008, -1.000, -0.212, -0.949, -0.523, -1.526, -1.482, -1.584, -1.656, -1.274, -0.657, -1.263, -0.741, 0.032, -0.201, -0.481, -0.360, -0.420, 0.094, -1.248, -5.000, -1.418, -1.252, -2.297, -5.000, -1.125, -1.611, -2.535, -1.845, -0.434, -0.257, -0.303, -0.237, -0.162, 0.587, -0.209, -5.000, -0.959, -0.630, -0.867, -1.236, -0.736, -0.394, -1.040, -1.033, 0.043, 0.351, 0.454, -0.024, -0.335, -0.016, -0.902, -0.086, -1.080, -0.923, -1.550, -1.238, -0.447, -0.476, -1.325, -1.087, 0.315, -0.561, -0.348, -0.026, -0.252, -0.415, -1.394, -0.020, -0.972, -1.177, -1.638, -1.273, -1.172, -1.152, -1.611, -2.156, -0.112, -0.731, -0.868, -0.393, -0.766, -0.702, -1.196, -5.000, -1.687, -1.830, -2.399, -5.000, -1.534, -2.184, -2.314, -1.966, -1.201, -1.364, -1.321, -1.010, -0.784, -0.537, -1.331, -5.000, -2.150, -1.859, -2.182, -2.193, -1.391, -1.512, -1.775, -1.532, -0.414, -0.328, -0.442, -0.421, -0.758, -0.795, -1.603, -0.606, -1.419, -1.624, -1.866, -1.829, -0.977, -1.372, -1.608, -1.367, -0.402, -1.209, -1.023, -0.672, -0.869, -1.282, -1.782, -1.004, -1.602, -1.870, -2.222, -1.949, -1.912, -1.796, -2.013, -1.979, -0.673, -1.251, -1.550, -1.128, -0.876, -0.664, -1.165, -5.000, -2.137, -1.675, -2.512, -5.000, -1.527, -1.544, -2.037, -1.644, -0.684, -0.689, -0.956, -0.761, -0.410, -0.126, -0.444, -5.000, -1.291, -1.044, -1.778, -1.643, -1.217, -1.204, -0.931, -1.251, -0.336, -0.122, -0.060, -0.231, -0.536, -0.631, -1.076, -0.642, -1.042, -0.920, -1.025, -1.913, -0.541, -0.364, -0.712, -0.849, -0.120, -0.462, -0.570, -0.404, -0.785, -0.731, -0.942, -0.672, -1.204, -0.969, -1.311, -1.619, -1.171, -1.154, -1.305, -1.208, -0.457, -0.910, -0.830, -0.827, 0.120, 0.259, -0.240, -5.000, -0.559, -0.384, -0.948, -5.000, -0.408, -0.451, -0.783, -0.843, -0.149, -0.211, 0.116, -0.327, 0.288, 0.738, 0.069, -5.000, -0.572, 0.068, 0.070, -0.469, -0.262, -0.077, -0.234, -0.699, 0.120, 0.552, 0.462, 0.108, 0.281, 0.696, 0.224, 0.272, -0.425, 0.142, 0.181, -0.259, 0.105, 0.365, -0.300, -0.141, 0.317, 0.016, -0.091, 0.202, 0.109, 0.036, -0.306, -0.226, -0.588, -0.497, -0.450, -0.523, -0.329, 0.056, -1.358, -0.459, -0.061, 0.018, -0.039, 0.015, 0.187, 0.031, -0.584, -5.000, -0.229, -0.361, -1.760, -5.000, -0.375, -0.808, -1.233, -0.825, 0.214, -0.140, 0.454, -0.011, 0.267, 0.707, -0.317, -5.000, -0.017, 0.158, 0.149, -0.015, 0.243, 0.361, -0.272, -0.128, 0.406, 0.521, 0.517, 0.349, 0.432, 0.525, -0.452, 0.496, 0.074, -0.279, -0.269, -0.225, 0.233, 0.224, -0.585, -0.286, 0.437, -0.451, -0.407, 0.185, -0.046, -0.261, -0.636, 0.549, -0.421, -0.596, -0.954, -0.358, -0.393, -0.355, -0.985, -0.604, 0.470, -0.580, -0.251, 0.347, -0.080, 0.559, -0.582, -5.000, -0.417, -0.754, -1.801, -5.000, -0.700, -0.668, -1.046, -0.996, -0.182, -0.666, -1.127, -0.604, 0.444, 0.501, -0.106, -5.000, -0.646, -0.545, -0.876, -0.551, 0.034, 0.033, -0.608, -0.060, 0.389, 0.684, 0.027, 0.255, 0.225, 0.545, -0.700, 0.158, 0.049, -0.208, -0.685, -0.996, 0.279, 0.597, -0.338, -0.445, 0.683, 0.008, 0.179, 0.108, -0.100, -0.192, -1.048, -0.046, -0.910, -0.606, -0.761, -1.234, -0.572, -0.364, -0.804, -0.439, 0.467, -0.161, -0.086, -0.037, -0.197, 0.289, -0.528, -5.000, -0.840, -0.718, -1.171, -5.000, -0.728, -0.699, -0.983, -1.057, -0.542, -0.174, -0.406, -0.234, 0.053, 0.795, 0.444, -5.000, -0.659, -0.233, -0.544, -0.665, -0.343, -0.403, -0.634, -0.507, 0.260, 0.205, 0.656, 0.174, -0.203, 0.490, 0.001, 0.216, -0.507, -0.087, -0.491, -0.911, -0.211, 0.150, -0.555, -0.526, -0.004, 0.453, 0.381, 0.093, -0.190, 0.118, -0.579, -0.346, -0.523, -0.373, -0.336, -1.032, -0.240, -0.203, -1.079, -0.651, 0.070, -0.150, 0.081, -0.328, 0.378, 0.755, 0.014, -5.000, -0.288, -0.226, -0.614, -5.000, -0.273, -0.204, -0.571, -0.752, -0.032, 0.232, 0.581, 0.098, 0.689, 1.089, 0.641, -5.000, -0.509, 0.207, 0.161, -0.279, -0.300, 0.301, -0.177, -0.785, 0.644, 0.947, 1.132, 0.663, 0.908, 1.200, 0.902, 1.235, 0.655, 1.083, 0.890, 0.397, 1.011, 1.119, 0.606, 0.484, 1.276, 1.007, 0.898, 0.787, 0.048, 0.566, 0.436, 0.640, -0.023, 0.249, -0.044, 0.023, 0.141, 0.607, 0.181, -0.157, 0.862, 0.612, 0.534, 0.314, 0.687, 1.079, -0.119, -5.000, 0.237, 0.235, -0.234, -5.000, -0.054, 0.070, -0.858, -0.594, 0.585, 0.451, 0.917, 0.562, 0.963, 1.342, 0.686, -5.000, 0.386, 0.863, 1.083, 0.700, 0.551, 1.028, 0.613, 0.440, 1.104, 1.419, 1.394, 0.941, 1.192, 1.443, 0.995, 1.418, 0.933, 1.025, 1.109, 0.764, 1.140, 1.200, 0.872, 0.747, 1.443, 1.073, 0.929, 1.122, 0.388, 0.671, 0.151, 1.054, 0.477, 0.436, 0.613, 0.424, 0.029, 0.484, -0.223, -0.029, 1.115, 0.568, 0.291, 0.835, 0.336, 0.668, -0.382, -5.000, -0.153, -0.114, -0.585, -5.000, -0.180, -0.106, -0.750, -0.218, -0.098, -0.084, -0.023, -0.126, 0.736, 0.853, 0.271, -5.000, 0.104, 0.295, 0.267, 0.337, 0.216, 0.254, -0.026, -0.022, 1.033, 0.798, 0.888, 0.647, 0.490, 0.424, -0.378, 0.864, 0.134, -0.273, -0.038, 0.027, 0.553, 0.570, 0.060, 0.062, 0.781, 0.034, -0.055, 0.242, -0.140, -0.449, -0.776, 0.309, -0.156, -0.307, -0.317, -0.164, 0.195, 0.108, -0.394, 0.010, 0.785, -0.053, -0.245, 0.013, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.194, 0.215, -0.600, -5.000, -0.668, -0.755, -1.655, -5.000, -1.489, -0.831, -1.479, -1.415, -0.117, -0.204, 0.167, -0.104, -0.303, 0.432, 0.042, -5.000, -0.740, -0.694, -0.790, -1.381, -0.880, -0.805, -1.322, -1.446, -0.232, 0.092, 0.495, -0.007, -0.417, 0.043, -0.435, -0.182, -0.640, -0.420, -0.647, -1.201, -0.292, -0.234, -0.847, -0.948, 0.115, -0.075, 0.200, -0.454, -0.517, -0.539, -0.484, -0.729, -0.919, -0.946, -2.082, -1.535, -0.097, -0.180, -1.165, -0.660, -0.080, 0.023, 0.367, -0.077, -0.043, 0.462, -0.703, -5.000, -0.875, -0.555, -1.070, -5.000, -0.761, -1.050, -1.794, -1.165, -0.326, 0.003, 0.197, -0.115, 0.432, 1.026, 0.325, -5.000, -0.464, 0.298, 0.100, -0.377, -0.097, 0.165, -0.427, -0.506, 0.775, 0.906, 1.070, 0.645, 0.479, 0.973, 0.266, 0.862, -0.097, 0.219, -0.021, -0.440, 0.211, 0.435, -0.435, -0.578, 1.050, 0.614, 0.542, 0.602, -0.440, -0.272, -0.810, -0.102, -1.027, -0.636, -1.050, -0.874, -1.066, -1.113, -1.686, -1.822, 0.084, -0.512, -0.242, -0.151, -0.036, 0.599, -0.516, -5.000, -1.200, -0.614, -1.433, -5.000, -0.799, -0.792, -1.740, -1.149, -0.232, 0.103, -0.929, -0.568, 0.364, 0.957, 0.290, -5.000, -0.762, -0.047, -0.208, -0.581, -0.283, 0.201, -0.305, -0.602, 0.594, 0.840, 0.880, 0.329, 0.381, 0.808, -0.132, 0.798, -0.041, 0.138, -0.107, -0.326, 0.036, 0.587, -0.226, -0.239, 0.567, 0.422, 0.162, 0.232, -0.778, -0.846, -1.653, -0.461, -0.904, -1.178, -1.347, -1.358, -1.403, -0.893, -1.996, -1.634, 0.042, -0.991, -1.074, -0.713, -0.331, 0.359, -0.662, -5.000, -1.523, -0.990, -2.183, -5.000, -1.435, -1.195, -1.493, -1.703, -0.565, -0.249, -0.390, -0.532, 0.152, 0.724, 0.455, -5.000, -1.021, -0.908, -0.981, -1.061, -1.009, -0.713, -0.838, -1.257, -0.001, 0.391, 0.679, -0.028, -0.416, 0.658, 0.181, 0.381, -0.473, -0.125, -0.385, -1.174, -0.471, -0.018, -0.722, -0.889, 0.123, 0.415, 0.544, -0.029, -0.291, -0.139, -0.605, -0.456, -0.805, -0.463, -0.532, -1.170, -0.839, -0.597, -1.091, -1.478, -0.131, -0.123, -0.337, -0.491, 0.000, 0.461, -0.510, -5.000, -0.689, -0.419, -1.092, -5.000, -1.024, -0.850, -1.404, -1.238, -0.115, 0.062, 0.166, -0.187, 0.410, 0.954, 0.380, -5.000, -0.837, -0.121, -0.051, -0.888, -0.475, -0.115, -0.426, -0.986, 0.240, 0.650, 0.926, 0.058, 0.299, 0.769, 0.289, 0.859, -0.287, 0.450, 0.046, -0.539, 0.040, 0.224, -0.108, -0.522, 0.394, 0.466, 0.423, 0.173, -0.262, 0.498, -0.100, 0.244, -0.891, -0.237, -0.662, -1.155, -0.691, -0.508, -0.822, -0.730, 0.349, 0.060, 0.113, 0.025, 0.146, 0.727, -0.493, -5.000, -0.764, -0.485, -1.466, -5.000, -0.588, -0.661, -1.741, -1.003, 0.177, 0.114, 0.395, 0.187, 0.616, 1.226, 0.441, -5.000, -0.447, 0.613, 0.416, -0.290, 0.304, 0.512, -0.114, -0.331, 0.663, 1.054, 1.177, 0.552, 0.654, 1.009, 0.301, 1.062, 0.009, 0.298, -0.096, -0.307, 0.215, 0.387, -0.349, -0.422, 1.051, 0.359, 0.295, 0.702, -0.063, 0.232, -0.656, 0.502, -0.221, -0.327, -0.756, -0.493, -0.380, -0.475, -1.304, -0.892, 0.663, -0.203, -0.295, 0.240, -0.208, 0.241, -0.565, -5.000, -1.229, -0.623, -1.207, -5.000, -0.793, -0.871, -1.698, -1.217, -0.274, -0.264, -0.884, -1.159, 0.215, 0.476, -0.201, -5.000, -0.922, -0.384, -0.586, -1.002, -0.320, -0.204, -0.525, -0.778, 0.277, 0.567, 0.690, 0.063, 0.474, 0.719, -0.170, 0.584, -0.174, -0.441, -0.525, -0.387, 0.101, -0.063, -0.393, -0.449, 0.370, -0.158, -0.487, -0.058, -0.100, -0.063, -0.703, 0.224, -0.563, -0.384, -0.855, -0.753, -0.332, -0.285, -0.981, -0.765, 0.465, -0.300, -0.647, -0.129, -0.611, 0.155, -0.533, -5.000, -1.673, -1.165, -1.750, -5.000, -1.507, -1.282, -1.623, -1.608, -0.848, -0.268, -0.378, -0.815, 0.091, 0.654, 0.128, -5.000, -1.209, -0.410, -0.547, -0.829, -0.835, -0.290, -0.583, -0.928, -0.151, 0.500, 0.717, -0.219, -0.641, 0.416, 0.067, 0.176, -1.178, -0.131, -0.575, -0.844, -0.393, -0.127, -0.648, -0.679, 0.043, 0.084, 0.377, -0.232, -0.378, 0.019, -0.278, 0.121, -0.818, -0.006, -0.470, -1.242, -0.580, -0.300, -0.697, -1.044, -0.078, -0.014, 0.103, -0.367, 0.445, 0.969, 0.319, -5.000, -0.225, 0.315, -0.187, -5.000, -0.107, 0.027, -0.801, -0.539, 0.506, 0.611, 0.541, 0.145, 0.733, 1.220, 0.911, -5.000, -0.349, 0.580, 0.614, -0.128, -0.013, 0.516, -0.012, -0.471, 0.495, 1.019, 1.204, 0.298, 0.936, 1.207, 0.894, 1.112, 0.356, 0.844, 0.705, 0.164, 0.673, 0.974, 0.384, 0.221, 1.051, 0.801, 0.931, 0.960, 0.473, 0.765, 0.280, 0.688, -0.149, 0.351, -0.100, -0.309, -0.141, 0.344, -0.484, -0.161, 0.764, 0.517, 0.260, 0.599, 0.825, 1.081, 0.251, -5.000, -0.106, 0.413, -0.196, -5.000, 0.101, 0.029, -0.599, -0.563, 0.597, 0.327, 0.814, 0.044, 1.055, 1.224, 0.852, -5.000, 0.055, 0.985, 1.061, 0.392, 0.914, 1.115, 0.640, 0.390, 0.935, 1.304, 1.403, 0.707, 1.246, 1.352, 0.895, 1.431, 0.596, 0.916, 0.752, 0.548, 0.859, 1.006, 0.346, 0.315, 1.348, 0.860, 0.717, 1.143, 0.413, 0.705, 0.010, 0.795, 0.479, 0.444, 0.133, 0.291, 0.230, 0.277, -0.354, -0.136, 1.052, 0.393, 0.205, 0.951, 0.980, 1.335, 0.742, -5.000, 0.490, 0.722, 0.064, -5.000, 0.395, 0.565, -0.450, 0.041, 0.684, 0.696, 0.484, 0.372, 1.107, 1.256, 0.754, -5.000, 0.292, 0.979, 0.901, 0.697, 0.886, 1.114, 0.717, 0.565, 1.279, 1.439, 1.225, 0.996, 1.342, 1.354, 0.798, 1.442, 1.044, 0.892, 0.944, 0.755, 1.287, 1.326, 0.876, 0.909, 1.342, 1.108, 1.037, 1.029, 0.594, 0.701, 0.104, 0.976, 0.594, 0.654, 0.507, 0.205, 0.709, 0.702, 0.069, 0.196, 1.121, 0.747, 0.620, 0.788, 0.007, 1.013, 0.454, -5.000, -0.537, 0.313, -0.199, -5.000, -0.267, 0.023, -0.644, -0.748, 0.124, 0.414, 0.455, -0.192, 0.473, 1.223, 0.756, -5.000, -0.359, 0.538, 0.497, -0.091, 0.007, 0.476, 0.025, -0.447, 0.389, 0.934, 1.079, 0.505, 0.207, 0.787, 0.094, 0.261, -0.140, 0.456, 0.282, -0.602, 0.164, 0.615, 0.043, -0.248, 0.200, 0.379, 0.752, 0.283, 0.283, 0.589, 0.054, 0.426, -0.567, 0.219, -0.031, -0.674, -0.181, 0.180, -0.393, -0.573, 0.489, 0.343, 0.716, 0.220, 0.179, 0.548, -0.033, -5.000, -0.330, -0.327, -0.671, -5.000, -0.211, -0.323, -0.602, -0.596, 0.155, 0.300, 0.782, 0.689, 0.598, 1.117, 0.657, -5.000, -0.399, 0.065, 0.292, -0.187, -0.132, 0.434, 0.010, -0.526, 0.651, 1.050, 1.169, 0.676, 0.794, 1.116, 0.808, 1.285, 0.255, 0.790, 0.605, 0.438, 0.899, 0.899, 0.406, 0.211, 1.121, 0.910, 0.612, 0.801, 0.281, 0.424, -0.017, 0.458, -0.499, -0.217, -0.204, -0.311, 0.381, 0.280, -0.100, 0.183, 0.729, 0.577, 0.512, 0.638, 0.618, 0.839, -0.278, -5.000, -0.328, 0.217, -0.800, -5.000, -0.318, -0.393, -1.272, -0.291, 0.657, 0.267, 0.732, 0.251, 1.137, 1.352, 0.536, -5.000, 0.171, 0.839, 0.890, 0.709, 0.655, 0.755, 0.381, 0.333, 1.194, 1.393, 1.361, 1.003, 1.101, 1.153, 0.745, 1.459, 0.732, 0.701, 0.900, 0.770, 1.056, 1.015, 0.639, 0.669, 1.398, 0.946, 0.818, 1.058, 0.140, 0.188, -0.154, 0.873, 0.223, -0.116, 0.160, 0.312, -0.136, -0.293, -0.851, -0.437, 0.959, 0.293, 0.318, 0.912, 0.166, 0.323, -0.623, -5.000, -0.126, -0.410, -1.146, -5.000, -0.361, -0.670, -0.782, -0.600, -0.067, -0.248, -0.747, -0.449, 0.575, 0.447, -0.372, -5.000, -0.113, 0.058, -0.047, 0.134, 0.258, 0.118, -0.108, 0.168, 0.946, 0.850, 0.889, 0.595, 0.179, -0.016, -0.387, 0.749, 0.107, -0.463, -0.217, 0.082, 0.519, 0.464, -0.138, 0.025, 0.606, -0.246, -0.229, 0.036, -0.338, -0.818, -0.969, 0.268, -0.126, -0.515, -0.445, -0.347, -0.202, -0.570, -0.963, -0.538, 0.589, -0.537, -0.843, 0.259, 0.706, 0.934, -0.059, -5.000, -0.061, 0.082, -0.882, -5.000, -0.227, -0.123, -0.317, -0.442, 0.262, 0.473, 0.299, -0.087, 1.068, 1.282, 0.764, -5.000, -0.125, 0.398, 0.382, 0.274, -0.055, 0.335, 0.127, -0.204, 0.825, 1.141, 1.190, 0.410, 1.302, 1.387, 1.115, 1.416, 1.226, 1.126, 1.193, 0.896, 1.314, 1.370, 1.148, 1.166, 1.460, 1.263, 1.171, 1.224, 0.650, 0.679, 0.155, 0.872, 0.803, 0.787, 0.835, 0.363, 0.865, 0.737, 0.398, 0.128, 1.009, 0.802, 0.763, 0.726, -0.230, 0.268, -0.500, -5.000, -0.840, -0.873, -1.444, -5.000, -0.919, -0.613, -1.316, -0.980, -0.017, 0.020, 0.391, 0.160, 0.362, 0.808, 0.337, -5.000, -0.548, 0.009, -0.109, -0.439, -0.407, -0.088, -0.481, -0.751, 0.515, 0.762, 0.859, 0.573, 0.182, 0.751, 0.226, 0.739, -0.171, 0.253, -0.094, -0.606, -0.068, -0.166, -0.450, -0.600, 0.606, 0.607, 0.329, 0.375, -0.300, -0.388, -0.937, -0.861, -0.675, -0.615, -1.125, -0.972, -0.380, -0.096, -0.306, -0.424, -0.055, 0.228, 0.009, 0.224, -0.086, 0.341, -0.620, -5.000, -0.748, -0.808, -1.669, -5.000, -0.942, -0.943, -1.752, -1.114, -0.185, -0.515, 0.343, 0.343, 0.694, 1.021, 0.054, -5.000, -0.189, 0.291, 0.317, 0.083, 0.024, 0.105, -0.425, -0.203, 1.039, 1.032, 1.012, 0.698, 0.511, 0.717, 0.028, 0.892, 0.010, 0.031, -0.149, 0.015, 0.364, 0.443, -0.387, -0.236, 1.056, 0.450, 0.338, 0.630, -0.485, -0.742, -1.009, -0.108, -0.964, -1.254, -1.275, -0.962, -1.274, -1.037, -1.650, -1.513, -0.019, -0.747, -0.300, -0.195, 0.102, 0.308, -0.698, -5.000, -0.959, -0.536, -1.510, -5.000, -0.931, -0.682, -1.683, -1.089, -0.201, -0.265, -0.650, -0.416, 0.308, 0.680, -0.079, -5.000, -0.758, -0.163, -0.183, -0.409, -0.233, 0.119, -0.463, -0.692, 0.812, 0.910, 0.971, 0.440, 0.224, 0.377, -0.485, 0.642, -0.230, -0.342, -0.473, -0.525, 0.061, 0.403, -0.508, -0.320, 0.615, 0.323, 0.177, 0.235, -0.803, -1.270, -1.472, -0.350, -0.945, -1.264, -0.948, -1.124, -1.626, -1.106, -1.593, -1.678, 0.028, -0.958, -0.949, -0.452, -0.362, -0.027, -1.114, -5.000, -1.451, -1.378, -1.615, -5.000, -1.269, -1.121, -1.555, -1.649, -0.196, -0.306, -0.694, -0.350, 0.057, 0.577, -0.176, -5.000, -1.237, -0.794, -0.823, -1.047, -0.934, -0.682, -0.939, -1.095, 0.091, 0.534, 0.591, -0.065, -0.224, 0.533, 0.262, 0.619, -0.687, -0.047, -0.263, -0.622, -0.412, 0.165, -0.671, -0.496, 0.427, 0.469, 0.418, 0.177, -0.546, -0.594, -0.683, -0.390, -0.641, -0.445, -0.702, -0.784, -0.974, -0.923, -1.444, -1.061, -0.076, -0.496, -0.267, -0.328, 0.105, 0.644, -0.211, -5.000, -0.877, -0.217, -0.974, -5.000, -0.692, -0.614, -0.976, -1.100, 0.053, 0.383, 0.524, 0.089, 0.645, 1.089, 0.569, -5.000, -0.593, 0.248, 0.307, -0.355, -0.247, 0.255, -0.166, -0.585, 0.719, 0.994, 1.234, 0.346, 0.465, 0.937, 0.611, 0.930, -0.164, 0.655, 0.213, -0.189, 0.281, 0.484, 0.012, -0.270, 0.802, 0.777, 0.755, 0.640, -0.136, 0.373, -0.013, 0.442, -0.713, -0.074, -0.231, -0.906, -0.469, -0.160, -0.318, -0.843, 0.439, 0.453, 0.443, 0.210, 0.207, 0.806, -0.068, -5.000, -0.614, 0.011, -0.830, -5.000, -0.735, -0.457, -1.196, -0.915, 0.200, 0.263, 0.914, 0.470, 0.670, 1.254, 0.567, -5.000, -0.407, 0.652, 0.528, -0.056, 0.362, 0.702, -0.050, -0.217, 0.916, 1.285, 1.376, 0.727, 0.883, 1.099, 0.401, 1.131, 0.007, 0.394, 0.108, -0.166, 0.336, 0.556, -0.364, -0.214, 1.172, 0.727, 0.518, 0.810, 0.257, 0.250, -0.112, 0.619, -0.215, -0.114, -0.573, -0.035, -0.528, -0.228, -1.010, -0.744, 0.841, 0.224, 0.057, 0.508, -0.198, 0.149, -0.521, -5.000, -1.030, -0.592, -1.380, -5.000, -0.725, -0.877, -1.405, -1.144, -0.002, 0.047, -0.398, -0.534, 0.049, 0.475, -0.247, -5.000, -1.168, -0.487, -0.422, -1.053, -0.260, -0.202, -0.577, -0.916, 0.242, 0.680, 0.796, 0.145, 0.391, 0.575, -0.339, 0.246, -0.229, -0.225, -0.667, -0.407, -0.087, -0.243, -0.660, -0.299, 0.292, -0.190, -0.162, 0.023, -0.137, 0.105, -0.445, 0.155, -0.492, -0.400, -0.720, -0.566, -0.479, -0.547, -0.999, -0.935, 0.430, -0.362, -0.581, -0.404, -0.175, 0.046, -0.562, -5.000, -1.451, -0.827, -1.360, -5.000, -1.273, -1.023, -1.238, -0.916, -0.320, 0.031, -0.038, -0.565, 0.143, 0.678, 0.100, -5.000, -0.960, -0.501, -0.461, -0.745, -0.516, -0.225, -0.340, -0.770, 0.320, 0.654, 0.690, 0.059, -0.407, 0.359, -0.047, 0.134, -0.654, -0.219, -0.498, -0.793, -0.226, -0.039, -0.419, -0.698, 0.119, 0.031, 0.354, -0.119, -0.449, -0.001, -0.370, -0.062, -0.570, -0.008, -0.331, -0.740, -0.460, -0.187, -0.755, -1.148, 0.012, 0.123, 0.121, -0.100, 0.660, 1.080, 0.179, -5.000, 0.090, 0.529, -0.138, -5.000, -0.184, 0.121, -0.504, -0.498, 0.101, 0.697, 0.540, 0.227, 1.052, 1.422, 0.920, -5.000, 0.004, 0.926, 0.925, 0.399, 0.197, 0.714, 0.388, -0.086, 0.699, 1.240, 1.291, 0.521, 1.141, 1.375, 0.911, 1.277, 0.585, 1.055, 0.712, 0.360, 1.061, 1.060, 0.429, 0.587, 1.278, 1.080, 0.793, 0.905, 0.689, 0.869, 0.463, 0.812, 0.255, 0.527, 0.018, 0.007, 0.147, 0.536, -0.385, -0.072, 0.906, 0.613, 0.341, 0.761, 0.291, 0.566, 0.023, -5.000, -0.188, 0.082, -0.509, -5.000, -0.012, -0.369, -1.131, -0.558, 0.253, 0.005, 0.639, 0.145, 0.679, 1.052, 0.136, -5.000, -0.180, 0.534, 0.452, 0.101, 0.521, 0.726, 0.062, 0.052, 0.900, 1.206, 1.117, 0.486, 0.763, 0.917, 0.124, 1.117, 0.243, 0.083, 0.060, 0.260, 0.485, 0.578, -0.393, -0.005, 1.168, 0.444, -0.046, 0.562, 0.048, -0.178, -0.644, 0.512, 0.129, -0.181, -0.386, 0.176, 0.147, -0.199, -0.758, -0.341, 0.855, 0.033, -0.251, 0.517, 0.473, 0.865, 0.007, -5.000, 0.119, 0.304, -0.710, -5.000, 0.140, -0.069, -1.082, -0.268, -0.034, -0.136, -0.424, 0.168, 0.791, 0.803, 0.331, -5.000, 0.044, 0.523, 0.359, 0.359, 0.455, 0.693, 0.012, 0.045, 1.000, 1.134, 0.879, 0.623, 0.711, 0.682, -0.249, 0.865, 0.369, -0.021, -0.182, -0.067, 0.620, 0.590, -0.137, 0.179, 0.803, 0.082, -0.230, -0.050, -0.019, -0.284, -0.679, 0.489, 0.075, -0.037, -0.358, -0.377, 0.020, -0.076, -0.527, -0.329, 0.793, -0.401, -0.267, 0.160, 0.487, 0.717, -0.315, -5.000, -0.615, -0.093, -0.592, -5.000, -0.690, -0.347, -1.013, -0.576, -0.013, 0.177, -0.059, -0.378, 0.773, 0.970, 0.153, -5.000, -0.316, 0.521, 0.395, 0.256, 0.169, 0.181, 0.089, -0.055, 0.632, 1.018, 0.937, 0.381, 0.824, 0.910, 0.196, 0.964, 0.245, 0.398, 0.273, 0.057, 0.693, 0.795, 0.421, 0.151, 0.761, 0.506, 0.402, 0.475, 0.538, 0.403, 0.028, 0.548, 0.187, 0.322, 0.177, -0.268, 0.244, 0.294, -0.235, -0.231, 0.656, 0.297, 0.216, 0.329, -0.164, -0.557, -0.843, -5.000, -0.826, -1.080, -1.676, -5.000, -0.304, -0.723, -1.072, -0.954, 0.014, 0.233, -0.083, 0.122, 0.144, 0.299, -0.285, -5.000, -0.518, -0.469, -0.417, -0.273, -0.348, 0.081, -0.431, -0.570, 0.474, 0.451, 0.402, 0.498, 0.135, 0.336, -0.047, 0.470, 0.026, 0.086, 0.067, 0.045, 0.449, 0.544, -0.024, 0.073, 0.616, 0.082, 0.136, 0.000, -0.172, -0.260, -0.446, 0.151, -0.249, -0.611, -0.785, -0.661, 0.210, 0.175, -0.312, -0.599, 0.162, -0.005, -0.144, -0.005, -0.005, 0.038, -0.741, -5.000, -0.867, -1.006, -1.662, -5.000, -0.674, -1.101, -1.801, -0.899, 0.317, -0.345, 0.011, 0.010, 0.658, 0.762, -0.142, -5.000, -0.122, 0.036, -0.028, 0.022, -0.081, -0.221, -0.564, 0.033, 0.803, 0.805, 0.706, 0.702, 0.453, 0.252, -0.521, 1.027, 0.057, -0.561, -0.181, -0.280, 0.472, 0.252, -0.219, 0.127, 0.815, 0.065, -0.158, 0.174, -0.418, -0.828, -0.883, 0.317, -0.257, -1.008, -0.884, -0.327, -0.627, -0.915, -1.441, -0.612, 0.442, -0.503, -0.362, 0.153, -0.401, -0.591, -1.330, -5.000, -0.820, -1.236, -2.377, -5.000, -0.500, -1.209, -1.553, -0.976, -1.934, -1.187, -1.468, -0.795, 0.252, -0.104, -0.767, -5.000, -0.527, -0.698, -0.933, -0.534, -0.341, -0.478, -0.767, -0.098, 0.476, 0.141, -0.075, 0.400, -0.364, -0.504, -0.875, 0.345, -0.422, -0.901, -0.837, -0.442, -0.123, -0.231, -0.501, -0.376, -0.061, -0.869, -0.633, -0.393, -0.807, -1.271, -1.264, -0.303, -0.554, -0.988, -0.991, -0.861, -0.464, -1.085, -1.259, -0.418, 0.004, -1.247, -1.067, -0.617, -0.133, 0.082, -0.738, -5.000, -0.986, -0.720, -1.408, -5.000, -0.989, -0.555, -0.766, -0.347, -0.348, 0.036, -0.805, -0.374, 0.469, 0.926, 0.129, -5.000, -0.548, -0.096, -0.199, 0.067, -0.441, -0.217, -0.386, -0.397, 0.508, 0.617, 0.825, 0.326, 0.757, 0.876, 0.522, 0.838, 0.571, 0.570, 0.595, 0.240, 1.021, 1.084, 0.702, 0.611, 0.835, 0.674, 0.714, 0.466, 0.072, -0.030, -0.614, 0.296, 0.035, 0.018, -0.201, -0.192, 0.355, 0.227, -0.482, -0.388, 0.431, 0.102, 0.189, 0.057, -0.609, -0.534, -1.102, -5.000, -1.452, -1.293, -1.567, -5.000, -0.696, -0.887, -1.660, -1.311, -0.060, -0.422, -0.079, -0.015, -0.055, 0.387, -0.302, -5.000, -0.966, -0.646, -0.540, -0.666, -0.923, -0.478, -0.761, -0.940, 0.545, 0.517, 0.502, 0.297, -0.275, 0.375, -0.199, 0.438, -0.779, -0.120, -0.496, -0.715, -0.505, -0.309, -0.802, -0.977, 0.664, 0.416, 0.260, 0.090, -0.799, -0.853, -1.086, -0.489, -0.863, -1.435, -2.253, -1.785, -0.403, -0.018, -0.184, -0.573, 0.416, -0.046, 0.290, -0.264, -0.535, -0.222, -1.238, -5.000, -0.831, -1.094, -1.902, -5.000, -1.361, -1.528, -2.394, -1.786, -0.381, -0.419, 0.314, 0.117, 0.562, 0.747, -0.198, -5.000, -0.345, -0.295, -0.276, -0.250, -0.360, -0.476, -0.805, -0.588, 0.795, 0.750, 0.674, 0.591, 0.003, 0.198, -0.527, 0.426, -0.390, -0.618, -0.609, -0.440, 0.095, -0.101, -0.885, -0.552, 0.787, 0.114, -0.091, 0.256, -0.880, -0.872, -1.306, -0.379, -1.027, -1.433, -1.298, -1.252, -1.190, -1.282, -2.049, -1.676, 0.026, -0.590, -0.463, -0.051, -0.452, -0.018, -1.476, -5.000, -0.985, -1.537, -2.270, -5.000, -1.245, -1.538, -2.546, -1.810, -0.174, -0.913, -1.253, -1.112, 0.034, 0.303, -0.281, -5.000, -0.867, -0.678, -0.956, -0.606, -0.400, -0.189, -0.938, -0.954, 0.611, 0.615, 0.621, 0.336, -0.185, -0.068, -0.967, 0.300, -0.650, -0.871, -1.031, -1.077, -0.137, -0.023, -0.993, -0.653, 0.458, -0.069, -0.268, -0.247, -1.147, -1.350, -2.013, -0.694, -1.011, -1.330, -1.486, -2.023, -1.677, -1.618, -3.212, -1.660, -0.425, -1.312, -1.008, -1.096, -0.837, -0.597, -0.429, -5.000, -1.585, -1.560, -2.180, -5.000, -1.635, -1.364, -2.256, -1.783, -1.107, -0.658, -0.904, -0.997, -0.341, 0.116, -0.241, -5.000, -0.955, -1.089, -1.223, -1.205, -1.715, -0.808, -0.828, -1.228, -0.055, 0.149, -0.035, 0.118, -0.206, -0.012, -0.311, 0.022, -0.876, -0.450, -0.598, -0.869, -0.434, -0.034, -1.067, -0.796, 0.146, 0.136, 0.173, -0.072, -1.043, -0.961, -1.172, -0.346, -0.826, -1.080, -1.263, -1.333, -0.959, -0.813, -1.117, -1.517, -0.522, -0.597, -0.727, -0.653, -0.847, -0.388, -1.008, -5.000, -1.714, -1.749, -2.644, -5.000, -1.257, -1.426, -1.734, -1.395, -0.099, -0.188, -0.239, -0.249, 0.113, 0.331, 0.020, -5.000, -0.651, -0.844, -0.620, -0.950, -0.714, -0.266, -0.729, -1.479, 0.413, 0.538, 0.742, 0.266, 0.049, 0.191, -0.722, 0.352, -0.227, -0.122, -0.356, -0.618, -0.180, -0.045, -0.506, -0.272, 0.550, 0.319, 0.244, 0.148, -0.210, -0.420, -0.659, -0.276, -0.998, -1.383, -1.316, -1.212, -0.826, -0.424, -1.116, -0.583, -0.067, -0.124, -0.023, -0.115, -0.561, -0.295, -1.295, -5.000, -1.358, -1.030, -1.820, -5.000, -1.181, -1.210, -2.334, -1.455, -0.107, -0.358, 0.243, -0.006, 0.353, 0.668, -0.079, -5.000, -0.312, -0.358, -0.365, -0.675, -0.238, -0.063, -0.818, -0.565, 0.534, 0.691, 0.708, 0.232, 0.167, 0.147, -0.448, 0.262, -0.646, -0.840, -0.895, -0.916, -0.239, -0.294, -1.076, -0.786, 0.642, 0.070, -0.218, -0.010, -0.670, -0.761, -1.126, -0.267, -0.737, -1.277, -1.450, -1.302, -0.890, -1.043, -1.703, -1.508, -0.069, -0.638, -0.545, -0.139, -0.788, -0.807, -1.604, -5.000, -1.387, -1.584, -1.850, -5.000, -1.222, -1.707, -2.200, -1.393, -0.671, -1.281, -1.444, -1.090, -0.604, -0.361, -0.392, -5.000, -1.352, -1.407, -1.452, -1.744, -0.786, -1.077, -1.227, -1.278, 0.041, 0.112, -0.110, 0.038, -0.524, -0.706, -1.331, -0.398, -1.168, -1.677, -2.091, -1.384, -0.437, -0.918, -1.061, -1.307, -0.375, -0.826, -0.725, -0.757, -0.941, -1.042, -1.429, -0.628, -1.021, -1.486, -1.690, -1.590, -1.290, -1.332, -1.413, -1.408, -0.542, -1.236, -1.269, -1.082, -0.790, -0.653, -1.347, -5.000, -1.696, -2.082, -2.435, -5.000, -1.195, -1.698, -2.054, -1.622, -0.440, -0.808, -1.046, -0.794, -0.201, -0.272, -0.300, -5.000, -1.246, -1.045, -1.204, -0.854, -0.658, -0.814, -0.904, -1.079, 0.151, 0.011, 0.060, -0.017, -0.750, -0.382, -0.707, -0.311, -1.060, -0.948, -1.259, -0.956, -0.702, -0.460, -0.935, -0.939, -0.413, -0.309, 0.227, -0.133, -0.603, -0.916, -0.854, -0.578, -0.999, -0.889, -1.272, -1.426, -0.759, -0.970, -1.716, -1.095, -0.335, -0.704, -0.783, -0.785, 0.332, 0.582, 0.014, -5.000, -0.388, -0.302, -0.806, -5.000, -0.266, -0.470, -0.912, -0.618, 0.207, 0.241, 0.123, 0.181, 0.784, 1.139, 0.692, -5.000, -0.032, 0.390, 0.496, 0.047, 0.064, 0.551, -0.031, -0.309, 0.661, 1.048, 1.068, 0.603, 0.767, 1.015, 0.413, 1.006, 0.209, 0.654, 0.615, -0.041, 0.741, 0.752, 0.117, 0.425, 1.043, 0.838, 0.583, 0.680, 0.304, 0.414, -0.129, 0.462, -0.195, -0.121, -0.239, -0.398, -0.023, 0.020, -0.434, -0.565, 0.578, 0.343, 0.307, 0.221, -0.208, -0.242, -0.818, -5.000, -0.843, -0.974, -2.115, -5.000, -0.618, -1.302, -2.026, -1.252, -0.197, -0.105, -0.044, -0.402, 0.375, 0.717, -0.229, -5.000, -0.480, -0.098, -0.087, -0.240, 0.097, 0.049, -0.437, -0.255, 0.533, 0.886, 0.718, 0.314, 0.260, 0.522, -0.320, 0.663, -0.275, -0.371, -0.587, -0.365, 0.171, 0.232, -0.845, -0.272, 0.794, -0.028, -0.219, 0.090, -0.017, -0.441, -0.677, 0.109, -0.474, -0.755, -0.942, -0.527, -0.429, -0.744, -1.171, -0.797, 0.386, -0.493, -0.313, -0.041, -0.166, 0.330, -0.602, -5.000, -0.480, -0.682, -1.519, -5.000, -0.451, -0.829, -1.511, -0.619, -0.411, -0.765, -0.771, -0.615, 0.518, 0.605, 0.046, -5.000, -0.268, 0.052, -0.272, -0.066, -0.005, 0.170, -0.304, -0.197, 0.585, 0.639, 0.369, 0.491, 0.201, 0.439, -0.539, 0.461, -0.151, -0.287, -0.676, -0.520, 0.016, 0.106, -0.632, -0.201, 0.253, -0.111, -0.242, -0.459, -0.341, -0.325, -0.791, 0.148, -0.600, -0.425, -0.801, -0.594, -0.380, -0.547, -1.523, -0.849, 0.107, -0.637, -0.789, -0.348, -0.126, 0.100, -0.423, -5.000, -0.701, -0.522, -1.500, -5.000, -0.441, -0.756, -1.207, -0.561, -0.231, -0.346, -0.427, -0.247, 0.533, 0.894, 0.091, -5.000, -0.507, -0.030, -0.058, -0.357, -0.439, 0.083, -0.190, -0.167, 0.566, 0.799, 0.643, 0.372, 0.430, 0.728, -0.004, 0.528, -0.152, 0.040, -0.247, -0.392, 0.407, 0.555, -0.069, -0.022, 0.506, 0.170, 0.467, 0.215, -0.202, 0.181, -0.288, 0.193, -0.032, 0.107, -0.182, -0.594, -0.009, -0.095, -0.834, -0.344, 0.121, -0.088, -0.208, -0.033 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_24(struct _training *tptr) {
  struct _training tinf = {
    0.524, 11, 4.350, { 2.094, 0.213, 0.694 }, { 1.116, -0.820, -2.795 }, 0, 
    { 0.057, -0.460, -0.728, -0.797, -0.738, -4.000, -0.451, -0.763, 0.292, -0.769, 0.553, -4.000, -0.879, -0.075, -0.980, 0.790, 0.493, -4.000, 1.019, 0.429, -0.375, -4.000, 1.316, -0.407, 1.090, -4.000, 0.559, 1.765 }, 
    {{ -0.145, 0.114, 0.377, -0.700},{ -0.465, -0.291, 0.321, 0.209},{ 0.038, -0.130, 0.001, 0.090},{ 0.019, -0.130, 0.053, 0.055},{ -0.024, -0.070, 0.085, 0.001},{ -0.061, -0.087, 0.037, 0.104},{ 0.011, -0.075, 0.033, 0.031},{ -0.012, 0.055, 0.042, -0.102},{ -0.056, -0.077, -0.026, 0.153},{ -0.032, -0.176, -0.003, 0.193},{ -0.051, -0.003, -0.022, 0.074},{ 0.009, -0.117, -0.019, 0.126},{ 0.137, -0.159, -0.012, 0.028},{ 0.163, -0.115, 0.026, -0.091},{ 0.021, -0.115, -0.029, 0.122},{ 0.055, -0.217, 0.001, 0.146},{ -0.083, 0.078, 0.050, -0.069},{ -0.030, -0.065, 0.031, 0.062},{ 0.053, -0.067, 0.019, -0.004},{ -0.080, 0.048, 0.057, -0.043},{ 0.016, -0.055, -0.029, 0.072},{ 0.097, -0.122, 0.019, 0.004},{ -0.022, 0.035, 0.061, -0.091},{ -0.027, -0.065, 0.024, 0.067},{ 0.083, -0.060, -0.006, -0.017},{ -0.004, 0.072, -0.012, -0.067},{ 0.004, -0.065, -0.003, 0.067},{ 0.043, -0.015, -0.077, 0.053},{ 0.028, 0.035, 0.033, -0.111},{ -0.100, -0.008, 0.068, 0.026},{ -0.014, 0.017, -0.006, 0.001},{ 0.031, 0.087, -0.034, -0.100} }, 
    {{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}} }, 
    0.000, { 0.173, 0.403, 0.041, -5.000, -0.399, 0.230, -0.102, -5.000, -0.230, -0.007, -0.353, -0.542, -0.381, 0.102, 0.167, 0.286, -0.046, 0.401, 0.076, -5.000, -0.637, 0.220, -0.584, -0.176, -0.343, -0.020, -0.271, -0.635, 0.341, 0.466, 0.203, 0.029, 0.036, 0.531, -0.198, 0.344, -0.038, 0.326, 0.237, -0.522, -0.218, 0.282, -0.086, -0.515, 0.008, 0.498, 0.533, -0.158, 0.002, 0.317, -0.280, 0.291, -0.127, 0.472, 0.049, -0.594, -0.128, 0.157, 0.152, -0.180, 0.136, 0.369, 0.326, 0.145, 0.595, 0.852, 0.345, -5.000, 0.056, 0.715, 0.135, -5.000, 0.500, 0.670, 0.467, 0.147, 0.329, 0.723, 0.782, 0.841, 0.384, 0.765, 0.469, -5.000, -0.247, 0.303, 0.090, 0.137, 0.264, 0.588, 0.270, -0.079, 0.563, 0.893, 0.612, 0.529, 0.363, 0.758, -0.003, 0.749, 0.543, 0.598, 0.456, -0.138, 0.564, 0.718, 0.492, 0.161, 0.709, 0.463, 0.951, 0.373, 0.538, 0.828, 0.211, 0.706, 0.625, 0.607, 0.579, -0.085, 0.261, 0.647, 0.415, 0.246, 0.685, 0.646, 0.723, 0.572, 0.002, 0.650, 0.227, -5.000, -0.397, 0.554, -0.242, -5.000, 0.128, 0.176, -0.339, -0.362, -0.117, 0.123, 0.109, 0.120, 0.055, 0.511, 0.027, -5.000, -0.519, 0.162, -0.423, -0.048, -0.147, 0.053, -0.333, -0.647, 0.281, 0.650, 0.316, 0.267, -0.092, 0.264, -0.600, 0.020, -0.278, -0.052, -0.016, -0.723, 0.084, 0.370, -0.031, -0.460, -0.059, -0.135, -0.005, -0.254, 0.178, 0.477, -0.231, 0.411, 0.238, 0.410, 0.484, -0.485, -0.062, 0.140, -0.008, -0.192, 0.459, 0.499, 0.394, 0.149, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.611, -0.367, -0.598, -5.000, -1.057, -0.623, -1.038, -5.000, -0.772, -0.485, -0.734, -1.002, -0.522, -0.128, 0.165, 0.170, -0.646, -0.166, -0.430, -5.000, -1.215, -0.672, -1.074, -0.792, -0.961, -0.592, -0.881, -1.416, -0.134, -0.265, -0.219, -0.365, -0.606, -0.306, -0.773, -0.268, -0.723, -0.509, -0.476, -1.109, -0.569, -0.474, -0.832, -1.012, -0.695, -0.465, -0.042, -0.668, -0.269, -0.328, -0.599, -0.097, -0.573, -0.345, -0.882, -0.623, -0.220, -0.198, -0.139, -0.648, -0.164, -0.305, -0.120, -0.481, 0.277, 0.630, 0.174, -5.000, -0.400, 0.365, -0.202, -5.000, 0.233, 0.347, 0.156, -0.251, 0.268, 0.697, 0.811, 0.616, 0.206, 0.673, 0.356, -5.000, -0.537, 0.250, -0.031, 0.044, 0.078, 0.405, -0.052, -0.392, 0.466, 0.699, 0.185, 0.096, 0.143, 0.507, -0.020, 0.646, 0.170, 0.466, 0.349, -0.306, 0.417, 0.498, 0.258, -0.205, 0.446, 0.169, 0.691, 0.328, 0.298, 0.594, 0.117, 0.738, 0.128, 0.443, 0.202, -0.483, -0.042, 0.245, 0.071, -0.189, 0.394, 0.227, 0.404, 0.248, -0.207, 0.309, -0.255, -5.000, -0.782, 0.177, -0.533, -5.000, -0.391, -0.287, -0.804, -1.103, -0.277, -0.262, -0.284, -0.325, -0.359, 0.263, -0.387, -5.000, -0.865, -0.317, -0.721, -0.725, -0.389, -0.451, -1.037, -1.069, -0.138, 0.204, -0.058, -0.020, -0.244, 0.078, -0.806, -0.061, -0.361, -0.173, -0.341, -0.843, -0.354, 0.003, -0.504, -0.789, -0.067, -0.333, -0.443, -0.289, -0.264, 0.042, -0.502, 0.087, -0.116, 0.047, -0.118, -0.981, -0.490, -0.192, -0.751, -0.916, 0.116, -0.093, -0.388, -0.327, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.038, 0.453, -0.130, -5.000, -0.623, 0.183, -0.529, -5.000, -0.338, -0.260, -0.532, -0.715, -0.276, 0.286, 0.203, 0.257, -0.427, 0.119, -0.264, -5.000, -1.047, -0.311, -0.505, -0.205, -0.622, -0.511, -0.631, -1.079, 0.171, 0.138, 0.027, -0.153, -0.120, 0.483, -0.096, 0.331, -0.138, 0.347, 0.129, -0.647, -0.154, 0.106, 0.022, -0.411, 0.135, 0.429, 0.686, 0.001, -0.014, 0.328, -0.248, 0.508, -0.053, 0.196, -0.283, -0.881, -0.532, -0.023, -0.376, -0.363, 0.344, 0.059, 0.180, -0.037, 0.156, 0.518, 0.097, -5.000, -0.709, 0.215, -0.522, -5.000, 0.005, 0.070, -0.287, -0.420, 0.179, 0.266, 0.407, 0.634, -0.092, 0.512, 0.087, -5.000, -0.789, -0.071, -0.277, -0.342, -0.071, 0.187, -0.341, -0.865, 0.306, 0.342, 0.177, 0.068, -0.331, 0.120, -0.437, 0.139, -0.379, -0.012, -0.228, -1.040, -0.006, 0.308, -0.036, -0.382, 0.046, 0.078, 0.383, -0.150, 0.435, 0.599, 0.023, 0.697, 0.118, 0.377, 0.158, -0.399, -0.053, 0.260, -0.134, -0.204, 0.429, 0.275, 0.269, 0.217, -0.270, 0.121, -0.220, -5.000, -0.865, 0.068, -0.671, -5.000, -0.327, -0.308, -0.858, -0.803, -0.275, -0.003, 0.069, 0.128, -0.437, -0.076, -0.368, -5.000, -0.943, -0.258, -0.814, -0.800, -0.452, -0.472, -0.957, -0.971, -0.204, 0.049, -0.168, -0.050, -0.122, 0.273, -0.508, 0.086, -0.523, -0.238, -0.349, -0.707, -0.182, -0.232, -0.420, -0.665, -0.227, -0.236, -0.128, -0.166, 0.125, 0.344, -0.365, 0.347, -0.241, 0.120, -0.130, -0.632, -0.152, -0.106, -0.417, -0.681, 0.103, -0.062, 0.014, -0.211, -0.482, -0.040, -0.368, -5.000, -1.339, -0.420, -1.182, -5.000, -0.534, -0.458, -0.781, -0.748, -0.581, -0.199, -0.182, -0.102, -0.232, 0.119, -0.205, -5.000, -1.209, -0.675, -0.949, -0.696, -0.481, -0.708, -1.102, -1.165, -0.270, -0.005, -0.384, -0.113, -0.642, -0.070, -0.876, -0.269, -0.782, -0.295, -0.428, -1.338, -0.594, -0.136, -0.532, -0.619, -0.374, -0.151, -0.110, -0.437, -0.385, 0.011, -0.613, -0.089, -0.436, -0.233, -0.452, -1.110, -0.732, -0.512, -0.561, -0.773, -0.126, -0.107, -0.087, -0.181, -0.175, 0.199, -0.291, -5.000, -0.803, -0.080, -0.278, -5.000, -0.128, -0.229, -0.598, -0.729, -0.450, -0.378, 0.057, -0.095, -0.219, 0.006, -0.158, -5.000, -0.473, -0.385, -0.776, -0.693, -0.541, -0.246, -0.569, -0.701, -0.138, 0.011, -0.204, -0.321, -0.271, 0.065, -0.189, -0.023, -0.341, -0.081, -0.311, -0.800, -0.343, -0.142, -0.752, -0.965, 0.140, -0.225, -0.004, -0.374, 0.305, 0.334, 0.055, 0.311, 0.038, -0.198, -0.376, -0.522, -0.154, -0.069, -0.231, -0.341, 0.263, 0.093, 0.095, -0.132, 0.408, 0.434, 0.133, -5.000, -0.071, 0.200, -0.221, -5.000, 0.068, 0.094, -0.125, -0.274, -0.272, 0.185, 0.382, 0.525, -0.014, 0.376, 0.115, -5.000, -0.455, 0.059, -0.183, -0.301, 0.211, 0.312, -0.123, -0.348, 0.244, 0.433, 0.077, 0.158, -0.161, 0.383, -0.209, 0.370, -0.250, 0.302, 0.155, -0.609, 0.301, 0.393, 0.165, -0.102, 0.202, 0.098, 0.383, -0.031, 0.371, 0.528, 0.277, 0.742, 0.269, 0.352, 0.485, -0.289, 0.397, 0.322, 0.149, 0.107, 0.285, 0.404, 0.493, 0.258, 0.333, 0.726, 0.503, -5.000, 0.138, 0.779, 0.143, -5.000, 0.122, 0.205, -0.087, -0.233, -0.066, 0.119, 0.202, 0.318, 0.210, 0.648, 0.223, -5.000, -0.434, 0.104, -0.340, -0.064, -0.345, 0.044, -0.243, -0.504, 0.274, 0.439, 0.265, 0.309, 0.327, 0.692, -0.157, 0.513, 0.212, 0.300, 0.379, -0.358, 0.243, 0.680, 0.216, 0.154, -0.126, 0.193, 0.362, 0.198, 0.240, 0.818, 0.200, 0.504, 0.076, 0.568, 0.405, -0.359, -0.274, 0.319, -0.026, -0.063, 0.229, 0.353, 0.204, 0.088, 0.284, 0.803, 0.322, -5.000, -0.124, 0.493, -0.111, -5.000, 0.276, 0.289, 0.029, -0.221, 0.031, 0.158, 0.178, 0.119, 0.332, 0.743, 0.462, -5.000, -0.478, 0.325, -0.095, 0.123, 0.049, 0.255, -0.079, -0.192, 0.271, 0.680, 0.394, 0.458, 0.007, 0.718, 0.085, 0.379, -0.117, 0.457, 0.432, -0.431, 0.006, 0.785, 0.369, -0.019, 0.173, 0.494, 0.506, 0.080, 0.329, 0.798, 0.108, 0.421, 0.063, 0.722, 0.538, -0.357, 0.094, 0.481, 0.106, -0.228, 0.291, 0.462, 0.451, 0.252, -0.065, 0.456, 0.032, -5.000, -0.763, 0.110, -0.275, -5.000, -0.481, -0.327, -0.630, -0.716, -0.589, 0.003, 0.030, 0.001, -0.392, 0.247, -0.232, -5.000, -0.840, -0.300, -0.890, -0.405, -0.544, -0.227, -0.469, -0.740, -0.057, 0.428, 0.010, -0.181, -0.291, 0.441, -0.449, 0.229, -0.399, 0.147, 0.308, -0.698, -0.153, 0.192, -0.142, -0.505, -0.070, 0.262, 0.462, -0.326, 0.065, 0.288, -0.147, 0.327, -0.187, 0.384, 0.216, -0.560, -0.261, 0.239, 0.245, -0.166, 0.253, 0.218, 0.377, 0.244, 0.526, 0.918, 0.527, -5.000, -0.067, 0.659, 0.179, -5.000, 0.229, 0.575, 0.449, 0.139, 0.025, 0.574, 0.859, 0.967, 0.246, 0.834, 0.497, -5.000, -0.398, 0.303, 0.326, 0.220, 0.125, 0.399, 0.083, -0.293, 0.495, 0.776, 0.418, 0.427, 0.136, 0.665, -0.134, 0.499, 0.146, 0.292, 0.525, -0.598, 0.136, 0.566, 0.455, -0.029, 0.231, 0.295, 0.750, -0.008, 0.531, 0.785, 0.414, 0.728, 0.422, 0.485, 0.626, -0.101, 0.238, 0.558, 0.624, 0.349, 0.607, 0.635, 0.779, 0.476, 0.080, 0.715, 0.166, -5.000, -0.436, 0.510, 0.066, -5.000, -0.166, 0.054, -0.398, -0.735, -0.292, 0.193, 0.146, 0.139, 0.038, 0.616, 0.151, -5.000, -0.547, 0.319, -0.257, -0.056, -0.244, 0.071, -0.313, -0.706, 0.201, 0.511, 0.236, 0.276, -0.232, 0.285, -0.506, -0.208, -0.105, 0.109, 0.163, -0.787, 0.126, 0.342, -0.047, -0.353, -0.286, -0.200, -0.060, -0.379, 0.098, 0.494, -0.097, 0.259, 0.492, 0.643, 0.792, -0.167, -0.045, 0.353, 0.060, 0.011, 0.446, 0.449, 0.568, 0.260, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.491, -0.147, -0.413, -5.000, -1.268, -0.574, -0.656, -5.000, -0.884, -0.633, -0.772, -1.134, -0.750, -0.209, -0.102, -0.044, -0.784, -0.401, -0.491, -5.000, -1.549, -0.871, -1.070, -1.025, -0.918, -0.697, -1.200, -1.526, -0.425, -0.346, -0.344, -0.605, -0.846, -0.326, -0.520, -0.335, -0.986, -0.394, -0.469, -1.162, -0.969, -0.313, -0.864, -1.048, -0.712, -0.578, -0.335, -0.841, -0.415, -0.637, -1.000, -0.436, -0.427, -0.673, -0.674, -1.028, -0.371, -0.621, -0.425, -0.523, -0.300, -0.034, 0.083, -0.438, 0.145, 0.400, -0.012, -5.000, -0.720, 0.257, -0.439, -5.000, -0.052, -0.040, -0.162, -0.419, -0.016, 0.355, 0.459, 0.504, -0.121, 0.605, 0.278, -5.000, -0.677, 0.204, 0.001, -0.009, -0.075, 0.012, -0.079, -0.570, 0.427, 0.464, 0.056, 0.167, -0.304, 0.175, -0.335, 0.020, -0.358, 0.184, 0.039, -0.527, -0.011, 0.192, 0.007, -0.082, -0.083, -0.072, 0.460, -0.059, -0.175, 0.199, -0.149, 0.416, 0.023, 0.215, -0.064, -0.494, -0.250, 0.020, -0.166, -0.420, 0.076, 0.035, 0.273, 0.043, -0.255, 0.403, -0.190, -5.000, -0.906, 0.181, -0.283, -5.000, -0.349, -0.220, -0.815, -1.293, -0.823, -0.131, -0.183, -0.228, -0.542, 0.307, -0.267, -5.000, -0.932, -0.363, -0.713, -0.941, -0.381, 0.029, -1.003, -1.102, -0.343, 0.067, -0.189, -0.193, -0.412, -0.007, -0.696, -0.465, -0.381, -0.062, -0.049, -0.712, -0.230, -0.046, -0.708, -0.627, -0.549, -0.310, -0.616, -0.345, -0.385, 0.029, -0.336, 0.024, -0.058, 0.225, 0.186, -0.903, -0.572, -0.179, -0.366, -0.740, -0.116, 0.069, -0.141, -0.241, -0.477, 0.167, 0.054, -5.000, -1.087, -0.239, -0.779, -5.000, -0.585, -0.435, -0.643, -0.912, -0.576, -0.100, -0.062, -0.167, -0.641, 0.161, -0.033, -5.000, -1.316, -0.613, -1.241, -0.568, -0.966, -0.859, -1.121, -1.230, -0.443, -0.091, -0.460, -0.528, 0.047, 0.271, -0.236, 0.023, -0.122, 0.194, 0.312, -1.036, 0.088, 0.198, -0.202, -0.669, 0.004, -0.059, 0.234, -0.376, -0.268, 0.161, -0.252, -0.146, -0.287, 0.095, 0.165, -1.083, -0.342, -0.092, -0.303, -0.687, -0.105, -0.031, 0.093, -0.313, -0.274, 0.530, -0.063, -5.000, -0.771, 0.132, -0.585, -5.000, -0.401, -0.172, -0.438, -0.753, -0.489, 0.077, 0.300, 0.302, -0.641, 0.062, -0.193, -5.000, -1.022, -0.398, -0.536, -0.167, -0.825, -0.381, -0.623, -0.805, 0.029, 0.285, -0.118, -0.233, -0.128, 0.639, -0.098, 0.543, -0.208, 0.348, 0.441, -0.588, 0.012, 0.397, -0.036, -0.617, -0.000, 0.452, 0.621, -0.110, -0.003, 0.447, 0.166, 0.317, -0.115, 0.272, 0.255, -0.773, -0.545, -0.128, -0.674, -0.649, -0.019, -0.131, -0.059, 0.004, 0.199, 0.661, 0.133, -5.000, -0.836, 0.181, -0.367, -5.000, -0.117, 0.119, -0.181, -0.471, -0.241, 0.241, 0.660, 0.655, -0.082, 0.568, 0.342, -5.000, -0.600, 0.047, -0.001, -0.135, -0.104, 0.223, -0.220, -0.761, 0.189, 0.560, 0.297, 0.257, -0.262, 0.224, -0.519, -0.315, -0.507, -0.010, 0.121, -0.921, -0.036, 0.228, -0.371, -0.574, -0.090, 0.131, 0.351, -0.141, 0.299, 0.588, 0.161, 0.811, -0.052, 0.308, 0.097, -0.473, -0.192, 0.192, -0.036, -0.313, 0.333, 0.198, 0.330, 0.183, -0.334, 0.271, -0.046, -5.000, -1.040, 0.083, -0.504, -5.000, -0.398, -0.180, -0.502, -1.101, -0.539, 0.030, 0.065, 0.106, -0.708, 0.065, -0.258, -5.000, -1.096, -0.521, -0.563, -0.717, -0.561, -0.369, -0.676, -0.972, -0.320, -0.078, -0.116, 0.018, -0.390, 0.218, -0.631, 0.110, -0.657, -0.208, -0.206, -0.756, -0.339, -0.044, -0.448, -0.647, -0.305, -0.304, -0.084, -0.292, -0.072, 0.384, -0.135, 0.177, -0.449, 0.186, 0.149, -0.605, -0.089, -0.035, -0.314, -0.610, -0.068, 0.161, 0.064, -0.458, -0.652, -0.080, -0.593, -5.000, -1.436, -0.490, -1.186, -5.000, -0.936, -0.651, -0.899, -1.038, -1.088, -0.527, -0.336, -0.273, -0.375, 0.199, -0.369, -5.000, -1.166, -0.611, -0.713, -0.768, -0.854, -0.545, -0.837, -0.862, -0.185, 0.176, -0.306, -0.091, -0.938, -0.215, -0.718, -0.459, -0.814, -0.418, -0.263, -1.263, -0.561, -0.225, -0.711, -0.921, -0.823, -0.271, -0.074, -0.637, -0.547, -0.200, -0.635, -0.278, -0.653, -0.203, -0.163, -1.021, -0.877, -0.546, -0.656, -0.696, -0.214, -0.312, 0.050, -0.300, -0.125, 0.561, 0.195, -5.000, -0.357, 0.401, -0.064, -5.000, -0.340, -0.118, -0.532, -0.607, -0.442, -0.124, 0.079, 0.191, -0.255, 0.436, 0.359, -5.000, -0.638, 0.156, 0.064, -0.254, 0.092, 0.348, 0.021, -0.195, 0.048, 0.545, 0.255, 0.256, -0.007, 0.772, 0.052, 0.565, -0.023, 0.395, 0.515, -0.445, 0.088, 0.402, -0.088, -0.228, 0.303, 0.190, 0.337, 0.078, 0.214, 0.741, 0.345, 0.495, -0.184, 0.211, 0.134, -0.578, -0.520, -0.081, -0.469, -0.581, -0.108, -0.074, -0.068, -0.078, 0.459, 0.856, 0.573, -5.000, -0.351, 0.575, 0.082, -5.000, 0.188, 0.261, 0.001, -0.333, -0.435, 0.331, 0.487, 0.579, 0.304, 0.839, 0.646, -5.000, -0.342, 0.523, 0.451, 0.048, 0.409, 0.549, 0.115, -0.059, 0.562, 0.834, 0.484, 0.503, 0.340, 0.602, 0.249, 0.841, 0.208, 0.569, 0.645, -0.374, 0.659, 0.636, 0.339, 0.022, 0.501, 0.398, 0.789, 0.089, 0.685, 1.095, 0.750, 1.045, 0.556, 0.843, 0.840, 0.038, 0.350, 0.643, 0.473, 0.213, 0.767, 0.751, 0.863, 0.546, 0.109, 0.777, 0.427, -5.000, -0.242, 0.699, 0.250, -5.000, 0.154, 0.397, -0.027, -0.203, -0.299, 0.313, 0.526, 0.368, -0.043, 0.558, 0.238, -5.000, -0.557, 0.127, -0.016, -0.133, 0.081, 0.100, -0.160, -0.468, 0.319, 0.618, 0.328, 0.364, 0.261, 0.497, -0.234, 0.141, 0.268, 0.276, 0.319, -0.427, 0.636, 0.645, 0.298, 0.016, 0.134, 0.104, 0.125, -0.205, 0.379, 0.659, -0.072, 0.480, -0.056, 0.480, 0.427, -0.531, 0.430, 0.445, 0.163, -0.136, 0.340, 0.405, 0.368, 0.102, -0.162, 0.519, 0.300, -5.000, -0.713, 0.217, -0.368, -5.000, 0.052, 0.033, -0.339, -0.425, -0.426, 0.115, -0.025, 0.248, -0.136, 0.515, 0.396, -5.000, -0.631, -0.012, -0.120, 0.046, 0.027, 0.065, -0.261, -0.432, 0.258, 0.665, 0.300, 0.192, -0.223, 0.311, -0.319, 0.021, 0.024, 0.197, 0.360, -0.770, 0.293, 0.414, 0.089, -0.220, -0.160, -0.002, 0.055, -0.405, 0.185, 0.525, -0.000, 0.280, 0.245, 0.443, 0.498, -0.490, -0.115, 0.279, 0.002, -0.306, 0.263, 0.341, 0.310, 0.041, -0.141, 0.432, -0.064, -5.000, -0.799, -0.078, -0.263, -5.000, -0.406, -0.410, -0.488, -0.647, -0.370, 0.109, -0.063, 0.134, -0.546, 0.165, -0.081, -5.000, -0.862, -0.332, -0.760, -0.404, -0.372, -0.390, -0.551, -0.877, 0.082, 0.440, -0.009, -0.114, -0.109, 0.541, 0.005, 0.626, -0.270, 0.162, 0.223, -0.686, -0.053, 0.149, -0.037, -0.476, 0.105, 0.279, 0.486, -0.020, 0.214, 0.427, -0.017, 0.396, 0.019, -0.049, -0.019, -0.634, -0.273, 0.230, 0.068, -0.243, 0.233, 0.336, 0.146, 0.296, 0.479, 0.875, 0.464, -5.000, -0.137, 0.683, 0.206, -5.000, 0.361, 0.545, 0.434, 0.010, 0.027, 0.611, 0.519, 0.683, 0.189, 0.601, 0.285, -5.000, -0.520, 0.067, 0.229, 0.099, -0.130, 0.094, -0.014, -0.563, 0.392, 0.684, 0.193, 0.149, 0.353, 0.673, 0.067, 1.049, 0.186, 0.508, 0.548, -0.202, 0.484, 0.740, 0.520, 0.285, 0.659, 0.513, 0.901, 0.381, 0.627, 0.682, 0.408, 0.995, 0.454, 0.564, 0.520, -0.219, 0.257, 0.456, 0.338, 0.180, 0.496, 0.558, 0.620, 0.445, -0.330, 0.289, -0.236, -5.000, -0.708, 0.053, -0.607, -5.000, -0.752, -0.381, -0.811, -1.016, -0.662, -0.271, -0.101, -0.639, -0.433, 0.124, -0.286, -5.000, -0.900, -0.217, -0.690, -0.619, -0.682, -0.308, -0.452, -0.929, -0.186, 0.259, -0.152, -0.095, -0.382, 0.021, -0.550, 0.015, -0.387, -0.139, -0.289, -0.705, -0.233, -0.012, -0.212, -0.561, -0.404, -0.268, -0.294, -0.470, -0.219, 0.055, -0.199, 0.420, -0.232, 0.080, -0.025, -0.681, -0.537, -0.207, -0.456, -0.451, 0.044, 0.012, -0.027, -0.175, 0.084, 0.604, -0.011, -5.000, -0.551, 0.690, -0.408, -5.000, -0.279, -0.057, -0.719, -0.532, -0.556, 0.083, -0.091, 0.214, 0.053, 0.528, 0.306, -5.000, -0.782, 0.223, -0.827, 0.064, -0.257, -0.539, -1.004, -0.862, 0.152, 0.748, 0.071, -0.129, 0.397, 1.049, 0.345, 0.902, 0.343, 0.708, 0.793, -0.370, 0.717, 0.859, 0.413, 0.050, 0.364, 0.593, 0.552, 0.282, 0.281, 0.709, 0.274, 0.847, 0.312, 0.607, 0.634, -0.460, 0.169, 0.526, 0.328, 0.120, 0.380, 0.463, 0.437, 0.183, -0.195, 0.208, -0.120, -5.000, -1.046, -0.023, -0.390, -5.000, -0.441, -0.339, -0.639, -0.823, -0.383, -0.032, 0.200, 0.301, -0.611, 0.021, -0.204, -5.000, -1.136, -0.454, -0.764, -0.434, -0.399, -0.244, -0.403, -1.051, 0.242, 0.399, 0.004, -0.124, -0.142, 0.538, -0.106, 0.473, -0.299, 0.148, 0.215, -0.714, -0.224, 0.031, -0.255, -0.563, 0.136, 0.188, 0.491, -0.170, 0.127, 0.208, -0.235, 0.281, 0.044, 0.121, -0.147, -0.930, -0.107, 0.148, 0.072, -0.104, 0.285, 0.407, 0.050, 0.115, 0.115, 0.626, 0.065, -5.000, -0.585, 0.465, -0.013, -5.000, 0.130, 0.253, 0.013, -0.235, -0.199, 0.371, 0.649, 0.627, -0.045, 0.554, 0.160, -5.000, -0.671, 0.113, 0.013, -0.071, 0.050, 0.126, -0.046, -0.473, 0.403, 0.678, 0.216, 0.120, 0.082, 0.438, -0.154, 0.569, 0.047, 0.353, 0.278, -0.490, 0.349, 0.422, 0.049, -0.110, 0.314, 0.238, 0.563, 0.125, 0.237, 0.522, 0.171, 0.740, 0.294, 0.369, 0.255, -0.303, -0.012, 0.217, 0.095, -0.195, 0.364, 0.228, 0.464, 0.108, 0.072, 0.780, 0.338, -5.000, -0.350, 0.513, 0.005, -5.000, 0.077, 0.276, -0.208, -0.629, -0.260, 0.435, 0.378, 0.451, 0.016, 0.651, 0.162, -5.000, -0.487, 0.189, -0.093, -0.244, -0.071, 0.166, -0.074, -0.742, 0.470, 0.827, 0.633, 0.449, 0.103, 0.469, -0.284, 0.422, -0.014, 0.193, 0.260, -0.494, 0.249, 0.466, 0.048, -0.353, 0.244, 0.122, 0.078, 0.125, 0.099, 0.448, 0.034, 0.671, 0.190, 0.631, 0.534, -0.597, -0.237, 0.254, 0.074, -0.281, 0.672, 0.538, 0.324, 0.100, -0.721, -0.235, -0.458, -5.000, -1.242, -0.638, -1.395, -5.000, -1.015, -0.604, -1.258, -1.106, -0.617, -0.134, -0.470, -0.618, -0.937, -0.457, -0.460, -5.000, -1.308, -0.845, -1.327, -1.092, -1.146, -0.916, -1.579, -1.586, -0.590, -0.448, -0.611, -0.506, -0.626, -0.258, -0.677, -0.056, -0.751, -0.379, -0.363, -1.231, -0.506, -0.195, -0.740, -0.984, -0.490, -0.395, -0.191, -0.649, -0.939, -0.357, -0.777, -0.244, -0.752, -0.402, -0.626, -1.305, -0.743, -0.524, -0.858, -1.062, -0.417, -0.482, -0.346, -0.803, 0.049, 0.649, 0.218, -5.000, -0.802, 0.401, -0.083, -5.000, -0.303, -0.015, -0.155, -0.544, -0.549, 0.426, 0.362, 0.432, -0.385, 0.419, 0.183, -5.000, -0.851, 0.159, -0.421, 0.005, -0.395, -0.177, -0.469, -0.807, 0.285, 0.610, 0.257, -0.010, -0.015, 0.772, 0.081, 0.621, -0.008, 0.519, 0.450, -0.605, 0.012, 0.318, 0.222, -0.451, 0.191, 0.614, 0.734, 0.028, 0.184, 0.571, 0.244, 0.449, -0.129, 0.443, 0.107, -0.754, -0.364, -0.097, -0.260, -0.327, 0.264, 0.105, 0.077, -0.107, 0.239, 0.872, 0.412, -5.000, -0.370, 0.598, -0.012, -5.000, 0.033, 0.336, -0.087, -0.358, -0.102, 0.368, 0.770, 0.739, 0.153, 0.733, 0.476, -5.000, -0.414, 0.306, 0.231, 0.079, 0.180, 0.486, 0.102, -0.331, 0.449, 0.787, 0.487, 0.407, 0.050, 0.464, -0.023, 0.694, 0.012, 0.363, 0.458, -0.614, 0.199, 0.426, 0.127, -0.178, 0.289, 0.342, 0.736, -0.006, 0.453, 0.798, 0.507, 1.024, 0.250, 0.599, 0.562, -0.158, 0.125, 0.378, 0.232, 0.025, 0.621, 0.526, 0.552, 0.299, -0.167, 0.503, 0.075, -5.000, -0.672, 0.069, -0.368, -5.000, -0.171, -0.126, -0.350, -0.818, -0.499, 0.223, 0.229, 0.149, -0.283, 0.411, 0.061, -5.000, -0.767, 0.001, -0.441, -0.344, -0.414, -0.217, -0.299, -0.749, 0.069, 0.333, 0.180, 0.093, -0.040, 0.594, -0.175, 0.300, -0.506, 0.329, 0.009, -0.620, -0.064, 0.089, -0.227, -0.330, -0.057, 0.129, 0.274, -0.118, 0.096, 0.545, 0.168, 0.554, -0.279, 0.123, 0.376, -0.598, -0.030, 0.177, -0.054, -0.345, 0.283, 0.536, 0.485, -0.174, -0.438, 0.125, -0.187, -5.000, -1.259, -0.179, -0.687, -5.000, -0.630, -0.238, -0.662, -0.808, -0.862, -0.339, -0.003, -0.156, -0.435, 0.169, 0.021, -5.000, -0.858, -0.257, -0.585, -0.580, -0.295, -0.280, -0.649, -0.895, -0.051, 0.384, 0.063, -0.061, -0.484, 0.134, -0.503, 0.241, -0.665, -0.089, -0.101, -1.079, -0.353, -0.038, -0.098, -0.654, -0.323, -0.095, 0.225, -0.284, -0.387, 0.016, -0.418, 0.203, -0.560, -0.242, -0.219, -1.070, -0.727, -0.291, -0.334, -0.766, -0.232, -0.300, 0.140, -0.155, -0.076, 0.541, 0.221, -5.000, -0.322, 0.426, -0.032, -5.000, -0.409, -0.047, -0.365, -0.544, -0.516, -0.041, 0.276, 0.328, -0.204, 0.377, 0.282, -5.000, -0.819, 0.120, 0.000, -0.299, 0.043, 0.336, 0.049, -0.273, 0.143, 0.660, 0.351, 0.278, 0.031, 0.675, 0.152, 0.663, -0.056, 0.335, 0.446, -0.411, 0.059, 0.205, -0.100, -0.396, 0.155, 0.243, 0.402, 0.047, 0.186, 0.589, 0.083, 0.622, 0.043, 0.204, 0.222, -0.657, -0.197, 0.115, -0.167, -0.270, 0.142, 0.006, -0.114, 0.120, 0.076, 0.626, 0.151, -5.000, -0.434, 0.288, -0.279, -5.000, -0.079, 0.090, -0.040, -0.392, -0.527, 0.075, 0.329, 0.516, -0.093, 0.493, 0.363, -5.000, -0.229, 0.417, 0.218, -0.169, 0.074, 0.295, 0.107, -0.483, 0.082, 0.537, 0.357, 0.190, -0.194, 0.420, -0.112, 0.638, -0.327, 0.333, 0.351, -0.740, 0.231, 0.441, 0.003, -0.018, -0.037, 0.035, 0.461, -0.260, 0.183, 0.646, 0.200, 0.805, 0.169, 0.309, 0.397, -0.260, 0.051, 0.307, 0.187, 0.042, 0.251, 0.348, 0.482, 0.092, 0.333, 0.928, 0.604, -5.000, -0.097, 0.740, 0.294, -5.000, 0.366, 0.667, 0.137, -0.192, -0.344, 0.528, 0.541, 0.476, 0.066, 0.714, 0.439, -5.000, -0.438, 0.299, 0.037, -0.121, 0.218, 0.305, 0.069, -0.329, 0.445, 0.796, 0.482, 0.462, 0.334, 0.762, 0.033, 0.648, 0.169, 0.448, 0.414, -0.337, 0.488, 0.630, 0.357, -0.167, 0.238, 0.230, 0.117, -0.029, 0.397, 0.866, 0.439, 0.840, 0.187, 0.612, 0.551, -0.266, 0.256, 0.620, 0.296, -0.051, 0.406, 0.633, 0.519, 0.189, -0.356, 0.402, 0.046, -5.000, -0.908, 0.163, -0.348, -5.000, -0.254, -0.201, -0.427, -0.601, -0.563, -0.130, 0.065, -0.014, -0.378, 0.145, 0.119, -5.000, -0.987, -0.177, -0.431, -0.390, -0.310, -0.100, -0.420, -0.596, 0.079, 0.473, -0.003, -0.028, -0.129, 0.331, -0.197, 0.241, -0.244, 0.131, 0.166, -0.735, 0.100, 0.242, -0.042, -0.463, -0.322, -0.074, -0.091, -0.368, 0.037, 0.407, -0.001, 0.313, 0.048, 0.306, 0.168, -0.598, -0.294, 0.081, -0.142, -0.515, -0.077, -0.150, -0.072, 0.004, 0.103, 0.517, -0.014, -5.000, -0.357, 0.348, -0.262, -5.000, -0.284, -0.148, -0.254, -0.361, -0.257, -0.097, -0.124, 0.251, -0.256, 0.348, -0.035, -5.000, -0.826, 0.110, -0.634, -0.160, -0.201, 0.030, 0.022, -0.451, 0.361, 0.787, 0.261, 0.187, 0.123, 0.690, -0.133, 0.390, 0.006, 0.303, 0.454, -0.558, 0.155, 0.482, 0.337, -0.078, 0.240, 0.543, 0.696, 0.133, 0.257, 0.567, -0.051, 0.152, 0.033, 0.177, 0.075, -0.664, -0.066, 0.310, 0.375, 0.071, 0.384, 0.478, 0.335, 0.355, 0.590, 0.835, 0.289, -5.000, 0.038, 0.617, 0.142, -5.000, 0.370, 0.454, 0.423, 0.054, 0.231, 0.522, 0.529, 0.751, 0.389, 0.782, 0.426, -5.000, -0.201, 0.301, 0.075, 0.240, 0.285, 0.458, 0.443, -0.167, 0.612, 0.956, 0.511, 0.556, 0.283, 0.721, 0.010, 0.396, 0.185, 0.319, 0.588, -0.223, 0.554, 0.743, 0.680, 0.288, 0.551, 0.339, 0.888, 0.202, 0.530, 0.807, 0.226, 0.372, 0.497, 0.607, 0.434, -0.072, 0.182, 0.594, 0.481, 0.319, 0.686, 0.519, 0.604, 0.524, -0.207, 0.301, -0.177, -5.000, -0.698, 0.306, -0.470, -5.000, -0.420, -0.564, -0.840, -0.621, -0.453, 0.032, -0.306, -0.163, -0.295, 0.357, -0.169, -5.000, -0.570, -0.050, -0.500, -0.300, -0.376, -0.134, -0.475, -0.839, 0.129, 0.649, 0.199, 0.359, -0.180, 0.196, -0.306, -0.603, -0.119, 0.058, -0.021, -0.708, 0.256, 0.417, 0.170, 0.025, -0.017, -0.082, 0.018, -0.323, -0.051, 0.202, -0.169, -0.339, 0.099, 0.150, 0.205, -0.298, -0.401, 0.079, -0.287, -0.311, 0.248, 0.187, 0.198, 0.016, 0.105, 0.520, -0.046, -5.000, -0.548, 0.567, -0.290, -5.000, -0.117, -0.095, -0.456, -0.403, -0.547, 0.170, -0.040, -0.001, -0.048, 0.372, 0.128, -5.000, -0.624, 0.413, -0.432, 0.099, -0.074, 0.042, -0.505, -0.383, 0.280, 0.673, 0.463, 0.225, 0.469, 0.808, 0.166, 0.262, 0.506, 0.796, 0.858, -0.222, 1.020, 1.145, 0.881, 0.385, 0.436, 0.618, 0.868, 0.469, 0.008, 0.588, -0.112, -0.067, 0.605, 0.876, 0.704, -0.344, 0.399, 0.765, 0.457, 0.194, 0.647, 0.636, 0.527, 0.270, 0.002, 0.390, -0.126, -5.000, -0.615, 0.191, -0.308, -5.000, -0.168, -0.070, -0.261, -0.532, -0.170, 0.109, 0.352, 0.315, -0.362, 0.228, -0.106, -5.000, -0.772, -0.150, -0.680, -0.113, -0.190, 0.197, -0.161, -0.521, 0.413, 0.699, 0.383, 0.208, -0.093, 0.606, -0.044, -0.170, 0.020, 0.309, 0.539, -0.663, 0.179, 0.362, 0.059, -0.240, 0.333, 0.372, 0.668, 0.192, 0.362, 0.561, 0.055, -0.089, 0.106, 0.293, -0.284, -0.439, -0.186, 0.103, 0.217, -0.106, 0.445, 0.348, 0.250, 0.396, 0.323, 0.633, 0.127, -5.000, -0.463, 0.434, 0.056, -5.000, 0.315, 0.438, 0.228, -0.160, -0.161, 0.416, 0.616, 0.711, 0.209, 0.595, 0.215, -5.000, -0.561, 0.142, 0.066, -0.085, 0.316, 0.444, 0.002, -0.151, 0.530, 0.830, 0.358, 0.416, 0.200, 0.582, -0.113, 0.095, 0.255, 0.437, 0.481, -0.396, 0.532, 0.666, 0.387, 0.057, 0.509, 0.255, 0.802, 0.268, 0.454, 0.669, 0.252, 0.610, 0.393, 0.531, 0.452, -0.103, 0.227, 0.558, 0.407, 0.042, 0.545, 0.370, 0.698, 0.405, 0.204, 0.789, 0.207, -5.000, -0.505, 0.610, 0.029, -5.000, 0.038, 0.156, -0.347, -0.190, -0.419, 0.392, 0.008, 0.304, 0.116, 0.703, 0.240, -5.000, -0.367, 0.316, -0.073, -0.122, 0.187, 0.357, -0.100, -0.551, 0.475, 0.860, 0.631, 0.668, -0.087, 0.342, -0.451, 0.113, 0.055, 0.297, 0.324, -0.678, 0.338, 0.708, 0.128, -0.175, 0.298, 0.275, 0.202, 0.200, 0.167, 0.497, -0.027, 0.195, 0.376, 0.555, 0.499, -0.541, -0.003, 0.308, -0.137, -0.170, 0.705, 0.603, 0.407, 0.173, -0.459, -0.167, -0.469, -5.000, -1.206, -0.622, -1.187, -5.000, -0.454, -0.571, -0.784, -0.880, -0.742, -0.309, -0.453, -0.536, -0.612, -0.352, -0.478, -5.000, -1.226, -0.662, -0.982, -0.879, -0.538, -0.854, -0.940, -1.308, -0.211, -0.245, -0.489, -0.471, -0.544, -0.199, -0.595, -0.460, -0.740, -0.311, -0.473, -1.038, -0.360, 0.002, -0.442, -0.748, -0.224, -0.286, -0.092, -0.517, -0.588, -0.267, -0.688, -0.841, -0.783, -0.416, -0.482, -1.043, -0.889, -0.247, -0.649, -0.753, -0.189, -0.211, -0.333, -0.303, -0.151, 0.364, -0.296, -5.000, -0.850, 0.015, -0.700, -5.000, -0.546, -0.129, -0.475, -0.701, -0.637, 0.056, 0.108, 0.173, -0.450, 0.131, -0.034, -5.000, -0.772, -0.125, -0.523, -0.152, -0.472, -0.225, -0.613, -0.752, 0.318, 0.452, 0.005, -0.058, -0.023, 0.451, -0.282, 0.198, -0.251, 0.242, 0.171, -0.752, -0.022, 0.230, -0.287, -0.301, 0.132, 0.429, 0.627, -0.064, 0.167, 0.556, -0.184, 0.245, -0.274, 0.403, -0.045, -0.776, -0.338, -0.080, -0.225, -0.176, 0.217, 0.201, 0.148, 0.190, 0.130, 0.609, 0.041, -5.000, -0.397, 0.300, -0.284, -5.000, 0.056, 0.186, -0.075, -0.323, 0.034, 0.330, 0.667, 0.721, 0.165, 0.758, 0.447, -5.000, -0.293, 0.288, 0.074, 0.084, 0.176, 0.431, -0.019, -0.268, 0.370, 0.618, 0.356, 0.473, -0.153, 0.322, -0.312, 0.086, -0.161, 0.223, 0.303, -0.659, 0.161, 0.403, 0.048, -0.075, 0.242, 0.287, 0.536, -0.054, 0.443, 0.694, 0.118, 0.290, 0.168, 0.495, 0.316, -0.274, -0.030, 0.449, 0.128, -0.056, 0.497, 0.413, 0.425, 0.198, -0.278, 0.379, -0.134, -5.000, -0.720, 0.156, -0.331, -5.000, 0.004, -0.064, -0.544, -0.651, -0.091, 0.087, 0.425, 0.267, -0.185, 0.337, -0.199, -5.000, -0.760, -0.052, -0.519, -0.339, -0.315, -0.234, -0.627, -0.653, 0.193, 0.226, 0.206, 0.201, -0.047, 0.537, -0.331, -0.214, -0.274, 0.109, 0.083, -0.676, 0.075, 0.198, -0.253, -0.372, 0.002, 0.036, 0.176, 0.017, 0.193, 0.613, -0.061, -0.025, -0.100, 0.657, 0.355, -0.335, 0.260, 0.225, -0.117, -0.233, 0.428, 0.462, 0.502, -0.241, -0.285, 0.182, -0.276, -5.000, -1.133, -0.284, -0.743, -5.000, -0.307, -0.231, -0.454, -0.607, -0.493, -0.002, -0.136, -0.025, -0.084, 0.426, 0.081, -5.000, -1.091, -0.333, -0.398, -0.326, -0.255, -0.028, -0.529, -0.527, 0.041, 0.352, 0.188, 0.106, -0.205, 0.127, -0.445, -0.169, -0.617, -0.071, -0.293, -0.928, -0.150, -0.013, -0.082, -0.542, -0.297, -0.042, 0.235, -0.235, -0.187, 0.204, -0.464, -0.196, -0.239, 0.007, -0.186, -0.707, -0.605, -0.245, -0.250, -0.570, 0.053, 0.041, 0.176, -0.155, 0.235, 0.651, 0.315, -5.000, -0.086, 0.526, 0.053, -5.000, 0.139, 0.162, -0.093, -0.244, -0.103, 0.147, 0.023, 0.426, 0.090, 0.637, 0.502, -5.000, -0.187, 0.462, 0.226, 0.044, 0.496, 0.710, 0.422, 0.175, 0.406, 0.907, 0.528, 0.502, 0.171, 0.664, 0.174, 0.154, 0.079, 0.496, 0.670, -0.364, 0.378, 0.535, 0.098, -0.007, 0.436, 0.461, 0.588, 0.210, 0.348, 0.685, 0.252, -0.026, 0.272, 0.451, 0.324, -0.292, 0.162, 0.396, 0.238, 0.061, 0.505, 0.281, 0.313, 0.307, 0.435, 0.580, 0.260, -5.000, -0.306, 0.281, -0.145, -5.000, 0.259, 0.135, -0.130, -0.340, 0.020, 0.104, 0.234, 0.431, 0.338, 0.692, 0.555, -5.000, -0.195, 0.414, 0.234, -0.071, 0.346, 0.480, 0.220, -0.071, 0.357, 0.605, 0.294, 0.440, 0.082, 0.359, 0.092, 0.385, -0.016, 0.409, 0.391, -0.659, 0.529, 0.575, 0.259, 0.184, 0.453, 0.206, 0.531, 0.063, 0.471, 0.717, 0.257, 0.678, 0.350, 0.451, 0.449, -0.253, 0.279, 0.470, 0.278, 0.171, 0.557, 0.362, 0.517, 0.267, 0.374, 0.849, 0.475, -5.000, -0.099, 0.718, 0.189, -5.000, 0.157, 0.518, 0.075, -0.167, -0.063, 0.405, 0.406, 0.268, 0.228, 0.716, 0.363, -5.000, -0.227, 0.204, -0.043, -0.045, 0.232, 0.310, -0.033, -0.266, 0.458, 0.690, 0.414, 0.471, 0.327, 0.671, -0.230, 0.160, 0.231, 0.360, 0.319, -0.419, 0.512, 0.581, 0.294, -0.053, 0.411, 0.227, 0.175, 0.120, 0.566, 0.771, 0.179, 0.227, 0.487, 0.601, 0.524, -0.367, 0.345, 0.561, 0.160, 0.180, 0.699, 0.660, 0.463, 0.246, -0.057, 0.526, 0.096, -5.000, -0.330, 0.368, -0.272, -5.000, 0.128, 0.205, 0.052, -0.173, -0.268, 0.112, 0.115, 0.213, 0.054, 0.431, 0.239, -5.000, -0.535, 0.153, -0.141, -0.187, -0.015, -0.019, -0.003, -0.252, 0.394, 0.775, 0.361, 0.377, -0.044, 0.562, -0.011, -0.124, -0.026, 0.205, 0.450, -0.604, 0.354, 0.520, 0.170, -0.198, 0.075, 0.357, 0.228, -0.047, 0.036, 0.417, -0.035, 0.038, 0.310, 0.291, 0.403, -0.690, -0.129, 0.184, 0.010, -0.238, 0.207, 0.123, -0.126, 0.014 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_25(struct _training *tptr) {
  struct _training tinf = {
    0.602, 11, 4.350, { 1.045, 0.200, 1.754 }, { 1.083, -1.105, -1.400 }, 0, 
    { -0.027, -0.315, -0.465, -0.729, -0.829, -0.813, -0.389, -4.000, 0.727, -0.745, 0.297, -4.000, -0.662, 0.121, -1.108, 0.106, 0.688, -4.000, 0.736, -0.102, -0.390, 0.483, 1.265, 1.148, 0.926, -0.442, -4.000, 1.532 }, 
    {{ -0.380, 0.064, 0.398, -0.745},{ -0.740, -0.356, 0.392, 0.224},{ -0.005, -0.090, 0.039, 0.073},{ -0.015, -0.178, 0.085, 0.119},{ 0.012, -0.027, 0.039, -0.032},{ -0.116, -0.064, 0.066, 0.095},{ 0.029, -0.117, 0.017, 0.106},{ -0.010, 0.070, -0.049, -0.030},{ -0.127, -0.029, 0.063, 0.061},{ 0.031, -0.174, -0.029, 0.226},{ -0.022, -0.037, 0.028, 0.034},{ -0.052, -0.020, -0.032, 0.121},{ 0.136, -0.076, -0.086, 0.086},{ 0.138, -0.108, -0.012, 0.024},{ -0.055, -0.009, -0.019, 0.091},{ 0.124, -0.152, -0.045, 0.138},{ 0.089, -0.117, 0.002, 0.068},{ -0.132, -0.050, 0.067, 0.089},{ -0.010, -0.015, -0.009, 0.045},{ 0.005, -0.074, 0.043, 0.036},{ -0.035, -0.062, -0.022, 0.147},{ 0.038, -0.076, -0.040, 0.124},{ -0.050, -0.017, 0.028, 0.031},{ -0.163, 0.042, 0.010, 0.068},{ 0.045, -0.109, -0.044, 0.162},{ -0.037, 0.012, 0.001, 0.017},{ -0.052, 0.048, -0.093, 0.106},{ 0.036, -0.095, 0.020, 0.068},{ -0.007, 0.063, 0.002, -0.100},{ -0.065, 0.063, -0.001, -0.035},{ -0.030, -0.044, 0.002, 0.086},{ -0.050, 0.025, 0.029, -0.035} }, 
    {{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}} }, 
    0.000, { 0.149, 0.125, -0.125, -5.000, -0.548, -0.249, -0.800, -5.000, -0.338, -0.364, -0.649, -0.796, -0.002, -0.347, 0.298, 0.199, 0.550, 0.585, 0.319, -5.000, -0.483, -0.201, -0.565, -0.029, -0.131, -0.081, -0.248, -0.464, 0.366, 0.722, 0.395, 0.178, 0.440, 0.791, 0.063, 0.870, 0.207, 0.573, 0.459, -0.088, 0.442, 0.550, 0.321, 0.034, 0.490, 0.376, 0.803, 0.380, -0.047, 0.056, -0.340, 0.156, -0.401, -0.071, -0.415, -0.944, -0.524, 0.104, -0.173, -0.224, 0.285, 0.058, 0.266, -0.101, 0.368, 0.288, -0.288, -5.000, -0.593, -0.055, -0.883, -5.000, 0.091, -0.321, -0.559, -0.432, -0.622, -0.429, 0.463, 0.672, 0.640, 0.756, 0.421, -5.000, -0.238, 0.079, 0.169, 0.093, 0.332, 0.446, 0.392, -0.082, 0.679, 0.915, 0.666, 0.387, 0.633, 0.700, -0.056, 1.148, 0.500, 0.383, 0.489, 0.122, 0.643, 0.627, 0.466, 0.262, 0.876, 0.226, 0.815, 0.727, 0.463, 0.425, 0.031, 0.948, 0.566, 0.023, -0.088, -0.411, 0.020, 0.209, -0.032, -0.393, 0.561, 0.166, 0.357, 0.524, 0.032, 0.099, -0.151, -5.000, -0.358, -0.018, -1.040, -5.000, -0.413, -0.623, -1.102, -1.102, -0.202, -0.705, -1.222, -0.554, 0.267, 0.380, 0.091, -5.000, -0.332, -0.423, -0.721, -0.201, 0.003, -0.112, -0.402, -0.474, 0.546, 0.633, 0.535, 0.472, -0.017, 0.045, -0.414, 0.341, -0.062, -0.266, -0.163, -0.907, 0.204, 0.197, -0.235, -0.373, 0.262, -0.332, -0.106, 0.099, 0.280, -0.017, -0.445, 0.513, -0.101, -0.050, -0.103, -0.655, -0.547, -0.662, -0.732, -0.742, 0.315, -0.169, -0.101, -0.026, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.781, -0.690, -1.027, -5.000, -1.252, -1.608, -1.433, -5.000, -1.003, -1.039, -1.188, -1.122, -0.164, 0.039, -0.051, -0.482, -0.565, -0.232, -0.384, -5.000, -1.023, -0.996, -0.903, -0.957, -0.957, -0.916, -1.209, -1.254, -0.369, -0.067, -0.217, -0.241, -0.735, -0.421, -0.546, 0.102, -0.949, -0.844, -0.705, -1.031, -0.872, -0.638, -0.868, -1.002, -0.559, -0.515, 0.068, -0.386, -0.990, -1.221, -0.920, -1.054, -1.254, -1.380, -1.827, -1.707, -0.756, -0.347, -0.991, -0.210, 0.115, -0.326, -0.294, -0.529, 0.186, 0.098, -0.518, -5.000, -1.060, -0.359, -1.121, -5.000, -0.269, -0.523, -0.761, -0.895, -0.154, 0.027, 0.199, 0.175, 0.222, 0.471, 0.202, -5.000, -0.660, -0.181, -0.358, 0.007, -0.167, -0.095, -0.398, -0.626, 0.590, 0.587, 0.247, 0.009, 0.160, 0.218, -0.372, 0.799, 0.055, -0.034, -0.147, -0.632, 0.182, 0.061, -0.154, -0.299, 0.449, -0.068, 0.589, 0.530, 0.182, 0.016, -0.362, 0.559, 0.062, -0.473, -0.933, -1.130, -0.588, -0.530, -0.748, -1.054, -0.046, -0.474, 0.111, -0.098, -0.507, -0.300, -0.906, -5.000, -1.043, -0.663, -1.290, -5.000, -1.045, -1.147, -1.584, -1.281, -0.837, -1.331, -1.640, -1.112, -0.329, -0.202, -0.595, -5.000, -1.014, -0.868, -1.297, -1.057, -0.530, -0.635, -1.231, -1.135, -0.110, 0.117, -0.260, -0.039, -0.298, -0.390, -1.040, 0.072, -0.536, -0.854, -0.881, -1.197, -0.227, -0.280, -0.945, -1.049, -0.151, -0.990, -0.800, -0.297, -0.462, -0.918, -1.248, -0.206, -0.670, -0.805, -1.032, -1.569, -1.509, -1.702, -1.700, -1.562, -0.466, -1.062, -1.208, -1.016, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.017, -0.068, -0.542, -5.000, -0.972, -0.455, -1.305, -5.000, -0.731, -0.842, -0.850, -1.078, 0.089, 0.044, 0.624, 0.284, -0.510, -0.065, -0.221, -5.000, -0.831, -0.617, -0.886, -0.553, -0.637, -0.575, -0.831, -1.449, 0.205, 0.180, 0.238, -0.014, -0.027, 0.377, -0.091, 0.445, -0.381, 0.182, 0.076, -0.510, -0.086, 0.080, -0.157, -0.487, 0.144, 0.317, 0.541, -0.002, -0.318, -0.215, -1.036, 0.233, -0.586, -0.572, -0.883, -1.586, -0.900, -1.027, -1.337, -1.332, -0.087, -0.415, -0.491, -0.251, -0.068, -0.055, -0.664, -5.000, -1.234, -0.569, -1.373, -5.000, -0.491, -0.894, -1.223, -1.092, -0.137, 0.051, -0.127, -0.161, -0.341, 0.112, 0.007, -5.000, -1.003, -0.539, -0.752, -0.940, -0.295, -0.265, -0.718, -0.887, -0.042, 0.217, 0.182, -0.103, -0.373, -0.272, -0.862, 0.359, -0.570, -0.598, -0.863, -1.179, -0.066, -0.092, -0.688, -0.442, 0.182, -0.222, 0.160, 0.167, 0.257, -0.075, -0.543, 0.784, -0.119, -0.562, -1.025, -0.911, -0.630, -0.514, -0.951, -1.082, 0.084, -0.543, -0.308, -0.125, -0.384, -0.378, -0.430, -5.000, -1.040, -0.589, -0.991, -5.000, -0.869, -1.028, -1.413, -1.342, -0.450, -0.060, -0.705, -0.609, -0.405, -0.312, -0.602, -5.000, -1.254, -1.022, -1.285, -1.181, -0.589, -0.799, -1.143, -1.247, -0.290, -0.183, -0.233, -0.136, -0.195, -0.040, -1.027, 0.347, -0.611, -0.831, -1.089, -1.104, -0.249, -0.599, -0.874, -0.954, -0.334, -0.493, -0.432, -0.341, -0.147, -0.233, -0.906, 0.168, -0.548, -0.355, -0.478, -0.903, -0.539, -0.830, -1.088, -1.355, -0.095, -0.702, -0.719, -0.739, -0.570, -0.418, -0.585, -5.000, -1.344, -1.026, -1.615, -5.000, -0.848, -1.071, -1.150, -1.249, -0.425, -0.929, -1.050, -0.462, -0.430, 0.026, -0.195, -5.000, -1.054, -0.946, -1.495, -0.884, -0.440, -0.805, -0.946, -1.072, -0.269, 0.081, -0.170, -0.301, -0.637, -0.165, -0.584, 0.108, -0.914, -0.668, -0.779, -1.099, -0.497, -0.295, -0.737, -0.643, -0.564, -0.427, -0.023, -0.369, -0.553, -0.602, -1.123, -0.042, -0.818, -0.570, -0.831, -1.205, -0.974, -0.768, -1.191, -1.103, -0.350, -0.711, -0.457, -0.446, -0.276, -0.158, -0.400, -5.000, -0.460, -0.630, -1.012, -5.000, 0.029, -0.425, -0.268, -0.554, -0.465, -0.335, 0.442, -0.166, 0.074, -0.023, 0.082, -5.000, -5.000, -0.239, -0.382, -0.570, -0.676, -0.032, -0.793, -0.472, -0.474, 0.228, 0.092, -0.073, 0.141, 0.215, -0.271, -0.432, 0.240, -0.111, -0.224, -0.133, -0.298, -0.247, -0.133, -0.392, 0.222, 0.107, -0.002, -0.061, 0.666, -0.042, 0.282, -0.048, -0.831, -0.411, -0.173, -0.866, -0.425, -0.725, -1.212, 0.268, 0.104, 0.422, -0.527, -0.096, 0.141, -0.441, -0.158, -5.000, -0.756, -0.560, -1.529, -5.000, -0.351, -0.653, -0.553, -0.662, -1.450, -0.329, 0.585, -0.271, -0.439, 0.099, -0.003, -5.000, -0.401, -0.342, -0.501, -0.555, -0.361, 0.002, -0.280, -0.484, 0.494, 0.292, -0.173, 0.108, 0.254, 0.102, -0.289, 0.250, -0.437, -0.327, -0.510, -0.520, 0.104, -0.060, -0.296, -0.160, 0.304, -0.192, 0.067, 0.105, 0.187, -0.118, -0.375, 0.731, -0.494, -0.469, -0.329, -0.672, 0.199, -0.045, -0.172, -0.529, -0.101, -0.320, -0.173, -0.005, 0.117, 0.128, -0.477, -5.000, 0.362, -0.162, -1.647, -5.000, -0.101, -0.166, -0.666, -0.494, -1.082, -0.041, -0.937, -0.184, 0.104, 0.065, -0.240, -5.000, -0.873, -0.620, -0.966, -0.692, -0.220, -0.492, -0.607, -0.735, 0.135, 0.598, 0.369, 0.360, 0.024, -0.043, -1.322, 0.338, -0.148, -0.359, -0.280, -0.940, 0.147, 0.256, 0.001, -0.453, 0.342, -0.335, -0.049, 0.282, 0.280, 0.252, -0.641, 0.615, 0.373, 0.334, 0.024, -0.646, 0.567, -0.483, -0.903, -0.817, 0.373, -0.288, -0.572, -0.052, 0.253, 0.449, 0.012, -5.000, -0.438, -0.332, -0.725, -5.000, 0.450, -0.468, -0.640, -0.195, -0.028, -0.283, -0.368, 0.025, -0.022, 0.086, 0.106, -5.000, -0.206, -0.155, -0.433, -0.382, -0.150, -0.226, -0.606, -0.507, 0.448, 0.477, 0.218, 0.204, 0.277, 0.308, -0.213, 0.435, 0.199, -0.033, 0.048, -0.668, 0.246, 0.389, 0.084, -0.145, 0.291, -0.158, 0.500, 0.046, 0.324, 0.255, 0.031, 0.473, 0.104, 0.539, 0.208, -0.928, 0.247, -0.148, -0.520, -0.361, 0.258, -0.017, -0.032, 0.044, 0.286, 0.529, 0.145, -5.000, -0.621, -0.043, -0.480, -5.000, -0.396, -0.834, -0.674, -0.892, -0.422, -0.213, 0.035, 0.417, 0.366, 0.687, 0.401, -5.000, -0.475, -0.092, -0.437, -0.170, -0.229, -0.019, -0.271, -0.678, 0.323, 0.760, 0.491, 0.118, 0.610, 0.990, 0.486, 1.138, 0.437, 0.807, 0.714, -0.148, 0.591, 0.699, 0.561, 0.210, 0.547, 0.509, 0.917, 0.548, 0.059, 0.102, 0.098, 0.626, -0.349, 0.149, -0.320, -1.050, 0.282, 0.177, -0.155, -0.122, 0.299, 0.077, 0.422, 0.161, 0.604, 0.783, 0.094, -5.000, -0.253, 0.305, -0.235, -5.000, -0.063, -0.048, -0.123, -0.338, -0.033, 0.049, 0.650, 0.473, 0.780, 0.889, 0.779, -5.000, -0.122, 0.345, 0.484, 0.211, 0.347, 0.549, 0.478, -0.064, 0.753, 0.982, 0.797, 0.541, 0.725, 0.941, 0.259, 1.216, 0.510, 0.542, 0.775, 0.243, 0.514, 0.636, 0.554, 0.216, 0.667, 0.267, 0.890, 0.721, 0.694, 0.821, 0.389, 1.078, 0.671, 0.279, 0.343, 0.147, 0.220, 0.288, 0.277, -0.024, 0.577, 0.395, 0.571, 0.535, 0.268, 0.374, 0.121, -5.000, -0.158, 0.419, -0.369, -5.000, -0.344, -0.329, -0.759, -0.862, -0.163, -0.368, -0.462, -0.353, 0.502, 0.614, 0.325, -5.000, -0.184, 0.233, -0.132, 0.171, 0.220, 0.102, -0.195, -0.235, 0.517, 0.850, 0.655, 0.560, 0.325, 0.614, -0.121, 0.766, 0.175, 0.217, 0.250, -0.271, 0.551, 0.562, 0.386, 0.099, 0.327, -0.244, 0.317, 0.242, 0.406, 0.249, -0.036, 0.848, 0.551, 0.585, 0.542, -0.139, -0.462, 0.039, -0.262, -0.316, 0.638, 0.334, 0.387, 0.357, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.470, -0.463, -0.755, -5.000, -1.483, -0.997, -1.404, -5.000, -1.175, -1.079, -1.023, -1.046, -0.082, -0.257, 0.090, -0.141, -0.464, -0.002, -0.228, -5.000, -0.718, -0.826, -0.889, -0.915, -0.837, -0.695, -0.731, -1.092, -0.487, -0.285, -0.108, -0.457, -0.457, -0.060, -0.156, 0.258, -0.685, -0.465, -0.392, -0.831, -0.825, -0.408, -0.852, -0.677, -0.368, -0.288, 0.174, -0.352, -0.639, -1.192, -1.211, -0.296, -1.549, -1.202, -1.014, -1.605, -0.042, 0.058, -0.040, -0.739, -0.538, -0.263, -0.242, -0.278, 0.290, 0.245, -0.396, -5.000, -0.834, -0.171, -0.983, -5.000, -0.344, -0.610, -0.865, -0.692, 0.171, -0.228, 0.212, 0.030, 0.006, 0.450, 0.208, -5.000, -0.473, -0.014, -0.125, -0.190, 0.111, 0.020, -0.265, -0.365, 0.455, 0.496, 0.382, 0.140, -0.038, 0.096, -0.330, 0.811, -0.129, -0.134, -0.193, -0.579, 0.072, 0.108, -0.242, -0.072, 0.204, -0.122, 0.586, 0.483, -0.032, 0.005, -0.475, 0.529, -0.162, -0.438, -0.652, -0.881, -0.621, -0.498, -0.792, -1.182, -0.126, -0.197, 0.110, -0.175, -0.071, 0.190, -0.245, -5.000, -0.857, 0.001, -0.615, -5.000, -0.679, -0.783, -1.230, -1.270, -0.699, -0.581, -0.862, -0.553, -0.213, 0.328, -0.229, -5.000, -0.818, -0.275, -0.671, -0.794, -0.322, -0.235, -0.640, -0.727, -0.206, 0.226, 0.240, -0.013, -0.062, 0.140, -0.623, 0.544, -0.140, -0.088, -0.213, -0.759, 0.075, 0.166, -0.243, -0.495, 0.019, -0.533, -0.354, 0.075, -0.276, -0.409, -0.949, 0.259, -0.407, -0.316, -0.549, -1.242, -0.834, -0.664, -1.222, -1.394, -0.363, -0.775, -0.777, -0.575, -0.128, 0.085, -0.025, -5.000, -1.213, -0.562, -1.074, -5.000, -0.993, -0.903, -1.100, -1.044, -0.769, -0.282, -0.736, -0.522, -0.285, 0.330, 0.137, -5.000, -1.098, -0.880, -1.356, -0.647, -0.768, -0.796, -1.024, -1.069, -0.382, 0.179, -0.163, -0.313, 0.136, 0.493, 0.052, 0.780, -0.075, 0.145, 0.171, -0.828, 0.140, 0.174, -0.134, -0.381, 0.279, -0.037, 0.606, 0.194, -0.166, -0.057, -0.470, 0.312, -0.317, -0.066, -0.182, -0.987, -0.517, -0.580, -0.766, -0.817, -0.177, -0.178, -0.135, -0.491, 0.239, 0.394, -0.009, -5.000, -0.777, -0.059, -0.717, -5.000, -0.379, -0.540, -0.402, -0.813, -0.164, -0.090, 0.722, 0.315, 0.063, 0.422, 0.246, -5.000, -0.647, -0.207, -0.441, 0.096, -0.408, -0.202, -0.541, -0.656, 0.436, 0.400, 0.428, 0.369, 0.214, 0.832, 0.271, 0.630, -0.036, 0.498, 0.514, -0.388, 0.110, 0.401, 0.083, -0.116, 0.296, 0.518, 0.832, 0.362, -0.189, 0.232, 0.139, 0.839, -0.580, -0.121, -0.092, -0.803, -1.100, -0.903, -1.014, -1.214, -0.391, -0.481, -0.175, -0.224, 0.278, 0.552, 0.041, -5.000, -0.801, -0.178, -0.653, -5.000, -0.257, -0.197, -0.442, -0.737, 0.134, -0.046, 0.422, 0.265, 0.246, 0.590, 0.411, -5.000, -0.735, -0.024, -0.051, -0.269, 0.027, 0.110, -0.198, -0.541, 0.267, 0.563, 0.642, 0.187, 0.036, 0.353, -0.057, 0.963, -0.184, -0.062, -0.042, -0.820, 0.017, 0.151, -0.106, -0.439, 0.184, 0.047, 0.503, 0.436, 0.473, 0.378, -0.016, 1.162, 0.109, -0.084, -0.169, -0.512, -0.344, -0.152, -0.549, -0.831, 0.246, -0.155, 0.068, 0.255, -0.126, 0.169, -0.087, -5.000, -0.835, -0.028, -0.585, -5.000, -0.406, -0.408, -0.825, -0.910, -0.551, -0.440, -0.340, -0.397, -0.200, 0.053, -0.120, -5.000, -0.934, -0.523, -0.463, -0.774, -0.217, -0.380, -0.576, -0.757, -0.162, 0.198, 0.354, -0.013, -0.067, 0.273, -0.300, 0.585, -0.256, -0.276, -0.139, -0.680, -0.041, -0.203, -0.384, -0.684, -0.074, -0.104, 0.046, -0.018, 0.039, 0.043, -0.344, 0.457, -0.316, 0.213, -0.071, -0.523, -0.350, -0.147, -0.543, -0.655, 0.081, -0.335, -0.179, -0.477, -0.577, -0.153, -0.454, -5.000, -1.315, -0.696, -1.129, -5.000, -0.895, -0.805, -0.884, -1.200, -0.803, -0.491, -0.513, -0.397, 0.184, 0.359, 0.170, -5.000, -0.845, -0.406, -0.743, -0.329, -0.285, -0.197, -0.413, -0.548, -0.039, 0.376, 0.385, -0.061, -0.415, 0.186, -0.262, 0.309, -0.590, -0.202, -0.140, -0.864, -0.427, -0.184, -0.338, -0.629, -0.472, -0.045, 0.445, -0.224, -0.289, -0.365, -0.637, 0.062, -0.713, -0.285, -0.361, -1.204, -1.035, -0.535, -0.642, -1.015, -0.495, -0.413, -0.063, -0.256, 0.172, 0.540, 0.261, -5.000, -0.638, -0.026, -0.637, -5.000, -0.391, -0.620, -0.617, -0.699, -0.003, -0.180, 0.183, 0.282, 0.508, 0.805, 0.668, -5.000, -0.513, 0.024, -0.039, -0.033, 0.038, 0.214, -0.088, -0.172, 0.480, 0.714, 0.714, 0.408, 0.658, 1.046, 0.588, 1.307, 0.152, 0.664, 0.790, -0.206, 0.487, 0.598, 0.066, 0.130, 0.638, 0.112, 0.528, 0.594, 0.364, 0.735, 0.358, 0.282, 0.174, 0.199, 0.139, -0.673, -0.609, -0.480, -1.168, -1.226, 0.211, -0.581, -0.045, -0.182, 0.736, 0.966, 0.542, -5.000, -0.212, 0.152, -0.401, -5.000, 0.052, -0.200, -0.183, -0.397, 0.074, 0.099, 0.745, 0.415, 0.699, 0.960, 0.931, -5.000, -0.383, 0.555, 0.667, 0.175, 0.586, 0.541, 0.316, 0.123, 0.664, 1.026, 1.013, 0.529, 0.799, 0.938, 0.711, 1.380, 0.466, 0.783, 0.798, -0.055, 0.767, 0.778, 0.506, 0.459, 0.868, 0.402, 1.017, 0.927, 1.063, 1.017, 0.903, 1.413, 0.676, 0.733, 0.720, 0.223, 0.388, 0.603, 0.326, 0.112, 0.918, 0.587, 0.855, 0.958, 0.544, 0.848, 0.619, -5.000, -0.127, 0.736, 0.228, -5.000, 0.313, 0.283, -0.089, -0.196, 0.010, 0.003, 0.235, 0.514, 0.621, 0.770, 0.588, -5.000, -0.176, 0.332, 0.141, 0.204, 0.380, 0.354, 0.050, -0.086, 0.698, 1.011, 0.905, 0.632, 0.844, 0.923, 0.236, 1.226, 0.694, 0.529, 0.661, 0.037, 1.038, 0.925, 0.722, 0.476, 0.861, 0.073, 0.547, 0.629, 0.940, 0.840, 0.368, 1.239, 0.516, 0.648, 0.685, 0.071, 0.275, 0.495, 0.361, -0.064, 0.735, 0.594, 0.693, 0.731, 0.051, 0.555, 0.345, -5.000, -0.712, 0.154, -0.353, -5.000, -0.167, -0.140, -0.431, -0.579, -0.613, -0.121, -0.310, 0.181, 0.286, 0.688, 0.475, -5.000, -0.463, 0.156, 0.049, 0.168, 0.125, 0.232, -0.109, -0.126, 0.233, 0.684, 0.621, 0.291, 0.017, 0.323, 0.176, 0.352, -0.166, 0.311, 0.346, -0.503, 0.396, 0.517, 0.164, -0.289, -0.170, 0.071, 0.401, -0.268, 0.151, 0.463, 0.139, 0.433, 0.229, 0.373, 0.392, -0.469, -0.298, 0.037, -0.052, -0.441, 0.126, 0.100, 0.260, -0.166, 0.203, 0.403, 0.005, -5.000, -0.593, -0.343, -0.875, -5.000, -0.595, -0.799, -0.623, -0.969, -0.179, -0.127, -0.030, -0.144, 0.417, 0.567, 0.504, -5.000, -0.487, -0.262, -0.495, 0.003, -0.021, -0.083, -0.275, -0.426, 0.416, 0.827, 0.548, 0.217, 0.616, 0.930, 0.456, 1.290, 0.209, 0.562, 0.552, -0.163, 0.466, 0.514, 0.419, 0.201, 0.574, 0.556, 0.931, 0.657, 0.467, 0.379, -0.316, 0.317, -0.399, 0.023, -0.381, -0.894, -0.271, -0.224, -0.026, -0.239, 0.524, 0.028, 0.215, 0.519, 0.810, 0.790, 0.329, -5.000, -0.113, 0.317, -0.224, -5.000, 0.180, -0.098, -0.239, -0.340, 0.064, 0.027, 0.457, 0.759, 0.747, 0.855, 0.724, -5.000, -0.326, 0.203, 0.423, 0.259, 0.134, 0.393, 0.160, -0.308, 0.609, 0.917, 0.466, 0.306, 0.744, 0.973, 0.643, 1.398, 0.524, 0.546, 0.788, 0.223, 0.736, 0.850, 0.801, 0.598, 0.923, 0.562, 1.193, 1.034, 0.736, 0.628, 0.133, 1.017, 0.627, 0.239, 0.212, -0.120, -0.073, 0.163, 0.011, -0.274, 0.560, 0.316, 0.411, 0.713, -0.010, -0.052, -0.174, -5.000, -0.431, -0.176, -0.712, -5.000, -0.682, -0.832, -1.096, -0.954, -0.318, -0.415, -0.906, -1.226, 0.271, 0.254, -0.091, -5.000, -0.575, -0.260, -0.765, -0.407, 0.044, -0.182, -0.513, -0.483, 0.424, 0.635, 0.412, 0.437, 0.066, 0.215, -0.250, 0.670, 0.043, -0.079, -0.081, -0.467, 0.366, 0.166, 0.141, -0.199, 0.213, -0.408, 0.032, 0.220, 0.127, -0.084, -0.185, 0.800, 0.132, -0.269, -0.197, -0.578, -0.634, -0.534, -0.855, -0.998, 0.337, -0.385, -0.258, -0.007, 0.741, 0.912, 0.492, -5.000, -0.960, 0.676, -0.735, -5.000, -0.784, -0.127, -0.483, -0.271, 0.017, -0.351, -0.089, -0.514, 1.070, 1.146, 0.854, -5.000, -0.206, 0.457, -0.246, 0.775, -0.003, 0.140, -0.524, -0.031, 0.844, 1.154, 0.798, 0.442, 1.317, 1.419, 1.052, 1.482, 1.272, 1.285, 1.255, 0.744, 1.410, 1.319, 1.162, 1.154, 1.331, 1.167, 1.335, 1.422, 0.932, 1.132, 0.655, 1.238, 1.034, 1.127, 0.985, 0.321, 0.820, 1.127, 0.863, 0.459, 1.011, 0.922, 0.973, 0.963, 0.042, 0.132, -0.111, -5.000, -0.960, -0.339, -1.019, -5.000, -0.285, -0.581, -0.648, -1.038, -0.015, -0.171, 0.291, 0.260, 0.269, 0.339, 0.323, -5.000, -0.657, -0.364, -0.464, -0.149, -0.186, -0.263, -0.462, -0.761, 0.486, 0.547, 0.431, 0.085, 0.314, 0.635, 0.172, 1.004, -0.012, 0.328, 0.313, -0.488, 0.124, 0.220, -0.216, -0.339, 0.365, 0.283, 0.784, 0.334, 0.077, -0.190, -0.668, 0.499, -0.339, -0.421, -0.998, -1.241, -0.179, 0.092, -0.453, 0.088, 0.245, 0.181, 0.149, -0.204, 0.362, 0.413, -0.153, -5.000, -0.625, 0.012, -0.522, -5.000, 0.141, -0.275, -0.468, -0.556, -0.042, 0.005, 0.289, 0.344, 0.535, 0.511, 0.349, -5.000, -0.631, 0.057, 0.140, 0.032, 0.247, 0.063, -0.069, -0.270, 0.778, 0.905, 0.591, 0.316, 0.428, 0.578, -0.000, 1.242, 0.283, 0.320, 0.365, -0.266, 0.460, 0.399, 0.129, 0.096, 0.787, 0.243, 0.834, 0.670, 0.333, 0.341, -0.021, 0.966, 0.288, -0.029, -0.344, -0.730, -0.239, -0.333, -0.596, -0.682, 0.205, 0.111, 0.329, 0.215, 0.200, 0.568, 0.175, -5.000, -0.771, 0.223, -0.349, -5.000, -0.396, -0.230, -0.689, -0.860, -0.271, -0.116, -0.151, -0.072, 0.346, 0.654, 0.278, -5.000, -0.670, 0.086, -0.126, -0.201, 0.257, 0.183, -0.127, -0.523, 0.434, 0.840, 0.831, 0.461, 0.529, 0.568, -0.074, 1.009, 0.359, 0.182, 0.200, -0.380, 0.585, 0.536, 0.235, -0.024, 0.712, -0.084, 0.024, 0.594, 0.203, 0.162, -0.206, 0.753, 0.005, 0.192, 0.088, -0.968, -0.384, -0.414, -0.724, -0.887, 0.545, 0.021, -0.211, -0.094, -0.346, -0.411, -0.743, -5.000, -1.045, -0.756, -1.383, -5.000, -1.124, -1.136, -1.435, -1.197, -0.368, -0.858, -1.512, -0.648, -0.242, 0.061, -0.164, -5.000, -1.225, -0.966, -1.122, -0.909, -0.770, -0.678, -1.092, -1.052, -0.359, 0.063, -0.228, -0.266, -0.360, 0.031, -0.197, 0.670, -0.410, -0.245, -0.299, -0.937, -0.285, -0.044, -0.493, -0.604, -0.119, -0.052, 0.326, -0.004, -0.761, -0.604, -0.675, -0.184, -0.573, -0.423, -0.664, -1.111, -0.780, -0.634, -1.071, -0.971, -0.494, -0.692, -0.546, -0.587, 0.601, 0.863, 0.313, -5.000, -0.672, 0.424, -0.217, -5.000, -0.205, -0.294, -0.441, -0.596, -0.200, 0.170, 0.494, 0.340, 0.397, 0.659, 0.546, -5.000, -0.359, 0.095, -0.127, 0.422, -0.202, -0.034, -0.249, -0.710, 0.739, 0.743, 0.484, 0.208, 0.479, 0.924, 0.349, 0.972, 0.178, 0.674, 0.525, -0.287, 0.327, 0.540, 0.314, 0.031, 0.584, 0.725, 0.942, 0.483, 0.048, 0.536, 0.137, 1.071, -0.365, 0.118, -0.345, -0.978, -0.772, -0.421, -0.841, -0.569, 0.068, -0.071, 0.028, -0.160, 0.443, 0.745, 0.077, -5.000, -0.453, 0.282, -0.320, -5.000, 0.069, 0.057, -0.312, -0.515, -0.102, 0.030, 0.654, 0.738, 0.516, 0.790, 0.589, -5.000, -0.538, 0.276, 0.271, 0.098, 0.277, 0.388, 0.060, -0.250, 0.572, 0.967, 0.888, 0.356, 0.364, 0.679, 0.047, 1.178, 0.171, 0.418, 0.445, -0.380, 0.440, 0.471, 0.299, -0.058, 0.666, 0.375, 0.810, 0.641, 0.768, 0.684, 0.377, 1.320, 0.484, 0.364, 0.291, -0.069, -0.093, 0.153, -0.229, -0.504, 0.709, 0.176, 0.270, 0.570, 0.055, 0.260, -0.015, -5.000, -0.782, -0.243, -0.634, -5.000, -0.526, -0.355, -0.792, -0.755, -0.432, -0.264, -0.095, 0.017, 0.228, 0.462, 0.120, -5.000, -0.556, -0.179, -0.435, -0.468, 0.003, -0.125, -0.346, -0.490, 0.216, 0.472, 0.676, 0.209, 0.372, 0.706, -0.006, 0.870, -0.180, 0.310, 0.144, -0.424, 0.317, 0.123, -0.113, -0.163, 0.414, 0.203, 0.425, 0.251, 0.388, 0.455, 0.117, 0.784, -0.267, 0.129, 0.215, -0.802, 0.104, -0.016, -0.294, -0.534, 0.640, 0.403, 0.464, -0.032, -0.143, 0.266, -0.204, -5.000, -1.157, -0.269, -0.789, -5.000, -0.730, -0.333, -0.628, -0.864, -0.226, -0.603, -0.529, -0.142, 0.254, 0.409, 0.126, -5.000, -0.685, -0.106, -0.586, -0.454, 0.158, 0.099, -0.202, -0.338, 0.217, 0.637, 0.553, 0.196, 0.114, 0.442, 0.074, 0.716, -0.257, 0.099, 0.080, -0.574, 0.098, 0.329, 0.169, -0.178, 0.220, 0.180, 0.610, 0.372, -0.098, 0.055, -0.313, 0.934, -0.388, -0.146, -0.252, -0.944, -1.059, -0.387, -0.602, -1.130, -0.030, -0.226, -0.150, 0.208, 0.314, 0.641, 0.238, -5.000, -0.287, 0.277, -0.155, -5.000, -0.083, -0.337, -0.265, -0.574, -0.303, 0.073, 0.563, 0.422, 0.554, 0.753, 0.623, -5.000, -0.286, 0.345, 0.137, 0.102, 0.405, 0.403, 0.299, -0.061, 0.606, 0.881, 0.877, 0.518, 0.849, 1.032, 0.464, 1.221, 0.412, 0.724, 0.751, 0.128, 0.560, 0.626, 0.059, 0.229, 0.749, 0.185, 0.531, 0.751, 0.570, 0.679, 0.352, 0.779, -0.045, 0.277, 0.214, -0.517, 0.049, -0.223, -0.786, -0.651, 0.517, -0.432, 0.102, 0.236, 0.369, 0.082, -0.075, -5.000, -0.457, -0.120, -0.507, -5.000, -0.069, -0.493, -0.321, -0.696, 0.098, -0.120, 0.054, 0.637, 0.268, 0.497, 0.358, -5.000, -0.177, 0.309, 0.028, -0.079, 0.131, 0.196, 0.003, -0.308, 0.364, 0.633, 0.484, 0.268, 0.195, 0.346, -0.014, 1.094, 0.008, 0.196, 0.237, -0.313, 0.317, 0.300, -0.016, -0.010, 0.431, 0.050, 0.370, 0.379, 0.564, 0.261, -0.183, 0.967, -0.103, -0.033, 0.039, -0.462, -0.072, 0.048, -0.291, -0.264, 0.214, -0.141, 0.034, 0.356, 0.483, 0.854, 0.590, -5.000, -0.154, 0.691, 0.197, -5.000, 0.383, 0.378, 0.021, -0.112, 0.054, -0.128, 0.427, 0.062, 0.695, 0.762, 0.566, -5.000, -0.061, 0.409, 0.135, 0.150, 0.584, 0.408, 0.095, 0.079, 0.826, 1.009, 0.871, 0.647, 0.871, 0.899, 0.340, 1.242, 0.585, 0.414, 0.505, 0.035, 0.905, 0.821, 0.611, 0.453, 0.859, 0.178, 0.408, 0.531, 0.787, 0.775, 0.350, 1.212, 0.498, 0.436, 0.483, -0.273, 0.040, 0.438, 0.142, 0.030, 0.894, 0.593, 0.505, 0.582, 0.381, 0.557, 0.323, -5.000, -0.894, 0.254, -0.357, -5.000, 0.034, -0.158, -0.265, -0.277, -0.101, -0.093, -0.368, 0.162, 0.653, 0.578, 0.601, -5.000, -0.498, 0.174, -0.174, 0.155, 0.388, 0.281, 0.100, -0.145, 0.548, 0.993, 0.829, 0.540, 0.738, 0.939, 0.393, 1.162, 0.555, 0.492, 0.493, -0.091, 0.730, 0.687, 0.495, 0.164, 0.648, 0.336, 0.653, 0.587, 0.664, 0.589, 0.410, 0.906, 0.539, 0.313, 0.365, -0.082, -0.279, 0.079, -0.205, -0.542, 0.505, -0.114, 0.112, 0.350, 0.199, 0.156, -0.168, -5.000, -0.449, -0.390, -0.958, -5.000, -0.480, -0.588, -0.424, -0.546, -0.322, -0.003, 0.150, 0.352, 0.267, 0.291, 0.349, -5.000, -0.525, -0.297, -0.623, -0.058, 0.001, 0.075, -0.003, -0.541, 0.414, 0.939, 0.468, 0.535, 0.419, 0.765, 0.004, 0.592, 0.435, 0.537, 0.686, -0.128, 0.624, 0.688, 0.491, 0.217, 0.619, 0.522, 0.888, 0.565, 0.131, 0.473, -0.057, 0.327, -0.384, -0.024, -0.857, -1.003, -0.037, -0.053, 0.210, -1.271, 0.183, 0.243, 0.272, 0.310, 0.382, 0.224, -0.372, -5.000, -0.663, -0.301, -1.365, -5.000, -0.393, -0.799, -0.665, -0.637, -0.307, -0.333, 0.091, 0.431, 0.636, 0.553, 0.282, -5.000, -0.238, -0.029, -0.042, 0.191, 0.362, 0.343, 0.218, -0.009, 0.663, 0.956, 0.533, 0.448, 0.427, 0.637, -0.269, -0.040, 0.234, 0.152, 0.469, -0.208, 0.597, 0.501, 0.523, 0.244, 0.698, 0.198, 0.811, 0.532, 0.362, 0.232, -0.220, 0.222, 0.201, -0.036, -0.218, -0.589, -0.284, 0.016, -0.263, -0.482, 0.395, -0.081, 0.254, 0.374, -0.542, -0.376, -0.709, -5.000, -0.798, -0.544, -1.261, -5.000, -1.212, -1.421, -1.256, -0.960, -0.072, -0.935, -1.793, -0.692, 0.126, 0.154, -0.148, -5.000, -0.857, -0.615, -0.912, -0.443, -0.544, -0.556, -0.861, -0.869, 0.330, 0.629, 0.451, 0.381, 0.004, 0.146, -0.362, -0.450, -0.100, -0.175, -0.188, -0.547, 0.276, 0.303, 0.262, 0.041, 0.054, -0.404, -0.206, 0.025, -0.301, -0.433, -0.695, -0.985, 0.088, -0.258, -0.024, -0.278, -0.619, -0.703, -1.081, -0.784, 0.211, -0.548, -0.723, -0.215, 0.422, 0.438, -0.002, -5.000, -0.769, 0.342, -1.342, -5.000, -0.253, -0.820, -1.175, -0.999, -0.717, 0.017, 0.320, -0.552, 0.262, 0.768, 0.308, -5.000, -0.520, 0.561, -0.422, 0.452, 0.415, 0.339, -0.332, 0.199, 0.621, 1.274, 0.901, 0.289, 0.944, 1.154, 0.556, 0.496, 1.061, 1.145, 1.030, 0.348, 1.401, 1.330, 1.104, 1.073, 1.234, 0.911, 1.274, 1.245, -0.164, 0.412, -0.533, 0.074, 0.679, 0.991, 0.869, 0.002, 0.748, 0.823, 0.189, 0.322, 0.850, 0.856, 0.791, 0.558, 0.008, 0.087, -0.628, -5.000, -0.983, -0.324, -1.708, -5.000, -0.104, -0.676, -0.578, -0.799, -0.128, -0.247, 0.210, -0.018, 0.194, 0.338, 0.308, -5.000, -0.804, -0.422, -0.732, 0.001, -0.171, -0.027, -0.176, -0.554, 0.583, 0.637, 0.365, 0.098, 0.245, 0.528, -0.091, 0.353, -0.056, 0.432, 0.349, -0.533, 0.171, 0.146, -0.280, -0.458, 0.528, 0.369, 0.713, 0.340, 0.095, -0.384, -0.861, 0.086, -0.682, -0.732, -1.200, -1.898, -0.494, 0.083, -0.243, -1.673, 0.311, 0.317, 0.213, 0.118, 0.432, 0.039, -0.524, -5.000, -0.743, -0.318, -1.094, -5.000, -0.069, -0.568, -0.754, -0.854, -0.224, -0.163, 0.304, 0.422, 0.314, 0.452, 0.054, -5.000, -0.672, -0.450, -0.314, -0.255, -0.058, -0.049, -0.241, -0.300, 0.579, 0.707, 0.354, 0.276, 0.350, 0.298, -0.310, 0.509, 0.159, 0.091, 0.135, -0.446, 0.464, 0.433, 0.107, 0.158, 0.636, 0.109, 0.657, 0.606, 0.418, 0.147, -0.334, 0.277, 0.225, -0.080, -0.306, -0.930, -0.443, -0.339, -0.700, -0.892, 0.060, -0.089, 0.239, 0.038, -0.072, 0.063, -0.271, -5.000, -0.620, -0.048, -0.676, -5.000, -0.703, -0.698, -1.331, -1.475, -0.472, -0.533, -1.317, -0.806, 0.249, 0.509, 0.029, -5.000, -0.704, -0.158, -0.530, -0.502, -0.166, -0.179, -0.392, -0.665, 0.418, 0.693, 0.574, 0.372, 0.003, 0.268, -0.569, 0.651, 0.006, -0.132, -0.168, -0.800, 0.320, 0.389, -0.139, -0.092, 0.410, -0.082, -0.203, 0.269, -0.203, -0.160, -0.398, -0.271, -0.310, -0.214, -0.467, -1.402, -0.649, -0.710, -1.007, -1.460, 0.220, -0.301, -0.488, -0.392, -0.213, -0.659, -0.946, -5.000, -1.616, -1.139, -1.697, -5.000, -0.964, -1.380, -1.399, -1.469, -1.100, -1.572, -1.182, -1.619, -0.418, -0.128, -0.433, -5.000, -1.354, -0.976, -1.231, -0.983, -0.900, -0.984, -1.133, -1.515, -0.296, 0.058, -0.448, -0.245, -0.401, -0.069, -0.578, -0.351, -0.720, -0.561, -0.697, -1.126, -0.050, -0.022, -0.617, -0.610, -0.066, -0.386, 0.072, -0.122, -0.670, -0.751, -1.267, -1.512, -0.790, -0.783, -0.624, -1.012, -0.931, -0.933, -1.262, -1.345, -0.480, -0.919, -0.863, -0.854, -0.016, -0.467, -0.643, -5.000, -0.995, -0.876, -1.107, -5.000, -0.675, -1.084, -1.083, -1.201, -0.520, -0.177, 0.304, 0.042, -0.049, -0.010, -0.100, -5.000, -0.687, -0.516, -0.998, -0.309, -0.536, -0.529, -0.897, -0.943, 0.219, 0.222, 0.094, 0.280, -0.024, 0.194, -0.232, 0.317, -0.188, 0.040, -0.302, -0.836, 0.010, -0.110, -0.262, -0.518, 0.286, 0.116, 0.324, -0.053, -0.108, 0.098, -0.401, -0.137, -0.728, -0.514, -0.723, -1.461, -0.500, -0.563, -1.097, -0.848, -0.118, -0.148, -0.512, -0.401, 0.158, -0.046, -0.548, -5.000, -1.097, -0.548, -1.195, -5.000, -0.515, -0.618, -0.945, -0.924, -0.187, -0.254, -0.005, 0.449, 0.375, 0.487, 0.175, -5.000, -0.741, -0.134, -0.328, -0.207, -0.006, 0.005, -0.202, -0.519, 0.290, 0.533, 0.394, 0.078, -0.079, 0.035, -0.678, -0.069, -0.370, -0.191, -0.121, -0.967, 0.069, 0.156, -0.288, -0.320, 0.368, -0.035, 0.423, 0.290, 0.377, 0.099, -0.650, 0.240, -0.150, -0.333, -0.482, -1.061, -0.593, -0.422, -1.019, -1.013, 0.069, -0.296, -0.197, 0.033, -0.377, -0.319, -0.725, -5.000, -1.089, -0.458, -1.410, -5.000, -0.887, -0.913, -1.457, -1.254, -0.574, -0.825, -1.569, -0.974, -0.299, -0.112, -0.568, -5.000, -0.970, -0.635, -0.999, -0.839, -0.399, -0.626, -1.012, -0.970, 0.020, 0.050, 0.150, 0.088, -0.160, -0.044, -0.978, -0.652, -0.566, -0.656, -0.709, -0.941, -0.025, -0.448, -0.655, -0.791, -0.079, -0.576, -0.345, -0.192, 0.003, -0.258, -1.116, -0.552, -0.439, 0.021, -0.448, -0.912, -0.462, -0.553, -0.924, -0.994, 0.281, -0.275, -0.255, -0.421, -0.550, -0.560, -1.008, -5.000, -1.353, -1.356, -1.735, -5.000, -0.952, -1.001, -1.314, -1.332, -0.615, -1.365, -1.696, -0.681, 0.039, 0.092, -0.213, -5.000, -1.237, -0.816, -1.046, -0.942, -0.392, -0.386, -0.744, -0.889, 0.113, 0.239, 0.122, -0.015, -0.214, -0.129, -0.727, -0.286, -0.782, -0.638, -0.585, -1.073, -0.439, -0.232, -0.471, -0.557, -0.231, -0.379, 0.096, -0.344, -0.599, -0.585, -0.841, 0.051, -0.605, -0.643, -0.910, -1.370, -1.133, -0.833, -1.423, -1.208, -0.318, -0.831, -0.733, -0.491, 0.271, 0.186, 0.141, -5.000, -0.116, 0.074, -0.784, -5.000, -0.057, -0.429, -0.435, -0.564, -0.073, -0.096, 0.027, 0.317, 0.430, 0.661, 0.433, -5.000, -0.271, 0.078, -0.065, 0.040, 0.536, 0.488, 0.229, 0.201, 0.650, 0.913, 0.731, 0.618, 0.456, 0.679, -0.115, 0.247, 0.365, 0.507, 0.663, -0.238, 0.639, 0.593, -0.023, 0.040, 0.648, 0.246, 0.508, 0.486, 0.271, 0.331, 0.087, -0.096, -0.271, 0.143, -0.494, -0.683, -0.011, -0.178, -0.367, -0.530, 0.503, 0.001, -0.039, -0.071, 0.467, -0.204, -0.303, -5.000, -0.724, -0.626, -1.326, -5.000, -0.482, -0.955, -1.033, -0.867, 0.250, -0.482, -0.108, -0.676, 0.532, 0.428, 0.334, -5.000, -0.370, -0.082, -0.067, -0.278, 0.110, -0.000, -0.264, -0.121, 0.307, 0.512, 0.226, 0.159, 0.313, 0.232, -0.402, 0.493, -0.233, 0.017, -0.112, -0.553, 0.291, 0.290, -0.134, -0.007, 0.536, -0.085, 0.494, 0.301, 0.337, 0.147, -0.286, 0.477, 0.093, -0.337, -0.453, -0.947, -0.081, -0.079, -0.616, -0.410, 0.438, -0.223, 0.182, 0.072, 0.388, 0.284, -0.231, -5.000, -0.123, 0.280, -0.579, -5.000, -0.137, -0.263, -0.786, -0.620, -0.389, -0.434, -0.281, -0.304, 0.446, 0.395, 0.029, -5.000, -0.238, -0.212, -0.422, -0.251, 0.141, -0.071, -0.458, -0.400, 0.707, 0.598, 0.528, 0.510, 0.342, 0.510, -0.595, 0.659, 0.233, -0.078, -0.091, -0.573, 0.610, 0.299, -0.055, -0.039, 0.581, -0.244, 0.013, 0.093, 0.681, 0.347, -0.530, 0.402, 0.285, 0.206, -0.050, -0.569, 0.026, 0.052, -0.414, -0.294, 0.635, 0.189, 0.034, 0.223, 0.124, 0.050, -0.264, -5.000, -0.404, 0.127, -0.804, -5.000, 0.157, -0.378, -0.625, -0.332, -0.538, -0.324, -0.541, -0.216, -0.011, 0.351, 0.193, -5.000, -0.897, -0.160, -0.497, -0.219, 0.286, 0.050, -0.194, -0.259, 0.412, 0.934, 0.681, 0.508, 0.219, 0.590, 0.141, 0.364, 0.169, 0.274, 0.495, -0.328, 0.526, 0.674, 0.335, -0.085, 0.572, 0.162, 0.509, 0.374, 0.161, 0.119, -0.310, 0.012, 0.376, 0.021, 0.187, -0.710, -0.262, -0.079, -0.280, -0.445, 0.208, -0.162, -0.219, 0.100 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_26(struct _training *tptr) {
  struct _training tinf = {
    0.656, 11, 4.350, { 0.877, 0.210, 1.913 }, { 1.292, -1.615, -4.000 }, 0, 
    { -0.192, -0.150, -0.060, -0.319, -0.384, 0.217, -0.397, 0.132, -0.583, -0.206, -0.443, -4.000, -0.623, 0.138, 0.439, 0.006, 0.445, -0.050, 1.634, 0.725, 0.548, 0.708, 0.366, 1.650, 2.058, -0.070, 1.699, 1.699 }, 
    {{ -0.061, -0.266, -0.080, 0.502},{ 0.074, -0.014, 0.097, -0.281},{ -0.031, 0.043, 0.061, -0.189},{ 0.058, 0.010, -0.009, -0.063},{ 0.133, 0.024, 0.065, -0.381},{ -0.115, 0.037, 0.132, -0.267},{ -0.004, -0.024, 0.013, 0.023},{ -0.090, -0.013, 0.053, 0.006},{ -0.095, -0.015, 0.087, -0.057},{ 0.019, -0.034, 0.060, -0.077},{ -0.018, -0.026, 0.006, 0.054},{ -0.008, -0.077, 0.042, 0.066},{ 0.260, -0.106, -0.274, 0.303},{ 0.419, -0.322, -0.459, 0.536},{ 0.430, -0.649, -0.373, 0.677},{ 0.204, -0.678, -0.458, 0.881},{ 0.054, -0.446, -0.297, 0.752},{ -0.006, -0.295, -0.085, 0.500},{ 0.189, -0.181, -0.092, 0.244},{ 0.276, -0.003, -0.114, -0.113},{ 0.672, -0.244, -0.236, -0.155},{ 0.706, -0.370, -0.237, -0.033},{ 0.463, 0.003, -0.222, -0.240},{ 0.247, -0.007, 0.046, -0.440},{ 0.087, -0.153, 0.162, -0.170},{ 0.174, -0.029, 0.003, -0.150},{ 0.329, -0.064, -0.142, -0.018},{ 0.442, -0.097, -0.238, 0.025},{ 0.229, 0.133, -0.260, -0.097},{ 0.095, 0.012, 0.000, -0.131},{ 0.226, -0.100, -0.012, -0.050},{ 0.083, 0.046, -0.047, -0.092} }, 
    {{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}} }, 
    0.000, { 0.064, -0.281, -0.176, -5.000, -0.387, -0.435, -0.871, -5.000, -0.477, -0.365, -0.097, -0.097, -0.101, -0.048, 0.025, -0.029, 0.756, 0.793, 0.377, -5.000, -0.637, 0.522, 0.022, 0.089, 0.405, 0.120, -0.027, -0.170, 1.030, 0.624, 0.780, 0.250, 0.696, 0.917, 0.249, 0.721, 0.093, 0.147, 0.314, -0.211, 0.762, 0.482, 0.497, 0.195, 1.020, 1.065, 1.120, 0.718, 0.121, -0.220, -0.059, -0.125, -0.120, -0.434, -0.709, -0.110, 0.129, -0.529, -0.273, -0.504, -0.767, 0.145, -0.010, -0.100, 0.700, 0.356, -0.391, -5.000, -0.356, -0.878, -1.083, -5.000, -0.018, 0.310, -0.821, -0.180, 0.212, -0.695, 0.346, 0.309, 1.133, 0.900, 0.530, -5.000, -0.369, 0.043, -0.097, 0.565, 0.510, 0.486, 0.127, 0.114, 1.255, 0.239, 0.617, 0.220, 0.871, 0.638, 0.237, 1.264, 0.433, 0.543, 0.196, -0.613, 0.781, 0.691, 0.451, 0.141, 1.038, 0.618, 0.899, 0.742, -0.092, -0.894, -1.372, -0.232, 0.052, -0.219, -0.712, 0.176, -0.379, -0.868, -1.206, -0.075, 0.244, -0.586, -0.422, -0.236, 0.088, -0.281, -1.036, -5.000, -0.541, -0.939, -1.524, -5.000, -0.113, -0.350, -1.270, -0.177, -0.383, -1.081, -0.507, -0.104, 0.764, 0.267, -0.019, -5.000, -1.479, -0.596, -1.112, -0.124, -0.109, -0.835, -1.080, -0.624, 1.014, 0.098, 0.275, 0.131, 0.119, -0.345, -0.817, -0.026, -0.357, -0.551, -1.124, -1.301, -0.216, -0.021, -1.037, -0.944, 0.279, 0.081, 0.128, 0.155, -0.161, -1.246, -1.515, -0.022, -0.463, -1.402, -1.721, -0.687, -0.610, -1.578, -1.327, -0.756, 0.168, -1.313, -0.915, -0.089, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.656, -1.334, -1.743, -5.000, -1.834, -2.266, -2.298, -5.000, -1.654, -1.798, -1.659, -1.458, -0.017, -0.787, -0.726, -0.254, -1.045, -0.582, -0.932, -5.000, -1.970, -1.114, -1.677, -1.558, -1.504, -1.702, -1.831, -2.006, 0.293, -0.467, -0.481, -0.308, -0.601, -0.253, -0.891, -0.286, -1.247, -1.161, -1.232, -1.536, -0.553, -0.571, -1.203, -1.207, 0.115, 0.171, 0.386, -0.039, -0.897, -0.840, -0.893, -0.372, -1.258, -1.928, -2.127, -1.719, -0.430, -1.130, -1.190, -0.590, -0.700, -0.717, -0.434, -0.194, -0.048, -0.054, -1.624, -5.000, -1.894, -1.678, -2.434, -5.000, -1.654, -1.254, -2.497, -1.753, -0.254, -1.127, -0.133, -0.046, 0.502, 1.048, 0.399, -5.000, -1.662, -0.477, -1.202, -0.309, -0.411, -0.402, -0.888, -0.814, 0.939, -0.268, 0.056, -0.048, -0.055, 0.285, -0.592, 0.288, -0.547, -0.082, -1.101, -1.377, -0.190, -0.099, -0.879, -0.767, 0.364, 0.165, 0.029, 0.364, -0.225, -1.115, -1.461, -0.822, -0.725, -0.543, -1.859, -0.921, -1.724, -1.661, -2.545, -1.746, -0.254, -0.367, -0.548, 0.173, -0.312, -0.252, -1.567, -5.000, -2.188, -1.593, -2.387, -5.000, -1.340, -0.920, -1.701, -1.524, -0.757, -1.695, -2.118, -0.795, 0.013, 0.247, -0.686, -5.000, -1.899, -1.039, -1.840, -1.005, -0.841, -1.143, -1.682, -1.422, 0.588, -0.446, 0.054, 0.088, -0.139, -0.458, -1.478, 0.031, -1.165, -1.232, -1.792, -1.634, -0.527, -0.784, -1.180, -1.434, 0.005, -0.402, -0.277, -0.095, -0.899, -1.157, -1.809, -0.549, -1.557, -1.661, -2.308, -1.651, -1.944, -1.777, -2.765, -2.006, -0.343, -1.467, -1.947, -0.781, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.615, -0.458, -1.115, -5.000, -1.650, -1.134, -1.977, -5.000, -1.205, -1.434, -1.590, -1.710, -0.566, -0.344, -0.357, -0.236, -0.404, 0.436, -0.139, -5.000, -1.877, -0.445, -0.994, -0.941, -0.595, -0.391, -1.023, -1.248, 0.877, 0.356, 0.336, 0.161, -0.322, -0.148, -0.798, -0.037, -0.477, -0.499, -1.292, -1.124, -0.760, -0.520, -0.924, -1.197, -0.025, 0.124, 0.053, 0.139, -0.136, -0.722, -0.386, -0.460, -1.094, -1.321, -2.153, -1.652, -1.369, -1.382, -2.130, -1.619, -0.254, -0.638, -1.485, 0.113, 0.232, 0.520, -1.014, -5.000, -1.504, -0.834, -1.959, -5.000, -1.094, -0.211, -1.946, -1.244, -0.105, -0.400, -0.075, 0.275, 0.629, 1.303, 0.860, -5.000, -1.245, 0.073, -0.614, -0.381, -0.046, 0.289, -0.522, -0.760, 0.935, 0.039, 0.508, -0.138, 0.279, 0.845, -0.205, 0.873, -0.297, 0.577, -0.431, -1.531, 0.141, 0.761, -0.223, -0.870, 0.739, 0.794, 0.629, 0.662, -0.031, -0.320, -1.202, -0.033, -0.169, 0.287, -0.967, -0.482, -0.391, -0.234, -1.464, -0.665, -0.046, -0.310, -0.565, 0.048, -0.117, -0.498, -1.082, -5.000, -1.862, -1.379, -2.078, -5.000, -0.933, -0.756, -1.366, -1.310, -0.063, -1.575, -1.127, -0.363, -0.200, -0.150, -0.541, -5.000, -2.111, -1.021, -1.765, -1.078, -0.598, -0.922, -1.201, -1.290, 0.614, -0.287, -0.221, -0.084, 0.032, -0.405, -1.133, 0.142, -1.173, -1.102, -1.893, -1.830, -0.946, -1.064, -1.311, -1.400, -0.002, -0.716, -0.292, -0.394, -0.332, -0.595, -1.103, -0.275, -1.116, -1.505, -2.050, -1.401, -1.350, -1.623, -2.049, -1.824, -0.139, -1.165, -1.455, -0.575, -0.698, 0.108, -0.541, -5.000, -2.100, -1.491, -2.043, -5.000, -1.676, -1.848, -1.511, -1.989, -0.199, -0.708, -0.631, -0.116, -0.180, 0.145, -0.416, -5.000, -1.717, -1.302, -1.931, -1.093, -1.503, -1.330, -1.506, -1.786, 0.463, -0.253, -0.324, 0.046, -0.635, -0.318, -0.650, -0.296, -1.420, -1.057, -1.519, -1.402, -1.295, -0.525, -0.580, -1.017, -0.241, 0.009, 0.303, -0.110, -0.157, -0.448, -1.044, -0.129, -1.723, -1.263, -1.510, -1.551, -2.027, -1.212, -1.691, -1.369, -0.365, -0.739, -1.147, -0.502, -0.095, 0.230, 0.004, -5.000, -0.458, -0.302, -0.887, -5.000, -0.416, -0.037, -0.237, -0.578, -0.070, 0.091, -0.434, -0.046, 0.250, 0.145, -0.179, -5.000, -0.668, -0.542, -0.572, 0.195, -0.038, -0.392, -0.426, -0.363, 0.435, 0.228, -0.076, 0.125, -0.248, 0.390, -0.248, 0.073, -0.216, -0.358, -0.372, -0.167, 0.091, -0.228, -0.367, -0.363, -0.331, -0.124, 0.159, 0.090, -0.202, 0.288, 0.131, -0.144, -0.346, -0.029, -0.342, -0.460, -0.751, -0.426, -0.541, -0.232, 0.292, -0.093, -0.139, 0.140, -0.049, -0.852, -0.716, -5.000, -1.200, -1.665, -1.664, -5.000, -0.579, -0.716, -1.476, -1.063, -0.146, -1.118, 0.205, 0.058, 0.211, -0.320, -0.451, -5.000, -0.722, -0.844, -0.895, -0.580, -0.100, -0.667, -0.822, -0.523, 0.610, -0.350, -0.527, 0.262, 0.167, 0.138, -0.654, 0.337, -0.551, -1.034, -1.287, -1.231, -0.309, -0.775, -0.755, -0.491, -0.312, -0.976, -0.820, -0.338, -0.295, -1.099, -1.996, -0.379, -0.584, -1.212, -1.475, -0.617, -1.099, -1.125, -1.804, -0.993, -0.092, -0.823, -0.555, -0.309, -0.336, 0.297, -0.609, -5.000, -0.604, -0.570, -1.655, -5.000, -0.641, -0.322, -0.546, -0.670, 0.148, -1.017, -1.022, -0.277, 0.434, 0.640, -0.109, -5.000, -0.417, -0.350, -1.002, -0.266, 0.435, -0.037, -0.469, -0.329, 0.776, 0.575, 0.414, 0.194, 0.189, -0.672, -1.207, 0.091, -0.491, -1.586, -1.530, -1.465, -0.365, -0.820, -0.894, -0.319, 0.052, -0.293, -0.899, 0.041, -0.126, -0.677, -1.193, -0.085, -0.512, -0.704, -1.679, -0.395, -0.496, -1.230, -1.775, -1.011, 0.089, -0.959, -1.235, -0.549, -0.023, -0.141, -0.557, -5.000, -0.385, -0.499, -0.714, -5.000, -0.749, -0.959, -0.713, -0.417, 0.044, -0.167, 0.051, -0.242, -0.852, 0.722, 0.249, -5.000, 0.072, 0.359, -0.506, -0.067, 0.066, 0.072, -0.268, -0.486, 0.421, 0.644, 0.294, 0.264, 0.352, 0.300, -0.050, 0.339, -0.146, -0.036, -0.241, -0.177, 0.262, -0.084, 0.024, 0.126, 0.404, 0.105, 0.486, 0.294, -0.228, -0.226, -0.201, -0.167, -0.455, -0.145, -0.396, -0.496, -0.178, -0.791, -0.378, -0.619, -0.014, -0.286, -0.304, -0.048, 0.265, 0.473, 0.099, -5.000, -0.504, 0.065, -0.025, -5.000, -0.412, 0.343, -0.279, -0.649, -0.132, -0.493, 0.143, -0.061, 0.567, 1.189, 0.852, -5.000, -1.119, 0.617, 0.074, -0.084, 0.116, 0.236, -0.320, -0.499, 0.719, 0.488, 1.085, 0.073, 1.375, 1.499, 1.144, 1.453, 0.588, 1.307, 1.188, 0.234, 1.222, 1.186, 1.021, 0.824, 1.406, 1.421, 1.438, 1.296, 0.010, 0.235, -0.016, 0.197, -0.220, 0.303, -0.187, 0.041, -0.358, 0.047, -0.680, -0.840, 0.359, -0.309, -0.077, -0.153, 0.799, 1.254, 0.255, -5.000, 0.164, 0.392, -0.005, -5.000, 0.290, 1.087, 0.054, -0.099, 0.335, -0.191, 0.997, 1.004, 1.143, 1.350, 0.980, -5.000, -0.161, 0.582, 0.421, 1.051, 0.880, 0.988, 0.564, 0.446, 1.390, 0.618, 1.062, 0.115, 1.129, 1.167, 0.822, 1.543, 0.746, 1.120, 0.821, 0.085, 1.050, 1.139, 0.861, 0.486, 1.207, 0.972, 0.854, 0.815, -0.493, -0.312, -1.004, -0.450, 0.386, 0.353, -0.149, 0.621, 0.281, -0.146, -0.655, -0.061, 0.448, -0.678, -0.281, -0.169, 0.566, 0.661, 0.084, -5.000, -0.082, 0.555, -0.302, -5.000, 0.616, 1.188, 0.259, 0.115, -0.098, -0.264, 0.399, 0.246, 1.024, 0.851, 0.348, -5.000, -0.571, 0.147, -0.371, 0.522, 0.630, 0.021, -0.317, -0.250, 1.237, 0.542, 0.704, 0.496, 1.025, 0.659, 0.185, 1.173, 0.473, 0.397, 0.057, -0.521, 0.840, 0.683, 0.158, -0.082, 1.042, 0.754, 0.721, 0.793, 0.609, 0.062, -0.830, 0.362, 0.471, -0.313, -0.848, 0.130, 0.027, -0.029, -0.791, 0.058, 0.848, -0.152, -0.249, 0.359, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.487, -0.841, -1.874, -5.000, -2.066, -1.946, -2.167, -5.000, -1.745, -2.112, -1.395, -1.854, -0.016, -0.835, -0.443, 0.161, -1.802, -0.956, -1.406, -5.000, -1.724, -1.265, -1.702, -1.583, -1.803, -1.719, -1.807, -1.883, -0.423, -0.684, -0.691, -0.795, -0.818, -0.157, -1.059, -0.403, -1.496, -1.076, -0.913, -1.388, -0.997, -0.784, -1.507, -1.834, -0.312, -0.118, 0.520, -0.455, 0.157, -0.758, -0.882, 0.034, -1.283, -1.823, -2.387, -1.294, -0.211, -0.572, -0.915, -0.234, 0.257, -0.017, 0.499, -0.130, 0.458, 0.316, -0.968, -5.000, -0.916, -0.902, -1.406, -5.000, -1.061, -0.912, -1.557, -1.342, -0.260, -1.006, 0.034, -0.155, 0.741, 1.268, 0.901, -5.000, -0.983, 0.378, -0.239, 0.337, 0.124, 0.275, -0.151, -0.378, 1.062, 0.141, 0.808, -0.269, 0.443, 0.794, 0.118, 1.048, -0.080, 0.558, -0.269, -0.827, 0.241, 0.290, -0.116, -0.361, 0.639, 0.346, 0.408, 0.536, -0.130, -0.534, -1.320, -0.462, -0.835, 0.051, -1.107, -0.218, -1.101, -1.290, -1.827, -1.181, 0.124, -0.604, -0.299, 0.027, 0.008, 0.529, -0.768, -5.000, -1.377, -0.838, -1.553, -5.000, -0.998, -0.030, -0.976, -1.188, -0.178, -1.032, -0.931, -0.575, 0.148, 0.704, -0.041, -5.000, -1.467, -0.525, -1.079, -0.604, -0.413, -0.355, -0.788, -0.995, 0.641, 0.011, 0.500, 0.059, 0.218, 0.361, -0.642, 0.659, -0.726, -0.313, -0.931, -1.224, -0.217, -0.063, -0.658, -0.912, 0.219, 0.243, 0.445, 0.316, -0.249, -0.285, -1.212, 0.225, -1.170, -0.860, -1.725, -1.055, -1.262, -1.072, -2.027, -1.356, -0.017, -0.663, -0.899, -0.146, -0.155, 0.062, -0.148, -5.000, -1.633, -0.811, -1.772, -5.000, -1.905, -1.829, -1.107, -1.683, -0.606, -0.680, -0.234, -0.280, 0.549, 1.127, 0.491, -5.000, -1.262, 0.122, -0.594, -0.045, -0.534, 0.044, -0.277, -0.557, 0.313, 0.213, 0.502, -0.407, -0.038, 0.656, -0.088, 0.499, -0.608, 0.266, -0.800, -1.420, 0.225, 0.580, -0.119, -0.576, 0.058, 0.429, 0.446, 0.330, -0.140, -0.138, -0.582, -0.383, -0.630, -0.893, -1.594, -1.321, -0.765, -1.354, -1.647, -1.065, -0.099, -0.520, -1.090, -0.758, -0.248, 0.431, -0.410, -5.000, -1.295, -0.058, -0.844, -5.000, -1.366, -0.660, -1.397, -1.870, 0.225, -0.042, -0.249, -0.027, 0.052, 1.081, 0.596, -5.000, -1.400, 0.610, 0.052, -0.313, -0.143, 0.298, -0.412, -0.637, 0.627, 0.643, 1.004, -0.140, 0.396, 1.129, 0.538, 1.156, -0.353, 0.579, 0.084, -0.685, -0.243, 0.068, -0.558, -1.077, 0.756, 0.660, 0.888, 0.829, -0.238, 0.245, -0.412, 0.133, -0.899, -0.575, -1.494, -0.511, -1.677, -1.269, -2.099, -1.653, 0.490, -0.055, 0.029, 0.795, 0.195, 0.822, -0.658, -5.000, -1.181, -0.347, -0.826, -5.000, -1.212, -0.430, -1.457, -1.499, -0.374, -0.568, -0.058, -0.132, 0.325, 1.181, 0.803, -5.000, -1.315, 0.380, -0.007, -0.328, -0.039, 0.294, -0.344, -0.601, 0.770, 0.323, 0.837, -0.416, 0.449, 1.005, 0.398, 1.179, -0.279, 0.794, 0.256, -0.982, 0.162, 0.550, -0.193, -0.518, 0.679, 0.704, 0.683, 0.700, 0.000, -0.203, -0.849, -0.103, -0.239, 0.760, -0.009, -0.063, -0.139, -0.125, -1.259, -0.466, 0.161, -0.397, -0.182, 0.193, 0.111, 0.446, -0.513, -5.000, -1.619, -0.578, -1.438, -5.000, -0.950, -0.066, -0.677, -1.308, -0.461, -0.551, -0.408, -0.326, -0.217, 0.527, -0.023, -5.000, -1.808, -0.202, -0.971, -1.085, -0.237, -0.052, -0.510, -0.915, 0.150, 0.207, 0.409, -0.130, 0.430, 0.610, 0.062, 0.814, -0.615, -0.023, -0.887, -0.830, -0.550, -0.229, -0.528, -0.907, 0.199, 0.276, 0.591, 0.452, 0.357, 0.365, -0.449, 0.612, -0.900, -0.453, -1.189, -0.412, -0.962, -0.758, -2.183, -1.308, 0.592, -0.206, -0.494, -0.040, -0.043, 0.365, -0.390, -5.000, -1.853, -0.815, -1.314, -5.000, -1.677, -1.197, -1.960, -2.127, -0.340, -0.806, -0.459, -0.710, -0.204, 0.682, 0.203, -5.000, -1.693, -0.408, -0.860, -0.804, -0.958, -0.699, -0.929, -1.245, -0.253, -0.016, 0.531, -0.629, -0.815, 0.389, -0.261, 0.179, -1.047, 0.051, -0.555, -1.200, -0.709, -0.245, -0.530, -0.800, -0.121, 0.292, 0.877, 0.182, -0.388, -0.081, -0.531, -0.025, -1.154, -0.499, -1.179, -1.136, -1.359, -1.163, -1.684, -1.319, -0.295, -0.504, -0.580, -0.083, 0.143, 0.307, 0.054, -5.000, -0.434, 0.506, -0.011, -5.000, 0.101, 0.368, 0.191, -0.565, -0.186, 0.455, 0.573, -0.120, 0.752, 1.274, 1.015, -5.000, -0.781, 1.085, 0.773, 0.267, 0.744, 0.914, 0.512, 0.046, 0.679, 1.022, 1.176, 0.025, 1.138, 1.382, 1.183, 1.375, 0.257, 1.177, 0.544, 0.108, 0.408, 0.707, -0.078, -0.588, 1.080, 0.876, 0.868, 1.140, 0.172, 0.659, 0.190, -0.085, 0.541, 0.754, -0.013, 0.635, 0.180, 0.193, 0.216, -0.200, 0.616, 0.225, -0.183, -0.059, 0.450, 0.631, -0.380, -5.000, -0.754, -0.450, -0.801, -5.000, -0.163, 0.032, -1.031, -0.953, -0.191, -0.463, -0.144, -0.395, 0.636, 0.913, 0.780, -5.000, -0.839, -0.033, 0.069, 0.208, 0.412, 0.440, 0.004, -0.149, 0.912, 0.509, 0.892, -0.124, 0.656, 1.314, 0.474, 0.993, -0.149, 0.561, 0.292, -0.374, 0.387, 0.357, -0.115, -0.146, 0.454, 0.477, 0.794, 0.633, -0.271, -0.463, -1.310, -0.299, -0.439, -0.257, -0.890, -0.386, -0.632, -1.024, -1.604, -1.049, 0.062, -0.617, -0.418, -0.026, 0.617, 1.090, 0.337, -5.000, -0.397, 0.909, 0.121, -5.000, 0.337, 1.102, 0.058, -0.078, 0.276, 0.112, 0.320, 0.436, 1.063, 1.181, 0.849, -5.000, -0.458, 1.067, 0.530, 0.577, 1.167, 1.190, 0.720, 0.739, 1.284, 1.217, 1.276, 0.909, 1.221, 1.093, 0.500, 1.319, 0.751, 0.664, 0.353, -0.140, 0.922, 0.805, 0.402, 0.540, 1.251, 0.905, 0.848, 1.176, 0.469, 0.698, -0.489, 0.844, 0.184, 0.031, -0.737, 0.053, -0.167, -0.303, -1.269, -0.514, 0.776, -0.347, -0.561, 0.605, -0.157, 0.244, -0.642, -5.000, -0.527, -0.096, -0.634, -5.000, -0.189, 0.052, -0.735, -0.638, -0.178, -0.056, -0.186, -0.312, -0.394, 0.680, 0.328, -5.000, -1.214, 0.012, -0.214, -0.446, -0.671, 0.011, -0.463, -0.735, 0.028, 0.841, 0.996, -0.313, -0.392, -0.382, -0.456, -0.162, -0.981, -0.257, -0.708, -1.087, -0.950, -0.378, -0.516, -0.896, -0.081, 0.013, 0.698, -0.142, -0.022, 0.072, -0.074, -0.079, -0.624, -0.185, -0.672, -0.762, -0.650, -0.791, -0.684, -1.261, -0.048, -0.294, -0.316, -0.176, 0.345, 0.890, 0.456, -5.000, -0.489, 0.111, -0.185, -5.000, -0.192, 0.604, -0.059, -0.945, -0.081, -0.277, -0.220, 0.126, 0.682, 1.211, 0.864, -5.000, -1.170, 0.286, -0.058, 0.249, -0.011, 0.192, -0.157, -0.302, 0.911, 0.447, 1.073, 0.012, 1.244, 1.431, 1.276, 1.309, 0.334, 1.198, 1.058, 0.229, 1.227, 1.286, 1.065, 0.683, 1.315, 1.409, 1.480, 1.313, -0.220, 0.297, -0.077, -0.046, 0.128, 0.453, -0.088, 0.563, 0.260, 0.176, -0.081, 0.045, 0.074, 0.354, 0.237, 0.145, 1.078, 0.928, -0.142, -5.000, -0.034, -0.163, -0.487, -5.000, 0.014, 0.899, -0.278, 0.029, 0.290, -0.570, 0.852, 0.827, 1.223, 1.201, 0.961, -5.000, -0.421, 0.283, 0.237, 0.908, 0.748, 0.825, 0.546, 0.369, 1.493, 0.415, 0.966, 0.284, 1.090, 0.938, 0.741, 1.524, 0.711, 0.762, 0.260, -0.394, 1.079, 1.017, 0.888, 0.472, 1.200, 0.905, 0.843, 1.065, -0.059, -0.589, -1.315, -0.360, 0.352, 0.206, -0.339, 0.650, 0.203, -0.568, -1.088, 0.127, 0.185, -0.907, -0.251, -0.079, 0.722, 0.668, -0.602, -5.000, -0.761, -0.328, -0.955, -5.000, 0.256, 0.760, -0.103, -0.238, -0.231, -0.570, -0.591, -0.124, 0.699, 0.580, 0.031, -5.000, -1.355, -0.423, -1.431, 0.099, 0.034, -0.448, -0.864, -0.712, 1.224, -0.002, 0.701, 0.609, 0.817, 0.872, 0.360, 1.051, 0.155, 0.628, 0.019, -0.422, 0.769, 0.796, 0.479, -0.284, 1.030, 1.041, 1.020, 0.879, 0.121, -0.251, -1.103, 0.389, -0.070, -0.554, -1.027, -0.096, -0.122, -0.307, -1.061, -0.346, 0.274, -0.370, -0.561, 0.340, 0.424, 0.756, -0.147, -5.000, -0.614, 0.487, -0.140, -5.000, -0.019, -0.067, -0.770, -0.689, 0.178, -0.126, 0.154, 0.062, 0.960, 1.424, 1.041, -5.000, -0.784, 0.980, 0.521, 0.734, 0.451, 0.794, 0.403, 0.038, 0.923, 1.004, 1.187, -0.165, 1.391, 1.599, 1.352, 1.559, 1.193, 1.513, 1.082, 0.572, 1.581, 1.661, 1.504, 1.420, 1.531, 1.545, 1.460, 1.558, 0.433, 0.713, -0.259, 0.347, 0.293, 0.490, -0.459, 0.464, 0.394, 0.241, 0.264, 0.182, 0.359, -0.127, -0.368, 0.444, -0.114, -0.116, -0.661, -5.000, -1.412, -0.673, -1.449, -5.000, -1.014, -0.648, -0.762, -1.705, -0.134, -0.319, -0.200, -0.460, 0.214, 0.822, 0.452, -5.000, -1.542, 0.386, -0.481, -0.397, -0.298, -0.127, -0.656, -0.972, 1.144, 0.495, 0.869, -0.254, -0.051, 0.748, -0.154, 0.335, -0.585, 0.556, -0.055, -0.491, -0.070, 0.152, -0.479, -0.750, 0.502, 0.558, 0.779, 0.480, -0.343, -0.124, -0.409, 0.239, -0.184, -0.193, -1.463, -0.493, -0.066, -0.286, -0.690, -0.494, 0.001, 0.068, 0.315, 0.307, 0.842, 0.025, -0.680, -5.000, -1.225, -1.356, -1.703, -5.000, -1.040, -0.635, -1.457, -1.311, -0.085, -1.466, 0.227, 0.278, 1.015, 1.203, 0.903, -5.000, -0.958, 0.393, 0.122, 0.420, 0.417, 0.488, 0.143, 0.022, 1.385, 0.428, 0.948, -0.021, 0.929, 0.772, 0.597, 1.365, 0.512, 0.555, -0.185, -0.584, 0.751, 0.629, 0.456, 0.001, 0.977, 0.592, 0.428, 0.881, 0.034, -0.706, -1.475, 0.205, -0.102, 0.283, -0.524, 0.418, -0.831, -0.584, -1.722, -0.647, 0.099, -0.661, 0.472, 0.781, 0.332, 0.353, -0.849, -5.000, -1.861, -1.126, -1.553, -5.000, -1.151, 0.102, -0.968, -1.229, -0.415, -0.962, -1.406, -0.314, 0.738, 0.698, 0.006, -5.000, -1.293, -0.185, -0.667, -0.014, -0.326, -0.283, -0.763, -0.981, 1.047, 0.414, 0.994, 0.095, 0.657, 0.532, -0.191, 0.932, -0.311, -0.231, -0.724, -1.266, 0.367, 0.366, -0.371, -0.790, 0.663, 0.455, 0.346, 0.667, -0.263, -0.557, -1.354, 0.501, -0.851, -0.785, -1.537, -0.813, -0.964, -0.608, -1.934, -1.374, 0.052, -0.550, -0.910, 0.095, -0.049, -0.482, -0.340, -5.000, -1.688, -1.613, -2.161, -5.000, -2.676, -1.714, -1.772, -2.024, -0.260, -0.722, -0.579, -0.353, -0.049, -0.130, -0.663, -5.000, -1.510, -1.318, -1.796, -1.029, -1.600, -1.215, -1.278, -1.200, 0.176, -0.344, -0.504, -0.374, -0.299, 0.105, -0.219, 0.110, -1.242, -0.555, -1.631, -1.355, -0.473, -0.129, -0.645, -1.378, -0.208, -0.241, -0.686, 0.029, -0.136, -0.677, -0.625, -0.617, -1.066, -1.510, -1.866, -1.722, -1.129, -1.060, -2.038, -1.798, -0.295, -0.963, -0.970, -0.158, 0.076, 0.482, -0.545, -5.000, -0.932, -0.116, -0.858, -5.000, -0.927, -0.525, -0.572, -1.256, 0.216, 0.009, -0.027, -0.298, 0.759, 1.209, 0.930, -5.000, -1.133, 0.744, 0.271, 0.003, 0.224, 0.541, -0.041, -0.494, 1.159, 0.931, 1.197, 0.180, 0.511, 1.100, 0.660, 1.064, -0.221, 0.659, 0.061, -0.551, 0.202, 0.344, -0.157, -0.687, 0.886, 0.905, 1.043, 1.060, 0.047, -0.130, -0.516, -0.095, -0.896, -0.063, -1.160, -0.065, -0.973, -0.737, -1.400, -1.060, 0.230, 0.020, -0.134, 0.952, 0.439, 0.676, -0.399, -5.000, -0.870, -0.106, -0.801, -5.000, -0.634, 0.111, -1.327, -1.185, -0.388, -0.837, 0.162, 0.026, 0.942, 1.301, 0.968, -5.000, -0.796, 0.670, 0.409, 0.294, 0.466, 0.735, 0.096, -0.234, 1.173, 0.677, 1.085, -0.060, 0.897, 0.911, 0.491, 1.328, 0.027, 0.516, -0.092, -0.956, 0.521, 0.633, 0.054, -0.361, 0.922, 0.711, 0.466, 0.895, -0.320, -0.282, -1.325, 0.273, 0.028, 0.669, -0.148, 0.301, -0.035, 0.079, -1.076, -0.251, 0.388, -0.558, -0.233, 0.576, 0.285, 0.313, -0.649, -5.000, -1.392, -0.655, -1.206, -5.000, -0.509, 0.194, -0.846, -1.032, -0.325, -0.688, -0.759, -0.015, 0.470, 0.619, 0.202, -5.000, -1.458, -0.222, -0.806, -0.384, 0.141, 0.161, -0.292, -0.672, 0.696, 0.614, 0.753, 0.152, 0.898, 0.983, 0.547, 0.918, -0.436, 0.297, -0.472, -0.811, 0.169, 0.191, -0.522, -0.406, 0.577, 0.628, 0.676, 0.725, 0.308, 0.395, -0.674, 0.692, -0.557, -0.227, -1.202, -0.150, -0.576, -0.385, -1.587, -0.919, 0.648, -0.177, -0.762, 0.329, 0.133, 0.136, -0.659, -5.000, -1.548, -1.304, -1.632, -5.000, -1.734, -1.499, -1.232, -1.908, -0.469, -0.997, -0.486, -0.115, 0.457, 0.718, 0.121, -5.000, -1.691, -0.732, -1.031, -0.805, -0.987, -0.571, -1.039, -1.319, 0.212, 0.033, 0.312, -0.428, -0.139, 0.590, 0.004, 0.352, -0.866, 0.076, -0.675, -1.323, -0.374, 0.123, -0.125, -1.002, 0.067, 0.483, 0.732, 0.350, -0.270, -0.426, -0.701, -0.302, -0.984, -0.536, -1.323, -1.090, -1.270, -0.815, -1.641, -1.397, -0.239, -0.384, -0.516, 0.041, 0.357, 0.619, -0.046, -5.000, -0.648, 0.530, -0.088, -5.000, -0.087, 0.511, 0.209, -0.687, -0.284, -0.191, 0.461, -0.038, 0.957, 1.299, 0.875, -5.000, -0.875, 0.903, 0.654, 0.376, 0.763, 0.849, 0.428, 0.115, 0.896, 0.905, 1.162, 0.260, 1.203, 1.462, 1.173, 1.241, 0.441, 1.274, 0.920, -0.233, 0.655, 0.959, 0.211, -0.168, 1.188, 1.142, 1.147, 1.031, 0.095, 0.607, -0.086, 0.408, 0.121, 0.849, -0.145, 0.298, -0.027, 0.122, -0.535, -0.370, 0.588, 0.344, -0.004, 0.775, 0.887, 0.466, -0.479, -5.000, -0.287, -0.388, -0.692, -5.000, -0.142, 0.277, -1.002, -0.705, -0.304, -0.955, 0.433, 0.069, 1.002, 0.947, 0.746, -5.000, -0.457, 0.405, 0.543, 0.551, 0.842, 0.706, 0.442, 0.206, 1.270, 0.696, 1.026, -0.031, 1.138, 1.021, 0.316, 1.314, 0.520, 0.793, 0.458, -0.190, 0.964, 0.760, 0.297, 0.133, 1.022, 0.788, 0.671, 1.021, -0.300, -0.460, -0.940, -0.206, -0.013, 0.052, -0.535, 0.294, 0.108, -0.613, -1.207, -0.367, 0.213, -0.732, -0.538, -0.120, 0.787, 0.913, 0.396, -5.000, -0.123, 0.601, 0.141, -5.000, 0.417, 1.007, -0.448, -0.316, 0.019, -0.422, -0.109, -0.138, 1.220, 0.965, 0.702, -5.000, -0.189, 0.863, 0.422, 0.811, 1.049, 0.854, 0.073, 0.160, 1.317, 1.121, 1.025, 0.989, 1.553, 1.053, 0.807, 1.528, 1.162, 0.399, 0.192, -0.500, 0.936, 0.529, -0.126, -0.018, 1.407, 0.753, 0.308, 1.053, 0.673, 0.250, -0.698, 1.119, 0.492, -0.200, -0.851, 0.261, -0.237, -0.551, -1.261, -0.536, 0.918, -0.449, -0.788, 0.755, 0.119, 0.533, -0.181, -5.000, -0.538, 0.410, -0.411, -5.000, -0.144, 0.185, -0.366, -0.317, 0.183, -0.027, -0.022, -0.152, 0.974, 1.040, 0.640, -5.000, -0.845, 0.825, 0.496, 0.650, 0.803, 0.839, 0.322, 0.467, 1.000, 0.924, 1.100, 0.085, 1.122, 1.218, 0.818, 1.322, 0.633, 1.052, 0.446, -0.085, 1.052, 1.162, 0.828, 0.643, 1.033, 0.843, 0.445, 1.065, 0.197, 0.420, -0.080, 0.139, 0.045, 0.265, -0.511, -0.053, -0.285, -0.317, -0.533, -0.616, 0.179, -0.485, -0.095, 0.694, -0.048, 0.118, -0.367, -5.000, -0.637, -0.474, -0.634, -5.000, -0.549, 0.054, -0.450, -0.452, -0.088, -0.157, 0.155, -0.120, 0.121, 0.284, -0.120, -5.000, -0.164, -0.314, -0.613, -0.054, -0.172, -0.286, -0.620, -0.440, 0.555, 0.249, 0.343, 0.254, 0.298, 0.633, 0.142, 0.258, 0.153, 0.225, 0.161, -0.675, 0.269, 0.226, 0.152, 0.034, 0.476, 0.727, 0.573, 0.410, -0.262, 0.209, -0.138, 0.075, -0.446, -0.281, -0.728, -0.158, 0.050, -0.222, -0.372, -0.295, 0.252, 0.131, 0.023, 0.013, 0.382, -0.307, -0.847, -5.000, -0.720, -1.165, -1.813, -5.000, -0.645, -0.379, -1.164, -0.747, -0.073, -0.824, 0.327, 0.577, 0.351, 0.174, 0.038, -5.000, -0.797, -0.963, -1.269, -0.082, 0.026, -0.275, -0.695, -0.325, 0.912, -0.231, -0.051, -0.084, 0.317, -0.137, -0.251, 1.026, -0.018, -0.256, -0.718, -0.635, 0.242, 0.030, -0.255, -0.234, 0.582, -0.012, 0.071, 0.280, -0.171, -1.023, -1.291, -0.217, -0.337, -0.683, -1.121, 0.081, -0.638, -1.093, -1.764, -0.362, 0.077, -0.994, -0.699, -0.297, 0.174, -1.027, -1.672, -5.000, -1.237, -1.334, -2.212, -5.000, -0.636, -0.456, -1.357, -0.473, -0.205, -1.367, -1.925, -0.882, -0.075, -0.937, -1.148, -5.000, -0.577, -1.103, -1.821, -0.652, -0.345, -1.274, -1.270, -0.773, 0.516, -0.739, -0.784, -0.125, -0.186, -0.912, -0.738, -0.011, -0.434, -1.004, -1.603, -0.689, -0.252, -0.744, -0.858, -0.533, 0.040, -0.760, -0.865, -0.418, -0.342, -1.756, -1.487, -0.372, -0.558, -1.724, -1.634, -0.516, -0.434, -1.169, -1.211, -0.630, -0.426, -1.555, -1.564, -0.584, -0.270, 0.045, -0.245, -5.000, -0.683, -0.201, -0.891, -5.000, -0.377, -0.471, -0.655, -0.421, -0.248, -0.355, -0.162, -0.281, 0.351, 0.645, 0.133, -5.000, -0.783, -0.129, -0.202, -0.159, 0.209, 0.325, -0.300, 0.057, 0.366, 0.555, 0.476, 0.148, 0.232, 0.906, 0.348, 0.534, 0.038, 0.810, 0.454, -0.105, 0.641, 1.025, 0.727, 0.879, 0.621, 0.881, 0.994, 0.520, 0.060, -0.040, -0.666, -0.014, -0.114, -0.007, -0.637, -0.139, 0.004, -0.086, -0.096, -0.397, -0.145, -0.801, -0.477, -0.101, -0.194, -0.776, -0.650, -5.000, -1.690, -1.470, -1.865, -5.000, -1.557, -0.981, -1.037, -0.756, -0.197, 0.053, -0.549, 0.065, -0.103, 0.319, 0.072, -5.000, -1.730, -0.340, -1.074, -0.885, -0.712, -0.539, -1.138, -1.257, 0.962, 0.249, 0.363, 0.009, -0.242, 0.043, -0.659, 0.082, -0.983, -0.089, -0.969, -0.972, -0.482, -0.352, -1.101, -0.775, 0.023, 0.079, 0.272, 0.043, 0.146, -0.391, -0.426, 0.018, -1.210, -1.063, -1.959, -1.369, -0.144, -0.303, -2.408, -0.597, 0.183, 0.059, -0.240, -0.071, 0.221, -0.595, -1.150, -5.000, -1.705, -1.876, -2.297, -5.000, -1.187, -1.469, -1.615, -1.508, -0.302, -1.173, -0.007, -0.011, 0.113, 0.485, 0.347, -5.000, -1.172, -0.338, -1.269, -0.334, -0.131, -0.324, -0.750, -0.688, 0.978, -0.253, 0.190, 0.216, 0.285, -0.140, -0.463, 0.585, -0.212, 0.028, -0.944, -0.771, 0.120, 0.103, -0.376, -0.545, 0.497, -0.020, 0.094, 0.288, -0.203, -1.047, -1.347, -0.266, -0.945, -0.529, -1.605, -0.534, -1.096, -1.522, -2.057, -1.334, 0.056, -0.861, -0.798, -0.052, -0.585, -1.138, -1.761, -5.000, -1.863, -2.107, -2.424, -5.000, -1.765, -1.444, -2.021, -1.787, -0.701, -1.672, -1.914, -0.864, -0.119, -0.414, -0.887, -5.000, -1.764, -1.551, -1.938, -1.295, -0.900, -1.150, -1.577, -1.302, 0.575, -0.246, 0.005, -0.032, -0.299, -0.741, -1.480, -0.154, -1.163, -1.058, -1.666, -1.558, -0.452, -0.514, -0.998, -1.240, -0.192, -0.288, -0.324, -0.263, -0.497, -1.480, -1.636, -0.458, -1.442, -1.805, -2.250, -1.491, -1.631, -1.596, -2.478, -2.012, -0.741, -1.522, -1.407, -0.801, -0.069, -0.351, -0.641, -5.000, -1.912, -1.972, -2.037, -5.000, -2.615, -1.983, -2.242, -1.773, -0.377, -0.500, -0.389, -0.172, 0.140, 0.587, 0.129, -5.000, -1.871, -0.578, -1.217, -0.666, -1.017, -0.722, -0.989, -1.031, 0.399, 0.017, 0.142, -0.041, -0.386, 0.309, -0.117, 0.246, -1.189, 0.264, -0.866, -0.927, -0.228, 0.182, -0.208, -0.477, 0.201, 0.484, 0.651, 0.349, -0.066, -0.474, -0.568, -0.128, -1.201, -1.123, -1.820, -1.597, -1.557, -1.237, -1.863, -1.536, -0.064, -1.019, -0.768, -0.600, -0.605, -0.551, -0.813, -5.000, -1.593, -1.597, -2.106, -5.000, -1.042, -1.365, -0.674, -1.367, -0.209, -0.588, -0.120, -0.319, 0.114, 0.315, -0.101, -5.000, -1.363, -0.833, -1.441, -0.938, -0.775, -0.682, -1.157, -1.224, 0.789, 0.311, 0.323, 0.034, -0.110, 0.075, -0.582, -0.029, -0.666, -0.347, -1.036, -1.124, -0.566, -0.697, -1.112, -1.152, -0.035, 0.110, 0.025, 0.287, -0.348, -0.719, -0.546, -0.218, -1.319, -1.244, -2.216, -1.442, -1.181, -1.331, -1.688, -1.184, -0.041, -0.612, -0.600, 0.018, -0.317, -0.916, -1.512, -5.000, -1.637, -1.933, -2.279, -5.000, -1.523, -1.263, -2.107, -1.707, -0.102, -1.252, -0.860, 0.034, 0.269, 0.253, -0.160, -5.000, -1.045, -1.088, -1.438, -0.924, -0.721, -0.620, -1.169, -1.193, 0.639, -0.566, -0.177, -0.200, -0.106, -0.601, -1.055, 0.410, -1.090, -0.836, -1.512, -2.032, -0.562, -0.356, -1.209, -1.095, 0.098, -0.332, -0.488, -0.197, -0.549, -1.348, -1.392, -0.572, -0.602, -0.942, -1.674, -0.866, -1.383, -1.569, -2.220, -1.247, -0.120, -1.257, -0.966, -0.722, -0.377, -1.481, -1.907, -5.000, -2.661, -2.088, -2.830, -5.000, -1.712, -1.856, -1.701, -2.004, -0.395, -1.868, -1.927, -0.676, -0.438, -0.728, -0.895, -5.000, -2.360, -1.997, -2.542, -1.968, -1.662, -1.706, -1.701, -2.099, -0.172, -0.939, -0.968, -0.632, -0.211, -0.581, -1.283, -0.477, -1.584, -1.692, -2.046, -2.014, -1.488, -1.408, -1.478, -1.914, -0.374, -0.868, -0.774, -0.874, -0.705, -1.568, -1.814, -0.572, -1.525, -2.060, -2.558, -1.877, -1.888, -2.337, -2.632, -2.188, -0.624, -1.930, -1.974, -0.755, -0.223, -0.825, -0.594, -5.000, -1.625, -1.682, -2.311, -5.000, -1.758, -1.392, -2.186, -2.125, -0.591, -1.063, -0.839, -0.545, -0.124, -0.023, -0.229, -5.000, -1.727, -1.368, -1.891, -1.388, -1.480, -1.258, -1.460, -1.543, 0.049, -0.202, -0.254, -0.458, -0.548, -0.119, -0.550, -0.118, -1.126, -0.580, -1.096, -1.399, -1.146, -0.357, -0.762, -1.303, -0.257, 0.113, 0.406, -0.155, -0.433, -0.717, -0.777, -0.348, -1.089, -1.086, -1.799, -1.737, -1.325, -1.691, -1.723, -1.765, -0.637, -1.156, -1.383, -0.926, 0.163, 0.272, -0.162, -5.000, -0.821, 0.103, -0.454, -5.000, 0.088, 0.538, -0.477, -0.490, 0.121, -0.186, 0.025, -0.104, 0.282, 0.801, 0.346, -5.000, -0.375, 0.218, -0.336, -0.171, 0.423, 0.453, 0.031, -0.314, 0.581, 0.385, 0.348, 0.450, 0.379, 0.808, 0.530, 0.747, 0.079, 0.669, 0.165, 0.002, 0.075, 0.253, -0.372, 0.004, 0.278, 0.498, 0.322, 0.514, -0.110, 0.310, -0.165, -0.069, 0.000, 0.171, -0.493, -0.436, -0.105, -0.025, -0.206, 0.020, 0.065, 0.013, 0.101, 0.011, -0.026, -0.783, -1.123, -5.000, -1.241, -2.027, -1.982, -5.000, -0.642, -1.174, -2.152, -1.002, -0.203, -0.955, 0.285, 0.149, 0.235, -0.478, -0.118, -5.000, -0.715, -0.957, -1.246, -0.342, -0.020, -0.726, -0.768, -0.689, 0.674, -0.177, -0.483, -0.019, 0.218, -0.013, -0.455, 0.508, -0.266, -0.500, -1.149, -1.072, 0.055, -0.392, -0.935, -0.591, 0.043, -0.360, -0.450, -0.168, -0.160, -0.995, -1.483, -0.024, -0.592, -1.347, -1.771, -0.766, -0.759, -1.694, -2.165, -1.192, -0.365, -1.039, -0.899, -0.142, -0.245, -0.447, -0.922, -5.000, -0.368, -0.965, -1.522, -5.000, -0.790, -0.442, -1.280, -0.755, -0.075, -1.217, -1.246, -0.141, 0.079, -0.118, -0.342, -5.000, -0.715, -0.828, -1.464, -0.648, 0.326, -0.204, -0.676, -0.288, 0.656, 0.407, 0.150, -0.314, 0.105, -0.530, -1.355, 0.263, -0.562, -1.382, -1.858, -1.292, 0.161, -0.901, -1.178, -1.140, 0.078, -0.710, -0.599, -0.395, 0.002, -1.070, -1.378, -0.128, -0.544, -1.466, -1.939, -1.063, -1.387, -1.754, -2.208, -1.290, -0.198, -1.145, -1.863, -0.614, -0.308, 0.354, -0.894, -5.000, -0.541, 0.108, -0.727, -5.000, -0.372, 0.099, -0.625, -0.092, -0.021, -0.076, -0.011, -0.153, 0.305, 0.628, 0.445, -5.000, -0.600, 0.009, -0.205, 0.008, 0.128, 0.241, 0.000, 0.066, 0.252, 0.380, 0.535, 0.196, 0.144, 0.458, 0.051, 0.573, -0.057, 0.783, 0.230, -0.359, 0.244, 0.298, 0.089, 0.545, 0.255, 0.238, 0.803, -0.060, -0.242, -0.117, -0.339, 0.066, -0.414, -0.412, -0.682, -0.717, -0.299, -0.650, -0.487, -0.805, -0.124, -0.328, -0.561, -0.467 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_27(struct _training *tptr) {
  struct _training tinf = {
    0.614, 11, 4.350, { 0.792, 0.399, 1.809 }, { 1.122, -1.190, -2.700 }, 0, 
    { -0.029, -0.856, -0.480, -0.744, -4.000, 1.052, -0.110, -0.172, -0.389, 0.400, -0.220, -4.000, -0.383, -0.008, -0.292, 0.541, 0.236, -4.000, 1.039, 0.748, 0.579, -1.297, -0.091, 0.824, 2.184, -0.466, 1.906, 1.429 }, 
    {{ 0.000, -0.268, -0.071, 0.394},{ -0.085, -0.071, 0.195, -0.165},{ 0.038, -0.051, 0.028, -0.005},{ 0.054, -0.119, 0.082, -0.014},{ 0.131, -0.040, 0.002, -0.083},{ 0.003, 0.011, 0.065, -0.136},{ 0.035, -0.162, 0.102, 0.032},{ 0.099, -0.127, 0.007, 0.072},{ -0.049, -0.077, 0.151, -0.098},{ 0.101, -0.159, 0.111, -0.060},{ 0.133, -0.083, 0.009, -0.030},{ 0.049, -0.034, 0.029, -0.045},{ 0.186, -0.195, -0.049, 0.144},{ 0.310, -0.359, -0.345, 0.458},{ 0.273, -0.373, -0.324, 0.483},{ 0.116, -0.507, -0.235, 0.612},{ 0.044, -0.362, -0.209, 0.553},{ 0.029, -0.262, -0.109, 0.407},{ 0.184, -0.272, -0.010, 0.175},{ 0.304, -0.158, -0.096, 0.023},{ 0.439, -0.206, -0.131, -0.062},{ 0.553, -0.362, -0.186, 0.014},{ 0.408, -0.112, -0.202, -0.044},{ 0.172, 0.017, -0.012, -0.219},{ 0.159, -0.147, 0.132, -0.196},{ 0.227, -0.122, 0.007, -0.086},{ 0.295, -0.086, -0.117, -0.036},{ 0.328, -0.201, -0.059, -0.008},{ 0.298, -0.022, -0.148, -0.097},{ 0.153, 0.013, -0.052, -0.112},{ 0.198, -0.194, 0.063, -0.044},{ 0.205, -0.054, -0.048, -0.070} }, 
    {{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}} }, 
    0.000, { 0.361, 0.160, -0.187, -5.000, -0.566, -0.272, -0.756, -5.000, -0.340, 0.094, -0.019, -0.467, -0.050, 0.010, -0.119, 0.248, 0.490, 0.705, 0.203, -5.000, -0.669, 0.337, -0.364, -0.047, 0.083, 0.054, -0.312, -0.273, 0.778, 0.300, 0.098, 0.375, 0.322, 0.819, 0.212, 0.826, -0.084, 0.463, -0.104, -0.465, 0.470, 0.360, 0.191, -0.060, 0.848, 0.812, 0.841, 0.676, -0.022, -0.053, -0.148, 0.230, -0.187, -0.440, -0.743, -0.290, -0.009, -0.193, 0.117, -0.089, -0.124, 0.172, 0.284, -0.117, 0.561, 0.544, -0.307, -5.000, -0.700, -0.339, -1.017, -5.000, 0.105, 0.579, -0.298, -0.128, 0.117, -0.280, 0.441, 0.667, 0.922, 1.050, 0.689, -5.000, -0.652, 0.081, -0.343, 0.437, 0.403, 0.355, 0.174, -0.020, 1.019, 0.024, 0.012, 0.113, 0.666, 0.859, 0.358, 1.061, 0.417, 0.651, 0.223, -0.557, 0.709, 0.779, 0.608, 0.332, 0.905, 0.732, 0.523, 0.608, -0.082, -0.016, -0.508, -0.044, 0.247, 0.294, -0.185, -0.009, 0.323, 0.216, -0.163, 0.032, 0.434, -0.058, -0.069, 0.009, -0.052, 0.050, -0.525, -5.000, -0.591, -0.576, -1.356, -5.000, -0.056, -0.112, -0.370, -0.205, -0.255, -0.907, -0.825, -0.142, 0.241, 0.317, 0.138, -5.000, -0.820, -0.591, -1.203, -0.108, -0.252, -0.662, -0.997, -0.823, 0.764, -0.276, -0.401, -0.086, -0.104, 0.268, -0.492, -0.017, -0.529, -0.044, -0.814, -0.922, -0.059, 0.188, -0.455, -0.339, 0.073, -0.002, -0.160, -0.322, -0.229, -0.506, -1.074, -0.407, -0.429, -0.827, -1.515, -0.737, -0.815, -0.943, -1.404, -0.933, 0.069, -0.886, -0.850, -0.356, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.749, -1.086, -1.144, -5.000, -1.412, -1.769, -2.206, -5.000, -1.256, -1.240, -0.681, -1.239, -0.237, -0.531, -0.400, 0.003, -0.549, -0.436, -0.804, -5.000, -1.159, -0.896, -1.351, -0.951, -0.957, -1.169, -1.220, -1.202, -0.086, -0.209, -0.688, 0.085, -0.448, -0.408, -0.934, -0.468, -0.862, -0.755, -1.319, -1.294, -0.668, -0.648, -1.384, -1.161, -0.103, -0.215, 0.013, -0.149, -0.313, -0.506, -0.438, -0.589, -0.917, -1.510, -2.146, -1.490, -0.803, -0.074, -1.410, -0.178, -0.185, -0.817, -0.923, -0.418, -0.004, 0.004, -1.272, -5.000, -1.331, -1.492, -2.353, -5.000, -0.887, -0.607, -1.105, -0.958, -0.320, -0.713, 0.122, 0.261, 0.629, 1.008, 0.371, -5.000, -1.209, -0.353, -1.043, -0.029, -0.139, -0.113, -0.498, -0.600, 0.675, -0.276, -0.422, -0.350, -0.005, 0.165, -0.462, 0.199, -0.427, -0.213, -1.003, -1.106, -0.103, -0.229, -0.365, -0.579, 0.289, 0.003, 0.285, -0.117, -0.328, -0.322, -0.913, -0.397, -0.449, -0.324, -1.154, -0.779, -0.593, -0.550, -1.132, -1.099, 0.316, 0.051, 0.255, 0.257, -0.383, -0.434, -1.238, -5.000, -1.648, -1.506, -2.031, -5.000, -0.825, -0.558, -1.200, -1.133, -0.939, -1.502, -1.893, -0.822, -0.089, 0.102, -0.634, -5.000, -1.446, -1.061, -1.653, -0.868, -0.621, -0.790, -1.130, -1.232, 0.165, -0.538, -0.475, -0.363, -0.331, -0.139, -1.159, -0.216, -1.237, -0.830, -1.505, -1.458, -0.567, -0.497, -1.188, -1.061, -0.133, -0.445, -0.185, -0.399, -0.988, -0.952, -1.538, -0.983, -1.050, -1.364, -2.113, -1.497, -1.632, -1.437, -2.464, -1.631, -0.364, -1.096, -1.148, -0.963, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.281, 0.139, -0.696, -5.000, -1.166, -0.378, -1.169, -5.000, -0.673, -0.375, -0.252, -0.997, -0.027, -0.053, -0.186, -0.155, 0.101, 0.663, 0.088, -5.000, -1.032, 0.108, -0.539, -0.488, -0.192, -0.039, -0.423, -0.675, 0.566, 0.292, 0.075, 0.048, -0.006, 0.466, -0.153, 0.307, -0.419, 0.030, -0.595, -0.623, -0.097, -0.184, -0.630, -0.668, 0.260, 0.119, 0.247, 0.176, -0.026, 0.139, -0.183, 0.001, -0.708, -0.635, -1.252, -0.668, -0.767, -0.575, -1.063, -1.031, 0.309, -0.071, -0.061, 0.342, 0.123, 0.487, -0.833, -5.000, -0.988, -0.708, -1.621, -5.000, -0.363, 0.273, -0.582, -0.555, -0.075, -0.132, -0.106, -0.175, 0.740, 1.239, 0.710, -5.000, -0.900, 0.387, -0.332, 0.100, 0.029, 0.173, -0.361, -0.499, 0.725, -0.082, 0.153, -0.033, 0.506, 0.983, 0.169, 0.853, -0.136, 0.781, 0.008, -0.939, 0.439, 0.720, 0.141, -0.237, 0.695, 0.767, 0.974, 0.456, -0.060, 0.617, -0.403, 0.215, -0.055, 0.661, -0.092, -0.373, 0.111, 0.431, -0.747, -0.381, 0.588, 0.386, 0.485, 0.364, -0.161, 0.109, -0.714, -5.000, -0.972, -0.471, -1.360, -5.000, -0.405, -0.177, -0.435, -0.715, -0.417, -0.626, -1.089, -0.435, 0.058, 0.333, -0.230, -5.000, -1.262, -0.279, -1.066, -0.492, -0.081, -0.396, -0.493, -0.811, 0.373, -0.017, -0.125, -0.347, -0.004, 0.262, -0.423, 0.259, -0.607, -0.195, -0.951, -0.631, -0.327, -0.398, -0.526, -0.483, 0.074, -0.011, -0.113, -0.064, -0.009, 0.072, -0.572, -0.004, -0.607, -0.612, -1.396, -0.702, -0.807, -0.848, -1.589, -0.907, 0.295, -0.296, -0.724, -0.440, -0.199, 0.023, -0.503, -5.000, -1.438, -0.968, -1.584, -5.000, -1.060, -0.980, -0.974, -1.313, -0.739, -0.767, -0.598, -0.663, -0.129, 0.492, -0.166, -5.000, -1.225, -0.223, -1.098, -0.859, -0.885, -0.756, -0.996, -1.095, 0.268, -0.300, -0.224, -0.394, -0.611, 0.048, -0.537, -0.122, -0.655, -0.153, -0.833, -0.947, -0.568, -0.245, -0.544, -0.791, -0.155, 0.180, 0.516, -0.144, -0.359, -0.258, -0.584, -0.216, -0.907, -0.479, -1.222, -1.079, -1.006, -0.816, -1.506, -1.081, -0.036, -0.289, -0.505, -0.303, -0.137, 0.159, -0.234, -5.000, -0.466, -0.394, -0.819, -5.000, -0.171, -0.069, -0.095, -0.245, -0.077, 0.021, 0.004, -0.140, 0.032, 0.089, -0.009, -5.000, -0.852, -0.290, -0.479, -0.295, -0.462, -0.448, -0.490, -0.558, 0.318, -0.111, 0.006, -0.168, 0.418, 0.274, -0.198, -0.039, -0.201, -0.044, -0.306, -0.358, -0.211, -0.326, -0.565, -0.353, -0.033, -0.215, -0.039, 0.176, -0.288, 0.115, -0.320, -0.093, 0.212, -0.055, -0.727, -0.375, -0.382, -0.420, -0.316, -0.064, 0.254, -0.221, 0.099, -0.229, 0.074, -0.377, -0.735, -5.000, -0.878, -1.049, -1.337, -5.000, -0.261, -0.316, -0.762, -0.650, 0.084, -0.736, -0.044, -0.199, 0.221, 0.266, 0.182, -5.000, -0.565, -0.101, -0.410, -0.169, 0.063, -0.110, -0.254, -0.462, 0.404, -0.113, -0.262, 0.270, 0.040, 0.236, -0.182, 0.212, -0.376, -0.415, -0.733, -0.797, -0.231, -0.536, -0.493, -0.297, -0.209, -0.499, -0.359, -0.216, -0.426, -0.417, -0.799, -0.298, -0.344, -0.356, -0.724, -0.540, -0.407, -0.802, -0.923, -0.445, -0.162, -0.532, -0.638, -0.352, -0.009, 0.216, -0.585, -5.000, -0.661, -0.250, -1.112, -5.000, -0.188, 0.217, -0.444, -0.421, -0.236, -0.335, -0.731, -0.066, 0.486, 0.531, 0.216, -5.000, -0.650, -0.206, -0.901, -0.059, 0.242, 0.026, -0.225, -0.000, 0.488, 0.392, 0.265, 0.366, -0.069, 0.184, -1.021, -0.107, -0.907, -0.930, -1.471, -0.861, -0.024, -0.110, -0.641, -0.448, 0.350, -0.176, -0.382, 0.017, -0.204, -0.371, -0.945, 0.003, -0.237, -1.121, -1.524, -0.526, -0.960, -1.057, -1.830, -1.011, 0.094, -0.603, -1.026, -0.072, 0.057, 0.088, -0.450, -5.000, -0.754, -0.298, -0.527, -5.000, -0.672, -0.318, -0.599, -0.324, -0.526, -0.244, -0.066, -0.476, 0.354, 0.885, 0.192, -5.000, -1.086, 0.190, -0.583, -0.132, -0.077, 0.206, -0.449, -0.490, 0.384, 0.355, 0.453, 0.252, 0.497, 0.604, -0.037, 0.340, -0.251, 0.022, -0.288, -0.539, 0.350, 0.175, -0.227, 0.040, 0.258, 0.355, 0.331, 0.520, 0.071, 0.060, -0.273, -0.042, -0.244, -0.553, -0.832, -0.306, -1.017, -0.527, -0.648, -0.681, 0.026, -0.288, -0.108, 0.043, 0.323, 0.767, 0.118, -5.000, -0.562, 0.386, 0.095, -5.000, -0.113, 0.657, 0.025, -0.409, 0.107, 0.120, 0.605, 0.221, 0.498, 1.025, 0.563, -5.000, -0.809, 0.497, 0.025, 0.007, 0.093, 0.273, -0.178, -0.261, 0.545, 0.467, 0.642, 0.280, 1.027, 1.202, 0.920, 1.265, 0.263, 1.016, 0.658, -0.096, 0.863, 0.738, 0.440, 0.408, 1.268, 1.144, 1.185, 1.057, 0.357, 0.626, 0.226, 0.361, 0.033, 0.262, -0.207, 0.073, -0.116, -0.226, -0.452, -0.328, 0.375, 0.443, 0.011, 0.212, 0.668, 1.021, 0.258, -5.000, 0.015, 0.219, -0.169, -5.000, 0.379, 1.067, 0.305, 0.311, 0.241, -0.046, 0.943, 1.023, 1.065, 1.275, 1.024, -5.000, -0.079, 0.429, 0.431, 0.820, 0.852, 0.940, 0.700, 0.363, 1.138, 0.418, 0.555, 0.339, 0.848, 1.040, 0.819, 1.365, 0.607, 0.927, 0.686, -0.134, 0.837, 0.809, 0.881, 0.446, 1.015, 0.862, 0.868, 0.850, -0.064, 0.337, -0.388, 0.253, 0.354, 0.690, 0.370, 0.385, 0.550, 0.592, 0.287, 0.279, 0.742, 0.210, 0.275, 0.093, 0.444, 0.640, 0.131, -5.000, -0.320, 0.382, -0.324, -5.000, 0.413, 0.894, 0.376, 0.148, 0.030, -0.016, 0.231, 0.257, 0.610, 0.707, 0.393, -5.000, -0.575, 0.236, -0.477, 0.244, 0.356, 0.155, -0.108, -0.266, 0.867, 0.406, 0.398, 0.263, 0.559, 0.805, 0.139, 0.892, 0.153, 0.712, 0.180, -0.246, 0.628, 0.801, 0.042, 0.047, 0.666, 0.774, 0.816, 0.644, 0.323, 0.318, -0.467, 0.476, 0.117, 0.017, -0.787, -0.199, -0.295, -0.063, -0.697, -0.205, 0.910, -0.036, -0.054, 0.345, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.404, -0.557, -0.839, -5.000, -1.312, -1.209, -1.619, -5.000, -1.522, -1.157, -0.843, -1.405, -0.160, -0.489, -0.267, -0.248, -0.720, -0.521, -0.805, -5.000, -1.155, -0.680, -0.954, -0.915, -1.109, -1.146, -1.244, -1.274, -0.265, -0.403, -0.657, -0.347, -0.563, -0.185, -0.734, -0.296, -0.893, -0.633, -1.153, -0.869, -0.985, -0.765, -1.311, -1.163, -0.623, -0.271, -0.138, -0.454, -0.128, -0.322, -0.344, -0.273, -0.763, -1.166, -1.852, -1.038, -0.208, 0.121, -0.184, -0.158, -0.264, -0.508, -0.606, -0.097, 0.257, 0.315, -0.649, -5.000, -0.699, -0.843, -1.504, -5.000, -0.299, -0.086, -0.485, -0.645, 0.086, -0.355, 0.318, 0.279, 0.786, 1.124, 0.673, -5.000, -0.637, 0.229, -0.522, 0.381, 0.280, 0.354, 0.048, -0.216, 0.868, 0.104, 0.149, -0.080, 0.368, 0.480, 0.133, 0.662, 0.012, 0.299, -0.370, -0.737, 0.171, 0.086, 0.023, -0.198, 0.448, 0.196, 0.412, 0.095, -0.204, 0.096, -0.717, -0.293, -0.273, 0.234, -0.639, -0.310, -0.400, -0.463, -1.237, -0.918, 0.278, 0.063, 0.521, 0.201, -0.174, -0.005, -0.644, -5.000, -1.097, -0.754, -1.391, -5.000, -0.616, -0.154, -0.793, -0.817, -0.544, -0.838, -1.137, -0.566, -0.024, 0.330, -0.279, -5.000, -1.197, -0.514, -0.983, -0.496, -0.345, -0.404, -0.618, -0.801, 0.121, -0.238, -0.211, -0.208, -0.033, 0.281, -0.606, 0.327, -0.717, -0.196, -0.851, -1.125, -0.320, -0.247, -0.827, -0.590, -0.040, -0.121, 0.087, -0.027, -0.257, -0.223, -1.145, -0.220, -0.764, -0.799, -1.479, -0.875, -1.249, -1.228, -1.988, -1.337, 0.033, -0.611, -0.532, -0.634, -0.235, 0.070, -0.500, -5.000, -1.164, -0.730, -1.271, -5.000, -1.066, -0.772, -0.832, -1.210, -0.239, -0.429, -0.439, -0.006, 0.586, 0.815, 0.396, -5.000, -0.630, -0.319, -0.588, -0.066, -0.116, 0.106, -0.166, -0.386, 0.362, -0.103, 0.051, -0.094, 0.173, 0.604, 0.004, 0.470, -0.195, 0.440, -0.251, -0.557, 0.290, 0.653, 0.056, -0.189, 0.270, 0.487, 0.744, 0.296, -0.001, -0.164, -0.537, -0.419, -0.490, -0.582, -1.202, -0.675, -0.811, -1.135, -1.210, -0.838, -0.277, -0.727, -0.876, -0.274, -0.036, 0.655, -0.250, -5.000, -0.894, 0.140, -0.568, -5.000, -0.571, 0.155, -0.132, -0.951, -0.242, 0.124, 0.169, -0.063, 0.176, 1.010, 0.441, -5.000, -0.893, 0.517, -0.109, -0.120, -0.040, 0.293, -0.247, -0.554, 0.386, 0.482, 0.570, 0.057, 0.403, 0.920, 0.415, 1.106, -0.295, 0.650, 0.025, -0.585, -0.117, 0.005, -0.519, -0.578, 0.632, 0.596, 0.725, 0.571, 0.279, 0.658, 0.126, 0.770, -0.549, -0.383, -1.058, -0.374, -1.125, -0.750, -1.181, -1.047, 0.816, 0.372, 0.657, 0.904, 0.119, 0.622, -0.447, -5.000, -1.001, -0.343, -1.019, -5.000, -0.379, 0.116, -0.557, -0.687, -0.364, -0.303, 0.055, 0.017, 0.488, 1.089, 0.596, -5.000, -1.019, 0.420, -0.101, 0.123, -0.027, 0.207, -0.331, -0.536, 0.541, 0.123, 0.240, -0.093, 0.491, 0.828, 0.371, 1.001, -0.292, 0.725, 0.067, -0.787, 0.087, 0.340, -0.151, -0.415, 0.626, 0.487, 0.703, 0.370, 0.279, 0.633, -0.483, 0.492, -0.074, 0.774, 0.051, -0.109, -0.087, 0.375, -0.543, -0.396, 0.597, 0.377, 0.530, 0.411, -0.193, 0.356, -0.566, -5.000, -1.007, -0.320, -1.125, -5.000, -0.450, -0.090, -0.364, -0.924, -0.426, -0.418, -0.558, -0.356, -0.161, 0.628, -0.056, -5.000, -1.276, 0.047, -0.664, -0.442, -0.133, -0.027, -0.340, -0.765, 0.165, 0.232, 0.356, -0.102, 0.479, 0.694, -0.176, 0.565, -0.490, 0.270, -0.671, -0.610, -0.380, -0.195, -0.881, -0.798, 0.199, 0.211, 0.412, 0.221, 0.153, 0.477, -0.392, 0.367, -0.517, -0.268, -1.118, -0.478, -0.886, -0.670, -1.496, -1.086, 0.750, -0.021, -0.204, -0.151, -0.485, 0.048, -0.525, -5.000, -1.296, -0.704, -1.139, -5.000, -0.999, -0.757, -1.013, -1.229, -0.790, -0.630, -0.445, -0.726, 0.000, 0.591, 0.074, -5.000, -1.153, -0.211, -0.721, -0.567, -0.732, -0.577, -0.687, -0.952, -0.148, -0.206, 0.088, -0.339, -0.498, 0.147, -0.482, -0.165, -0.687, 0.286, -0.503, -0.972, -0.505, -0.136, -0.397, -0.761, -0.021, 0.214, 0.909, -0.029, -0.363, -0.034, -0.379, 0.036, -0.754, -0.463, -0.999, -0.748, -1.102, -0.884, -1.180, -1.141, 0.162, -0.198, 0.039, -0.215, 0.144, 0.649, -0.369, -5.000, -0.430, 0.458, 0.184, -5.000, -0.024, 0.430, -0.071, -0.436, -0.180, 0.270, 0.126, 0.292, 0.485, 1.011, 0.652, -5.000, -0.633, 0.787, 0.245, 0.019, 0.403, 0.664, 0.197, -0.047, 0.438, 0.656, 0.792, 0.176, 0.984, 1.152, 0.944, 1.143, 0.259, 1.036, 0.443, -0.276, 0.359, 0.478, -0.322, -0.143, 0.985, 0.876, 0.967, 0.967, 0.528, 0.819, 0.093, 0.476, 0.169, 0.523, 0.061, 0.141, 0.113, -0.026, -0.199, -0.184, 0.742, 0.302, 0.325, 0.587, 0.094, 0.381, -0.498, -5.000, -0.517, -0.620, -1.140, -5.000, -0.116, 0.023, -0.434, -0.409, -0.093, -0.421, 0.244, -0.081, 0.300, 0.771, 0.418, -5.000, -0.648, -0.029, -0.233, -0.031, 0.143, 0.110, -0.163, -0.355, 0.314, 0.068, 0.235, 0.018, 0.415, 0.980, 0.308, 0.780, -0.086, 0.428, 0.090, -0.476, 0.174, 0.132, -0.288, -0.270, 0.391, 0.257, 0.475, 0.162, -0.022, 0.198, -0.661, 0.096, -0.252, 0.159, -0.470, -0.358, -0.312, -0.227, -0.923, -0.593, 0.072, -0.205, -0.213, 0.156, 0.370, 0.845, -0.005, -5.000, -0.627, 0.440, -0.273, -5.000, 0.145, 0.764, -0.116, -0.154, -0.094, -0.102, 0.000, 0.035, 0.320, 0.506, 0.428, -5.000, -0.666, 0.612, -0.090, 0.209, 0.672, 0.712, 0.315, 0.240, 0.662, 0.596, 0.531, 0.371, 0.835, 0.959, 0.290, 0.947, 0.384, 0.612, -0.074, -0.251, 0.289, 0.334, -0.127, -0.028, 0.798, 0.450, 0.395, 0.722, 0.327, 0.615, -0.415, 0.645, 0.158, -0.172, -0.848, -0.193, -0.802, -0.657, -1.303, -0.746, 0.745, -0.314, -0.191, 0.321, -0.303, 0.049, -0.177, -5.000, -0.913, -0.088, -0.846, -5.000, -0.278, -0.427, -0.586, -0.583, -0.169, -0.068, -0.046, -0.058, -0.042, 0.571, 0.154, -5.000, -0.845, 0.001, -0.309, -0.183, -0.386, 0.007, -0.376, -0.437, 0.073, 0.513, 0.540, 0.210, -0.140, 0.167, -0.354, -0.168, -0.626, -0.142, -0.648, -0.679, -0.599, -0.367, -0.537, -0.750, 0.103, 0.187, 0.543, 0.212, 0.057, 0.002, -0.340, 0.100, -0.529, -0.288, -0.710, -0.393, -0.239, -0.693, -0.988, -1.008, 0.260, -0.161, -0.364, 0.005, 0.452, 0.724, 0.036, -5.000, -0.524, 0.070, -0.276, -5.000, -0.146, 0.518, 0.062, -0.324, 0.096, 0.160, 0.470, 0.493, 0.490, 1.020, 0.596, -5.000, -0.779, 0.260, -0.153, 0.180, 0.122, 0.306, -0.012, -0.142, 0.641, 0.416, 0.654, 0.234, 0.711, 1.085, 0.657, 1.194, 0.234, 0.757, 0.272, -0.324, 0.626, 0.562, 0.262, 0.228, 1.104, 1.133, 1.152, 1.023, 0.030, 0.405, 0.097, 0.249, 0.247, 0.279, -0.191, 0.292, 0.255, 0.078, -0.066, 0.005, 0.612, 0.517, 0.284, 0.619, 0.798, 0.816, -0.020, -5.000, -0.327, -0.109, -0.554, -5.000, 0.392, 0.926, 0.022, 0.182, 0.166, -0.133, 0.663, 0.873, 1.153, 1.179, 1.003, -5.000, -0.468, 0.069, 0.077, 0.774, 0.850, 0.811, 0.683, 0.352, 1.242, 0.315, 0.432, 0.189, 0.831, 0.912, 0.765, 1.350, 0.673, 0.790, 0.455, -0.236, 0.896, 0.800, 0.818, 0.508, 1.124, 0.860, 0.844, 0.832, 0.153, 0.286, -0.662, 0.357, 0.477, 0.533, 0.083, 0.400, 0.640, 0.542, 0.290, 0.273, 0.671, 0.069, 0.229, 0.245, 0.520, 0.614, -0.342, -5.000, -0.735, -0.254, -0.977, -5.000, 0.112, 0.573, 0.081, -0.297, -0.174, -0.532, -0.737, -0.088, 0.485, 0.661, 0.159, -5.000, -0.754, -0.102, -1.138, 0.116, 0.093, -0.315, -0.382, -0.513, 1.006, 0.083, 0.193, 0.149, 0.492, 0.835, 0.158, 0.788, 0.091, 0.714, 0.014, -0.530, 0.488, 0.735, 0.206, -0.141, 0.757, 0.846, 0.828, 0.705, 0.117, 0.053, -0.646, 0.411, -0.058, -0.059, -0.923, -0.243, -0.428, -0.371, -0.923, -0.555, 0.625, -0.073, -0.380, 0.116, 0.270, 0.556, -0.389, -5.000, -0.935, 0.035, -0.395, -5.000, -0.100, 0.147, -0.241, -0.461, 0.245, -0.275, 0.012, -0.195, 0.825, 1.109, 0.868, -5.000, -0.601, 0.530, 0.251, 0.461, 0.497, 0.716, 0.460, -0.048, 0.916, 0.579, 0.828, 0.042, 1.220, 1.380, 0.930, 1.424, 1.026, 1.395, 0.881, 0.306, 1.403, 1.520, 1.215, 1.338, 1.398, 1.436, 1.398, 1.395, 0.223, 0.416, -0.136, 0.109, 0.280, 0.131, -0.560, 0.256, 0.086, 0.135, -0.070, 0.129, 0.723, 0.072, -0.149, 0.529, -0.208, 0.142, -0.833, -5.000, -1.081, -0.415, -1.165, -5.000, -0.409, 0.083, -0.178, -0.741, -0.203, -0.188, 0.134, 0.350, 0.145, 0.698, 0.158, -5.000, -0.951, 0.211, -0.538, -0.171, -0.111, -0.020, -0.363, -0.688, 0.712, 0.284, 0.434, -0.278, -0.019, 0.533, -0.089, 0.443, -0.262, 0.416, -0.327, -0.588, 0.017, 0.004, -0.574, -0.566, 0.514, 0.361, 0.497, 0.378, 0.082, 0.306, -0.166, 0.226, -0.249, -0.162, -1.067, -0.517, 0.164, 0.109, -0.284, -0.133, 0.467, 0.150, 0.180, 0.470, 0.451, 0.424, -0.510, -5.000, -0.994, -1.135, -1.693, -5.000, -0.308, 0.019, -0.429, -0.571, -0.142, -0.683, 0.091, 0.124, 1.156, 1.175, 0.911, -5.000, -0.676, -0.025, -0.410, 0.374, 0.539, 0.526, 0.152, 0.092, 1.157, 0.114, 0.148, 0.056, 0.740, 0.817, 0.726, 1.217, 0.459, 0.724, 0.218, -0.517, 0.745, 0.688, 0.565, 0.187, 0.930, 0.711, 0.814, 0.599, 0.054, 0.182, -0.503, 0.172, 0.003, 0.601, -0.210, 0.237, 0.047, 0.193, -0.420, -0.524, 0.640, 0.429, 0.812, 0.545, 0.121, 0.207, -0.701, -5.000, -1.252, -0.929, -1.459, -5.000, -0.534, -0.032, -0.441, -0.985, -0.645, -0.700, -1.260, -0.604, 0.596, 0.733, 0.178, -5.000, -0.962, -0.201, -0.804, -0.064, -0.110, -0.093, -0.527, -0.536, 0.849, 0.068, 0.511, -0.136, 0.328, 0.702, -0.211, 0.743, -0.474, 0.121, -0.649, -1.043, 0.276, 0.429, -0.372, -0.470, 0.583, 0.405, 0.156, 0.440, -0.405, -0.386, -1.247, -0.084, -0.611, -0.573, -1.187, -0.678, -0.918, -0.667, -1.983, -1.190, 0.249, -0.285, -0.279, -0.437, -0.560, -0.516, -0.542, -5.000, -1.406, -1.480, -1.659, -5.000, -1.230, -1.121, -1.303, -1.487, -0.470, -0.397, -0.802, -0.592, -0.212, -0.215, -0.501, -5.000, -0.871, -0.967, -1.359, -0.962, -0.739, -0.675, -0.936, -0.896, 0.036, -0.231, -0.481, -0.428, -0.314, 0.004, -0.262, 0.060, -0.639, -0.371, -0.935, -0.706, -0.385, -0.175, -0.562, -0.901, -0.092, -0.144, -0.252, -0.180, -0.450, -0.675, -0.725, -0.516, -0.872, -0.863, -1.213, -0.969, -0.885, -0.969, -1.623, -1.223, -0.161, -0.863, -0.804, -0.396, 0.410, 0.904, -0.065, -5.000, -0.648, 0.367, -0.377, -5.000, -0.125, 0.418, 0.123, -0.729, 0.005, 0.239, 0.410, -0.094, 0.445, 0.964, 0.601, -5.000, -0.996, 0.419, -0.074, 0.188, 0.165, 0.405, -0.074, -0.434, 0.839, 0.538, 0.704, 0.032, 0.493, 0.937, 0.420, 1.027, 0.023, 0.719, -0.034, -0.373, 0.289, 0.182, -0.256, -0.266, 0.802, 0.753, 0.785, 0.799, 0.147, 0.478, -0.128, 0.168, -0.303, 0.278, -0.510, -0.043, -0.330, -0.172, -0.731, -0.643, 0.723, 0.489, 0.506, 0.785, 0.445, 0.634, -0.294, -5.000, -0.842, -0.356, -0.933, -5.000, -0.047, 0.542, -0.421, -0.597, -0.292, -0.747, 0.217, 0.165, 0.908, 1.091, 0.831, -5.000, -0.730, 0.238, -0.115, 0.280, 0.280, 0.441, -0.126, -0.341, 0.999, 0.194, 0.423, -0.114, 0.624, 0.836, 0.482, 1.118, 0.020, 0.632, 0.145, -0.524, 0.495, 0.498, 0.085, -0.093, 0.800, 0.632, 0.678, 0.618, -0.225, 0.313, -0.617, 0.564, -0.175, 0.565, -0.175, -0.013, 0.137, 0.304, -0.339, -0.254, 0.672, 0.251, 0.275, 0.347, 0.161, 0.485, -0.640, -5.000, -1.006, -0.440, -1.053, -5.000, -0.093, 0.322, -0.282, -0.575, -0.288, -0.483, -0.477, -0.253, 0.009, 0.410, 0.118, -5.000, -1.264, -0.071, -0.855, -0.107, 0.019, -0.019, -0.479, -0.629, 0.695, 0.225, 0.214, -0.055, 0.668, 1.050, 0.246, 0.576, -0.039, 0.620, -0.258, -0.439, 0.223, 0.433, -0.296, -0.175, 0.473, 0.643, 0.641, 0.588, 0.013, 0.431, -0.550, 0.437, -0.697, 0.103, -0.921, -0.204, -0.514, -0.359, -1.128, -0.730, 0.469, 0.050, -0.169, -0.006, -0.018, 0.378, -0.509, -5.000, -1.188, -0.632, -1.325, -5.000, -0.813, -0.541, -0.594, -1.188, -0.893, -0.631, -0.513, -0.453, 0.157, 0.761, 0.205, -5.000, -1.012, -0.290, -0.797, -0.477, -0.568, -0.550, -0.640, -0.902, 0.357, -0.111, -0.086, -0.246, -0.169, 0.527, -0.028, 0.144, -0.449, 0.474, -0.346, -0.864, -0.225, 0.141, -0.087, -0.550, 0.205, 0.505, 0.779, 0.246, -0.311, -0.083, -0.957, -0.357, -0.681, -0.297, -0.980, -0.944, -0.889, -0.716, -1.043, -1.068, 0.031, -0.009, -0.182, 0.002, 0.434, 1.048, -0.013, -5.000, -0.646, 0.498, -0.026, -5.000, 0.226, 0.789, 0.306, -0.076, -0.119, 0.063, 0.452, 0.017, 0.891, 1.080, 0.801, -5.000, -0.687, 0.778, 0.275, 0.432, 0.748, 0.822, 0.497, 0.114, 0.790, 0.750, 0.882, 0.303, 1.034, 1.123, 0.903, 1.165, 0.409, 1.050, 0.536, -0.188, 0.763, 0.729, -0.082, 0.032, 1.090, 1.010, 1.064, 0.953, 0.503, 0.870, 0.220, 0.565, 0.288, 0.767, 0.041, 0.300, 0.301, 0.411, -0.194, -0.088, 1.037, 0.861, 0.676, 0.743, 0.495, 0.629, -0.435, -5.000, -0.616, -0.379, -0.971, -5.000, 0.205, 0.504, -0.187, -0.298, -0.072, -0.294, 0.376, 0.137, 0.994, 0.810, 0.688, -5.000, -0.483, 0.121, 0.119, 0.511, 0.725, 0.511, 0.357, 0.138, 1.073, 0.393, 0.668, 0.215, 0.915, 0.932, 0.550, 1.136, 0.368, 0.799, 0.555, -0.196, 0.842, 0.636, 0.414, 0.169, 0.885, 0.680, 0.729, 0.679, -0.088, 0.446, -0.610, 0.069, 0.060, 0.466, -0.043, 0.085, 0.374, 0.164, -0.245, -0.210, 0.547, 0.170, 0.179, 0.270, 0.952, 1.048, 0.696, -5.000, -0.210, 0.704, 0.326, -5.000, 0.766, 1.195, 0.237, 0.343, 0.236, 0.319, 0.652, 0.645, 0.979, 0.936, 0.966, -5.000, -0.230, 0.876, 0.081, 0.627, 1.061, 0.774, 0.469, 0.411, 1.258, 1.008, 0.967, 0.935, 1.032, 1.078, 0.601, 1.261, 0.740, 0.672, 0.198, -0.380, 0.672, 0.483, -0.080, 0.200, 1.033, 0.652, 0.317, 0.789, 0.328, 0.635, -0.240, 1.023, 0.509, 0.250, -0.526, 0.141, -0.381, -0.501, -1.178, -0.436, 1.013, 0.174, -0.052, 0.611, 0.063, 0.587, -0.277, -5.000, -0.763, 0.198, -0.300, -5.000, -0.321, 0.013, -0.398, -0.503, -0.040, -0.050, 0.346, -0.066, 0.734, 0.741, 0.543, -5.000, -0.730, 0.388, 0.124, 0.350, 0.738, 0.762, 0.476, 0.353, 0.812, 0.556, 0.852, 0.433, 0.996, 1.030, 0.717, 1.178, 0.482, 0.959, 0.289, -0.032, 0.650, 0.724, 0.094, 0.142, 0.957, 0.813, 0.633, 0.792, 0.076, 0.049, -0.591, 0.283, 0.088, -0.219, -0.534, -0.118, -0.413, -0.420, -0.587, -0.560, 0.566, 0.019, -0.255, 0.485, -0.059, 0.098, -0.452, -5.000, -0.576, -0.589, -1.044, -5.000, -0.055, 0.119, -0.146, -0.186, -0.021, -0.095, -0.093, 0.036, 0.222, 0.374, -0.015, -5.000, -0.766, -0.248, -0.581, -0.187, 0.076, -0.008, -0.444, -0.202, 0.500, 0.169, -0.089, 0.283, 0.246, 0.430, 0.112, 0.445, 0.036, -0.092, -0.489, -0.366, 0.125, -0.115, -0.246, -0.178, 0.543, 0.419, 0.388, 0.265, 0.154, 0.015, -0.263, -0.181, -0.042, -0.280, -0.753, -0.284, -0.149, 0.164, 0.108, 0.111, -0.022, 0.021, -0.124, 0.253, 0.025, 0.022, -0.507, -5.000, -0.622, -0.648, -1.257, -5.000, -0.018, 0.213, -0.603, -0.104, -0.055, -0.487, 0.259, 0.448, 0.762, 0.751, 0.450, -5.000, -0.341, -0.206, -0.556, 0.263, 0.480, 0.398, 0.031, 0.080, 0.771, 0.102, 0.045, 0.008, 0.334, 0.322, 0.049, 0.907, 0.156, 0.171, -0.370, -0.635, 0.316, 0.152, 0.080, 0.082, 0.609, 0.195, 0.316, 0.349, -0.148, -0.222, -0.934, 0.138, 0.144, 0.125, -0.551, -0.051, 0.057, -0.107, -0.512, -0.096, 0.191, -0.380, -0.350, 0.038, -0.278, -0.597, -0.946, -5.000, -0.615, -1.340, -1.810, -5.000, -0.451, -0.561, -0.907, -0.206, -0.220, -1.197, -1.409, -0.448, 0.099, -0.379, -0.564, -5.000, -0.743, -0.814, -1.666, -0.633, -0.303, -0.721, -0.851, -0.477, 0.268, -0.383, -0.716, -0.184, 0.003, -0.280, -0.740, 0.104, -0.266, -0.470, -1.034, -0.747, -0.048, -0.271, -0.639, -0.401, 0.055, -0.358, -0.410, -0.270, -0.726, -0.757, -1.280, -0.375, -0.570, -0.877, -1.698, -0.755, -0.713, -1.084, -1.433, -0.638, -0.158, -1.037, -1.034, -0.456, -0.033, -0.091, -0.537, -5.000, -0.698, -0.677, -1.099, -5.000, -0.378, -0.010, -0.667, -0.624, -0.156, -0.321, -0.168, -0.272, 0.365, 0.716, 0.182, -5.000, -0.340, -0.016, -0.510, -0.073, 0.275, 0.178, -0.153, -0.204, 0.348, 0.288, 0.222, 0.399, 0.686, 0.513, 0.182, 0.469, 0.237, 0.900, 0.237, -0.106, 0.645, 1.108, 0.477, 0.674, 0.795, 0.849, 0.741, 0.620, -0.147, -0.291, -0.418, -0.183, 0.036, -0.353, -0.836, -0.043, -0.112, -0.762, -0.971, -0.278, 0.180, -0.302, -0.359, -0.073, -0.114, -0.162, -1.251, -5.000, -1.199, -0.925, -1.628, -5.000, -0.534, -0.403, -0.344, -0.667, -0.356, -0.240, -0.553, -0.099, -0.008, 0.511, 0.006, -5.000, -0.869, -0.042, -0.616, -0.243, -0.441, -0.210, -0.605, -0.514, 0.561, 0.136, 0.167, 0.116, -0.187, 0.103, -0.358, 0.097, -0.407, -0.041, -0.670, -0.498, -0.208, -0.339, -0.847, -0.650, 0.083, -0.055, 0.162, 0.129, -0.276, -0.025, -0.337, -0.126, -0.325, -0.572, -1.238, -0.943, 0.167, -0.295, 0.060, -0.144, 0.119, -0.139, 0.129, -0.081, -0.057, -0.157, -0.840, -5.000, -1.155, -1.004, -2.094, -5.000, -0.628, -0.572, -0.823, -1.018, -0.109, -0.858, -0.110, 0.013, 0.500, 0.865, 0.480, -5.000, -0.576, -0.236, -0.940, 0.149, 0.244, 0.056, -0.257, -0.219, 0.737, -0.109, -0.217, -0.017, 0.224, 0.141, -0.058, 0.649, 0.001, 0.210, -0.599, -0.570, 0.237, 0.120, -0.039, -0.073, 0.579, 0.181, 0.416, 0.252, -0.164, -0.190, -0.675, -0.193, -0.167, 0.057, -0.754, -0.394, -0.292, -0.394, -0.802, -0.692, 0.180, -0.267, 0.204, 0.058, -0.526, -0.621, -1.277, -5.000, -1.469, -1.442, -1.945, -5.000, -0.618, -1.196, -1.169, -1.154, -0.527, -1.290, -1.715, -0.626, -0.118, -0.064, -0.653, -5.000, -1.234, -1.115, -1.587, -0.867, -0.501, -0.930, -1.132, -0.915, 0.285, -0.372, -0.386, -0.433, -0.357, -0.149, -1.044, -0.120, -0.911, -0.627, -1.304, -1.204, -0.323, -0.192, -0.855, -0.740, 0.049, -0.305, -0.232, -0.228, -0.771, -0.989, -1.369, -0.641, -0.937, -1.184, -1.715, -1.222, -1.298, -1.269, -2.231, -1.464, -0.298, -0.941, -0.990, -0.932, -0.579, -0.727, -1.125, -5.000, -1.233, -1.075, -1.762, -5.000, -1.328, -1.261, -1.276, -1.600, -0.456, -0.241, -0.244, -0.172, 0.020, 0.272, -0.174, -5.000, -1.069, -0.878, -1.131, -0.551, -0.560, -0.576, -0.705, -0.779, 0.251, -0.113, -0.233, -0.084, -0.210, 0.182, -0.256, -0.012, -0.653, 0.152, -0.572, -0.569, -0.053, 0.079, -0.374, -0.381, 0.026, 0.283, 0.604, 0.151, -0.349, -0.533, -0.412, -0.154, -0.709, -0.736, -1.287, -0.718, -0.878, -1.126, -1.105, -1.050, -0.412, -0.717, -0.692, -0.324, -0.163, 0.042, -1.234, -5.000, -1.344, -1.039, -1.804, -5.000, -0.325, -0.309, -0.671, -0.836, -0.269, -0.190, -0.381, -0.874, 0.020, 0.445, 0.007, -5.000, -1.069, -0.439, -1.041, -0.557, -0.315, -0.220, -0.764, -0.734, 0.652, 0.268, -0.005, 0.190, -0.080, 0.322, -0.406, 0.230, -0.514, -0.255, -1.254, -1.046, -0.292, -0.461, -1.098, -0.653, 0.207, 0.014, 0.204, 0.152, -0.182, -0.094, -0.440, -0.090, -0.711, -0.678, -1.446, -0.820, -0.628, -0.531, -0.894, -0.691, 0.196, -0.328, -0.164, -0.033, -0.129, -0.071, -1.197, -5.000, -1.202, -1.025, -1.414, -5.000, -0.582, -0.308, -0.883, -0.740, -0.168, -0.572, -0.182, -0.186, 0.450, 0.761, 0.230, -5.000, -1.151, -0.291, -0.982, -0.388, -0.334, -0.179, -0.685, -0.713, 0.600, -0.218, -0.416, -0.127, -0.015, 0.040, -0.682, 0.363, -0.608, -0.271, -1.127, -1.182, -0.163, -0.181, -0.570, -0.501, 0.273, -0.073, -0.054, -0.055, -0.137, -0.064, -1.070, -0.084, -0.355, -0.213, -1.066, -0.806, -0.600, -0.339, -1.223, -0.813, 0.010, -0.562, -0.510, 0.030, -0.543, -0.469, -1.141, -5.000, -1.757, -1.300, -2.373, -5.000, -0.827, -0.871, -0.946, -1.151, -0.322, -1.528, -1.367, -0.680, -0.462, -0.117, -0.797, -5.000, -1.384, -0.976, -1.949, -1.148, -0.907, -1.178, -1.160, -1.172, -0.019, -0.579, -0.798, -0.551, -0.094, 0.140, -0.883, -0.118, -1.151, -0.529, -1.604, -1.695, -0.538, -0.702, -1.079, -0.972, -0.171, -0.242, -0.353, -0.501, -0.562, -0.687, -1.383, -0.673, -0.894, -1.079, -2.217, -1.437, -1.393, -1.453, -2.176, -1.641, -0.406, -1.348, -1.684, -1.278, -0.549, -0.536, -0.751, -5.000, -1.389, -1.399, -1.778, -5.000, -1.138, -1.091, -1.267, -1.296, -0.764, -1.012, -0.924, -0.362, -0.287, 0.102, -0.401, -5.000, -1.064, -0.567, -1.314, -0.772, -1.074, -1.049, -1.041, -1.120, -0.070, -0.401, -0.481, -0.256, -0.536, 0.152, -0.565, -0.283, -1.003, -0.265, -0.885, -1.049, -0.713, -0.331, -0.674, -0.929, -0.052, 0.046, 0.495, -0.149, -0.419, -0.554, -1.030, -0.349, -0.651, -0.781, -1.397, -1.007, -0.934, -1.067, -1.615, -1.044, -0.193, -0.737, -0.760, -0.417, 0.389, 0.784, 0.075, -5.000, -0.335, 0.204, -0.272, -5.000, 0.241, 0.580, 0.161, -0.216, -0.168, 0.182, 0.309, 0.394, 0.622, 1.038, 0.606, -5.000, -0.294, 0.559, -0.081, 0.063, 0.649, 0.663, 0.171, 0.030, 0.543, 0.492, 0.353, 0.400, 0.673, 1.048, 0.618, 0.727, 0.169, 1.058, 0.263, -0.139, 0.375, 0.325, -0.248, 0.078, 0.854, 0.663, 0.746, 0.559, -0.017, 0.580, 0.046, 0.190, -0.019, 0.310, -0.259, -0.169, 0.012, -0.062, 0.068, 0.122, 0.579, 0.296, 0.203, 0.237, 0.022, -0.266, -0.753, -5.000, -1.166, -1.469, -1.896, -5.000, -0.310, -0.344, -0.928, -0.506, -0.483, -0.582, -0.326, -0.238, 0.618, 0.639, 0.335, -5.000, -0.765, -0.078, -0.584, 0.075, 0.398, 0.142, -0.152, -0.215, 0.552, 0.109, -0.004, 0.035, 0.314, 0.248, -0.116, 0.506, -0.220, -0.091, -0.580, -0.774, 0.330, -0.085, -0.182, -0.216, 0.466, 0.168, 0.161, 0.156, -0.208, -0.370, -1.240, -0.393, -0.346, -0.200, -0.952, -0.430, -0.316, -0.887, -1.195, -0.738, -0.108, -0.653, -0.563, -0.128, 0.233, 0.205, -0.756, -5.000, -0.703, -0.298, -1.112, -5.000, 0.081, 0.113, -0.368, -0.366, -0.146, -0.542, -0.477, -0.227, 0.402, 0.330, 0.470, -5.000, -0.644, -0.005, -0.893, -0.290, 0.539, 0.304, -0.072, -0.000, 0.668, 0.496, 0.253, 0.389, 0.455, 0.425, -0.436, 0.398, -0.180, -0.146, -0.884, -0.926, 0.193, -0.146, -0.519, -0.534, 0.408, 0.095, -0.088, 0.021, -0.078, -0.338, -1.046, -0.019, -0.316, -0.774, -1.550, -0.926, -0.874, -1.209, -1.668, -1.295, -0.029, -0.776, -0.937, -0.313, -0.481, 0.153, -0.451, -5.000, -0.996, -0.241, -1.054, -5.000, -0.198, 0.103, -0.183, -0.255, 0.025, -0.087, -0.238, -0.280, 0.212, 0.497, 0.042, -5.000, -0.504, 0.148, -0.467, -0.069, 0.228, 0.380, -0.112, -0.141, 0.394, 0.307, 0.303, 0.195, 0.495, 0.670, 0.200, 0.504, 0.108, 0.830, 0.001, -0.207, 0.240, 0.594, 0.027, -0.087, 0.481, 0.464, 0.726, 0.209, -0.141, -0.119, -0.430, 0.045, -0.180, -0.417, -0.842, -0.464, -0.537, -0.471, -0.964, -0.448, -0.004, -0.507, -0.693, -0.245 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_28(struct _training *tptr) {
  struct _training tinf = {
    0.453, 11, 4.350, { 1.533, 0.296, 1.170 }, { 0.389, -0.661, -0.124 }, 1, 
    { -1.092, -3.455, -1.131, -1.388, -0.619, -0.880, -0.171, -0.067, 1.571, -4.000, 0.161, -4.000, 0.247, 0.413, 2.315, -0.410, 1.132, 0.851, 1.918, 2.079, 0.338, -0.369, 0.228, 0.170, 1.729, 0.225, 1.104, 2.300 }, 
    {{ 0.183, -0.271, 0.157, -0.157},{ 0.107, -0.071, -0.075, 0.004},{ 0.113, 0.175, -0.388, -0.012},{ 0.201, 0.068, -0.496, 0.042},{ 0.166, 0.085, -0.565, 0.099},{ 0.082, -0.055, -0.415, 0.216},{ 0.206, -0.145, -0.421, 0.155},{ 0.280, -0.136, -0.432, 0.071},{ 0.238, -0.166, -0.393, 0.121},{ 0.208, -0.224, -0.341, 0.160},{ 0.320, -0.183, -0.421, 0.045},{ 0.201, -0.075, -0.351, 0.080},{ 0.250, -0.136, -0.356, 0.068},{ 0.285, -0.032, -0.427, -0.015},{ 0.189, -0.242, -0.295, 0.168},{ 0.294, -0.305, -0.361, 0.121},{ 0.204, 0.023, -0.341, -0.005},{ 0.208, -0.140, -0.377, 0.129},{ 0.126, -0.067, -0.341, 0.147},{ 0.173, -0.059, -0.285, 0.063},{ 0.048, -0.048, -0.305, 0.189},{ 0.196, -0.136, -0.393, 0.147},{ 0.213, -0.119, -0.183, -0.005},{ 0.118, -0.021, -0.356, 0.132},{ 0.235, -0.238, -0.351, 0.145},{ 0.238, -0.261, -0.242, 0.096},{ 0.218, -0.219, -0.330, 0.142},{ 0.201, -0.320, -0.361, 0.228},{ 0.171, -0.153, -0.393, 0.183},{ 0.189, -0.247, -0.438, 0.238},{ 0.166, -0.183, -0.449, 0.230},{ 0.213, -0.107, -0.393, 0.110} }, 
    {{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}} }, 
    0.000, { 0.680, 0.872, 0.244, -5.000, 0.305, 0.091, -1.400, -5.000, 0.112, 0.619, 0.216, 0.339, 0.279, 0.583, -0.079, -0.008, 1.003, 1.318, 0.534, -5.000, 0.777, 0.609, -0.525, -0.566, 0.558, 0.784, 0.336, 0.263, -0.132, 0.843, 0.237, 0.223, -0.146, 0.294, -0.482, -0.132, 0.114, 0.405, -1.398, -1.208, -0.227, 0.358, -0.627, -0.354, 0.146, 0.616, 0.015, 0.373, 0.199, 0.947, 0.055, 0.056, 0.551, 1.066, -0.089, -0.791, 0.167, 1.131, 0.278, 0.288, 0.280, 1.010, 0.499, 0.062, 0.436, 0.322, -0.707, -5.000, 0.145, -0.266, -1.850, -5.000, 0.156, 0.192, 0.126, 0.231, 0.421, 0.086, 0.280, -0.177, 0.723, 1.013, 0.025, -5.000, 0.914, 0.680, -0.200, -0.419, 0.649, 0.677, 0.578, 0.298, -0.214, 0.698, 0.325, -0.088, 0.317, 0.829, -0.079, 0.253, 0.364, 0.682, -0.314, -0.844, -0.158, 0.531, 0.199, 0.042, 0.284, 0.623, 0.100, 0.583, 0.452, 1.086, 0.178, 0.207, 0.488, 0.726, 0.218, -0.861, 0.063, 0.761, 0.302, -0.307, 0.379, 0.906, 0.678, 0.347, -0.135, -0.177, -0.835, -5.000, -0.568, -0.313, -1.651, -5.000, -0.310, 0.300, -0.560, -0.387, -0.381, -0.806, -0.803, -0.850, 0.089, 0.536, -0.349, -5.000, -0.360, -0.135, -1.431, -0.963, 0.238, 0.343, -0.558, -0.963, -0.690, -0.045, -0.441, -1.047, -1.108, -0.333, -1.131, -1.008, -1.128, -0.323, -1.468, -1.924, -0.605, -0.591, -0.500, -1.425, -0.939, -0.182, -0.486, -0.592, -0.658, 0.243, -1.453, -0.942, -0.840, -0.142, -1.524, -1.928, -0.632, -0.317, -1.485, -1.571, -0.838, -0.442, -0.702, -0.982, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.266, 0.413, -0.390, -5.000, 0.039, 0.139, -1.931, -5.000, 0.142, 0.703, -0.119, -0.330, 0.429, 0.519, 0.352, 0.085, 0.528, 0.893, 0.029, -5.000, 0.258, 0.200, -0.842, -0.584, -0.434, 0.147, -0.402, -0.645, -0.264, 0.550, 0.071, -0.298, -0.016, 0.111, -0.492, 0.104, -0.126, 0.229, -0.443, -0.555, -0.533, 0.287, -0.424, -0.753, 0.249, 0.619, 0.456, 0.591, -0.336, 0.650, -0.411, 0.094, -0.153, 0.780, -0.267, -0.928, -0.203, 0.942, 0.021, -0.117, 0.447, 1.074, 0.678, 0.408, 0.545, 0.238, -0.922, -5.000, -0.282, -0.273, -1.820, -5.000, 0.028, 0.014, -0.796, -0.647, 0.476, 0.094, -0.032, -0.414, 0.343, 0.705, -0.269, -5.000, 0.156, 0.377, -0.776, -0.224, -0.103, -0.148, 0.029, -0.212, -0.454, 0.545, 0.104, -0.242, 0.044, 0.295, -0.423, 0.509, 0.220, 0.642, -0.668, 0.011, -0.405, 0.430, -0.132, -0.374, 0.310, 0.620, 0.556, 0.997, 0.281, 0.925, 0.074, 0.246, 0.029, 0.555, -0.240, -0.681, -0.472, 0.571, -0.237, -0.635, 0.445, 0.922, 0.789, 0.463, -0.555, -0.353, -1.610, -5.000, -1.035, -0.979, -2.279, -5.000, -1.447, -0.568, -1.413, -1.522, -1.362, -1.603, -1.334, -1.963, -1.232, -1.120, -2.691, -5.000, -1.441, -1.397, -2.061, -3.264, -1.338, -0.932, -1.212, -2.206, -1.145, -0.598, -1.070, -1.251, -1.524, -1.492, -1.847, -1.974, -1.679, -1.881, -1.921, -2.012, -1.264, -1.311, -1.432, -1.268, -1.354, -0.616, -1.604, -1.116, -1.541, -1.340, -1.718, -2.076, -1.986, -1.268, -1.910, -2.245, -2.077, -1.838, -1.895, -2.043, -1.137, -1.222, -1.672, -1.503, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.579, 0.634, -0.125, -5.000, 0.133, 0.122, -1.694, -5.000, 0.381, 0.543, 0.133, -0.120, 0.556, 0.914, 0.574, 0.363, 0.752, 0.843, 0.328, -5.000, 0.371, 0.142, -1.104, -0.312, 0.000, 0.279, -0.069, -0.252, 0.051, 0.702, 0.287, -0.101, 0.168, 0.551, 0.171, 0.601, -0.252, 0.578, -0.484, -0.827, -0.052, 0.448, 0.003, -0.288, 0.384, 0.829, 0.508, 0.712, -0.271, 0.452, -0.480, -0.325, -0.637, 0.421, -0.302, -0.864, -0.214, 0.262, -0.241, -0.595, 0.098, 0.657, 0.332, 0.052, 0.755, 0.732, -0.437, -5.000, -0.012, 0.277, -1.623, -5.000, 0.478, 0.883, -0.024, 0.145, 1.080, 0.862, 0.713, 0.529, 0.752, 1.098, 0.333, -5.000, 0.307, 0.472, -0.824, -0.207, -0.266, 0.493, -0.259, -0.132, 0.109, 1.056, 0.707, 0.022, 0.681, 0.978, 0.151, 0.787, 0.064, 0.566, -0.334, 0.077, -0.087, 0.652, -0.434, -0.475, 0.705, 1.079, 0.856, 1.082, 0.396, 0.980, 0.373, 0.559, -0.018, 0.995, -0.046, -0.591, 0.070, 0.725, -0.198, -0.195, 0.767, 1.072, 0.942, 0.597, 0.278, 0.335, -0.318, -5.000, -0.330, 0.469, -1.508, -5.000, 0.010, 0.467, 0.031, -0.427, 0.675, 0.797, 0.472, -0.243, 0.241, 0.712, -0.420, -5.000, 0.037, 0.231, -1.124, -1.074, -0.219, 0.322, 0.025, -0.470, -0.096, 0.330, 0.007, -0.534, 0.149, 0.619, 0.016, 0.057, -0.370, 0.161, -0.939, -0.470, -0.394, -0.031, -0.099, -0.678, -0.007, 0.314, 0.129, 0.392, 0.150, 0.718, -0.281, -0.150, -0.719, 0.457, -0.220, -0.494, -0.786, -0.329, -0.675, -1.277, -0.033, 0.306, -0.111, -0.514, 0.428, 0.701, -0.279, -5.000, -0.580, -0.421, -1.873, -5.000, -0.165, 0.620, 0.013, -0.227, 0.168, 0.473, -0.433, -0.013, 0.247, 0.782, -0.109, -5.000, -0.547, -0.636, -1.230, -0.764, -0.687, 0.163, -0.487, -0.606, -0.290, 0.416, -0.230, -0.355, -0.311, 0.500, -0.505, -0.171, -0.972, 0.309, -1.207, -1.676, -0.629, 0.113, -0.306, -0.990, 0.152, 0.745, 0.499, -0.242, -0.589, 0.234, -1.073, -0.880, -1.232, -0.191, -0.873, -1.761, -1.003, -0.176, -0.962, -1.238, -0.304, 0.447, 0.046, -0.820, 1.135, 0.912, 0.135, -5.000, 0.705, 0.509, -1.150, -5.000, 0.603, 0.923, 0.441, 0.322, 0.906, 0.993, 0.618, 0.571, 1.268, 1.223, 0.563, -5.000, 0.968, 0.568, -0.562, -0.171, 0.604, 0.549, 0.281, 0.133, 0.605, 0.995, 0.493, 0.218, 0.790, 1.002, 0.181, 0.762, 0.504, 0.707, -0.554, -0.147, 0.347, 0.801, -0.049, 0.192, 0.616, 0.956, 0.507, 1.061, 0.445, 0.925, -0.265, 0.084, 0.100, 0.547, -0.642, -0.885, 0.070, 0.589, -0.151, -0.062, 0.255, 0.904, 0.302, 0.357, 0.861, 0.875, -0.577, -5.000, 0.383, 0.498, -1.503, -5.000, 0.447, 0.673, -0.200, 0.005, 0.662, 0.724, 0.567, 0.332, 0.746, 1.092, -0.154, -5.000, 0.452, 0.498, -1.094, -0.415, -0.106, 0.336, -0.100, -0.259, -0.329, 0.654, 0.043, -0.210, 0.418, 0.757, -0.384, 0.477, 0.029, 0.750, -0.701, -0.373, -0.168, 0.692, -0.299, -0.127, 0.089, 1.060, 0.380, 0.935, 0.504, 1.134, -0.016, 0.274, 0.301, 0.944, -0.078, -0.465, 0.131, 0.937, -0.175, -0.188, 0.678, 1.025, 0.539, 0.622, 1.052, 1.167, -0.284, -5.000, 0.342, 0.570, -1.750, -5.000, 0.173, 0.794, -0.286, 0.066, 0.523, 0.668, 0.377, 0.362, 0.971, 1.211, -0.467, -5.000, 0.373, 0.365, -1.512, -0.660, -0.072, 0.561, -0.309, -0.332, 0.045, 0.591, -0.003, 0.034, 0.457, 1.102, -0.286, 0.361, -0.002, 0.345, -1.094, -0.512, -0.206, 0.415, -0.401, -0.192, 0.401, 0.635, 0.436, 0.608, 0.288, 1.007, -0.803, -0.046, -0.254, -0.233, -0.682, -1.122, -0.664, 0.043, -0.882, -0.771, 0.122, 0.578, -0.034, 0.154, 0.731, 1.238, 0.330, -5.000, 0.186, 0.867, -1.170, -5.000, 0.071, 0.913, 0.380, -0.279, 0.223, 0.556, -0.191, -0.048, 0.697, 1.287, 0.255, -5.000, 0.264, 0.601, -1.251, -1.101, -0.106, 0.616, -0.069, -0.608, -0.063, 0.631, -0.271, -0.130, 0.196, 0.895, -0.268, 0.051, -0.446, 0.278, -1.137, -1.542, -0.674, 0.236, -0.430, -1.163, -0.156, 0.540, 0.080, -0.497, 0.304, 0.835, -0.211, -0.227, -0.528, 0.289, -0.664, -1.414, -0.571, 0.366, -0.711, -1.132, -0.363, 0.467, -0.284, -0.543, 0.500, 0.710, -0.324, -5.000, 0.245, 0.229, -0.793, -5.000, 0.730, 0.992, 0.683, 0.202, 0.887, 0.842, 0.585, 0.683, 1.154, 1.174, 0.626, -5.000, 0.899, 0.455, -0.142, 0.081, 0.276, 0.695, 0.317, 0.021, 0.516, 0.880, 0.695, 0.592, 0.564, 0.670, 0.242, 0.649, 0.580, 0.704, -0.478, -0.806, 0.465, 0.778, 0.489, 0.011, 0.566, 0.813, 0.340, 0.657, 0.656, 0.870, 0.262, 0.495, 0.788, 1.127, 0.118, -0.773, 0.515, 1.043, 0.567, 0.130, 0.642, 1.001, 0.603, 0.383, 0.731, 0.510, -0.362, -5.000, 0.811, 0.336, -0.915, -5.000, 0.898, 0.711, 0.782, 0.303, 1.197, 0.852, 0.982, 0.702, 1.143, 1.166, 0.531, -5.000, 1.200, 0.712, 0.039, 0.395, 0.712, 0.742, 0.925, 0.454, 0.775, 0.938, 0.750, 0.433, 1.150, 1.087, 0.426, 1.219, 1.132, 1.065, 0.359, 0.136, 0.757, 1.025, 0.788, 0.603, 1.114, 1.027, 0.857, 1.161, 0.846, 1.150, 0.380, 0.833, 0.948, 0.982, 0.576, -0.590, 0.564, 0.917, 0.683, 0.210, 1.048, 1.153, 1.002, 0.794, -0.022, -0.057, -0.827, -5.000, 0.076, 0.322, -1.401, -5.000, 0.454, 0.545, 0.108, -0.316, 0.480, -0.048, 0.020, -0.516, 0.408, 0.559, -0.132, -5.000, 0.202, 0.076, -1.247, -0.359, 0.264, 0.653, 0.544, -0.020, 0.116, 0.466, -0.060, -0.702, -0.270, 0.044, -0.755, -0.067, -0.308, -0.200, -1.007, -1.045, -0.437, 0.143, -0.079, -0.565, -0.332, 0.171, -0.199, 0.197, -0.537, -0.399, -1.055, -0.679, -0.030, -0.115, -0.432, -1.957, -0.686, -0.450, -0.796, -1.226, -0.307, -0.159, -0.526, -1.186, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.332, 0.178, -0.523, -5.000, 0.242, 0.190, -1.495, -5.000, 0.494, 0.649, 0.179, 0.127, 0.846, 0.874, 0.714, 0.557, 0.893, 0.873, 0.199, -5.000, 0.545, 0.223, -0.504, 0.028, -0.012, 0.405, 0.044, -0.374, 0.521, 0.789, 0.479, 0.156, 0.367, 0.531, 0.093, 0.802, 0.526, 0.748, 0.131, 0.036, 0.241, 0.831, 0.174, 0.084, 0.683, 0.997, 0.562, 0.743, 0.147, 0.640, -0.085, 0.537, 0.265, 0.959, -0.278, -0.520, 0.210, 0.952, 0.173, -0.000, 0.764, 1.060, 0.574, 0.289, 0.462, -0.194, -1.193, -5.000, -0.032, -0.387, -1.177, -5.000, 0.192, 0.184, -0.253, -0.486, 0.852, 0.435, 0.485, -0.268, 0.729, 0.560, -0.151, -5.000, 0.404, 0.015, -0.430, -0.301, 0.021, -0.064, -0.384, -0.627, 0.480, 0.560, 0.248, -0.198, 0.522, 0.612, -0.081, 0.996, 0.865, 0.671, -0.155, 0.388, 0.470, 0.641, 0.296, -0.013, 0.823, 0.585, 0.506, 0.947, 0.111, 0.387, -0.248, 0.145, 0.221, 0.601, -0.236, -0.560, -0.081, 0.455, -0.289, -0.404, 0.759, 0.684, 0.633, 0.563, -0.278, -0.689, -1.387, -5.000, -0.657, -0.430, -0.901, -5.000, -0.498, -0.483, -0.762, -1.104, -0.421, -0.593, -0.357, -0.446, -0.372, -0.100, -1.234, -5.000, -0.712, -0.563, -1.194, -1.292, -0.589, -0.032, -0.591, -1.132, -0.390, 0.036, -0.431, -1.088, -1.080, -0.648, -1.827, -0.928, -1.186, -0.659, -1.295, -1.227, -1.211, -0.533, -0.757, -1.254, -1.004, -0.824, -0.852, -0.604, -1.278, -1.310, -2.078, -1.890, -1.186, -0.907, -2.510, -1.743, -1.883, -1.131, -1.713, -1.762, -0.889, -0.685, -2.516, -1.407, 0.526, 0.398, -0.845, -5.000, 0.105, 0.229, -1.598, -5.000, -0.044, 0.366, -0.190, -0.167, 0.011, 0.047, 0.006, -0.253, 0.215, 0.682, -0.815, -5.000, -0.143, -0.124, -1.001, -0.423, -0.984, -0.234, -0.388, -0.840, -0.207, 0.134, -0.346, -0.770, 0.082, 0.675, -0.663, -0.045, -0.827, -0.162, -1.414, -1.092, -1.383, -0.482, -0.753, -1.127, -0.414, 0.073, -0.028, 0.407, -0.655, 0.017, -1.060, -0.977, -1.021, -0.744, -2.526, -1.510, -1.218, -0.678, -1.336, -1.060, -0.744, -0.217, -0.850, -0.725, -0.219, -0.095, -1.060, -5.000, -0.114, 0.090, -0.558, -5.000, 0.251, 0.403, 0.039, -0.422, 0.467, 0.556, 0.203, 0.109, 0.639, 0.558, 0.217, -5.000, 0.274, 0.004, -0.851, -0.458, -0.157, 0.113, -0.370, -0.595, 0.395, 0.630, 0.069, -0.197, 0.421, 0.500, 0.182, 0.602, -0.015, 0.550, -1.172, -0.857, -0.064, 0.254, 0.063, -0.466, 0.313, 0.520, 0.348, 0.417, -0.458, -0.071, -1.116, -0.438, -1.023, -0.118, -1.456, -1.030, -0.411, -0.286, -0.620, -1.231, -0.414, 0.336, -0.219, -0.429, 0.432, 0.277, -1.124, -5.000, -0.168, -0.208, -1.257, -5.000, 0.109, 0.530, -0.300, -0.065, 0.980, 0.630, 0.584, 0.326, 0.802, 0.878, -0.560, -5.000, 0.462, 0.286, -1.150, -0.068, -0.320, -0.183, -0.671, -0.455, 0.272, 0.645, 0.153, 0.018, 0.794, 0.838, 0.236, 0.951, 0.414, 0.663, -0.182, -0.558, 0.258, 0.616, 0.049, -0.311, 1.026, 0.728, 0.723, 0.963, 0.244, 0.636, 0.200, 0.241, -0.165, 0.504, -1.172, -0.736, -0.172, 0.616, -0.252, -0.923, 0.470, 0.797, 0.671, 0.649, 0.124, 0.159, -0.666, -5.000, -0.112, 0.311, -1.771, -5.000, 0.136, 0.248, -0.117, -0.530, 0.729, 0.734, 0.275, -0.049, 0.475, 0.421, -0.519, -5.000, 0.243, -0.065, -0.565, -0.470, 0.190, -0.336, 0.174, -0.544, 0.154, 0.432, 0.140, -0.382, 0.407, 0.762, 0.196, 0.110, -0.280, 0.074, -0.212, -0.193, 0.076, -0.044, 0.031, -0.439, 0.109, 0.474, 0.107, -0.012, 0.065, 0.373, -0.462, -0.275, -0.707, 0.118, -0.851, -0.652, -0.547, -0.787, -0.428, -1.457, -0.111, -0.073, -0.187, -0.813, 0.037, 0.109, -0.525, -5.000, -0.775, -0.191, -2.287, -5.000, -0.413, 0.412, -0.263, -0.591, 0.147, 0.033, -0.692, -0.280, 0.021, 0.748, -0.446, -5.000, -0.535, -0.427, -0.518, -0.660, -0.871, -0.067, -0.431, -0.935, -0.430, 0.199, -0.507, -0.311, -0.390, 0.356, -0.574, 0.022, -0.906, 0.227, -0.495, -1.318, -0.719, -0.178, -0.409, -1.088, 0.045, 0.528, 0.117, -0.324, -1.084, -0.511, -1.163, -0.773, -1.329, -0.455, -0.675, -2.031, -1.487, -0.283, -1.352, -1.270, -0.434, 0.116, -1.056, -1.567, 0.955, 0.854, 0.088, -5.000, 0.256, 0.316, -1.782, -5.000, 0.227, 0.759, -0.008, -0.017, 0.577, 0.672, 0.316, 0.369, 0.834, 0.767, 0.086, -5.000, 0.219, -0.089, -0.791, -0.448, -0.080, -0.056, -0.514, -0.465, 0.138, 0.206, -0.063, -0.133, 0.686, 0.721, 0.087, 0.623, 0.252, 0.393, -0.730, -0.670, -0.112, 0.428, -0.279, -0.258, 0.305, 0.772, 0.286, 0.629, -0.078, 0.441, -0.460, -0.278, -0.388, 0.088, -1.010, -1.150, -0.611, -0.041, -0.657, -0.831, -0.290, 0.472, -0.168, -0.099, 0.842, 0.635, -0.349, -5.000, 0.633, 0.425, -1.098, -5.000, 0.547, 0.782, 0.199, 0.079, 0.943, 0.615, 0.708, 0.425, 0.952, 1.052, 0.148, -5.000, 0.647, 0.401, -0.959, -0.159, 0.249, 0.396, 0.032, -0.178, 0.308, 0.777, 0.236, -0.032, 1.030, 1.165, 0.142, 0.991, 0.513, 0.948, -0.117, -0.195, 0.557, 0.919, 0.283, 0.161, 0.935, 1.129, 0.687, 0.934, 0.578, 1.048, 0.292, 0.666, 0.437, 0.820, -0.034, -0.677, 0.516, 0.979, 0.175, -0.125, 0.762, 1.075, 0.614, 0.329, 0.925, 0.429, -0.767, -5.000, 0.489, 0.187, -1.139, -5.000, 0.243, 0.812, -0.173, -0.127, 0.726, 0.283, 0.596, 0.341, 0.937, 1.162, -0.477, -5.000, 0.523, 0.332, -1.394, -0.442, 0.167, 0.619, -0.035, -0.083, 0.252, 0.520, -0.107, -0.112, 0.487, 0.857, -0.338, 0.315, -0.064, -0.021, -1.436, -0.875, -0.176, 0.153, -0.244, -0.532, 0.270, 0.336, 0.008, 0.411, 0.226, 0.261, -0.814, -0.345, -0.244, -0.091, -1.071, -0.932, -0.398, -0.203, -1.069, -0.741, -0.117, -0.407, -0.465, -0.583, 0.417, 0.259, -0.226, -5.000, 0.179, 0.354, -0.960, -5.000, -0.178, 0.538, 0.260, -0.725, 0.229, 0.132, -0.296, -0.225, 0.488, 1.010, 0.138, -5.000, 0.196, 0.267, -1.210, -0.788, -0.152, 0.528, 0.168, -0.945, -0.125, 0.336, -0.508, -0.709, -0.100, 0.649, -0.439, -0.076, -0.567, -0.063, -1.124, -1.858, -0.895, -0.045, -0.668, -1.334, -0.718, 0.145, -0.279, -0.489, -0.179, 0.288, -1.466, -0.661, -0.936, -0.213, -1.512, -1.860, -0.789, -0.006, -0.685, -1.357, -0.554, -0.131, -0.324, -0.776, 0.643, 0.609, 0.283, -5.000, 0.496, 0.318, -0.982, -5.000, 0.564, 0.690, 0.574, 0.342, 0.471, 0.687, 0.371, 0.422, 0.809, 0.921, 0.604, -5.000, 0.463, 0.025, -0.073, -0.143, -0.136, 0.188, -0.079, -0.124, 0.106, 0.746, 0.143, 0.315, 0.079, 0.220, -0.311, 0.044, 0.176, 0.454, -0.622, -0.812, -0.192, 0.212, 0.269, -0.407, 0.032, 0.555, -0.018, 0.137, 0.112, 0.507, -0.146, -0.241, 0.210, 0.595, -0.593, -1.206, 0.072, 0.404, -0.103, -0.661, -0.141, 0.487, -0.152, -0.518, 0.803, 0.455, -0.274, -5.000, 0.680, 0.606, -0.919, -5.000, 0.893, 0.760, 0.713, 0.444, 1.109, 0.703, 0.954, 0.572, 0.784, 1.028, 0.231, -5.000, 0.821, 0.679, -0.180, -0.084, 0.656, 0.700, 0.767, 0.405, 0.146, 0.800, 0.447, -0.102, 0.532, 0.844, 0.245, 0.678, 0.752, 1.025, 0.333, -0.006, 0.294, 0.820, 0.851, 0.364, 0.613, 0.851, 0.671, 0.999, 0.353, 0.878, 0.284, 0.278, 0.533, 0.584, 0.268, -0.680, 0.324, 0.539, 0.170, 0.125, 0.687, 0.946, 0.549, 0.419, 0.135, 0.203, -0.917, -5.000, 0.149, 0.289, -1.515, -5.000, 0.028, 0.356, -0.465, -0.239, 0.020, -0.062, -0.170, -0.702, 0.239, 0.633, -0.609, -5.000, -0.210, 0.186, -1.094, -0.781, -0.230, 0.683, -0.087, -0.511, -0.207, 0.227, -0.608, -0.713, -0.610, 0.181, -0.630, -0.528, -0.403, -0.213, -1.071, -1.583, -0.677, -0.063, -0.314, -0.899, -0.835, -0.063, -0.361, -0.397, -0.637, -0.040, -0.753, -1.159, -0.257, 0.001, -0.858, -1.338, -0.999, -0.379, -1.232, -1.350, -0.438, -0.462, -0.715, -1.108, 0.757, 0.585, -0.326, -5.000, 0.424, 0.341, -0.939, -5.000, 0.309, 0.830, 0.241, 0.108, 0.370, 0.496, 0.167, 0.156, 0.685, 1.018, 0.331, -5.000, 0.384, 0.348, -0.547, -0.095, -0.064, 0.698, 0.049, -0.148, 0.226, 0.561, 0.041, -0.168, 0.541, 0.999, -0.206, 0.380, 0.167, 0.607, -0.583, -0.821, 0.169, 0.506, 0.377, -0.287, 0.458, 0.895, 0.685, 0.726, 0.148, 0.594, -0.583, -0.264, -0.111, 0.205, -0.353, -1.288, -0.202, 0.200, -0.748, -0.854, 0.020, 0.361, -0.130, -0.640, 0.449, 0.011, -0.299, -5.000, 0.289, 0.224, -1.705, -5.000, 0.386, 0.472, 0.269, -0.089, 0.552, 0.611, 0.458, 0.402, 0.502, 0.269, -0.126, -5.000, 0.250, -0.131, -0.480, -0.023, -0.070, -0.025, -0.273, -0.399, 0.415, 0.574, -0.080, -0.163, -0.279, 0.368, -0.669, -0.146, -0.228, 0.006, -0.462, -0.771, -0.490, 0.194, -0.392, -0.592, -0.086, 0.377, -0.167, 0.140, -0.543, -0.297, -0.726, -0.517, -0.163, 0.179, -0.640, -0.953, -0.707, -0.158, -0.763, -0.945, -0.133, 0.258, -0.291, -0.450, 0.820, 0.302, -0.366, -5.000, 0.018, 0.008, -1.327, -5.000, 0.622, 0.525, 0.490, 0.223, 0.862, 0.639, 0.751, 0.368, 0.653, 0.498, 0.120, -5.000, 0.247, 0.267, -0.278, -0.068, 0.169, 0.355, 0.237, -0.165, 0.484, 0.647, 0.533, 0.220, 0.490, 0.774, 0.142, 0.707, 0.598, 0.576, 0.010, 0.286, 0.254, 0.687, 0.184, 0.037, 0.513, 0.718, 0.442, 0.929, 0.103, 0.674, -0.106, 0.166, 0.080, 0.321, -0.130, -0.597, -0.281, 0.308, -0.262, -0.812, 0.566, 0.730, 0.431, 0.414, -0.073, -0.363, -1.395, -5.000, -0.583, -0.440, -1.802, -5.000, -0.585, -0.297, -0.253, -0.785, -0.491, -0.675, -0.189, -0.767, -0.453, -0.143, -1.079, -5.000, -0.578, -0.318, -1.588, -0.799, -0.462, -0.203, -0.415, -1.402, -0.445, -0.106, -0.158, -0.411, -0.910, 0.113, -0.999, -0.970, -1.091, -0.553, -1.362, -0.993, -0.983, -0.251, -0.731, -0.645, -0.470, -0.131, -0.214, -0.121, -1.212, -0.951, -1.760, -1.666, -1.208, -0.951, -1.050, -2.342, -1.849, -1.571, -1.797, -2.109, -1.221, -1.085, -1.298, -1.220, 0.200, -0.147, -1.336, -5.000, -0.551, -0.428, -1.835, -5.000, -0.395, -0.051, -1.059, -0.764, -0.608, -0.650, -0.807, -0.623, 0.204, 0.185, -1.083, -5.000, -0.601, -0.652, -1.649, -1.598, -1.086, -0.944, -0.953, -1.610, -0.395, 0.062, -0.852, -2.052, -0.063, -0.074, -0.822, -0.704, -2.016, -1.125, -1.643, -1.819, -1.517, -0.821, -1.151, -1.394, -0.548, -0.173, -0.545, -0.027, -0.685, -0.684, -1.270, -1.212, -1.217, -0.822, -2.264, -1.899, -1.486, -1.595, -1.503, -2.069, -0.782, -0.652, -0.816, -0.907, 0.489, 0.226, -0.248, -5.000, 0.138, -0.035, -0.954, -5.000, 0.124, 0.187, 0.114, -0.411, 0.476, 0.499, 0.316, 0.248, 0.550, 0.361, -0.117, -5.000, 0.101, -0.340, -1.086, -0.491, -0.170, 0.010, -0.376, -0.708, 0.273, 0.393, 0.029, -0.199, -0.131, 0.192, -0.556, -0.174, -0.517, 0.145, -1.012, -1.372, -0.468, -0.037, -0.832, -0.918, -0.238, 0.335, -0.114, 0.013, -0.694, -0.059, -1.400, -0.953, -1.068, -0.266, -1.594, -1.719, -1.063, -0.260, -0.947, -1.513, -0.480, 0.046, -0.559, -0.741, 0.589, 0.500, -0.366, -5.000, 0.244, 0.085, -1.290, -5.000, 0.415, 0.861, 0.009, 0.030, 0.936, 0.530, 0.806, 0.429, 0.779, 0.810, -0.075, -5.000, 0.275, 0.295, -0.422, -0.188, 0.193, 0.529, -0.019, -0.377, 0.407, 0.797, 0.396, 0.132, 0.144, 0.595, -0.140, 0.462, 0.046, 0.454, -0.456, -0.484, -0.612, 0.077, -0.278, -0.669, 0.210, 0.246, 0.180, 0.595, 0.150, 0.544, -0.175, 0.104, -0.106, 0.524, -0.186, -0.725, -0.943, 0.360, -0.706, -0.693, 0.299, 0.655, 0.396, 0.165, 0.275, 0.171, -0.801, -5.000, -0.177, 0.321, -1.310, -5.000, 0.163, -0.118, -0.166, -0.764, 0.359, 0.113, 0.069, -0.636, 0.241, 0.402, -0.856, -5.000, 0.029, -0.018, -0.815, -0.433, -0.295, 0.062, 0.101, -0.639, 0.036, 0.062, -0.139, -0.744, -0.044, 0.502, -0.458, -0.402, -0.555, 0.177, -0.434, -0.620, -0.512, -0.009, -0.303, -0.533, -0.290, 0.101, -0.247, -0.194, -0.307, 0.407, -0.816, -0.757, -0.752, 0.382, -0.548, -0.709, -0.698, -0.625, -0.756, -1.338, -0.623, -0.117, -0.754, -0.838, 0.214, 0.182, -0.641, -5.000, -0.514, -0.709, -2.019, -5.000, -0.610, 0.271, -0.573, -0.384, -0.224, -0.214, -0.437, -0.138, 0.131, 0.456, -0.565, -5.000, -0.583, -0.549, -2.024, -0.462, -0.734, -0.302, -1.072, -1.059, -0.474, 0.264, -1.370, -0.571, -0.760, 0.176, -0.806, -0.529, -1.027, 0.013, -1.149, -1.313, -0.947, -0.570, -0.505, -0.943, -0.376, -0.025, -0.184, -0.440, -0.868, -0.339, -1.355, -0.992, -0.777, -0.392, -1.218, -1.745, -1.568, -1.103, -1.372, -1.623, -0.751, -0.321, -0.712, -1.042, 0.880, 0.409, -0.405, -5.000, 0.578, -0.015, -1.204, -5.000, 0.292, 0.240, 0.073, -0.045, 0.711, 0.537, 0.274, 0.505, 1.031, 0.952, 0.210, -5.000, 0.741, 0.160, -0.446, -0.404, 0.401, 0.287, -0.081, -0.065, 0.555, 0.828, 0.224, 0.526, 0.563, 0.574, -0.263, 0.060, 0.118, 0.327, -0.701, -1.331, -0.237, 0.225, -0.328, -0.603, 0.119, 0.430, -0.143, 0.236, 0.313, 0.448, -0.637, -0.387, -0.156, -0.065, -0.749, -1.486, -0.206, -0.041, -0.556, -0.761, -0.240, 0.310, -0.189, -0.431, 0.745, 0.505, -0.310, -5.000, 0.588, 0.409, -1.659, -5.000, 0.609, 0.722, 0.182, 0.217, 0.915, 0.408, 0.807, 0.667, 1.054, 0.991, 0.195, -5.000, 0.709, 0.465, -0.543, 0.017, 0.541, 0.618, 0.495, -0.211, 0.448, 0.930, 0.635, 0.483, 0.559, 0.899, -0.059, 0.604, 0.449, 0.578, -0.177, -0.680, -0.112, 0.730, 0.059, -0.028, 0.518, 0.550, 0.398, 0.701, 0.751, 1.018, 0.090, 0.226, 0.426, 0.743, 0.028, -0.848, 0.040, 0.711, 0.119, -0.341, 0.423, 0.922, 0.388, 0.294, 0.717, 0.423, -0.812, -5.000, 0.500, 0.520, -1.295, -5.000, 0.481, 0.629, -0.293, 0.040, 0.594, 0.361, 0.622, 0.455, 0.880, 0.909, -0.384, -5.000, 0.831, 0.402, -1.078, -0.237, 0.500, 0.746, 0.156, -0.005, 0.450, 0.723, 0.430, 0.301, 0.177, 0.622, -0.469, -0.097, -0.052, 0.121, -0.715, -1.153, -0.121, 0.367, -0.006, -0.496, -0.076, 0.360, -0.190, -0.041, 0.068, 0.491, -0.433, -0.581, -0.352, -0.035, -0.988, -1.665, -0.494, -0.068, -0.741, -0.999, -0.107, 0.117, -0.435, -0.835, 1.025, 0.814, 0.338, -5.000, 1.004, 0.716, -0.778, -5.000, 0.596, 0.854, 0.633, 0.573, 0.559, 0.612, 0.058, 0.766, 0.934, 1.220, 0.491, -5.000, 0.877, 0.376, -0.595, 0.091, 0.444, 0.569, 0.549, 0.089, 0.497, 0.803, -0.071, 0.481, 0.765, 1.081, 0.074, 0.334, 0.097, 0.623, -0.782, -1.113, 0.059, 0.186, -0.050, -0.327, 0.006, 0.632, 0.180, 0.367, 0.134, 0.767, -0.464, -0.271, -0.473, 0.197, -0.714, -1.210, -0.354, 0.153, -0.499, -0.489, -0.414, 0.260, -0.349, -0.740, -0.307, -0.334, -0.745, -5.000, -0.089, -0.648, -1.707, -5.000, 0.379, 0.169, 0.286, -0.297, 0.366, 0.345, 0.078, -0.123, 0.353, 0.416, 0.068, -5.000, 0.372, -0.042, -0.768, -0.267, -0.006, 0.052, -0.119, -0.213, 0.264, 0.553, 0.168, 0.096, 0.053, 0.310, -0.804, 0.357, 0.090, 0.162, -0.815, -0.791, 0.004, 0.312, -0.239, -0.308, 0.074, 0.341, -0.266, 0.319, -0.126, 0.048, -0.485, 0.214, -0.139, 0.468, -0.539, -0.699, -0.029, 0.343, 0.026, -0.215, -0.112, 0.287, -0.213, -0.203, 0.195, -0.163, -1.114, -5.000, 0.279, -0.073, -1.695, -5.000, 0.733, 0.653, 0.659, 0.206, 1.119, 0.625, 0.607, 0.166, 0.697, 0.725, -0.064, -5.000, 0.928, 0.588, -0.530, 0.276, 0.558, 0.896, 0.936, 0.150, 0.529, 0.878, 0.587, -0.049, 0.672, 0.738, -0.276, 1.157, 0.957, 0.964, -0.215, 0.142, 0.675, 0.871, 0.584, 0.524, 0.629, 0.951, 0.207, 1.036, 0.396, 0.723, 0.089, 0.767, 0.572, 0.734, -0.088, -0.425, 0.418, 0.756, 0.294, 0.186, 0.561, 0.779, 0.497, 0.529, -0.489, -0.285, -1.105, -5.000, -0.121, 0.051, -1.841, -5.000, 0.181, 0.299, -0.272, -0.523, 0.090, -0.145, -0.308, -0.719, -0.176, 0.351, -0.964, -5.000, -0.120, -0.084, -1.456, -0.641, -0.054, 0.333, -0.103, -0.963, -0.154, 0.133, -0.485, -1.084, -0.648, 0.037, -0.921, -0.197, -0.769, -0.418, -1.286, -1.912, -0.613, 0.153, -0.404, -0.620, -0.776, -0.191, -0.548, -0.033, -0.671, -0.544, -1.135, -0.631, -0.774, -0.442, -1.586, -1.469, -0.792, -0.453, -1.199, -1.237, -0.728, -0.640, -1.046, -1.369, 0.277, 0.158, -1.353, -5.000, -0.109, -0.033, -2.038, -5.000, 0.175, 0.537, -0.056, -0.107, 0.241, 0.135, -0.137, -0.159, 0.297, 0.574, -0.465, -5.000, 0.120, 0.100, -1.528, -0.465, -0.048, 0.246, -0.133, -0.414, 0.058, 0.444, -0.663, -0.258, 0.128, 0.513, -0.689, 0.548, -0.252, 0.090, -1.200, -0.846, -0.304, 0.098, -0.390, -0.262, -0.201, 0.148, -0.273, 0.275, -0.311, 0.080, -1.186, -0.500, -0.590, -0.209, -1.485, -1.603, -0.393, -0.326, -1.191, -0.957, -0.457, -0.370, -0.997, -0.746, -0.127, -0.508, -1.286, -5.000, -0.271, -0.487, -2.116, -5.000, 0.078, 0.156, -0.210, -0.282, 0.605, 0.525, 0.305, 0.041, 0.210, 0.165, -0.718, -5.000, 0.105, -0.334, -1.726, -0.123, -0.415, -0.285, -0.456, -0.622, 0.644, 0.333, 0.111, -0.085, -0.069, 0.334, -0.423, 0.542, 0.024, 0.298, -1.088, -0.400, -0.114, 0.136, -0.553, -0.426, 0.388, 0.632, -0.021, 0.554, -0.444, -0.216, -0.827, -0.024, -0.122, 0.250, -1.345, -0.713, -0.313, 0.060, -0.522, -0.452, -0.102, -0.024, -0.061, 0.031, 0.373, -0.225, -0.994, -5.000, -0.162, -0.116, -1.635, -5.000, 0.517, 0.217, 0.110, -0.041, 0.998, 0.497, 0.493, -0.011, 0.569, 0.658, -0.201, -5.000, 0.292, 0.226, -0.979, 0.283, 0.171, 0.204, 0.101, -0.265, 0.632, 0.627, 0.384, -0.153, 0.552, 0.582, -0.096, 1.108, 0.745, 0.924, -0.197, 0.742, 0.304, 0.852, 0.222, 0.220, 0.737, 0.865, 0.597, 1.228, 0.180, 0.700, 0.097, 0.617, 0.285, 0.397, -0.595, -0.213, 0.234, 0.591, -0.121, -0.049, 0.590, 0.738, 0.471, 0.573, -0.406, -0.524, -1.587, -5.000, -0.731, -0.271, -1.364, -5.000, -0.396, 0.472, -0.322, -0.411, -0.048, -0.361, -0.195, -0.700, -0.342, -0.143, -1.333, -5.000, -0.660, -0.122, -1.196, -0.417, -0.859, -0.536, -0.780, -1.242, -0.197, 0.389, -0.607, -0.755, -0.549, -0.178, -1.379, -0.048, -0.718, -0.409, -0.982, -0.986, -0.379, -0.447, -0.285, -0.895, -0.456, 0.037, -0.130, 0.070, -1.136, -1.057, -1.546, -1.150, -1.338, -0.545, -1.361, -1.213, -1.294, -0.718, -1.497, -1.372, -0.906, -1.074, -1.122, -0.882, -0.175, -0.546, -2.020, -5.000, -0.681, -0.820, -2.642, -5.000, -0.718, -0.610, -1.143, -0.991, -0.661, -1.026, -1.296, -1.235, -0.142, -0.138, -1.843, -5.000, -0.931, -0.784, -1.968, -1.398, -1.377, -0.585, -1.255, -1.932, -0.587, -0.284, -1.510, -1.185, -0.429, -0.903, -1.382, -0.348, -1.628, -1.103, -1.511, -1.582, -1.472, -0.998, -1.439, -1.756, -0.697, -0.799, -0.830, -0.125, -0.878, -0.693, -1.971, -0.888, -1.577, -1.116, -1.541, -2.334, -1.369, -1.668, -1.642, -1.516, -0.993, -0.731, -1.324, -1.128, -0.428, -0.565, -1.342, -5.000, -0.503, -0.923, -3.632, -5.000, -0.032, -0.067, -0.114, -0.613, 0.326, 0.419, -0.290, -0.326, 0.263, 0.201, -0.440, -5.000, -0.229, -0.688, -1.326, -0.572, -0.159, -0.292, -1.068, -0.792, 0.250, 0.391, -0.166, -0.380, 0.152, 0.253, -0.507, 0.379, -0.334, 0.014, -1.418, -0.944, -0.303, -0.175, -0.235, -0.685, -0.135, 0.246, -0.600, 0.167, -0.621, -0.396, -1.269, -0.418, -0.908, -0.290, -1.988, -1.444, -0.842, -0.163, -0.873, -1.328, -0.496, -0.214, -0.803, -0.656, 0.313, -0.222, -1.031, -5.000, -0.210, -0.187, -1.822, -5.000, 0.494, 0.698, -0.202, -0.091, 1.051, 0.492, 0.599, 0.116, 0.642, 0.629, -0.286, -5.000, 0.439, 0.414, -0.711, 0.043, 0.078, 0.485, -0.079, -0.455, 0.462, 0.686, 0.335, -0.070, 0.587, 0.585, -0.260, 1.026, -0.122, 0.595, -0.705, -0.255, -0.419, 0.192, -0.453, -0.239, 0.302, 0.314, -0.097, 0.920, 0.044, 0.571, -0.359, 0.335, -0.211, 0.462, -0.728, -0.486, -0.374, 0.528, -0.708, -0.476, 0.192, 0.452, 0.118, 0.315, -0.310, -0.599, -1.464, -5.000, -0.440, -0.220, -2.086, -5.000, -0.033, 0.053, -0.377, -0.682, 0.292, -0.171, -0.116, -0.783, 0.021, -0.178, -0.926, -5.000, 0.014, -0.146, -1.107, -0.385, 0.023, -0.173, 0.171, -0.634, -0.114, 0.102, -0.401, -1.131, -0.215, 0.136, -0.783, -0.115, -0.563, -0.167, -0.983, -0.570, -0.305, -0.236, -0.695, -0.889, -0.811, -0.596, -1.077, -0.693, -0.532, -0.216, -1.083, -0.821, -0.949, -0.336, -1.418, -1.191, -0.966, -1.242, -1.179, -1.594, -1.354, -0.911, -1.499, -1.635, -0.101, -0.574, -1.351, -5.000, -0.830, -1.334, -1.979, -5.000, -0.369, -0.062, -0.485, -0.634, -0.408, -0.631, -0.899, -0.612, -0.024, 0.091, -1.140, -5.000, -0.454, -0.742, -1.280, -0.873, -0.876, -0.274, -0.695, -1.561, -0.448, -0.058, -0.936, -0.586, -0.766, -0.209, -0.799, -0.093, -0.904, -0.175, -1.004, -1.232, -1.208, -0.483, -0.719, -1.228, -0.708, -0.319, -0.859, -0.792, -0.522, -0.783, -1.831, -1.032, -1.472, -0.714, -1.519, -1.960, -1.459, -1.031, -1.463, -1.588, -1.083, -0.890, -1.226, -1.318, 0.035, -0.089, -0.808, -5.000, 0.145, -0.544, -1.857, -5.000, 0.259, 0.308, -0.207, -0.176, 0.677, 0.394, -0.043, 0.264, 0.794, 0.497, 0.009, -5.000, 0.465, -0.176, -1.901, -0.483, 0.533, 0.414, -0.054, -0.206, 0.529, 0.626, 0.051, 0.136, 0.537, 0.165, -0.438, 0.571, 0.112, 0.193, -1.662, -0.844, -0.036, 0.212, -0.537, -0.360, 0.278, 0.423, -0.206, 0.543, 0.050, 0.142, -0.628, 0.068, -0.103, 0.027, -1.199, -0.740, 0.020, 0.156, -0.328, -0.156, 0.043, 0.231, -0.299, 0.062, 0.514, 0.275, -0.366, -5.000, 0.302, 0.040, -1.446, -5.000, 0.513, 0.817, 0.416, 0.177, 1.010, 0.608, 0.462, 0.527, 0.844, 0.952, 0.160, -5.000, 0.717, 0.524, -0.725, 0.195, 0.626, 0.939, 0.716, 0.253, 0.645, 0.970, 0.502, 0.370, 0.664, 0.861, -0.340, 1.047, 0.250, 0.665, -0.766, -0.110, 0.297, 0.677, 0.073, 0.319, 0.569, 0.666, 0.130, 0.983, 0.408, 0.881, -0.237, 0.604, 0.148, 0.655, -0.467, -0.627, 0.377, 0.960, 0.248, -0.116, 0.615, 0.812, 0.381, 0.300, 0.423, 0.189, -0.705, -5.000, 0.068, -0.252, -1.552, -5.000, 0.372, 0.562, -0.143, -0.084, 0.563, 0.143, 0.309, 0.209, 0.645, 0.765, -0.510, -5.000, 0.563, 0.268, -1.604, -0.169, 0.484, 0.867, 0.242, 0.083, 0.466, 0.696, 0.039, 0.054, 0.276, 0.193, -0.547, 0.411, -0.179, -0.227, -1.213, -1.075, -0.041, 0.301, -0.286, -0.430, -0.074, 0.302, -0.613, 0.085, -0.216, 0.010, -0.797, -0.387, -0.347, -0.458, -1.273, -1.485, -0.305, 0.035, -0.885, -0.821, -0.285, -0.336, -1.030, -0.778, 0.158, -0.100, -0.488, -5.000, 0.033, -0.258, -1.622, -5.000, -0.009, 0.309, -0.063, -0.290, -0.107, -0.204, -0.669, 0.072, 0.330, 0.728, -0.454, -5.000, 0.234, -0.049, -1.046, -0.486, -0.050, 0.303, 0.244, -0.526, 0.039, 0.369, -0.510, -0.036, 0.247, 0.614, -0.006, 0.147, -0.368, 0.007, -0.878, -1.321, -0.501, -0.148, -0.445, -0.647, -0.506, -0.176, -0.576, -0.216, -0.509, -0.200, -1.094, -0.965, -0.477, -0.643, -1.492, -1.513, -0.532, -0.369, -0.916, -0.912, -0.639, -0.293, -1.091, -0.803 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_29(struct _training *tptr) {
  struct _training tinf = {
    0.427, 11, 4.350, { 1.724, 0.318, 0.958 }, { 0.707, -1.147, -1.462 }, 1, 
    { -0.928, -1.288, -1.026, -0.719, -4.000, -1.084, -0.634, 0.339, 0.836, -0.751, -1.887, -4.000, 0.065, 0.182, 1.718, 0.524, 1.865, 0.893, 0.102, 1.820, 0.623, -0.492, 2.225, 0.823, 2.369, 0.309, 1.833, 2.746 }, 
    {{ 0.156, -0.371, -0.014, 0.069},{ 0.319, -0.189, -0.230, -0.100},{ 0.262, -0.066, -0.310, -0.055},{ 0.246, -0.195, -0.332, 0.062},{ 0.290, -0.149, -0.279, -0.054},{ 0.258, -0.190, -0.323, 0.040},{ 0.262, -0.284, -0.254, 0.050},{ 0.328, -0.141, -0.369, -0.062},{ 0.312, -0.132, -0.310, -0.079},{ 0.289, -0.232, -0.277, -0.000},{ 0.293, -0.189, -0.244, -0.053},{ 0.286, -0.296, -0.310, 0.057},{ 0.269, -0.293, -0.356, 0.098},{ 0.307, -0.239, -0.296, -0.011},{ 0.225, -0.264, -0.373, 0.141},{ 0.205, -0.262, -0.221, 0.088},{ 0.227, -0.277, -0.269, 0.097},{ 0.155, -0.224, -0.281, 0.151},{ 0.214, -0.245, -0.312, 0.116},{ 0.243, -0.137, -0.269, -0.004},{ 0.245, -0.159, -0.252, -0.002},{ 0.257, -0.239, -0.208, 0.005},{ 0.221, -0.104, -0.245, -0.012},{ 0.219, -0.193, -0.300, 0.076},{ 0.237, -0.222, -0.200, 0.016},{ 0.191, -0.122, -0.122, -0.041},{ 0.169, -0.094, -0.200, 0.017},{ 0.234, -0.141, -0.203, -0.029},{ 0.220, -0.146, -0.190, -0.017},{ 0.196, -0.138, -0.138, -0.025},{ 0.182, -0.070, -0.214, -0.005},{ 0.187, -0.077, -0.129, -0.062} }, 
    {{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}} }, 
    0.000, { 0.265, 0.660, -0.276, -5.000, -0.166, 0.405, -0.345, -5.000, 0.278, 0.759, 0.115, 0.011, 0.305, 0.658, 0.203, 0.089, 0.182, 0.522, 0.182, -5.000, -0.261, 0.108, -0.686, -0.294, -0.244, -0.035, -0.302, -0.448, 0.506, 0.451, 0.374, -0.049, 0.276, 0.672, -0.016, 0.302, 0.009, 0.230, -0.075, -0.585, 0.401, 0.453, 0.241, 0.102, 0.412, 0.423, 0.414, 0.078, 0.138, 0.558, -0.200, 0.114, -0.089, 0.043, -0.382, -0.386, 0.258, 0.502, 0.534, 0.033, 0.307, 0.455, 0.645, 0.152, 0.739, 1.194, -0.290, -5.000, 0.304, 0.948, -0.121, -5.000, 0.424, 0.819, -0.442, 0.017, 0.806, 0.940, 0.540, 0.290, 0.614, 0.896, 0.448, -5.000, 0.533, 0.841, 0.132, 0.283, 0.424, 0.595, 0.377, 0.180, 0.762, 0.955, 0.813, 0.018, 0.921, 1.313, 0.607, 0.890, 0.817, 0.921, 0.768, 0.235, 0.942, 1.180, 0.638, 0.561, 1.017, 1.095, 1.050, 0.497, 0.675, 1.060, 0.246, 0.718, 0.737, 0.709, 0.412, 0.096, 0.543, 0.803, 0.459, 0.249, 0.855, 0.976, 1.231, 0.709, -0.291, 0.188, -0.806, -5.000, -0.684, -0.722, -1.382, -5.000, -0.129, -0.243, -0.835, -0.520, -0.399, -0.430, -1.045, -0.851, -0.368, -0.238, -0.517, -5.000, -0.902, -0.691, -1.193, -0.873, -0.595, -0.743, -0.752, -0.846, -0.155, -0.196, -0.703, -0.951, -0.437, -0.181, -0.803, -0.562, -0.855, -0.504, -0.843, -1.278, -0.494, 0.008, -0.769, -0.600, -0.479, -0.183, -0.855, -0.692, -0.560, -0.154, -0.664, -0.424, -0.798, -0.749, -1.177, -1.097, -0.339, -0.178, -0.661, -0.581, -0.278, -0.539, -0.599, -0.831, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.387, 0.179, -0.868, -5.000, -0.677, -0.197, -1.236, -5.000, -0.037, 0.487, -0.153, -0.348, 0.027, 0.310, 0.022, -0.164, -0.445, 0.063, -0.317, -5.000, -0.906, -0.526, -1.068, -0.665, -0.728, -0.342, -0.625, -0.757, 0.144, 0.085, -0.087, -0.354, -0.124, 0.361, -0.192, 0.062, -0.496, -0.217, -0.477, -0.841, -0.308, 0.303, -0.505, -0.367, -0.037, 0.213, 0.080, -0.115, -0.338, -0.099, -0.715, -0.260, -0.676, -0.403, -1.123, -0.934, 0.008, -0.011, -0.104, -0.217, -0.047, 0.015, 0.329, -0.028, 0.342, 0.892, -0.867, -5.000, -0.111, 0.690, -0.914, -5.000, 0.259, 0.506, -0.571, -0.290, 0.902, 1.114, 0.753, 0.504, -0.029, 0.303, 0.023, -5.000, -0.102, 0.370, -0.551, 0.110, -0.014, 0.133, -0.129, -0.189, 0.672, 0.660, 0.576, -0.113, 0.751, 1.276, 0.168, 0.537, 0.671, 0.836, 0.345, 0.065, 0.652, 0.711, 0.177, 0.015, 0.694, 0.817, 0.857, 0.297, 0.237, 0.728, -0.145, 0.194, 0.185, 0.443, -0.585, -0.404, -0.242, -0.201, -0.571, -0.684, 0.469, 0.788, 1.231, 0.493, -0.678, -0.131, -1.232, -5.000, -0.817, -0.725, -1.298, -5.000, -0.620, -0.636, -1.013, -0.877, -0.452, -0.852, -1.355, -1.066, -0.489, -0.248, -0.498, -5.000, -0.902, -0.650, -0.771, -0.876, -0.627, -0.505, -0.770, -0.413, -0.021, -0.224, -0.601, -0.650, -0.564, -0.454, -0.868, -0.754, -1.003, -0.666, -1.440, -1.489, -0.772, -0.544, -1.340, -1.076, -0.333, -0.237, -0.878, -1.094, -0.768, -0.642, -1.176, -0.871, -1.141, -0.896, -0.630, -1.300, -0.971, -0.937, -1.373, -1.103, -0.435, -0.628, -0.872, -0.989, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.059, 0.506, -0.482, -5.000, -0.392, 0.259, -0.994, -5.000, -0.021, 0.337, 0.008, -0.289, 0.098, 0.492, 0.209, -0.264, 0.074, 0.361, 0.163, -5.000, -0.024, 0.332, -0.656, -0.269, -0.261, 0.141, 0.145, -0.718, 0.401, 0.524, 0.373, -0.367, 0.404, 0.735, -0.050, 0.364, -0.019, 0.360, -0.094, -0.559, 0.166, 0.367, -0.112, -0.246, 0.375, 0.594, 0.506, 0.145, 0.119, 0.526, -0.269, 0.212, -0.263, 0.204, -0.379, -0.550, 0.099, 0.405, -0.032, -0.241, 0.206, 0.482, 0.476, 0.090, 0.457, 0.873, -0.715, -5.000, -0.019, 0.668, -0.841, -5.000, 0.042, 0.593, -0.712, -0.380, 0.559, 0.790, 0.406, -0.081, 0.357, 0.606, 0.224, -5.000, 0.124, 0.748, -0.209, 0.150, 0.062, 0.363, 0.071, -0.110, 0.733, 0.795, 0.663, -0.325, 0.672, 0.956, 0.362, 0.534, 0.141, 0.676, 0.060, -0.253, 0.473, 0.744, -0.038, -0.012, 0.801, 0.779, 0.763, 0.255, 0.705, 0.920, 0.235, 0.697, 0.574, 0.761, 0.029, -0.032, 0.430, 0.703, 0.090, -0.022, 0.891, 0.947, 1.166, 0.442, -0.186, 0.009, -0.814, -5.000, -0.892, -0.365, -1.260, -5.000, -0.116, -0.412, -0.635, -0.835, -0.617, -0.242, -0.987, -0.485, -0.376, -0.030, -0.592, -5.000, -0.255, -0.162, -0.733, -0.490, -0.426, -0.298, -0.636, -0.497, -0.090, 0.221, -0.410, -0.538, -0.268, 0.090, -0.536, -0.423, -0.884, -0.340, -0.779, -1.010, -0.413, -0.324, -0.689, -0.653, -0.308, -0.232, -0.579, -0.769, -0.332, -0.088, -0.591, -0.482, -0.725, -0.616, -1.389, -1.167, -0.201, -0.245, -0.504, -0.554, -0.098, -0.404, -0.536, -0.756, -0.064, 0.253, -0.708, -5.000, -0.623, -0.554, -1.250, -5.000, -0.469, -0.281, -0.886, -0.769, -0.508, -0.202, -0.655, -0.613, -0.183, 0.120, -0.340, -5.000, -0.543, -0.245, -1.274, -0.647, -0.881, -0.348, -0.970, -0.996, -0.100, -0.100, -0.477, -0.585, -0.098, 0.275, -0.334, -0.100, -0.549, -0.054, -0.412, -1.057, -0.226, 0.102, -0.389, -0.559, 0.140, 0.192, 0.077, -0.202, -0.088, 0.258, -0.448, -0.057, -0.309, -0.043, -0.414, -0.786, -0.168, 0.024, -0.322, -0.708, -0.122, 0.134, 0.054, -0.407, 0.123, 0.512, -0.240, -5.000, -0.166, 0.354, -0.477, -5.000, 0.059, 0.537, -0.147, -0.189, 0.095, 0.452, 0.114, -0.094, 0.118, 0.438, 0.056, -5.000, -0.048, 0.383, -0.506, -0.214, 0.087, 0.281, -0.143, -0.299, 0.327, 0.400, 0.406, -0.040, 0.253, 0.634, -0.150, 0.298, 0.031, 0.375, 0.048, -0.337, 0.278, 0.542, 0.001, -0.037, 0.255, 0.368, 0.329, 0.046, 0.048, 0.519, -0.254, -0.038, -0.225, 0.204, -0.292, -0.522, 0.117, 0.484, -0.070, -0.190, 0.116, 0.325, 0.528, -0.023, 0.364, 0.767, -0.503, -5.000, -0.016, 0.579, -0.474, -5.000, 0.278, 0.547, -0.440, -0.087, 0.454, 0.434, 0.525, -0.008, 0.374, 0.611, 0.186, -5.000, 0.226, 0.621, -0.214, 0.175, 0.311, 0.520, 0.321, 0.182, 0.657, 0.751, 0.556, 0.021, 0.574, 0.890, 0.274, 0.543, 0.174, 0.663, 0.211, -0.038, 0.668, 0.767, 0.258, 0.141, 0.570, 0.556, 0.689, 0.273, 0.447, 0.846, 0.207, 0.407, 0.320, 0.478, 0.094, -0.061, 0.332, 0.617, 0.183, -0.083, 0.484, 0.719, 1.071, 0.425, 0.101, 0.441, -0.549, -5.000, -0.544, -0.222, -0.926, -5.000, -0.260, -0.198, -0.584, -0.576, -0.303, -0.089, -0.359, -0.428, -0.173, 0.372, -0.085, -5.000, -0.241, 0.098, -0.656, -0.719, 0.044, -0.200, -0.250, -0.302, 0.157, 0.202, 0.083, -0.393, -0.174, -0.005, -0.913, -0.382, -0.635, -0.163, -1.005, -0.966, -0.163, -0.172, -0.674, -0.704, -0.192, -0.240, -0.581, -0.449, -0.137, 0.101, -0.570, -0.230, -0.542, -0.525, -0.844, -0.787, -0.260, -0.090, -0.306, -0.404, -0.061, -0.217, -0.246, -0.277, -0.075, 0.260, -0.392, -5.000, -0.389, -0.275, -0.890, -5.000, -0.462, -0.096, -0.529, -0.585, -0.242, -0.198, -0.559, -0.378, -0.035, 0.195, -0.062, -5.000, -0.305, -0.255, -0.604, -0.258, -0.615, -0.119, -0.405, -0.604, 0.128, 0.189, -0.094, -0.240, -0.336, 0.174, -0.609, -0.206, -0.464, -0.326, -0.671, -0.853, -0.486, -0.021, -0.595, -0.523, -0.186, 0.067, -0.197, -0.305, -0.158, 0.156, -0.480, -0.211, -0.348, -0.140, -0.420, -0.677, -0.140, -0.118, -0.360, -0.521, -0.065, 0.053, -0.174, -0.241, 0.099, 0.644, -0.621, -5.000, -0.208, 0.334, -0.385, -5.000, 0.293, 0.779, 0.037, -0.045, 0.281, 0.568, 0.111, 0.017, -0.229, 0.287, -0.063, -5.000, -0.410, -0.109, -0.659, -0.601, -0.438, -0.225, -0.588, -0.863, 0.155, 0.267, 0.115, -0.427, 0.269, 0.624, -0.177, 0.182, 0.090, 0.168, 0.021, -0.584, 0.283, 0.481, -0.015, -0.095, 0.319, 0.265, 0.271, -0.077, 0.074, 0.541, -0.344, 0.171, 0.005, 0.017, -0.168, -0.506, 0.194, 0.437, 0.386, 0.124, 0.325, 0.470, 0.633, 0.096, 0.647, 1.049, -0.797, -5.000, 0.159, 0.738, -0.598, -5.000, 0.260, 0.656, -0.525, -0.114, 0.653, 0.668, 0.272, 0.129, 0.143, 0.589, 0.015, -5.000, 0.141, 0.446, -0.247, -0.141, -0.050, 0.140, -0.078, -0.328, 0.469, 0.638, 0.501, -0.406, 0.875, 1.314, 0.447, 0.845, 0.599, 0.778, 0.418, 0.186, 0.903, 0.952, 0.248, 0.330, 0.915, 0.799, 0.800, 0.225, 0.659, 1.062, 0.385, 0.745, 0.672, 0.488, 0.245, -0.018, 0.551, 0.699, 0.305, 0.283, 0.766, 0.893, 1.131, 0.489, 0.195, 0.781, -0.700, -5.000, -0.209, 0.114, -0.709, -5.000, 0.125, 0.277, -0.504, -0.378, -0.089, 0.278, -0.636, -0.521, 0.070, 0.498, 0.127, -5.000, 0.005, 0.173, -0.458, -0.253, -0.197, -0.106, -0.272, -0.464, 0.336, 0.346, -0.076, -0.692, 0.406, 0.816, 0.122, 0.388, 0.022, 0.443, 0.279, -0.427, 0.535, 0.701, 0.074, 0.053, 0.449, 0.515, 0.241, -0.138, -0.099, 0.231, -0.457, 0.015, -0.190, 0.049, -0.453, -0.564, 0.269, 0.295, 0.003, -0.155, 0.305, 0.191, 0.008, -0.387, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.268, 0.361, -1.019, -5.000, -0.573, -0.120, -1.032, -5.000, -0.006, 0.381, -0.320, -0.332, -0.052, 0.316, 0.292, -0.300, -0.349, 0.167, -0.216, -5.000, -0.738, -0.322, -1.055, -0.649, -0.990, -0.383, -0.690, -0.715, -0.020, 0.145, -0.037, -0.579, 0.130, 0.708, 0.175, 0.388, -0.341, 0.152, -0.193, -0.648, -0.144, 0.340, -0.356, -0.380, 0.072, 0.396, 0.399, -0.094, -0.541, 0.066, -0.723, -0.534, -0.845, -0.390, -1.158, -0.982, -0.006, 0.347, -0.095, -0.259, 0.051, 0.097, 0.196, -0.281, 0.472, 0.821, -1.204, -5.000, -0.068, 0.683, -1.065, -5.000, 0.103, 0.425, -0.579, -0.451, 0.922, 0.975, 0.636, 0.324, -0.240, 0.249, -0.067, -5.000, -0.245, 0.352, -0.490, -0.213, -0.291, -0.040, -0.315, -0.485, 0.515, 0.593, 0.614, -0.256, 0.938, 1.335, 0.554, 0.834, 0.724, 0.863, 0.425, 0.313, 0.607, 0.762, 0.110, -0.029, 0.766, 0.736, 0.996, 0.463, 0.053, 0.637, -0.253, 0.139, -0.014, 0.335, -0.359, -0.422, -0.823, -0.545, -0.974, -1.038, 0.359, 0.654, 1.109, 0.432, -0.457, 0.014, -1.156, -5.000, -1.071, -0.958, -1.438, -5.000, -0.553, -0.554, -1.033, -1.035, -0.784, -0.573, -1.376, -1.232, -0.468, -0.000, -0.409, -5.000, -0.594, -0.679, -0.878, -0.665, -0.338, -0.328, -0.828, -0.645, -0.193, -0.192, -0.521, -0.794, -0.230, 0.423, -0.618, -0.261, -0.412, -0.447, -0.476, -0.827, -0.068, 0.024, -0.859, -0.660, 0.141, 0.315, -0.417, -0.676, -0.655, -0.165, -1.148, -0.557, -1.013, -0.772, -1.299, -1.232, -0.789, -0.819, -1.482, -1.174, -0.442, -0.677, -0.880, -0.940, 0.065, 0.675, -0.887, -5.000, -0.561, -0.099, -1.142, -5.000, -0.427, -0.123, -0.876, -0.556, -0.411, -0.072, -0.785, -0.557, -0.129, 0.300, -0.025, -5.000, -0.388, -0.218, -1.002, -0.121, -0.596, -0.458, -1.019, -0.867, -0.124, 0.063, -0.519, -0.617, 0.058, 0.866, 0.026, 0.453, -0.065, 0.528, 0.233, -0.845, 0.003, 0.394, -0.216, -0.178, 0.115, 0.580, 0.241, -0.182, -0.282, 0.249, -0.933, -0.490, -0.550, -0.256, -0.440, -1.213, -0.753, -0.950, -1.283, -1.108, -0.495, -0.406, -0.977, -0.704, -0.193, 0.332, -0.813, -5.000, -0.564, 0.197, -1.095, -5.000, -0.243, 0.325, -0.384, -0.490, -0.093, 0.338, -0.211, -0.522, -0.348, 0.066, -0.266, -5.000, -0.464, 0.062, -0.945, -0.663, -0.462, -0.282, -0.636, -0.529, -0.079, -0.024, -0.072, -0.948, 0.470, 0.858, 0.026, 0.460, 0.018, 0.607, -0.036, -0.420, 0.046, 0.189, -0.257, -0.392, 0.329, 0.422, 0.309, 0.093, 0.055, 0.738, -0.075, 0.321, -0.035, 0.387, -0.213, -0.497, -0.141, 0.264, -0.264, -0.370, 0.168, 0.540, 0.486, 0.023, 0.149, 0.635, -0.834, -5.000, -0.318, 0.529, -0.329, -5.000, -0.252, 0.132, -0.659, -0.750, 0.171, 0.385, -0.262, -0.214, 0.001, 0.346, -0.077, -5.000, -0.047, 0.412, -0.418, -0.190, -0.139, -0.047, -0.410, -0.315, 0.425, 0.461, 0.260, -0.564, 0.519, 0.906, 0.052, 0.439, 0.138, 0.333, -0.316, -0.726, 0.183, 0.366, -0.566, -0.377, 0.539, 0.439, 0.322, -0.231, 0.521, 0.869, 0.096, 0.524, 0.436, 0.610, 0.175, 0.021, 0.188, 0.327, -0.103, -0.202, 0.539, 0.718, 0.914, 0.177, -0.204, 0.337, -0.766, -5.000, -0.700, -0.397, -0.934, -5.000, -0.231, -0.285, -0.649, -0.755, -0.513, -0.357, -0.706, -0.973, -0.418, 0.082, -0.395, -5.000, -0.191, 0.089, -0.584, -0.468, -0.093, -0.278, -0.593, -0.686, -0.103, 0.173, -0.292, -0.817, 0.329, 0.843, 0.108, 0.131, -0.416, 0.244, 0.129, -0.572, -0.010, 0.118, -0.465, -0.454, 0.106, 0.307, 0.033, -0.290, -0.069, 0.416, -0.283, -0.095, -0.455, -0.101, -0.557, -0.577, -0.094, 0.015, -0.222, -0.406, 0.009, 0.063, -0.080, -0.492, -0.339, 0.180, -1.035, -5.000, -1.199, -0.564, -1.176, -5.000, -0.757, -0.387, -0.879, -0.838, -0.791, -0.236, -0.758, -0.953, -0.589, 0.101, -0.434, -5.000, -0.854, -0.500, -0.911, -0.811, -0.865, -0.495, -0.892, -0.991, -0.323, -0.425, -0.647, -0.940, -0.379, 0.554, -0.450, -0.098, -0.659, 0.107, -0.442, -1.108, -0.058, 0.144, -0.277, -0.567, 0.045, 0.390, 0.045, -0.514, -0.231, 0.476, -0.466, 0.054, -0.290, 0.212, -0.118, -0.761, -0.375, 0.068, -0.264, -0.664, -0.111, 0.181, 0.215, -0.414, 0.223, 0.784, -0.435, -5.000, -0.093, 0.544, -0.511, -5.000, 0.196, 0.741, 0.021, -0.097, 0.241, 0.657, 0.138, -0.025, 0.096, 0.745, 0.284, -5.000, -0.019, 0.393, -0.404, -0.234, -0.193, 0.265, -0.200, -0.533, 0.467, 0.415, 0.449, -0.304, 0.557, 0.828, 0.182, 0.529, 0.233, 0.634, 0.215, -0.195, 0.336, 0.755, 0.183, 0.120, 0.415, 0.625, 0.510, 0.183, 0.175, 0.741, -0.100, 0.199, -0.105, 0.389, -0.328, -0.360, -0.160, 0.403, -0.159, -0.443, 0.157, 0.408, 0.511, -0.054, 0.300, 0.755, -0.909, -5.000, -0.069, 0.624, -0.784, -5.000, 0.073, 0.430, -0.467, -0.517, 0.508, 0.611, 0.066, -0.017, 0.152, 0.556, 0.058, -5.000, 0.074, 0.359, -0.119, 0.036, -0.157, 0.248, -0.002, -0.164, 0.329, 0.608, 0.490, -0.348, 0.820, 1.142, 0.370, 0.723, 0.391, 0.750, 0.391, 0.109, 0.571, 0.754, 0.174, 0.155, 0.739, 0.787, 0.741, 0.333, 0.711, 1.020, 0.355, 0.687, 0.344, 0.704, 0.395, 0.258, 0.402, 0.526, 0.126, -0.304, 0.599, 0.785, 1.082, 0.376, 0.577, 0.951, -0.394, -5.000, -0.150, 0.204, -0.706, -5.000, 0.100, 0.207, -0.440, -0.408, 0.055, 0.301, -0.290, -0.172, 0.107, 0.582, 0.135, -5.000, 0.076, 0.315, -0.419, -0.230, -0.032, 0.264, -0.100, -0.392, 0.535, 0.698, 0.324, -0.055, 0.511, 0.950, 0.179, 0.482, 0.015, 0.418, 0.086, -0.507, 0.414, 0.662, 0.154, 0.033, 0.557, 0.643, 0.287, 0.062, 0.231, 0.510, -0.097, 0.244, -0.041, 0.118, -0.150, -0.517, 0.217, 0.612, 0.205, -0.075, 0.395, 0.385, 0.282, -0.088, -0.280, 0.146, -0.785, -5.000, -0.601, -0.473, -1.057, -5.000, -0.503, -0.373, -0.868, -0.757, -0.471, -0.206, -0.566, -0.644, -0.365, -0.008, -0.335, -5.000, -0.576, -0.405, -1.096, -0.649, -0.859, -0.455, -0.874, -1.075, -0.371, -0.123, -0.584, -0.791, -0.712, -0.113, -0.963, -0.654, -1.040, -0.791, -1.171, -1.178, -1.027, -0.790, -1.453, -1.134, -0.649, -0.438, -0.980, -0.833, -0.337, 0.034, -0.764, -0.348, -0.727, -0.306, -0.877, -0.858, -0.554, -0.287, -0.780, -0.919, -0.344, -0.273, -0.400, -0.506, 0.198, 0.840, -0.327, -5.000, -0.176, 0.606, -0.476, -5.000, 0.468, 0.829, -0.029, 0.172, 0.313, 0.693, 0.316, 0.110, 0.200, 0.528, 0.362, -5.000, -0.256, 0.165, -0.540, 0.087, -0.094, 0.119, -0.313, -0.576, 0.486, 0.553, 0.596, -0.142, 0.476, 0.769, -0.078, 0.551, 0.230, 0.305, -0.132, -0.379, 0.674, 0.676, 0.119, 0.063, 0.437, 0.485, 0.313, 0.064, 0.360, 0.601, -0.009, 0.425, -0.026, 0.104, -0.494, -0.488, 0.404, 0.593, 0.489, 0.157, 0.492, 0.608, 0.711, 0.199, 0.751, 1.187, -0.426, -5.000, 0.469, 1.096, -0.414, -5.000, 0.445, 0.843, -0.362, 0.182, 0.876, 0.983, 0.639, 0.494, 0.538, 0.895, 0.379, -5.000, 0.551, 0.927, -0.075, 0.743, 0.728, 0.640, 0.398, 0.513, 0.942, 1.129, 0.867, 0.136, 0.903, 1.224, 0.655, 1.007, 0.905, 0.894, 0.619, 0.449, 0.918, 1.049, 0.399, 0.449, 1.051, 0.857, 0.754, 0.442, 0.646, 0.977, 0.326, 0.906, 0.774, 0.714, 0.235, 0.150, 0.724, 0.853, 0.470, 0.273, 1.026, 1.076, 1.308, 0.864, 0.099, 0.634, -0.622, -5.000, -0.375, 0.220, -0.964, -5.000, -0.119, 0.197, -0.725, -0.610, -0.207, 0.203, -0.723, -0.619, -0.096, 0.186, -0.091, -5.000, -0.164, 0.370, -0.701, -0.162, -0.013, -0.068, -0.338, -0.574, 0.450, 0.510, 0.106, -0.521, 0.012, 0.570, -0.011, 0.106, -0.120, 0.114, -0.132, -0.350, 0.174, 0.411, -0.268, -0.195, 0.269, 0.338, -0.031, -0.291, -0.363, -0.004, -0.230, -0.178, -0.486, -0.293, -0.496, -0.658, 0.153, 0.347, -0.092, -0.162, 0.296, 0.047, -0.026, -0.433, 0.388, 0.793, -0.294, -5.000, 0.023, 0.442, -0.597, -5.000, 0.412, 0.408, -0.468, -0.293, -0.013, 0.326, -0.330, -0.448, 0.351, 0.825, 0.238, -5.000, 0.167, 0.459, -0.577, 0.269, -0.164, 0.132, -0.360, -0.689, 0.500, 0.492, 0.117, -0.216, 0.682, 1.012, 0.086, 0.647, 0.299, 0.667, 0.747, -0.321, 0.902, 0.823, 0.232, 0.065, 0.755, 0.807, 0.679, 0.159, 0.202, 0.617, -0.133, 0.287, 0.177, 0.271, 0.090, -0.247, 0.436, 0.611, 0.266, -0.017, 0.279, 0.447, 0.333, -0.080, -0.249, 0.379, -0.825, -5.000, -0.703, 0.135, -1.133, -5.000, -0.047, 0.198, -0.565, -0.520, 0.134, 0.462, 0.188, 0.032, -0.386, 0.081, -0.153, -5.000, -0.552, 0.020, -0.740, -0.342, -0.596, -0.076, -0.665, -0.662, 0.400, 0.526, 0.449, -0.268, 0.197, 0.654, -0.054, 0.232, -0.123, 0.087, -0.398, -0.877, -0.151, 0.184, -0.797, -0.497, 0.278, 0.394, 0.409, 0.041, -0.276, 0.044, -0.675, -0.167, -0.401, -0.299, -0.865, -0.852, 0.054, 0.169, 0.092, 0.056, 0.089, 0.479, 0.680, -0.103, 0.425, 0.975, -1.023, -5.000, -0.044, 0.731, -0.734, -5.000, 0.374, 0.631, -0.655, -0.109, 0.828, 0.929, 0.780, 0.454, -0.166, 0.138, -0.063, -5.000, -0.219, 0.265, -0.527, -0.041, -0.031, 0.065, -0.130, -0.461, 0.761, 0.728, 0.545, -0.151, 0.713, 1.173, 0.345, 0.599, 0.439, 0.723, 0.345, -0.066, 0.605, 0.474, -0.076, -0.189, 0.575, 0.464, 0.544, -0.107, -0.004, 0.477, -0.306, 0.035, 0.178, 0.380, -0.083, -0.433, -0.270, -0.104, -0.458, -0.639, 0.413, 0.661, 1.091, 0.409, 0.029, 0.709, -0.877, -5.000, -0.751, -0.468, -0.568, -5.000, -0.150, -0.081, -0.780, -0.605, -0.428, -0.034, -0.317, -0.829, 0.113, 0.526, 0.089, -5.000, -0.237, 0.088, -0.349, -0.399, -0.240, -0.038, -0.169, -0.384, 0.549, 0.551, 0.399, -0.357, 0.055, 0.637, -0.106, 0.183, -0.417, 0.116, -0.026, -0.888, 0.211, 0.383, -0.436, -0.382, 0.253, 0.347, -0.027, -0.357, -0.510, -0.283, -0.873, -0.731, -0.717, -0.579, -0.828, -1.038, -0.450, -0.108, -0.559, -0.550, -0.172, -0.049, -0.202, -0.499, -0.299, 0.087, -1.114, -5.000, -0.789, -0.457, -1.032, -5.000, -0.818, -0.469, -1.165, -0.919, -0.676, -0.426, -1.061, -0.814, -0.489, 0.018, -0.338, -5.000, -0.667, -0.250, -1.201, -0.466, -1.087, -0.742, -1.274, -1.143, -0.029, -0.287, -0.524, -0.814, -0.298, 0.107, -0.314, -0.250, -0.982, -0.125, -0.208, -0.942, -0.391, -0.185, -0.787, -0.933, -0.056, 0.193, -0.061, -0.536, -0.769, -0.618, -0.801, -0.729, -0.912, -0.637, -0.910, -1.260, -1.116, -0.882, -1.352, -1.082, -0.610, -0.384, -0.581, -0.707, 0.184, 0.741, -0.507, -5.000, -0.390, 0.423, -0.875, -5.000, 0.280, 0.730, -0.016, -0.148, 0.207, 0.681, 0.129, -0.170, 0.204, 0.660, 0.316, -5.000, -0.073, 0.630, -0.398, -0.027, -0.182, 0.046, 0.002, -0.434, 0.524, 0.708, 0.540, -0.533, 0.544, 0.876, 0.247, 0.571, 0.089, 0.589, -0.122, -0.469, 0.308, 0.269, -0.078, -0.256, 0.571, 0.602, 0.530, 0.220, 0.192, 0.753, -0.139, 0.346, -0.205, 0.320, -0.477, -0.224, 0.099, 0.518, 0.018, 0.033, 0.505, 0.560, 0.696, 0.170, 0.660, 1.106, -0.965, -5.000, -0.051, 0.828, -0.746, -5.000, 0.315, 0.756, -0.540, -0.020, 0.477, 0.781, 0.531, 0.024, 0.121, 0.620, 0.151, -5.000, -0.126, 0.545, -0.558, -0.113, 0.103, 0.288, -0.033, -0.281, 0.739, 0.727, 0.497, -0.332, 0.663, 1.024, 0.268, 0.500, 0.001, 0.557, 0.321, -0.202, 0.266, 0.476, -0.396, -0.293, 0.635, 0.547, 0.519, -0.120, 0.658, 0.966, 0.101, 0.663, 0.232, 0.444, -0.127, -0.059, 0.348, 0.532, -0.055, -0.081, 0.793, 0.914, 1.060, 0.373, -0.000, 0.379, -0.843, -5.000, -0.628, -0.192, -1.314, -5.000, -0.263, -0.401, -0.706, -0.801, -0.300, 0.050, -0.600, -0.653, -0.368, 0.151, -0.377, -5.000, -0.294, 0.300, -0.527, -0.278, -0.484, -0.480, -0.736, -0.809, -0.008, 0.312, -0.210, -0.668, 0.273, 0.779, 0.100, -0.087, -0.350, 0.332, -0.406, -0.600, 0.265, 0.211, -0.494, -0.319, 0.159, 0.201, -0.073, -0.472, -0.071, 0.232, -0.336, -0.074, -0.657, -0.182, -0.788, -0.520, 0.054, 0.136, -0.178, -0.388, 0.085, 0.097, -0.077, -0.521, -0.093, 0.424, -0.670, -5.000, -1.048, -0.340, -1.230, -5.000, -0.420, 0.053, -0.982, -0.709, -0.487, 0.010, -0.499, -0.600, -0.183, 0.377, -0.049, -5.000, -0.635, -0.088, -0.960, -0.546, -0.606, -0.136, -0.642, -0.879, -0.004, -0.001, -0.395, -0.776, -0.129, 0.351, -0.279, -0.114, -0.549, -0.162, -0.371, -1.005, -0.055, -0.081, -0.407, -0.463, 0.015, 0.105, 0.055, -0.522, -0.137, 0.394, -0.401, 0.043, -0.319, 0.043, -0.191, -0.665, -0.152, 0.069, -0.227, -0.494, -0.016, 0.168, 0.270, -0.398, 0.315, 0.865, -0.292, -5.000, -0.110, 0.591, -0.515, -5.000, 0.346, 0.830, 0.048, 0.048, 0.247, 0.688, 0.319, 0.049, 0.497, 0.925, 0.557, -5.000, 0.317, 0.740, -0.053, 0.156, 0.277, 0.752, 0.043, -0.035, 0.647, 0.792, 0.735, 0.039, 0.443, 0.782, 0.155, 0.413, 0.104, 0.263, -0.088, -0.358, 0.464, 0.382, -0.159, -0.261, 0.297, 0.346, 0.190, -0.055, 0.326, 0.742, -0.019, 0.269, -0.054, 0.176, -0.381, -0.354, 0.307, 0.676, 0.086, -0.034, 0.392, 0.617, 0.660, 0.113, 0.523, 0.937, -0.395, -5.000, 0.061, 0.804, -0.488, -5.000, 0.463, 0.809, -0.642, 0.021, 0.442, 0.662, 0.608, 0.168, 0.338, 0.749, 0.222, -5.000, 0.178, 0.618, -0.351, 0.289, 0.558, 0.571, 0.196, 0.282, 0.722, 0.819, 0.648, -0.310, 0.487, 0.925, 0.288, 0.509, 0.115, 0.375, 0.205, -0.006, 0.448, 0.331, -0.313, -0.289, 0.385, 0.369, 0.204, -0.166, 0.591, 0.817, 0.200, 0.527, 0.257, 0.413, -0.027, -0.100, 0.490, 0.536, 0.159, -0.025, 0.620, 0.768, 0.957, 0.278, 0.433, 0.938, -0.407, -5.000, -0.242, 0.093, -0.699, -5.000, 0.059, 0.412, -0.407, -0.524, 0.007, 0.354, -0.015, -0.227, 0.148, 0.556, 0.325, -5.000, 0.166, 0.607, -0.294, 0.052, 0.312, 0.483, -0.074, -0.385, 0.682, 0.958, 0.532, -0.105, 0.460, 0.816, 0.156, 0.329, -0.102, 0.360, 0.015, -0.562, 0.610, 0.901, 0.207, 0.157, 0.450, 0.484, 0.141, -0.153, 0.007, 0.279, -0.426, 0.134, -0.495, -0.147, -0.588, -0.677, 0.351, 0.625, 0.142, 0.015, 0.260, 0.234, 0.090, -0.249, 0.003, 0.465, -0.516, -5.000, -0.448, -0.201, -0.852, -5.000, -0.018, 0.183, -0.577, -0.342, -0.183, 0.055, -0.351, -0.328, -0.005, 0.405, -0.070, -5.000, -0.204, -0.032, -0.578, -0.047, -0.367, -0.161, -0.253, -0.352, 0.375, 0.174, -0.170, -0.257, 0.032, 0.462, -0.290, 0.110, -0.523, -0.225, -0.145, -0.869, -0.045, 0.040, -0.272, -0.525, 0.037, -0.048, -0.105, -0.544, -0.053, 0.269, -0.287, 0.052, -0.335, 0.002, -0.115, -0.547, -0.114, 0.098, -0.207, -0.460, -0.005, -0.044, -0.018, -0.366, 0.057, 0.590, -0.354, -5.000, -0.332, 0.209, -0.566, -5.000, 0.264, 0.615, 0.010, -0.027, 0.162, 0.513, 0.044, 0.129, -0.028, 0.414, 0.036, -5.000, -0.437, -0.101, -0.756, -0.208, 0.034, 0.078, -0.218, -0.326, 0.385, 0.449, 0.279, 0.027, 0.266, 0.566, -0.023, 0.291, 0.020, 0.076, -0.264, -0.816, 0.399, 0.544, 0.166, 0.019, 0.285, 0.285, 0.214, -0.081, 0.156, 0.430, -0.360, 0.066, -0.121, -0.090, -0.553, -0.556, 0.339, 0.445, 0.380, 0.010, 0.268, 0.403, 0.458, 0.125, 0.510, 0.950, -0.551, -5.000, 0.066, 0.683, -0.468, -5.000, 0.399, 0.637, -0.274, 0.153, 0.643, 0.671, 0.504, 0.293, 0.380, 0.710, -0.006, -5.000, 0.248, 0.612, -0.345, 0.287, 0.681, 0.684, 0.295, 0.418, 0.781, 0.960, 0.675, 0.170, 0.679, 0.995, 0.279, 0.781, 0.575, 0.666, 0.221, -0.026, 0.853, 0.941, 0.277, 0.337, 0.743, 0.660, 0.525, 0.239, 0.478, 0.813, 0.249, 0.732, 0.448, 0.439, 0.126, 0.150, 0.433, 0.531, 0.283, 0.366, 0.744, 0.893, 1.044, 0.541, -0.140, 0.294, -0.586, -5.000, -0.535, -0.225, -1.039, -5.000, -0.236, -0.048, -0.726, -0.522, -0.293, -0.019, -0.776, -0.465, -0.244, 0.044, -0.365, -5.000, -0.413, 0.082, -0.787, -0.375, -0.167, -0.118, -0.618, -0.442, 0.220, 0.248, -0.233, -0.470, -0.041, 0.239, -0.297, -0.057, -0.284, -0.057, -0.340, -0.776, 0.097, 0.270, -0.477, -0.452, -0.043, 0.177, -0.276, -0.389, -0.428, -0.075, -0.612, -0.155, -0.432, -0.574, -0.767, -0.778, -0.117, -0.122, -0.349, -0.219, -0.091, -0.037, -0.386, -0.454, 0.127, 0.549, -0.354, -5.000, -0.412, 0.150, -0.707, -5.000, 0.135, 0.264, -0.342, -0.275, -0.111, 0.230, -0.353, -0.324, 0.171, 0.622, -0.024, -5.000, -0.012, 0.391, -0.458, 0.086, 0.111, 0.064, -0.351, -0.374, 0.459, 0.481, 0.061, -0.070, 0.336, 0.794, -0.084, 0.372, 0.098, 0.590, 0.397, -0.272, 0.616, 0.572, 0.027, 0.108, 0.491, 0.633, 0.486, 0.058, 0.051, 0.589, -0.173, 0.107, 0.037, 0.264, -0.191, -0.408, 0.157, 0.430, -0.007, -0.035, 0.149, 0.292, 0.091, -0.071, -0.115, 0.352, -0.653, -5.000, -0.500, 0.007, -1.122, -5.000, -0.007, 0.260, -0.503, -0.327, 0.057, 0.436, 0.041, 0.031, -0.192, 0.085, -0.135, -5.000, -0.805, -0.189, -0.876, -0.427, -0.379, -0.077, -0.395, -0.881, 0.315, 0.376, 0.221, -0.218, 0.108, 0.465, -0.338, 0.119, -0.138, 0.068, -0.478, -0.800, -0.186, 0.108, -0.645, -0.490, 0.277, 0.336, 0.159, 0.019, -0.197, 0.309, -0.715, -0.309, -0.551, -0.110, -1.172, -0.916, 0.129, 0.035, -0.033, -0.149, 0.079, 0.267, 0.313, -0.093, 0.217, 0.601, -1.161, -5.000, -0.326, 0.375, -1.073, -5.000, 0.289, 0.434, -0.505, -0.350, 0.657, 0.593, 0.499, 0.275, -0.172, 0.232, -0.198, -5.000, -0.298, 0.121, -0.589, -0.037, 0.181, 0.183, -0.166, -0.187, 0.652, 0.678, 0.438, 0.168, 0.327, 0.903, -0.101, 0.184, 0.195, 0.487, 0.070, -0.484, 0.430, 0.262, -0.209, -0.185, 0.359, 0.478, 0.215, -0.169, 0.063, 0.470, -0.266, 0.245, -0.028, 0.225, -0.521, -0.514, -0.410, -0.192, -0.571, -0.596, 0.466, 0.463, 0.990, 0.264, -0.074, 0.442, -1.135, -5.000, -0.650, -0.426, -1.222, -5.000, -0.042, -0.265, -0.836, -0.258, -0.206, -0.155, -0.738, -0.869, -0.253, 0.420, -0.157, -5.000, -0.378, -0.044, -0.619, -0.534, -0.383, -0.214, -0.354, -0.652, 0.285, 0.251, -0.086, -0.374, -0.201, 0.154, -0.607, -0.279, -0.740, -0.145, -0.549, -1.102, -0.158, 0.011, -0.714, -0.639, 0.038, 0.007, -0.529, -0.659, -0.395, -0.413, -0.876, -0.529, -0.560, -0.819, -1.335, -1.288, -0.336, -0.375, -0.935, -1.063, -0.482, -0.392, -0.638, -0.697, -0.402, 0.026, -0.881, -5.000, -0.956, -0.559, -1.327, -5.000, -0.662, -0.357, -0.938, -0.791, -0.407, -0.393, -0.971, -0.761, -0.382, 0.078, -0.258, -5.000, -0.891, -0.474, -0.907, -0.396, -0.810, -0.716, -1.205, -0.903, -0.023, -0.086, -0.508, -0.680, -0.337, 0.197, -0.474, -0.279, -0.747, -0.074, -0.424, -0.717, -0.394, -0.126, -0.742, -0.745, -0.106, 0.372, -0.067, -0.478, -0.552, -0.240, -0.862, -0.746, -0.725, -0.476, -1.162, -1.030, -0.801, -0.956, -1.155, -1.086, -0.428, -0.381, -0.668, -0.539, -0.057, 0.451, -0.547, -5.000, -0.711, -0.019, -1.232, -5.000, 0.068, 0.447, -0.021, 0.017, 0.147, 0.497, 0.133, -0.166, 0.155, 0.559, 0.067, -5.000, -0.311, 0.280, -0.632, -0.153, -0.018, 0.357, -0.054, -0.346, 0.528, 0.619, 0.417, -0.149, 0.338, 0.627, -0.035, 0.398, -0.084, 0.361, -0.368, -0.491, 0.149, 0.239, 0.132, -0.185, 0.430, 0.448, 0.211, -0.041, 0.118, 0.474, -0.158, 0.202, -0.226, 0.108, -0.805, -0.559, 0.015, 0.288, 0.265, -0.013, 0.221, 0.456, 0.380, 0.068, 0.407, 0.959, -0.643, -5.000, -0.221, 0.676, -0.935, -5.000, 0.348, 0.546, -0.592, -0.294, 0.506, 0.760, 0.398, -0.011, 0.161, 0.721, 0.218, -5.000, -0.159, 0.599, -0.466, 0.152, 0.120, 0.420, -0.000, -0.244, 0.706, 0.703, 0.511, -0.321, 0.489, 0.884, 0.046, 0.444, -0.030, 0.283, -0.100, -0.303, 0.334, 0.300, -0.478, -0.416, 0.522, 0.397, 0.233, -0.163, 0.399, 0.797, -0.037, 0.491, 0.207, 0.119, -0.562, -0.400, 0.169, 0.309, -0.216, -0.276, 0.598, 0.700, 0.873, 0.119, -0.020, 0.363, -0.628, -5.000, -0.585, -0.217, -1.065, -5.000, 0.094, -0.045, -0.623, -0.268, -0.247, 0.079, -0.408, -0.621, -0.167, 0.256, -0.280, -5.000, -0.055, 0.246, -0.736, -0.255, -0.098, -0.237, -0.516, -0.458, 0.292, 0.537, 0.071, -0.271, 0.199, 0.701, -0.036, 0.023, -0.511, 0.266, -0.568, -0.639, 0.232, 0.170, -0.250, -0.163, 0.292, 0.284, -0.171, -0.330, -0.028, 0.251, -0.278, -0.035, -0.398, 0.059, -0.720, -0.650, 0.130, 0.225, -0.197, -0.227, 0.180, 0.121, -0.036, -0.509, -0.163, 0.230, -0.635, -5.000, -0.872, -0.322, -1.280, -5.000, -0.497, -0.196, -0.660, -0.732, -0.271, -0.121, -0.463, -0.509, -0.184, 0.280, -0.263, -5.000, -0.696, -0.331, -1.087, -0.595, -0.575, 0.092, -0.658, -0.766, 0.098, 0.148, -0.291, -0.464, -0.111, 0.391, -0.544, 0.014, -0.671, -0.242, -0.633, -0.964, -0.216, -0.167, -0.513, -0.624, -0.045, 0.095, -0.103, -0.406, -0.246, 0.254, -0.525, -0.114, -0.385, 0.008, -0.462, -0.706, -0.342, -0.127, -0.447, -0.475, -0.178, 0.113, 0.112, -0.381, 0.258, 0.703, -0.191, -5.000, -0.073, 0.541, -0.454, -5.000, 0.365, 0.630, -0.040, -0.024, 0.290, 0.546, 0.196, 0.024, 0.236, 0.726, 0.288, -5.000, 0.072, 0.595, -0.214, -0.046, 0.304, 0.466, 0.096, -0.100, 0.508, 0.703, 0.417, 0.046, 0.298, 0.672, -0.192, 0.241, 0.062, 0.447, -0.111, -0.399, 0.240, 0.416, -0.249, -0.150, 0.327, 0.424, 0.131, 0.005, 0.164, 0.637, -0.147, 0.053, -0.053, 0.170, -0.344, -0.372, 0.201, 0.615, 0.095, 0.056, 0.213, 0.448, 0.480, 0.079, 0.309, 0.711, -0.587, -5.000, -0.034, 0.556, -0.618, -5.000, 0.278, 0.541, -0.464, -0.189, 0.383, 0.553, 0.233, 0.080, 0.299, 0.641, 0.159, -5.000, 0.144, 0.633, -0.230, 0.099, 0.499, 0.598, 0.160, 0.127, 0.555, 0.742, 0.498, -0.011, 0.510, 0.983, 0.007, 0.547, 0.224, 0.487, -0.128, -0.293, 0.605, 0.558, -0.102, -0.020, 0.540, 0.637, 0.353, -0.049, 0.474, 0.836, 0.083, 0.475, 0.208, 0.413, -0.126, -0.231, 0.410, 0.577, 0.099, 0.040, 0.528, 0.726, 0.859, 0.277, 0.540, 1.039, -0.269, -5.000, -0.037, 0.343, -0.822, -5.000, 0.358, 0.582, -0.200, -0.080, 0.269, 0.561, -0.027, -0.032, 0.383, 0.861, 0.318, -5.000, 0.343, 0.850, -0.444, 0.026, 0.399, 0.662, 0.089, -0.030, 0.759, 1.087, 0.550, 0.060, 0.572, 1.041, 0.164, 0.499, 0.193, 0.595, 0.027, -0.405, 0.788, 0.994, 0.253, 0.379, 0.590, 0.723, 0.282, 0.017, 0.272, 0.507, -0.175, 0.177, -0.075, -0.020, -0.511, -0.521, 0.385, 0.609, 0.215, 0.023, 0.289, 0.242, -0.011, -0.254, -0.062, 0.376, -0.479, -5.000, -0.422, -0.082, -0.607, -5.000, -0.191, 0.102, -0.529, -0.190, -0.154, 0.061, -0.288, -0.261, 0.003, 0.449, -0.026, -5.000, -0.247, 0.014, -0.609, -0.241, -0.358, -0.124, -0.420, -0.536, 0.232, 0.384, -0.092, -0.093, -0.044, 0.518, -0.288, -0.103, -0.338, 0.086, -0.203, -0.668, -0.100, 0.129, -0.345, -0.413, 0.082, 0.259, 0.002, -0.372, -0.098, 0.332, -0.385, -0.143, -0.286, 0.248, -0.192, -0.567, -0.094, 0.161, -0.242, -0.337, -0.096, -0.000, -0.120, -0.277 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_30(struct _training *tptr) {
  struct _training tinf = {
    0.432, 11, 4.350, { 1.939, 0.169, 0.893 }, { 0.948, -3.197, -4.000 }, 0, 
    { 0.269, -1.033, -1.264, -2.223, -4.000, 0.699, -1.710, -4.000, -4.000, -0.056, -1.713, -4.000, -2.289, -1.229, -4.000, 0.185, -1.286, -1.939, -4.000, -1.980, -1.291, -0.558, 0.829, -1.010, 0.301, -0.618, 1.481, 1.970 }, 
    {{ -0.082, -0.729, -0.368, 0.535},{ 0.219, -0.422, -0.218, 0.153},{ 0.504, -0.974, -0.644, 0.164},{ 0.416, -0.967, -0.358, 0.169},{ 0.399, -0.789, -0.267, 0.098},{ 0.358, -0.759, -0.199, 0.106},{ 0.390, -0.756, -0.184, 0.052},{ 0.389, -0.504, -0.306, 0.026},{ 0.344, -0.529, -0.327, 0.107},{ 0.273, -0.447, -0.325, 0.158},{ 0.251, -0.377, -0.348, 0.162},{ 0.199, -0.325, -0.380, 0.208},{ 0.244, -0.378, -0.405, 0.195},{ 0.202, -0.277, -0.330, 0.160},{ 0.187, -0.289, -0.380, 0.203},{ 0.162, -0.264, -0.360, 0.208},{ 0.214, -0.256, -0.360, 0.151},{ 0.168, -0.271, -0.399, 0.221},{ 0.163, -0.314, -0.230, 0.169},{ 0.162, -0.306, -0.219, 0.160},{ 0.178, -0.185, -0.395, 0.167},{ 0.183, -0.332, -0.251, 0.168},{ 0.167, -0.202, -0.218, 0.101},{ 0.142, -0.179, -0.316, 0.164},{ 0.180, -0.191, -0.230, 0.087},{ 0.142, -0.139, -0.316, 0.142},{ 0.123, -0.144, -0.221, 0.114},{ 0.144, -0.109, -0.287, 0.108},{ 0.158, -0.048, -0.266, 0.041},{ 0.133, -0.087, -0.230, 0.075},{ 0.159, -0.131, -0.241, 0.080},{ 0.094, -0.025, -0.262, 0.091} }, 
    {{{ -0.856, -4.000, -4.000, -0.046, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -1.186, -4.000, -4.000, 0.223, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { 0.342, -4.000, -4.000, 1.919, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -1.042, -4.000, -4.000, 0.743, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -0.368, -4.000, -4.000, 0.293, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -1.009, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { 0.839, -4.000, -4.000, 2.528, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -0.186, -4.000, -4.000, 1.243, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ 1.436, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -0.740, -4.000, -4.000, -0.156, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 1.010, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 1.855, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { 0.087, -4.000, -4.000, 0.975, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -0.946, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 1.743, -4.000, -4.000, 1.229, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { 2.038, -4.000, -4.000, 2.060, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -1.215, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 1.461, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, 1.401, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -0.681, -4.000, -4.000, 0.018, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 0.674, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, 2.794, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, 2.092, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, 3.043, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, 1.546, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}} }, 
    -2.021, { 0.336, 0.619, 0.131, -5.000, -0.495, 0.456, -0.464, -5.000, -0.182, 0.240, -0.693, -0.291, 0.071, 0.677, 0.097, 0.233, 0.472, 0.816, 0.475, -5.000, -0.780, 0.207, -0.283, 0.121, -0.146, 0.151, -0.054, -0.162, 0.639, 0.867, 0.938, 0.531, 0.226, 0.676, -0.105, 0.241, -0.051, 0.367, 0.407, -0.521, 0.497, 0.898, 0.305, -0.045, 0.503, 0.363, 0.209, 0.167, 0.421, 0.787, 0.153, 0.539, 0.238, 0.790, 0.678, -0.329, 0.527, 1.096, 0.773, 0.563, 0.457, 0.484, 0.454, 0.407, 0.779, 0.949, 0.242, -5.000, -0.095, 0.718, -0.406, -5.000, 0.433, 0.675, -0.543, -0.192, 0.693, 1.062, 0.549, 0.565, 0.470, 0.798, 0.754, -5.000, -0.302, 0.175, 0.119, 0.475, 0.265, 0.603, 0.498, 0.352, 0.665, 0.807, 1.006, 0.799, 0.687, 1.083, 0.383, 0.661, 0.481, 0.863, 0.977, 0.027, 0.612, 1.057, 0.729, 0.121, 0.811, 0.592, 0.862, 0.588, 0.713, 0.930, 0.295, 0.689, 0.430, 0.785, 0.972, -0.079, 0.026, 0.529, 0.194, -0.046, 0.630, 0.434, 0.784, 0.599, 0.277, 0.643, 0.008, -5.000, -0.589, 0.505, -0.613, -5.000, 0.307, 0.705, -0.123, -0.001, -0.062, 0.407, -0.572, -0.118, 0.085, 0.478, 0.105, -5.000, -0.706, -0.067, -0.650, -0.488, -0.244, 0.180, 0.082, -0.030, 0.288, 0.252, 0.415, 0.338, -0.117, 0.242, -0.544, -0.510, -0.687, -0.566, -0.016, -1.143, 0.081, 0.342, -0.120, -0.631, -0.256, -0.379, -0.429, -0.376, 0.006, 0.054, -0.541, -0.045, -0.536, -0.167, -0.025, -0.928, 0.211, 0.362, 0.140, -0.286, -0.170, -0.418, -0.393, -0.450, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.504, -0.448, -0.848, -5.000, -1.237, -0.681, -1.267, -5.000, -0.900, -0.586, -0.984, -1.000, -0.775, -0.206, -0.369, -0.291, -0.671, -0.162, -0.502, -5.000, -1.266, -0.978, -1.168, -0.704, -1.447, -0.692, -0.882, -1.223, 0.197, -0.140, 0.066, -0.081, -0.696, -0.374, -0.947, -0.751, -1.059, -0.679, -0.606, -1.511, -0.973, -0.531, -1.090, -1.228, -0.590, -0.496, -0.564, -0.593, -0.556, -0.487, -0.982, -0.586, -0.950, -0.847, -0.599, -1.309, 0.078, 0.643, 0.030, -0.312, -0.324, -0.009, -0.064, -0.353, 0.766, 0.920, 0.343, -5.000, -0.132, 0.830, -0.454, -5.000, 0.349, 0.305, -0.766, -0.619, 0.612, 0.983, 0.814, 0.823, 0.568, 0.842, 0.842, -5.000, -0.275, 0.439, 0.231, 0.749, 0.351, 0.372, 0.595, 0.172, 0.832, 0.785, 1.011, 0.763, 0.563, 0.858, 0.040, 0.173, 0.222, 0.526, 0.605, -0.389, 0.375, 0.748, 0.171, -0.275, 0.621, 0.399, 0.551, 0.268, 0.356, 0.500, 0.061, 0.297, 0.102, 0.593, 0.554, -0.478, -0.963, -0.741, -1.010, -1.235, -0.050, -0.294, 0.261, 0.130, -0.165, 0.017, -0.614, -5.000, -1.285, -0.333, -1.077, -5.000, -0.675, -0.270, -0.702, -0.915, -0.848, -0.664, -1.038, -0.999, -0.635, -0.025, -0.203, -5.000, -1.174, -0.612, -1.096, -1.220, -0.914, -0.556, -0.925, -1.303, -0.327, -0.320, -0.212, -0.216, -0.479, -0.375, -0.863, -1.109, -1.002, -0.987, -0.577, -1.428, -0.406, -0.184, -0.480, -0.906, -0.616, -0.706, -0.741, -0.631, -0.807, -0.948, -1.062, -1.189, -1.509, -1.116, -0.884, -1.635, -1.325, -0.819, -0.928, -1.355, -0.817, -1.007, -0.927, -0.935, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.195, 0.376, -0.373, -5.000, -0.928, 0.208, -1.266, -5.000, -0.258, -0.221, -1.271, -0.993, -0.188, 0.180, -0.403, -0.178, 0.169, 0.483, 0.261, -5.000, -0.890, -0.109, -0.763, -0.015, -0.284, -0.010, -0.169, -0.566, 0.247, 0.367, 0.712, 0.289, -0.057, 0.169, -0.584, -0.212, -0.493, -0.261, -0.139, -0.963, -0.320, 0.002, -0.396, -0.866, 0.094, -0.014, 0.047, -0.226, 0.055, 0.300, -0.366, 0.311, -0.140, 0.563, 0.191, -0.649, 0.063, 0.328, 0.050, -0.307, 0.152, 0.188, -0.096, 0.159, 0.481, 0.657, -0.162, -5.000, -0.596, 0.462, -1.258, -5.000, -0.195, -0.008, -1.234, -1.111, 0.266, 0.506, -0.030, 0.097, 0.251, 0.666, 0.522, -5.000, -0.538, 0.220, -0.555, -0.049, 0.050, 0.187, -0.126, -0.373, 0.334, 0.564, 0.931, 0.267, -0.048, 0.355, -0.661, -0.402, -0.481, 0.004, -0.374, -1.028, -0.153, 0.363, -0.241, -0.745, 0.374, -0.010, 0.366, -0.053, 0.630, 0.803, 0.046, 0.666, 0.221, 0.792, 0.654, -0.369, 0.081, 0.408, -0.242, -0.469, 0.431, 0.059, 0.095, 0.149, -0.430, -0.313, -0.757, -5.000, -1.253, -0.410, -1.262, -5.000, -0.842, -0.967, -1.505, -1.163, -0.911, -0.744, -1.482, -0.919, -0.878, -0.537, -0.726, -5.000, -1.704, -1.008, -1.800, -1.461, -1.062, -0.937, -1.458, -1.136, -0.781, -0.895, -0.881, -0.740, -0.692, 0.035, -1.150, -1.135, -1.065, -0.776, -0.860, -1.511, -0.389, -0.474, -0.767, -0.877, -0.788, -0.996, -1.032, -0.541, -0.257, -0.030, -0.931, -0.644, -1.163, -0.373, -0.660, -1.097, -0.282, -0.199, -0.935, -0.740, -0.341, -0.761, -0.843, -0.758, -0.272, -0.128, -0.835, -5.000, -1.678, -0.779, -1.986, -5.000, -0.978, -0.841, -1.347, -1.327, -0.869, -0.480, -1.122, -0.905, -0.420, -0.272, -0.291, -5.000, -1.395, -0.944, -1.601, -0.866, -0.970, -0.784, -0.873, -0.996, -0.255, -0.413, -0.374, -0.261, -0.302, -0.127, -1.198, -0.547, -0.837, -0.578, -0.827, -1.533, -0.210, -0.121, -0.390, -0.905, -0.157, -0.369, -0.338, -0.274, -0.346, -0.132, -1.009, -0.396, -0.661, 0.072, -0.608, -1.235, -0.300, -0.097, -0.494, -0.805, -0.368, -0.446, -0.585, -0.639, 0.244, 0.535, -0.055, -5.000, -0.801, -0.027, -0.672, -5.000, -0.528, -0.444, -1.067, -1.071, -0.512, -0.051, -0.547, -0.177, 0.133, 0.610, 0.139, -5.000, -0.923, -0.213, -0.552, -0.363, -0.465, -0.253, -0.556, -1.010, -0.090, 0.192, 0.334, -0.025, -0.092, 0.319, -0.474, -0.355, -0.463, -0.036, -0.169, -0.912, -0.263, 0.191, -0.551, -0.712, -0.169, -0.007, -0.512, -0.361, 0.078, 0.427, -0.261, 0.082, -0.294, 0.215, -0.038, -0.660, -0.268, 0.029, -0.116, -0.361, -0.095, -0.029, -0.236, -0.134, 0.616, 0.816, 0.285, -5.000, -0.357, 0.668, -0.369, -5.000, 0.282, 0.412, -0.813, -0.398, 0.116, 0.725, 0.303, 0.298, 0.268, 0.668, 0.556, -5.000, -0.365, 0.572, 0.021, -0.009, 0.177, 0.427, 0.225, -0.054, 0.403, 0.684, 0.925, 0.430, 0.236, 0.680, -0.143, -0.050, 0.000, 0.526, 0.039, -0.712, 0.246, 0.671, -0.095, -0.257, 0.384, 0.367, 0.178, 0.008, 0.705, 0.988, 0.369, 0.801, 0.476, 0.893, 0.848, -0.088, 0.432, 0.726, 0.227, 0.071, 0.537, 0.460, 0.226, 0.411, 0.363, 0.411, -0.202, -5.000, -0.782, 0.135, -0.808, -5.000, -0.149, 0.079, -0.791, -0.788, -0.325, -0.044, -0.731, -0.339, -0.475, -0.054, -0.451, -5.000, -1.168, -0.449, -1.194, -1.098, -0.367, -0.282, -0.445, -0.707, -0.176, -0.344, -0.231, -0.079, -0.206, 0.026, -1.171, -0.957, -0.718, -1.079, -0.637, -1.410, -0.147, -0.148, -0.607, -0.850, -0.395, -0.810, -1.172, -0.669, -0.042, -0.100, -0.917, -0.287, -0.582, -0.494, -0.579, -1.073, -0.477, -0.107, -0.636, -0.799, -0.266, -0.787, -1.027, -0.472, 0.222, 0.652, 0.207, -5.000, -0.747, 0.341, -0.655, -5.000, 0.056, 0.271, -0.485, -0.509, -0.202, 0.199, -0.426, -0.192, 0.125, 0.479, 0.274, -5.000, -0.970, -0.095, -0.640, -0.489, -0.060, 0.081, -0.365, -0.378, 0.308, 0.350, 0.152, 0.117, -0.181, 0.285, -0.530, -0.427, -0.667, -0.221, -0.335, -1.133, -0.145, 0.096, -0.607, -0.743, -0.222, -0.299, -0.489, -0.434, 0.020, 0.498, -0.289, -0.085, -0.445, -0.028, 0.031, -0.854, -0.024, 0.160, -0.295, -0.471, -0.146, -0.211, -0.308, -0.321, 0.218, 0.667, -0.005, -5.000, -0.799, 0.367, -0.742, -5.000, -0.325, -0.005, -1.083, -0.578, -0.258, 0.207, -0.361, -0.044, 0.106, 0.676, 0.164, -5.000, -1.050, -0.236, -0.680, -0.535, -0.619, -0.201, -0.603, -0.583, 0.278, 0.446, 0.625, 0.295, 0.240, 0.705, -0.378, 0.158, -0.069, 0.318, 0.324, -0.679, 0.544, 0.836, -0.010, -0.056, 0.549, 0.441, 0.124, 0.218, 0.513, 0.818, -0.060, 0.575, 0.288, 0.901, 0.673, -0.088, 0.718, 1.203, 0.876, 0.767, 0.728, 0.686, 0.580, 0.661, 0.907, 1.114, 0.569, -5.000, 0.060, 0.840, 0.025, -5.000, 0.426, 0.638, -0.544, -0.140, 0.690, 0.964, 0.573, 0.538, 0.406, 0.628, 0.525, -5.000, -0.413, 0.080, -0.149, -0.181, -0.009, 0.281, 0.111, -0.163, 0.456, 0.697, 0.908, 0.553, 0.707, 1.063, 0.315, 0.663, 0.482, 0.816, 0.849, -0.115, 0.668, 1.096, 0.701, 0.179, 0.713, 0.549, 0.822, 0.528, 0.780, 1.040, 0.440, 0.730, 0.622, 1.031, 1.065, 0.282, 0.350, 0.773, 0.241, 0.169, 0.727, 0.453, 0.697, 0.712, 0.321, 0.804, 0.244, -5.000, -0.615, 0.751, -0.404, -5.000, 0.365, 0.897, -0.074, 0.007, 0.124, 0.631, -0.484, 0.187, 0.204, 0.712, 0.347, -5.000, -0.450, 0.323, -0.465, -0.379, 0.023, 0.569, 0.278, 0.029, 0.447, 0.522, 0.325, 0.488, 0.403, 0.824, 0.083, 0.062, 0.138, 0.225, 0.663, -0.200, 0.366, 0.733, 0.078, -0.293, 0.149, 0.157, 0.139, 0.162, 0.418, 0.703, 0.108, 0.552, 0.059, 0.437, 0.727, -0.233, 0.624, 0.904, 0.523, 0.165, 0.422, 0.340, 0.175, -0.019, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.808, -0.487, -0.976, -5.000, -1.516, -0.792, -1.188, -5.000, -1.136, -0.838, -1.266, -1.538, -0.851, -0.565, -0.624, -0.500, -1.058, -0.412, -0.604, -5.000, -1.247, -0.891, -1.076, -1.209, -1.374, -1.108, -1.348, -1.268, -0.385, -0.375, -0.465, -0.496, -0.854, -0.281, -1.073, -1.026, -1.156, -0.685, -0.555, -1.376, -1.156, -0.726, -1.333, -1.245, -0.821, -0.590, -0.816, -0.866, -0.584, -0.471, -0.808, -0.728, -0.982, -0.620, -0.523, -1.364, -0.126, -0.198, -0.027, -0.307, -0.829, -0.423, -0.548, -0.632, 0.614, 0.749, 0.121, -5.000, -0.354, 0.521, -0.566, -5.000, -0.131, -0.043, -0.897, -0.910, 0.302, 0.749, 0.523, 0.622, 0.250, 0.656, 0.572, -5.000, -0.671, 0.115, -0.307, 0.039, -0.091, 0.040, -0.000, -0.290, 0.467, 0.411, 0.468, 0.234, -0.125, 0.368, -0.511, -0.396, -0.293, 0.010, 0.011, -0.756, -0.238, 0.212, -0.335, -0.813, 0.027, 0.052, 0.031, -0.157, 0.008, 0.231, -0.384, -0.078, -0.273, 0.210, 0.093, -0.739, -1.166, -0.876, -1.191, -1.305, -0.530, -0.623, -0.413, -0.479, -0.290, 0.268, -0.278, -5.000, -1.330, -0.256, -0.892, -5.000, -0.687, -0.261, -1.005, -1.124, -0.776, -0.430, -1.051, -0.936, -0.362, 0.099, -0.176, -5.000, -1.229, -0.393, -0.902, -1.049, -0.590, -0.317, -0.671, -0.944, -0.308, -0.381, -0.239, -0.166, -0.254, 0.287, -0.734, -0.466, -0.580, -0.562, -0.020, -1.066, -0.130, 0.188, -0.263, -0.812, -0.478, -0.491, -0.757, -0.599, -0.424, -0.267, -0.710, -0.316, -0.725, -0.672, -0.313, -1.217, -0.990, -0.396, -0.766, -1.608, -0.680, -0.796, -0.795, -0.875, 0.225, 0.386, -0.207, -5.000, -1.192, 0.282, -1.282, -5.000, -0.148, 0.197, -0.520, -0.386, -0.636, 0.110, -0.614, -0.256, -0.332, 0.224, -0.206, -5.000, -1.587, -0.599, -1.362, -0.339, -0.492, -0.407, -0.305, -0.287, -0.068, -0.177, -0.294, 0.001, -0.009, 0.746, -0.728, 0.060, -0.152, 0.166, 0.007, -1.108, 0.281, 0.381, 0.276, -0.308, -0.224, -0.204, -0.248, 0.051, -0.183, 0.196, -0.681, -0.050, -0.309, 0.140, 0.202, -1.019, 0.026, 0.131, -0.027, -0.492, -0.305, -0.438, -0.487, -0.315, 0.072, 0.351, -0.544, -5.000, -1.033, 0.144, -1.016, -5.000, -0.405, -0.162, -1.354, -1.508, -0.411, 0.129, -0.694, -0.347, -0.187, 0.445, -0.046, -5.000, -1.095, -0.339, -0.877, -0.573, -0.394, -0.151, -0.465, -0.958, -0.035, 0.310, 0.273, -0.054, -0.112, 0.099, -0.490, -0.261, -0.692, -0.333, -0.123, -1.114, -0.316, -0.012, -0.516, -0.870, 0.079, -0.230, -0.175, -0.403, 0.187, 0.532, -0.143, 0.435, -0.099, 0.557, 0.367, -0.687, 0.057, 0.491, 0.067, -0.440, 0.041, 0.116, -0.135, 0.035, 0.442, 0.687, -0.125, -5.000, -0.734, 0.480, -0.780, -5.000, -0.172, -0.032, -0.967, -1.321, 0.078, 0.449, 0.268, -0.201, 0.205, 0.694, 0.382, -5.000, -0.748, 0.103, -0.244, -0.167, -0.134, 0.167, -0.154, -0.620, 0.065, 0.390, 0.571, 0.158, -0.285, -0.084, -0.748, -0.751, -0.666, -0.108, -0.498, -1.284, -0.325, 0.098, -0.783, -0.825, -0.020, -0.133, -0.002, -0.405, 0.589, 0.743, 0.054, 0.468, 0.195, 0.577, 0.616, -0.358, 0.099, 0.447, -0.386, -0.355, 0.284, -0.023, 0.058, 0.059, 0.254, 0.461, -0.029, -5.000, -1.259, 0.291, -1.064, -5.000, 0.043, -0.026, -1.210, -0.712, -0.395, 0.044, -0.922, -0.577, -0.222, 0.142, -0.085, -5.000, -1.306, -0.140, -1.007, -0.601, -0.301, -0.154, -0.862, -0.523, -0.140, -0.196, -0.301, -0.197, 0.306, 0.698, -0.366, -0.618, -0.426, 0.175, 0.009, -1.105, -0.025, 0.031, -0.762, -0.755, -0.207, -0.435, -0.576, -0.045, 0.540, 0.962, -0.031, 0.279, -0.201, 0.555, 0.423, -0.497, 0.615, 0.568, -0.412, -0.276, 0.349, 0.051, -0.092, -0.414, -0.026, 0.338, -0.362, -5.000, -1.546, -0.257, -1.567, -5.000, -0.788, -0.462, -1.313, -0.929, -0.907, -0.192, -0.863, -0.742, -0.026, 0.144, 0.128, -5.000, -1.301, -0.633, -0.910, -0.338, -0.791, -0.300, -0.762, -0.921, 0.025, 0.079, -0.012, -0.150, -0.250, 0.233, -0.607, -0.314, -0.628, -0.109, -0.301, -1.290, -0.284, 0.092, -0.440, -0.814, -0.143, -0.029, -0.046, -0.122, -0.051, 0.175, -0.403, -0.016, -0.487, 0.500, 0.302, -0.857, -0.135, 0.292, -0.063, -0.661, -0.098, 0.086, -0.009, -0.522, 0.328, 0.812, 0.153, -5.000, -0.633, 0.530, -0.415, -5.000, -0.178, 0.136, -0.974, -0.754, -0.476, 0.325, -0.285, 0.022, 0.286, 0.808, 0.469, -5.000, -0.976, 0.050, -0.255, -0.076, 0.003, 0.127, 0.071, -0.358, 0.322, 0.581, 0.710, 0.323, 0.353, 0.680, 0.245, 0.293, 0.006, 0.412, 0.550, -0.438, 0.380, 0.772, -0.189, -0.199, 0.435, 0.322, -0.452, 0.098, 0.396, 0.849, 0.052, 0.537, 0.134, 0.879, 0.495, -0.339, 0.084, 0.714, 0.250, 0.007, 0.234, 0.113, -0.407, 0.313, 0.739, 0.986, 0.436, -5.000, -0.284, 0.828, -0.403, -5.000, 0.292, 0.351, -1.260, -0.853, 0.166, 0.847, 0.580, 0.349, 0.358, 0.866, 0.643, -5.000, -0.456, 0.450, 0.085, 0.108, 0.183, 0.240, 0.046, -0.185, 0.359, 0.590, 0.933, 0.504, 0.113, 0.550, -0.664, -0.241, -0.241, 0.337, -0.158, -1.106, 0.017, 0.606, -0.536, -0.582, 0.275, 0.144, -0.158, -0.342, 0.846, 1.093, 0.350, 0.879, 0.609, 0.942, 0.912, 0.211, 0.445, 0.770, 0.061, -0.073, 0.656, 0.370, 0.016, 0.373, 0.921, 1.156, 0.481, -5.000, -0.245, 1.063, 0.139, -5.000, 0.776, 0.918, -0.111, 0.279, 0.153, 0.732, -0.087, 0.335, 0.339, 0.815, 0.253, -5.000, -0.553, 0.505, -0.170, 0.056, 0.376, 0.618, 0.327, 0.327, 0.523, 0.733, 0.534, 0.584, 0.830, 1.131, 0.063, 0.317, 0.413, 0.532, 0.722, -0.062, 0.618, 0.917, 0.025, -0.138, 0.512, 0.198, -0.202, 0.384, 0.805, 1.081, 0.348, 0.858, 0.331, 0.762, 0.885, -0.069, 0.394, 0.743, 0.130, 0.129, 0.555, 0.252, -0.176, 0.231, 0.465, 1.002, 0.537, -5.000, -0.709, 0.705, -0.240, -5.000, 0.326, 0.603, -0.397, -0.076, -0.117, 0.598, 0.044, 0.086, 0.481, 0.938, 0.696, -5.000, -0.773, 0.423, -0.108, 0.024, 0.173, 0.529, 0.329, -0.003, 0.610, 0.647, 0.451, 0.357, 0.117, 0.791, -0.214, -0.220, -0.238, 0.224, 0.250, -1.128, 0.090, 0.514, -0.101, -0.612, -0.006, -0.047, -0.283, -0.176, 0.157, 0.781, 0.003, 0.197, -0.334, 0.450, 0.485, -0.710, 0.170, 0.601, 0.089, -0.220, -0.103, -0.022, -0.244, -0.300, 0.221, 0.557, -0.047, -5.000, -0.703, 0.209, -0.654, -5.000, -0.407, -0.057, -1.033, -0.652, -0.285, 0.472, -0.112, -0.004, 0.253, 0.682, 0.336, -5.000, -1.182, -0.532, -0.720, -0.180, -0.548, -0.480, -0.392, -0.475, 0.430, 0.494, 0.819, 0.365, 0.146, 0.524, -0.035, 0.313, -0.299, 0.152, 0.325, -0.835, 0.275, 0.715, -0.089, -0.335, 0.542, 0.509, 0.405, 0.263, 0.314, 0.495, -0.113, 0.509, 0.002, 0.661, 0.546, -0.419, 0.474, 1.021, 0.735, 0.459, 0.463, 0.355, 0.422, 0.341, 0.878, 1.031, 0.319, -5.000, 0.037, 0.893, -0.283, -5.000, 0.465, 0.562, -0.831, -0.226, 0.799, 1.222, 0.773, 0.565, 0.375, 0.690, 0.571, -5.000, -0.656, 0.033, -0.233, 0.119, -0.077, 0.154, 0.175, -0.041, 0.699, 0.869, 1.037, 0.761, 0.498, 0.848, 0.285, 0.518, 0.411, 0.857, 0.910, -0.237, 0.529, 1.010, 0.559, 0.131, 0.885, 0.778, 1.075, 0.775, 0.660, 0.783, 0.199, 0.858, 0.396, 0.860, 0.998, 0.069, 0.009, 0.445, -0.013, -0.084, 0.658, 0.485, 0.758, 0.704, 0.000, 0.482, -0.155, -5.000, -0.847, 0.495, -0.682, -5.000, -0.165, 0.169, -0.663, -0.332, -0.341, 0.084, -0.906, -0.448, -0.342, 0.192, -0.216, -5.000, -1.052, -0.229, -1.086, -1.000, -0.334, -0.080, -0.474, -0.540, -0.003, -0.055, -0.068, 0.030, -0.320, 0.183, -0.410, -0.541, -0.438, -0.217, -0.062, -0.734, -0.089, 0.218, -0.416, -0.693, -0.215, -0.190, -0.464, -0.303, -0.265, 0.015, -0.397, -0.207, -0.699, -0.052, -0.150, -0.715, -0.082, 0.154, -0.293, -0.664, -0.217, -0.168, -0.515, -0.646, 0.270, 0.332, -0.182, -5.000, -0.925, 0.146, -0.810, -5.000, -0.355, -0.086, -0.789, -0.451, -0.510, 0.204, -0.373, -0.454, -0.305, 0.122, -0.153, -5.000, -1.337, -0.598, -1.043, -0.781, -0.812, -0.637, -0.830, -0.739, -0.025, -0.128, -0.171, -0.243, 0.398, 0.529, -0.314, 0.033, -0.376, -0.066, 0.210, -0.779, 0.056, 0.427, 0.103, -0.294, 0.227, 0.172, 0.148, 0.038, 0.185, 0.423, -0.390, 0.219, -0.200, 0.272, 0.343, -0.594, 0.451, 0.653, 0.329, -0.042, -0.077, -0.010, -0.141, -0.436, -0.268, 0.054, -0.303, -5.000, -1.086, -0.040, -0.829, -5.000, -0.613, -0.126, -0.684, -0.967, -0.543, 0.180, 0.090, 0.223, -0.151, 0.210, -0.056, -5.000, -1.132, -0.668, -0.833, -0.270, -0.904, -0.441, -0.543, -0.935, 0.609, 0.245, 0.474, 0.181, -0.103, 0.263, -0.502, -0.343, -0.626, -0.095, -0.044, -0.896, -0.160, 0.122, -0.458, -0.971, 0.176, 0.278, -0.014, -0.170, -0.344, -0.053, -0.523, 0.006, -0.713, 0.144, 0.006, -0.720, -0.464, 0.403, -0.064, -0.352, -0.258, -0.075, -0.029, -0.302, 0.496, 0.823, 0.109, -5.000, -0.545, 0.547, -0.456, -5.000, -0.005, 0.186, -0.750, -0.811, 0.382, 0.980, 1.023, 0.731, 0.001, 0.510, 0.284, -5.000, -0.819, 0.012, -0.212, -0.004, -0.300, 0.131, 0.251, 0.025, 0.350, 0.616, 0.683, 0.533, 0.180, 0.584, -0.077, -0.168, 0.001, 0.357, 0.398, -0.446, -0.037, 0.509, 0.009, -0.351, 0.366, 0.224, 0.137, 0.127, 0.173, 0.420, 0.121, 0.376, -0.023, 0.490, 0.480, -0.257, -0.954, -0.703, -1.151, -1.121, -0.121, -0.079, 0.194, 0.106, 0.348, 0.848, 0.249, -5.000, -0.889, 0.809, -0.471, -5.000, 0.252, 0.528, -0.020, -0.231, -0.039, 0.448, -0.085, -0.201, -0.053, 0.806, 0.423, -5.000, -0.804, 0.152, -0.700, -0.172, -0.279, 0.362, 0.098, -0.072, 0.333, 0.490, 0.415, 0.367, 0.271, 0.812, -0.046, 0.043, -0.105, 0.010, 0.389, -0.584, 0.472, 0.811, 0.232, -0.118, 0.261, 0.085, 0.017, 0.118, 0.094, 0.352, -0.093, 0.247, -0.238, -0.170, 0.457, -0.686, 0.062, 0.245, -0.181, -0.439, 0.203, -0.220, -0.006, -0.332, -0.613, -0.562, -0.855, -5.000, -1.527, -0.731, -1.469, -5.000, -1.339, -0.694, -1.203, -1.155, -1.234, -0.488, -0.890, -0.802, -0.827, -0.360, -0.472, -5.000, -1.632, -0.756, -1.230, -0.996, -0.992, -0.788, -1.260, -1.144, -0.443, -0.482, -0.238, -0.364, -0.734, -0.280, -0.789, -0.858, -1.103, -0.731, -0.905, -1.353, -0.880, -0.369, -0.825, -1.130, -0.563, -0.408, -0.363, -0.665, -0.766, -0.433, -0.938, -0.607, -1.131, -0.419, -0.453, -1.189, -0.562, -0.194, -0.657, -0.814, -0.528, -0.654, -0.496, -0.849, 0.345, 0.537, 0.029, -5.000, -0.731, 0.555, -0.613, -5.000, -0.142, 0.227, -0.756, -0.624, -0.022, 0.464, 0.056, 0.011, 0.433, 0.738, 0.557, -5.000, -0.772, 0.174, -0.473, 0.430, -0.137, 0.080, -0.112, -0.581, 0.520, 0.695, 0.961, 0.413, 0.013, 0.350, -0.074, 0.051, -0.556, -0.048, 0.177, -0.709, -0.029, 0.357, -0.075, -0.536, 0.272, 0.225, 0.129, -0.104, 0.099, 0.413, -0.034, 0.545, -0.099, 0.611, 0.464, -0.478, 0.343, 0.703, 0.260, 0.178, 0.300, 0.307, 0.167, 0.064, 0.605, 0.943, 0.393, -5.000, -0.374, 0.901, -0.570, -5.000, 0.404, 0.589, -0.695, -0.520, 0.543, 0.883, 0.826, 0.207, 0.657, 1.022, 0.851, -5.000, -0.109, 0.681, 0.142, 0.599, 0.424, 0.661, 0.233, 0.184, 0.589, 0.951, 1.159, 0.638, 0.069, 0.650, -0.096, -0.095, -0.103, 0.438, 0.516, -0.326, 0.104, 0.652, 0.051, -0.270, 0.451, 0.276, 0.450, 0.021, 0.709, 1.014, 0.543, 0.880, 0.414, 1.110, 0.973, 0.053, 0.482, 0.978, 0.396, 0.135, 0.771, 0.611, 0.718, 0.584, 0.329, 0.573, 0.110, -5.000, -0.810, 0.051, -0.909, -5.000, -0.267, 0.015, -1.058, -0.481, -0.453, 0.043, -0.534, -0.119, -0.172, 0.337, 0.112, -5.000, -1.195, -0.384, -0.798, -0.468, -0.255, -0.269, -0.849, -0.666, -0.019, 0.239, 0.184, -0.054, 0.074, 0.578, -0.215, -0.406, -0.483, 0.301, 0.238, -0.764, 0.392, 0.209, -0.663, -0.398, -0.030, -0.031, -0.266, -0.017, 0.185, 0.563, 0.060, 0.148, -0.287, 0.431, 0.375, -0.626, 0.285, 0.412, -0.344, -0.223, 0.258, 0.304, 0.030, -0.353, -0.463, -0.081, -0.592, -5.000, -1.590, -0.558, -1.373, -5.000, -0.827, -0.495, -0.987, -0.873, -0.675, -0.120, -0.708, -0.495, -0.445, 0.161, -0.033, -5.000, -1.470, -0.642, -0.939, -0.530, -0.772, -0.266, -0.710, -0.727, -0.072, 0.068, -0.170, -0.178, -0.506, -0.000, -0.499, -0.540, -0.810, -0.294, -0.450, -1.022, -0.330, -0.033, -0.445, -0.709, -0.330, -0.313, -0.137, -0.405, -0.462, -0.074, -0.509, -0.317, -0.679, 0.140, -0.178, -0.980, -0.234, 0.139, -0.248, -0.678, -0.368, -0.201, -0.138, -0.519, 0.176, 0.737, -0.023, -5.000, -0.654, 0.455, -0.337, -5.000, -0.189, -0.058, -1.028, -0.778, -0.638, 0.274, 0.002, -0.177, 0.309, 0.859, 0.353, -5.000, -0.973, 0.232, -0.161, 0.197, 0.004, 0.056, -0.131, -0.677, 0.286, 0.735, 0.775, 0.262, 0.315, 0.675, 0.062, 0.108, -0.212, 0.346, 0.475, -0.452, 0.340, 0.754, -0.016, -0.211, 0.381, 0.423, -0.173, -0.138, 0.262, 0.752, 0.052, 0.421, 0.227, 0.883, 0.611, -0.278, 0.344, 0.766, 0.381, 0.179, 0.302, 0.401, 0.028, 0.204, 0.131, 0.505, -0.066, -5.000, -0.504, 0.499, -0.828, -5.000, 0.023, 0.187, -0.549, -0.932, -0.139, 0.549, 0.017, -0.041, 0.137, 0.622, 0.287, -5.000, -0.414, 0.500, -0.005, -0.012, -0.085, 0.205, 0.070, -0.208, 0.171, 0.538, 0.567, 0.171, -0.347, 0.043, -0.152, -0.268, -0.376, 0.258, -0.099, -0.631, -0.131, 0.417, -0.081, -0.461, 0.121, 0.117, 0.150, -0.191, 0.334, 0.626, 0.173, 0.451, 0.177, 0.677, 0.685, -0.165, 0.201, 0.589, 0.213, -0.018, 0.411, 0.354, 0.206, 0.240, 0.109, 0.675, 0.116, -5.000, -0.786, 0.664, -0.399, -5.000, 0.270, 0.493, -0.705, -0.195, -0.129, 0.442, -0.367, -0.101, -0.066, 0.413, 0.048, -5.000, -0.813, 0.337, -0.486, -0.517, -0.120, 0.186, -0.039, -0.126, 0.237, 0.542, 0.277, 0.164, 0.158, 0.552, -0.192, -0.203, -0.305, -0.122, 0.085, -0.655, 0.193, 0.458, -0.205, -0.320, -0.062, -0.102, -0.274, 0.002, -0.004, 0.419, -0.286, -0.056, -0.347, 0.118, 0.185, -0.606, -0.121, 0.414, -0.167, -0.385, -0.029, -0.018, -0.232, -0.368, 0.242, 0.597, -0.125, -5.000, -0.912, 0.546, -0.493, -5.000, 0.088, 0.269, -0.383, -0.327, -0.352, 0.368, -0.292, -0.303, 0.102, 0.607, 0.175, -5.000, -1.007, -0.085, -0.537, -0.114, -0.295, -0.039, -0.050, -0.209, 0.331, 0.462, 0.283, 0.107, 0.168, 0.577, -0.132, -0.193, -0.462, 0.027, 0.079, -0.921, -0.291, 0.106, -0.391, -0.785, -0.124, -0.112, -0.088, -0.182, 0.173, 0.462, -0.061, 0.108, -0.083, 0.393, 0.462, -0.610, 0.133, 0.310, 0.093, -0.391, -0.078, -0.003, -0.043, -0.332, 0.250, 0.562, -0.082, -5.000, -0.611, 0.311, -0.608, -5.000, -0.272, 0.034, -0.952, -0.503, -0.165, 0.406, -0.172, 0.151, 0.463, 0.809, 0.514, -5.000, -0.754, 0.032, -0.234, 0.197, -0.166, -0.026, 0.001, -0.180, 0.617, 0.661, 0.832, 0.603, 0.251, 0.684, 0.025, 0.427, -0.079, 0.387, 0.377, -0.547, 0.486, 0.841, 0.240, -0.121, 0.568, 0.569, 0.444, 0.393, 0.334, 0.656, -0.162, 0.510, 0.147, 0.698, 0.470, -0.317, 0.544, 0.932, 0.741, 0.429, 0.429, 0.429, 0.345, 0.422, 0.825, 0.968, 0.297, -5.000, -0.163, 0.826, -0.290, -5.000, 0.358, 0.404, -0.826, -0.454, 0.661, 1.160, 0.619, 0.770, 0.516, 0.792, 0.678, -5.000, -0.214, 0.297, 0.115, 0.455, 0.321, 0.467, 0.209, 0.212, 0.864, 0.963, 1.069, 0.923, 0.431, 0.833, 0.290, 0.477, 0.340, 0.745, 0.731, -0.052, 0.578, 1.009, 0.666, 0.137, 0.856, 0.780, 0.951, 0.710, 0.686, 0.803, 0.209, 0.878, 0.418, 0.829, 0.855, 0.001, 0.120, 0.556, -0.056, 0.012, 0.554, 0.369, 0.577, 0.635, 0.154, 0.558, -0.233, -5.000, -0.698, 0.578, -0.675, -5.000, -0.026, 0.288, -0.663, -0.426, -0.349, 0.151, -0.825, -0.345, -0.137, 0.356, -0.136, -5.000, -0.825, 0.028, -0.881, -0.638, -0.397, -0.025, -0.329, -0.332, 0.136, 0.120, -0.082, 0.081, -0.252, 0.271, -0.629, -0.703, -0.462, -0.352, -0.099, -0.870, 0.120, 0.317, -0.370, -0.611, -0.148, -0.306, -0.397, -0.271, 0.043, 0.409, -0.400, -0.011, -0.173, 0.020, 0.018, -0.586, 0.084, 0.434, -0.010, -0.345, 0.033, -0.178, -0.452, -0.302, 0.521, 0.646, 0.181, -5.000, -0.517, 0.465, -0.549, -5.000, -0.195, 0.022, -0.622, -0.521, -0.181, 0.424, -0.297, -0.132, 0.234, 0.546, 0.265, -5.000, -0.981, 0.029, -0.659, 0.027, -0.283, -0.157, -0.575, -0.276, 0.339, 0.266, 0.084, 0.160, 0.803, 1.030, 0.065, 0.322, 0.154, 0.413, 0.611, -0.279, 0.665, 0.973, 0.585, 0.068, 0.623, 0.571, 0.413, 0.372, 0.535, 0.798, 0.065, 0.499, 0.365, 0.691, 0.711, -0.243, 0.769, 1.040, 0.596, 0.388, 0.341, 0.322, 0.078, -0.025, -0.022, 0.201, -0.210, -5.000, -0.922, 0.094, -0.731, -5.000, -0.390, -0.046, -0.646, -0.697, -0.369, 0.244, -0.070, 0.170, -0.035, 0.381, 0.098, -5.000, -1.159, -0.299, -0.696, -0.105, -0.541, -0.295, -0.236, -0.544, 0.779, 0.243, 0.572, 0.329, 0.142, 0.588, -0.365, 0.072, -0.145, 0.269, 0.119, -0.621, 0.099, 0.169, -0.553, -0.817, 0.288, 0.304, 0.115, 0.011, -0.042, 0.209, -0.400, 0.122, -0.403, 0.257, 0.088, -0.784, 0.128, 0.548, 0.078, 0.017, 0.063, 0.304, 0.469, 0.072, 0.836, 1.070, 0.461, -5.000, -0.216, 0.900, -0.301, -5.000, 0.515, 0.561, -0.754, -0.567, 0.665, 1.233, 1.016, 0.902, 0.486, 0.825, 0.590, -5.000, -0.694, 0.052, 0.005, 0.197, 0.292, 0.445, 0.580, 0.264, 0.759, 0.868, 1.053, 0.783, 0.624, 0.961, 0.106, 0.257, 0.397, 0.776, 0.605, -0.169, 0.536, 1.017, 0.107, -0.051, 0.854, 0.637, 0.591, 0.564, 0.590, 0.795, 0.211, 0.807, 0.352, 0.890, 0.742, -0.082, -0.494, -0.055, -0.772, -0.677, 0.312, 0.164, 0.244, 0.481, 0.691, 1.081, 0.496, -5.000, -0.496, 1.035, -0.210, -5.000, 0.423, 0.821, 0.049, 0.032, 0.165, 0.761, -0.306, 0.141, 0.374, 0.926, 0.640, -5.000, -0.636, 0.607, -0.211, 0.219, 0.347, 0.702, 0.540, 0.283, 0.745, 0.845, 0.730, 0.628, 0.486, 0.993, -0.139, 0.088, 0.304, 0.435, 0.639, -0.516, 0.759, 0.990, 0.398, -0.002, 0.460, 0.190, 0.082, 0.349, 0.388, 0.610, -0.145, 0.432, 0.034, 0.309, 0.691, -0.395, 0.457, 0.561, 0.123, -0.268, 0.503, 0.187, 0.117, -0.136, -0.267, -0.004, -0.595, -5.000, -1.221, -0.297, -1.406, -5.000, -0.836, -0.299, -1.116, -0.761, -0.793, -0.315, -1.002, -0.575, -0.510, -0.004, -0.266, -5.000, -1.325, -0.510, -0.962, -0.547, -1.006, -0.483, -0.763, -0.694, -0.078, -0.135, -0.281, -0.141, -0.515, -0.242, -0.704, -0.784, -0.913, -0.521, -0.661, -1.138, -0.626, -0.192, -0.741, -0.961, -0.390, -0.281, -0.346, -0.437, -0.559, -0.283, -0.853, -0.383, -0.658, -0.202, -0.395, -0.982, -0.200, 0.078, -0.559, -0.649, -0.359, -0.379, -0.431, -0.597, 0.106, 0.339, -0.283, -5.000, -1.011, 0.190, -1.168, -5.000, -0.188, -0.011, -1.013, -0.843, -0.099, 0.443, -0.308, 0.025, 0.336, 0.746, 0.506, -5.000, -1.103, -0.110, -0.631, 0.209, 0.019, 0.176, -0.066, -0.300, 0.496, 0.769, 0.979, 0.596, 0.078, 0.226, -0.188, -0.136, -0.303, 0.095, 0.031, -0.776, 0.221, 0.560, -0.191, -0.263, 0.355, 0.346, 0.105, -0.044, 0.123, 0.462, -0.116, 0.466, -0.014, 0.745, 0.374, -0.461, 0.520, 0.783, 0.450, 0.174, 0.372, 0.351, 0.323, 0.221, 0.685, 1.014, 0.427, -5.000, -0.213, 0.854, -0.554, -5.000, 0.432, 0.574, -0.568, -0.397, 0.501, 0.930, 0.539, 0.454, 0.569, 1.090, 0.795, -5.000, -0.364, 0.494, -0.046, 0.385, 0.365, 0.555, 0.207, 0.224, 0.600, 0.913, 1.040, 0.679, 0.074, 0.580, -0.235, -0.042, -0.154, 0.361, 0.400, -0.524, 0.147, 0.725, -0.092, -0.392, 0.557, 0.403, 0.313, 0.121, 0.626, 1.021, 0.367, 0.725, 0.318, 0.936, 0.879, -0.186, 0.439, 0.842, 0.110, -0.038, 0.598, 0.425, 0.398, 0.358, 0.263, 0.532, -0.048, -5.000, -0.860, 0.326, -1.218, -5.000, -0.109, 0.032, -0.990, -0.671, -0.273, 0.345, -0.651, -0.140, -0.063, 0.347, -0.077, -5.000, -0.967, 0.043, -0.930, -0.289, -0.409, -0.212, -0.752, -0.500, 0.310, 0.222, 0.174, 0.231, 0.061, 0.646, -0.376, -0.459, -0.464, 0.236, 0.028, -1.009, 0.215, 0.343, -0.445, -0.626, 0.218, -0.218, -0.348, -0.021, 0.354, 0.827, -0.082, 0.255, -0.259, 0.721, 0.441, -0.464, 0.543, 0.601, -0.111, -0.117, 0.432, 0.246, 0.019, -0.280, -0.180, 0.064, -0.494, -5.000, -1.281, -0.117, -1.500, -5.000, -0.520, -0.312, -1.093, -0.888, -0.620, -0.061, -0.734, -0.490, -0.163, 0.313, 0.027, -5.000, -1.163, -0.621, -1.209, -0.728, -0.590, -0.375, -0.606, -0.533, 0.218, 0.155, -0.015, 0.054, -0.145, 0.415, -0.355, -0.130, -0.449, 0.143, -0.273, -0.968, -0.032, 0.262, -0.276, -0.550, 0.072, 0.214, 0.083, 0.008, -0.197, 0.141, -0.636, -0.153, -0.554, 0.393, -0.017, -0.829, -0.034, 0.339, -0.044, -0.324, -0.182, 0.002, -0.185, -0.370, 0.161, 0.602, -0.078, -5.000, -0.519, 0.242, -0.600, -5.000, -0.138, -0.136, -1.041, -0.766, -0.395, 0.279, -0.184, -0.029, 0.413, 0.927, 0.471, -5.000, -0.876, 0.018, -0.297, 0.171, 0.128, 0.254, -0.089, -0.480, 0.476, 0.813, 0.702, 0.427, 0.129, 0.495, -0.235, -0.132, -0.128, 0.353, 0.279, -0.548, 0.374, 0.726, -0.114, -0.196, 0.291, 0.449, -0.021, -0.071, 0.222, 0.652, -0.067, 0.170, -0.005, 0.613, 0.430, -0.566, 0.293, 0.750, 0.440, 0.152, 0.327, 0.433, 0.053, 0.087, 0.203, 0.454, -0.139, -5.000, -0.767, 0.381, -0.682, -5.000, -0.168, 0.039, -1.035, -1.047, -0.068, 0.486, 0.223, -0.007, 0.197, 0.719, 0.313, -5.000, -0.522, 0.395, -0.249, -0.108, 0.082, 0.277, -0.091, -0.215, 0.250, 0.659, 0.595, 0.377, -0.388, 0.133, -0.480, -0.445, -0.384, 0.158, -0.022, -0.782, -0.047, 0.403, -0.274, -0.411, 0.207, 0.336, 0.082, -0.205, 0.302, 0.517, -0.056, 0.279, 0.024, 0.577, 0.476, -0.514, 0.186, 0.500, -0.065, -0.226, 0.289, 0.278, 0.024, 0.093, 0.304, 0.743, -0.046, -5.000, -0.627, 0.737, -0.580, -5.000, 0.190, 0.378, -0.674, -0.391, -0.154, 0.384, -0.579, -0.213, -0.181, 0.354, -0.071, -5.000, -0.735, 0.159, -0.685, -0.545, -0.006, 0.161, -0.190, -0.274, 0.217, 0.351, 0.221, 0.209, -0.115, 0.559, -0.439, -0.487, -0.277, -0.044, 0.006, -0.759, 0.213, 0.480, -0.350, -0.437, -0.040, -0.234, -0.494, -0.117, 0.157, 0.490, -0.334, -0.067, -0.260, 0.172, 0.014, -0.632, -0.113, 0.293, -0.390, -0.441, 0.100, -0.113, -0.506, -0.272, 0.265, 0.609, -0.077, -5.000, -0.747, 0.495, -0.668, -5.000, 0.071, 0.136, -0.555, -0.483, -0.413, 0.180, -0.480, -0.244, 0.280, 0.696, 0.165, -5.000, -0.895, 0.038, -0.505, -0.062, -0.252, 0.019, -0.222, -0.293, 0.340, 0.411, 0.178, 0.142, 0.121, 0.572, -0.339, -0.265, -0.395, 0.041, 0.000, -0.775, -0.240, 0.082, -0.395, -0.638, -0.146, 0.036, -0.196, -0.221, 0.282, 0.647, -0.145, 0.057, -0.017, 0.358, 0.350, -0.525, 0.073, 0.415, -0.031, -0.413, -0.050, -0.000, -0.173, -0.228 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_31(struct _training *tptr) {
  struct _training tinf = {
    0.558, 11, 4.350, { 0.613, 0.169, 2.219 }, { 0.925, -1.726, -2.989 }, 1, 
    { -0.027, -0.637, -1.230, -1.204, -4.000, -0.308, -1.367, -4.000, -0.925, 0.055, -1.121, -4.000, -1.011, -0.188, -0.916, 1.284, 0.642, -1.171, 0.281, -1.258, 0.494, 0.981, 2.243, 2.345, 1.782, 0.633, 3.272, 2.293 }, 
    {{ -0.411, -0.547, 0.451, 0.139},{ -0.377, -0.474, 0.272, 0.334},{ 0.413, -0.452, -0.132, 0.099},{ 0.439, -0.567, -0.105, 0.114},{ 0.433, -0.557, -0.110, 0.121},{ 0.339, -0.409, 0.019, -0.004},{ 0.398, -0.567, -0.033, 0.094},{ 0.431, -0.443, -0.092, 0.023},{ 0.321, -0.436, 0.007, 0.057},{ 0.312, -0.477, -0.043, 0.154},{ 0.308, -0.427, -0.079, 0.160},{ 0.183, -0.343, -0.015, 0.169},{ 0.242, -0.443, -0.047, 0.212},{ 0.265, -0.296, -0.064, 0.094},{ 0.121, -0.202, -0.017, 0.117},{ 0.202, -0.412, -0.141, 0.314},{ 0.214, -0.232, -0.137, 0.169},{ 0.162, -0.252, -0.058, 0.162},{ 0.183, -0.224, -0.039, 0.096},{ 0.179, -0.116, -0.086, 0.045},{ 0.121, -0.143, -0.105, 0.154},{ 0.167, -0.183, -0.088, 0.128},{ 0.208, -0.134, -0.132, 0.080},{ 0.083, -0.128, -0.027, 0.094},{ 0.167, -0.210, -0.121, 0.183},{ 0.136, -0.090, -0.137, 0.117},{ 0.031, -0.031, -0.054, 0.071},{ 0.123, -0.210, -0.116, 0.220},{ 0.130, -0.125, -0.056, 0.076},{ 0.031, -0.071, -0.058, 0.119},{ 0.108, -0.164, -0.148, 0.224},{ 0.156, -0.107, -0.099, 0.076} }, 
    {{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}} }, 
    0.000, { 0.258, 0.296, -0.544, -5.000, -0.289, -0.281, -1.158, -5.000, -0.348, -0.038, -0.254, -0.275, -0.040, -0.111, -0.194, -0.205, 0.681, 0.512, 0.548, -5.000, -0.316, -0.320, -0.370, 0.154, -0.304, -0.187, -0.004, -0.205, 0.594, 0.355, 0.706, -0.081, 0.521, 0.878, 0.413, 1.011, 0.459, 0.800, 0.749, -0.147, 0.956, 1.002, 0.555, 0.799, 0.938, 0.993, 1.092, 0.623, -0.052, 0.328, -0.141, 0.300, -0.258, 0.313, -0.363, -0.781, -0.067, 0.635, 0.411, 0.250, 0.245, 0.279, 0.473, 0.106, -0.040, 0.023, -1.230, -5.000, -0.605, -0.428, -1.559, -5.000, -0.539, -0.591, -1.109, -0.601, 0.088, -0.466, 0.523, 0.090, 0.484, 0.290, 0.261, -5.000, -0.020, -0.259, -0.143, 0.472, 0.059, -0.144, 0.258, 0.208, 0.680, 0.230, 0.325, -0.107, 0.801, 0.901, 0.356, 1.177, 0.481, 0.607, 0.665, -0.172, 0.741, 0.681, 0.729, 0.372, 0.986, 0.609, 1.103, 0.615, 0.106, 0.076, -0.475, 0.532, -0.011, 0.084, 0.119, -0.355, 0.113, 0.067, -0.192, -0.422, 0.510, 0.140, 0.779, 0.152, -0.338, -0.295, -0.797, -5.000, -0.995, -1.037, -2.077, -5.000, -0.628, -0.909, -1.221, -0.406, -0.308, -0.862, -1.517, -0.594, -0.027, -0.067, -0.407, -5.000, -0.890, -1.053, -1.581, -0.883, -0.422, -0.681, -0.774, -0.346, 0.305, 0.035, 0.297, 0.071, -0.353, -0.934, -1.375, -0.432, -0.802, -1.157, -1.296, -1.070, -0.061, -0.439, -0.481, -0.192, 0.020, -0.773, -0.728, -0.438, -0.558, -0.812, -1.270, -0.554, -0.554, -1.628, -1.665, -1.065, -0.820, -1.507, -1.458, -0.659, -0.495, -1.132, -1.030, -0.966, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.629, -0.790, -1.338, -5.000, -1.024, -1.274, -2.310, -5.000, -0.853, -0.928, -0.932, -0.949, -0.287, -0.241, -0.455, -0.069, -0.783, -0.405, -0.490, -5.000, -1.690, -1.173, -1.491, -0.961, -1.100, -1.207, -0.785, -1.032, -0.062, -0.255, -0.189, -0.371, -0.568, -0.235, -0.703, -0.076, -1.088, -0.496, -0.906, -1.699, -0.497, -0.578, -1.202, -0.801, -0.025, 0.012, 0.370, -0.043, -0.734, -1.231, -1.349, -0.727, -2.444, -1.540, -2.576, -1.982, -0.305, -0.362, -1.300, 0.226, -0.244, -0.301, -0.310, -0.087, 0.085, -0.117, -1.877, -5.000, -1.302, -0.744, -2.254, -5.000, -0.895, -0.882, -1.474, -0.966, -0.070, -0.138, -1.161, 0.152, 0.641, 0.697, 0.180, -5.000, -0.618, -0.107, -0.576, 0.023, -0.109, 0.033, -0.422, -0.254, 0.433, 0.035, -0.198, -0.065, -0.081, 0.383, -0.136, 0.532, -0.255, 0.058, -0.620, -0.771, 0.009, 0.218, -0.398, -0.559, 0.318, -0.024, 0.358, -0.178, -0.358, -0.588, -1.221, -0.077, -0.563, -0.257, -1.090, -1.591, -1.112, -0.662, -1.002, -1.567, 0.038, -0.167, 0.134, -0.349, -0.411, -0.786, -1.814, -5.000, -1.373, -0.973, -2.631, -5.000, -1.136, -1.640, -2.016, -1.169, -0.834, -1.372, -1.635, -1.322, -0.510, -0.707, -1.019, -5.000, -1.532, -1.449, -2.153, -1.504, -0.850, -1.141, -1.447, -1.064, -0.331, -0.426, -0.564, -0.557, -0.808, -1.217, -2.029, -0.868, -1.333, -1.683, -1.982, -2.198, -0.770, -1.167, -1.229, -1.265, -0.546, -1.066, -1.230, -0.861, -1.383, -1.924, -2.154, -1.347, -2.237, -2.213, -2.595, -2.807, -2.188, -2.303, -2.857, -2.404, -1.150, -2.045, -2.057, -1.634, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.337, -0.127, -1.109, -5.000, -1.049, -0.805, -1.889, -5.000, -0.874, -0.812, -1.356, -1.096, -0.289, -0.278, -0.362, -0.522, -0.119, 0.059, 0.179, -5.000, -0.833, -0.389, -1.051, -0.530, -1.024, -0.836, -0.868, -1.166, 0.094, 0.115, 0.080, -0.435, -0.260, 0.322, -0.505, 0.053, -0.837, 0.105, -0.719, -1.168, -0.560, -0.296, -0.848, -0.684, -0.045, -0.005, -0.108, -0.091, -0.415, -0.157, -0.880, 0.085, -1.113, -0.802, -1.468, -1.695, -1.278, -0.811, -1.359, -1.456, -0.218, -0.625, -0.022, -0.461, -0.304, -0.083, -1.457, -5.000, -1.398, -0.711, -2.410, -5.000, -0.756, -0.945, -1.555, -1.348, -0.105, -0.277, -0.166, -0.234, 0.146, 0.340, 0.131, -5.000, -0.937, -0.376, -1.173, -0.441, -0.433, -0.375, -0.549, -0.761, 0.205, 0.065, 0.185, -0.392, 0.118, 0.199, -0.316, 0.472, -0.793, 0.142, -0.833, -1.584, -0.194, -0.005, -0.597, -0.846, 0.343, -0.084, 0.154, -0.206, -0.099, -0.204, -0.834, 0.360, -1.068, -0.590, -1.413, -1.385, -1.050, -0.522, -1.118, -1.333, 0.371, -0.509, 0.129, -0.113, -0.584, -0.729, -1.101, -5.000, -1.638, -0.575, -2.324, -5.000, -1.283, -1.438, -1.548, -1.422, -0.685, -1.063, -1.437, -0.950, -0.297, -0.385, -0.754, -5.000, -1.449, -0.805, -1.814, -1.584, -0.631, -0.997, -0.985, -1.143, -0.193, -0.081, -0.183, -0.615, -0.477, -0.456, -1.209, -0.769, -0.796, -0.677, -1.322, -1.652, -0.391, -0.702, -0.439, -0.617, -0.585, -1.023, -0.887, -0.444, -0.319, -0.466, -1.233, -0.396, -1.486, -0.943, -1.303, -1.522, -0.957, -1.125, -1.677, -1.324, 0.235, -1.236, -1.067, -0.805, -0.500, -0.490, -0.853, -5.000, -1.480, -1.367, -2.325, -5.000, -1.275, -1.069, -1.206, -1.445, -0.712, -0.341, -0.793, -0.610, -0.202, 0.167, -0.232, -5.000, -1.295, -1.165, -1.814, -1.195, -0.962, -1.036, -0.601, -1.039, -0.132, -0.094, 0.127, -0.473, -0.484, -0.113, -0.295, -0.060, -1.021, -0.340, -1.008, -1.554, -0.592, -0.148, -0.500, -0.652, -0.195, 0.337, 0.360, -0.371, -0.404, -0.364, -0.709, -0.315, -0.982, -0.644, -1.299, -1.375, -1.051, -0.948, -1.331, -1.162, -0.138, -0.191, -0.303, -0.467, -0.133, -0.260, -0.526, -5.000, -0.496, -0.536, -1.278, -5.000, -0.673, -0.546, -0.349, -0.622, -0.235, -0.339, -0.215, -0.075, -0.193, -0.151, -0.078, -5.000, -0.688, -0.343, -0.657, -0.258, -0.590, -0.582, -0.628, -0.738, 0.100, -0.085, -0.133, -0.176, 0.198, 0.043, -0.410, 0.119, -0.481, -0.114, -0.251, -0.524, -0.088, -0.246, -0.395, -0.290, 0.049, -0.188, 0.001, -0.225, -0.364, -0.214, -0.249, 0.143, -0.240, -0.276, -0.632, -0.582, -0.341, -0.128, -0.389, -0.471, -0.184, 0.093, 0.007, -0.264, 0.091, -0.147, -0.879, -5.000, -1.071, -0.838, -1.354, -5.000, -0.305, -0.924, -1.075, -0.433, -0.234, -0.577, -0.146, -0.054, 0.181, -0.004, -0.208, -5.000, -0.332, -0.085, -0.381, 0.156, -0.082, -0.492, -0.211, -0.333, 0.086, 0.174, 0.018, -0.009, 0.086, -0.119, -0.473, 0.565, -0.344, 0.058, -0.370, -0.453, -0.111, -0.400, -0.311, -0.240, 0.106, -0.439, -0.257, -0.287, -0.151, -0.522, -0.932, 0.460, -0.282, -0.792, -0.701, -0.395, -0.646, -0.466, -0.412, -0.670, -0.012, -0.700, -0.555, -0.105, -0.272, -0.399, -1.461, -5.000, -0.888, -0.442, -1.825, -5.000, -0.601, -0.880, -0.968, -0.529, -0.362, -0.129, -1.698, -0.503, -0.178, 0.194, -0.864, -5.000, -0.984, -1.040, -1.425, -0.950, -0.354, -0.599, -0.709, -0.377, 0.190, 0.474, 0.280, 0.202, -0.583, -1.209, -1.540, -0.383, -0.881, -0.962, -1.622, -1.095, -0.529, -0.800, -0.965, -0.616, -0.460, -0.752, -0.915, -0.106, -0.440, -1.067, -1.128, -0.720, -0.813, -1.814, -1.510, -0.784, -0.924, -1.100, -1.527, -1.226, -0.051, -0.786, -1.043, -0.500, -0.454, -0.025, -0.441, -5.000, -0.700, -0.504, -1.430, -5.000, -0.448, -0.510, -0.770, -0.420, -0.528, -0.526, -0.571, -0.498, -0.053, 0.331, 0.134, -5.000, -0.626, -0.349, -1.031, -0.850, -0.147, -0.658, -0.528, -0.605, 0.198, 0.292, 0.146, 0.218, -0.026, -0.011, -0.899, 0.036, -0.465, -0.701, -0.822, -0.873, -0.352, -0.566, -0.693, -0.730, -0.385, -0.021, -0.496, -0.200, -0.095, -0.120, -0.614, -0.158, -0.223, -0.604, -0.681, -0.806, -0.522, -0.417, -0.502, -0.494, -0.282, -0.389, -0.471, -0.289, 0.566, 0.887, -0.166, -5.000, -0.412, 0.013, -0.673, -5.000, -0.309, 0.139, -0.487, -0.360, -0.209, 0.014, -0.103, -0.108, 0.896, 1.046, 0.867, -5.000, -0.399, -0.178, -0.243, 0.219, -0.296, -0.028, 0.013, -0.296, 0.759, 0.563, 0.748, -0.108, 1.139, 1.300, 0.872, 1.386, 0.734, 1.106, 1.099, 0.222, 1.183, 1.010, 0.681, 0.833, 1.337, 1.273, 1.224, 0.845, 0.095, 0.186, -0.387, 0.137, 0.047, 0.401, -0.010, -0.317, -0.409, 0.012, 0.137, -0.069, 0.342, 0.333, 0.559, 0.192, 1.049, 1.135, -0.111, -5.000, 0.078, 0.140, -0.657, -5.000, 0.121, 0.134, -0.381, 0.055, -0.188, -0.387, -1.109, -0.224, 1.364, 1.411, 1.173, -5.000, 0.426, 0.573, 0.665, 0.976, 0.527, 0.543, 0.695, 0.475, 1.118, 0.967, 0.826, -0.166, 1.023, 1.140, 0.591, 1.315, 0.567, 0.802, 0.989, 0.195, 0.802, 0.595, 0.794, 0.530, 1.000, 0.616, 0.858, 0.564, 0.317, 0.373, -0.215, 0.671, 0.351, 0.313, 0.507, 0.020, 0.162, 0.168, -0.052, -0.095, 0.404, 0.085, 0.408, 0.031, 0.446, 0.540, -0.285, -5.000, -0.252, 0.429, -0.890, -5.000, 0.109, 0.393, -0.398, 0.011, 0.024, -0.017, -0.470, -0.001, 0.838, 0.554, 0.534, -5.000, -0.267, 0.246, -0.180, 0.325, 0.680, 0.486, 0.555, 0.599, 0.970, 0.920, 0.694, 0.670, 0.624, 0.506, -0.055, 0.890, 0.388, 0.503, 0.439, -0.080, 0.851, 0.732, 0.135, -0.161, 0.875, 0.147, 0.434, 0.597, -0.023, 0.136, -0.577, 0.723, 0.019, -0.066, 0.012, -0.368, -0.252, -0.268, -0.406, -0.174, 0.668, -0.211, 0.236, -0.266, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.743, -0.682, -1.211, -5.000, -1.021, -0.782, -1.646, -5.000, -1.162, -0.773, -1.299, -1.237, -0.139, -0.490, 0.157, -0.369, -0.700, -0.390, -0.429, -5.000, -1.134, -0.892, -1.176, -1.001, -1.128, -1.111, -1.013, -1.291, -0.294, -0.195, -0.054, -0.390, -0.451, 0.122, -0.635, -0.197, -1.068, -0.420, -0.921, -1.185, -0.565, -0.432, -1.402, -0.888, 0.127, 0.271, 0.430, -0.065, -1.031, -1.276, -1.218, -0.623, -0.864, -1.338, -2.233, -1.398, 0.408, -1.135, -0.398, -5.000, 0.193, -0.616, -0.030, -0.260, 0.639, 0.470, -1.193, -5.000, -0.676, -0.788, -1.826, -5.000, -0.631, -0.652, -1.030, -1.092, -0.278, -0.185, 0.354, 0.192, 0.759, 1.145, 0.671, -5.000, -0.532, 0.259, -0.139, 0.132, -0.064, 0.290, -0.318, -0.373, 0.751, 0.464, 0.000, 0.082, 0.038, 0.256, -0.231, 0.411, -0.442, -0.000, -0.545, -0.900, 0.007, 0.166, -0.292, -0.500, 0.140, -0.141, 0.386, -0.088, -0.598, -0.489, -0.961, -0.087, -0.794, -0.226, -1.106, -0.911, -1.099, -1.092, -1.126, -1.202, -0.157, -0.302, 0.084, -0.263, -0.116, 0.071, -1.026, -5.000, -1.109, -0.229, -1.676, -5.000, -1.187, -1.353, -1.889, -1.073, -0.498, -0.878, -1.552, -1.044, -0.113, 0.333, -0.436, -5.000, -1.043, -0.317, -1.234, -0.911, -0.445, -0.273, -1.050, -0.741, -0.186, 0.027, -0.205, -0.422, -0.120, 0.039, -0.769, 0.230, -0.497, -0.548, -1.050, -1.147, -0.288, -0.265, -0.803, -0.508, 0.096, -0.247, -0.488, -0.218, -1.085, -0.994, -1.647, -0.618, -1.418, -1.250, -1.719, -1.923, -1.779, -1.919, -2.053, -1.992, -0.701, -1.052, -1.227, -1.283, -0.018, -0.077, -0.585, -5.000, -1.556, -0.634, -2.039, -5.000, -1.064, -0.487, -0.814, -0.942, -0.567, -0.543, -0.725, -0.452, 0.362, 0.864, 0.504, -5.000, -1.420, -0.195, -1.290, -0.551, -0.718, -0.111, 0.102, -0.213, 0.190, 0.376, 0.287, -0.130, 0.482, 0.813, 0.335, 0.727, -0.374, 0.270, -0.207, -0.862, 0.712, 0.450, 0.162, -0.052, 0.178, 0.476, 0.732, 0.244, -0.434, -0.400, -0.708, -0.283, -0.873, -0.885, -1.177, -1.443, -1.093, -1.033, -1.012, -1.648, -0.663, -0.321, -0.625, -0.933, 0.194, 0.412, -0.731, -5.000, -0.719, -0.098, -1.335, -5.000, -0.610, -0.311, -0.923, -0.974, -0.322, 0.002, 0.243, -0.149, 0.524, 0.685, 0.494, -5.000, -0.686, -0.244, -0.372, 0.312, -0.242, -0.168, -0.386, -0.718, 0.193, 0.621, 0.605, -0.274, 0.667, 1.086, 0.596, 1.176, -0.458, 0.846, 0.322, -0.846, 0.281, 0.285, -0.533, -0.231, 0.681, 0.472, 0.479, 0.554, 0.011, 0.691, -0.024, 0.643, -0.933, 0.508, -0.197, -1.063, -0.718, -0.210, -0.967, -1.360, 0.351, 0.147, 0.098, 0.298, 0.475, 0.647, -1.072, -5.000, -1.466, -0.071, -1.877, -5.000, -0.771, -0.552, -1.472, -0.994, -0.341, -0.334, -0.074, -0.020, 0.811, 1.002, 0.584, -5.000, -0.817, 0.285, -0.432, 0.041, 0.164, 0.134, -0.222, -0.349, 0.325, 0.614, 0.528, -0.475, 0.496, 0.713, -0.114, 0.987, -0.335, 0.747, -0.053, -0.680, 0.013, 0.230, -0.199, -0.637, 0.673, 0.004, 0.233, 0.180, 0.399, 0.359, -0.365, 0.865, -0.327, 0.182, -0.536, -0.856, -0.418, -0.142, -0.709, -0.960, 0.557, 0.054, 0.240, 0.017, 0.093, 0.329, -0.802, -5.000, -1.159, 0.247, -1.617, -5.000, -0.727, -0.663, -1.157, -1.120, -0.560, -0.060, -0.748, -0.836, 0.325, 0.524, 0.076, -5.000, -1.007, 0.141, -0.704, -0.808, 0.119, -0.090, -0.463, -0.421, 0.086, 0.685, 0.554, -0.487, 0.622, 0.680, -0.092, 0.623, 0.003, 0.630, -0.265, -0.463, 0.350, 0.064, -0.329, -0.256, 0.144, -0.222, -0.324, 0.453, 0.591, 0.869, -0.120, 0.661, -0.341, 0.806, -0.090, -0.709, 0.060, -0.029, -0.564, -0.934, 0.954, 0.006, 0.016, -0.013, 0.106, 0.478, -0.313, -5.000, -1.467, -0.476, -1.513, -5.000, -1.360, -0.644, -1.090, -1.141, -0.792, -0.224, -0.683, -0.697, 0.517, 0.907, 0.492, -5.000, -1.172, -0.510, -1.177, -0.607, -0.580, -0.359, -0.015, -0.482, 0.076, 0.423, 0.705, -0.424, 0.123, 0.597, 0.226, 0.683, -0.667, 0.429, -0.261, -0.980, 0.164, 0.308, -0.247, -0.611, 0.143, 0.554, 0.981, -0.002, -0.085, 0.242, -0.160, 0.525, -0.854, 0.235, -0.430, -1.255, -0.627, -0.109, -0.618, -0.970, 0.276, 0.315, 0.445, -0.214, 0.409, 0.621, -0.312, -5.000, -0.482, 0.131, -0.517, -5.000, -0.343, -0.012, -0.505, -0.321, -0.453, 0.159, -0.080, -0.105, 0.744, 0.958, 0.849, -5.000, -0.496, 0.286, 0.079, 0.239, 0.167, 0.449, 0.169, -0.051, 0.404, 0.698, 0.907, -0.148, 0.911, 1.092, 0.861, 1.208, 0.276, 1.088, 0.683, 0.029, 0.699, 0.717, -0.207, -0.160, 0.892, 0.804, 0.896, 0.644, 0.114, 0.834, 0.286, 0.582, -0.015, 0.715, 0.125, -0.474, -0.244, 0.314, -0.277, -0.350, 0.522, 0.461, 0.380, 0.258, 0.657, 0.826, -0.565, -5.000, -0.317, -0.095, -1.132, -5.000, -0.222, -0.099, -0.601, -0.267, -0.220, -0.078, 0.569, -0.143, 1.082, 1.107, 0.822, -5.000, -0.092, 0.499, 0.352, 0.424, 0.781, 0.695, 0.573, 0.354, 0.743, 1.041, 1.109, -0.263, 1.136, 1.202, 0.715, 1.309, 0.145, 0.952, 0.738, 0.064, 0.628, 0.651, 0.102, 0.091, 1.075, 0.547, 0.856, 0.823, 0.867, 0.942, 0.251, 1.237, 0.103, 0.490, 0.151, -0.134, -0.083, 0.460, -0.128, -0.237, 0.892, 0.342, 0.647, 0.537, 0.630, 0.864, 0.029, -5.000, -0.154, 0.790, -0.430, -5.000, 0.464, 0.599, -0.099, 0.346, 0.037, 0.335, -0.410, -0.097, 0.840, 1.159, 0.364, -5.000, -0.200, 0.801, 0.120, 0.320, 0.952, 0.936, 0.653, 0.690, 0.875, 1.306, 0.971, 0.390, 1.077, 1.043, 0.420, 1.247, 0.513, 0.894, 0.440, -0.023, 0.896, 0.633, -0.005, 0.065, 0.708, 0.174, 0.110, 0.799, 0.592, 0.874, 0.279, 1.061, 0.268, 0.553, 0.230, -0.668, 0.038, 0.080, -0.158, -0.040, 1.132, 0.075, 0.174, 0.427, 0.012, 0.327, -0.097, -5.000, -0.815, -0.142, -0.783, -5.000, -0.387, -0.205, -0.344, -0.592, -0.361, -0.274, -0.165, -0.147, 0.070, 0.627, 0.503, -5.000, -0.880, -0.044, -0.317, -0.573, -0.061, 0.075, -0.197, -0.595, -0.267, 0.319, 0.547, -0.193, -0.436, 0.058, -0.351, -0.401, -0.859, -0.024, -0.611, -1.088, -0.431, -0.364, -0.527, -1.051, -0.686, -0.410, 0.403, -0.716, -0.165, 0.177, -0.167, -0.056, -0.640, -0.057, -0.276, -0.587, -0.694, -0.383, -0.812, -0.467, -0.054, -0.226, 0.026, -0.242, 0.455, 0.665, -0.414, -5.000, -0.305, -0.298, -0.978, -5.000, -0.451, -0.005, -0.432, -0.405, -0.322, -0.289, 0.037, -0.013, 0.974, 1.197, 0.815, -5.000, -0.228, -0.252, -0.185, 0.391, -0.469, -0.020, 0.171, -0.204, 0.859, 0.730, 0.967, -0.017, 0.997, 1.158, 0.768, 1.328, 0.578, 0.956, 0.864, 0.233, 1.179, 1.171, 0.739, 0.912, 1.209, 1.104, 1.180, 1.085, 0.198, 0.540, -0.026, 0.608, 0.087, 0.213, 0.107, -0.547, 0.354, 0.599, 0.483, 0.323, 0.423, 0.324, 0.475, 0.342, 0.626, 0.783, -0.895, -5.000, -0.226, -0.167, -0.838, -5.000, -0.290, -0.232, -0.667, -0.140, -0.537, -0.111, 0.737, 0.130, 1.140, 1.248, 1.055, -5.000, 0.126, 0.264, 0.239, 1.097, 0.283, 0.506, 0.493, 0.645, 1.215, 0.919, 0.727, -0.056, 1.121, 1.111, 0.747, 1.356, 0.751, 0.968, 1.038, 0.548, 1.005, 0.754, 0.923, 0.636, 1.086, 0.793, 1.147, 0.915, 0.198, 0.261, -0.398, 0.824, 0.274, 0.169, 0.239, -0.339, 0.012, 0.037, -0.251, -0.327, 0.521, 0.422, 0.351, 0.343, 0.173, 0.062, -1.053, -5.000, -0.642, -0.099, -1.495, -5.000, -0.494, -0.483, -1.240, -0.362, -0.260, -0.148, -1.215, -0.546, 0.550, 0.387, -0.197, -5.000, -0.594, -0.072, -0.945, 0.156, 0.320, 0.192, 0.111, 0.456, 0.841, 0.852, 0.733, 0.415, 0.420, 0.287, -0.313, 0.783, 0.254, 0.405, -0.048, -0.108, 0.778, 0.335, -0.505, -0.140, 0.765, -0.075, -0.110, 0.687, -0.371, -0.272, -0.872, 0.400, -0.149, -0.509, -0.727, -0.939, -0.401, -0.665, -0.591, -0.191, 0.689, -0.382, -0.621, -0.095, 0.685, 0.774, -0.014, -5.000, -0.453, 0.084, -1.021, -5.000, -0.546, -0.062, -0.270, -0.459, -0.288, 0.001, -0.593, -0.167, 1.158, 1.323, 0.993, -5.000, -0.673, 0.380, -0.506, 0.569, 0.151, 0.060, 0.233, 0.085, 0.887, 0.920, 1.082, 0.087, 1.506, 1.559, 1.247, 1.561, 1.301, 1.353, 1.296, 0.914, 1.615, 1.462, 1.276, 1.330, 1.595, 1.408, 1.546, 1.505, 0.599, 0.985, 0.212, 0.881, 0.358, 0.741, 0.553, -0.233, 0.489, 0.658, 0.601, 0.244, 0.939, 0.584, 0.655, 0.586, 0.020, 0.251, -0.497, -5.000, -0.775, -0.195, -1.316, -5.000, -0.727, -0.434, -0.808, -0.806, -0.132, 0.006, 0.304, -0.208, 0.173, 0.566, 0.484, -5.000, -1.058, -0.426, -0.545, -0.074, -0.610, -0.487, -0.749, -0.835, 0.479, 0.598, 0.752, -0.305, 0.292, 0.884, 0.428, 0.914, -0.353, 0.483, -0.023, -0.544, 0.062, 0.035, -0.599, -0.482, 0.569, 0.602, 0.720, 0.432, -0.250, -0.346, -0.641, -0.234, -0.769, -0.602, -1.188, -1.738, -0.219, 0.014, -0.037, -0.139, -0.001, -0.123, 0.579, 0.138, 0.761, 0.761, -0.702, -5.000, -0.580, -0.056, -1.432, -5.000, -0.228, -0.004, -0.808, -0.429, -0.131, -0.120, 1.011, 0.256, 0.877, 1.035, 0.783, -5.000, -0.470, -0.025, -0.135, 0.713, 0.393, 0.645, 0.319, 0.285, 1.194, 0.737, 0.483, 0.181, 0.883, 0.934, 0.438, 1.155, 0.474, 0.773, 0.340, -0.010, 0.851, 0.708, 0.507, 0.204, 1.102, 0.844, 1.111, 0.730, 0.252, 0.218, -0.356, 0.691, 0.069, 0.245, -0.398, -0.606, -0.135, -0.273, -0.493, -0.640, 0.633, 0.236, 0.794, 0.120, 0.264, 0.393, -0.694, -5.000, -1.110, 0.410, -1.708, -5.000, -0.987, -0.601, -1.420, -0.830, -0.533, -0.313, -1.250, -0.636, 0.448, 0.557, 0.118, -5.000, -0.926, 0.243, -0.681, -0.586, -0.032, 0.044, -0.319, -0.144, 0.550, 0.806, 0.733, -0.056, 0.654, 0.737, -0.072, 0.992, 0.117, 0.189, -0.219, -0.676, 0.767, 0.408, -0.339, -0.119, 0.925, 0.301, 0.327, 0.707, -0.297, -0.064, -0.793, 0.408, -0.945, -0.504, -0.901, -1.796, -0.705, -0.781, -1.314, -1.144, 0.607, -0.134, -0.192, -0.798, -0.308, -0.508, -0.791, -5.000, -1.537, -0.975, -1.917, -5.000, -1.608, -0.683, -1.597, -1.490, -0.732, -0.966, -1.129, -0.655, 0.072, 0.460, 0.081, -5.000, -1.330, -0.616, -1.457, -1.085, -1.590, -0.830, -0.978, -0.859, -0.048, 0.196, 0.198, -0.311, 0.001, 0.368, -0.062, 0.526, -0.760, -0.042, -0.571, -0.928, -0.203, -0.119, -0.523, -0.635, 0.192, 0.401, 0.549, -0.092, -0.576, -0.497, -0.767, -0.205, -0.796, -0.642, -1.356, -1.245, -1.184, -1.238, -1.703, -1.610, -0.583, -0.644, -0.597, -0.891, 0.727, 0.896, -0.244, -5.000, 0.023, 0.322, -0.854, -5.000, -0.296, 0.126, -0.390, -0.649, 0.046, 0.272, 0.155, -0.180, 0.876, 0.950, 0.794, -5.000, -0.065, 0.210, -0.489, 0.667, 0.196, 0.327, 0.293, 0.021, 0.846, 1.034, 1.051, -0.195, 0.706, 1.137, 0.749, 1.244, -0.068, 1.090, 0.460, -0.171, 0.589, 0.526, 0.059, -0.009, 0.880, 0.862, 0.946, 0.825, 0.319, 0.661, -0.010, 0.973, -0.603, 0.439, -0.244, -0.644, -0.450, 0.022, -0.624, -0.847, 0.785, 0.608, 0.550, 0.579, 0.564, 0.589, -0.683, -5.000, -0.725, 0.174, -1.066, -5.000, -0.196, 0.059, -0.754, -0.652, -0.016, 0.058, 0.834, -0.099, 0.694, 0.765, 0.536, -5.000, -0.303, -0.157, -0.433, 0.409, 0.401, 0.369, 0.193, -0.131, 0.773, 0.881, 0.964, -0.327, 0.800, 0.731, 0.182, 1.072, 0.038, 0.627, 0.127, -0.325, 0.517, 0.441, 0.074, -0.136, 1.020, 0.449, 0.843, 0.711, 0.174, 0.178, -0.317, 0.861, -0.253, -0.605, -0.723, -0.973, -0.089, 0.109, -0.344, -0.552, 0.807, 0.243, 0.625, 0.347, 0.111, 0.155, -0.888, -5.000, -0.962, -0.482, -1.183, -5.000, -0.725, -0.740, -0.936, -0.861, -0.792, -0.198, -0.535, -0.691, 0.271, 0.235, -0.055, -5.000, -0.867, -0.096, -0.976, -0.572, 0.136, -0.220, -0.502, -0.450, 0.260, 0.671, 0.624, -0.281, 0.574, 0.688, -0.168, 0.590, -0.154, 0.810, -0.024, -0.096, 0.579, 0.177, -0.193, -0.151, 0.374, -0.180, 0.137, 0.590, 0.558, 0.886, -0.115, 0.806, -0.664, 0.386, 0.030, -0.439, -0.259, -0.045, -0.598, -0.537, 0.823, -0.058, 0.066, 0.017, -0.114, -0.219, -0.604, -5.000, -1.284, -1.030, -1.938, -5.000, -1.227, -0.616, -0.842, -0.773, -0.791, -0.355, -0.861, -0.642, 0.305, 0.539, 0.246, -5.000, -0.165, -0.482, -1.231, -0.798, -0.822, -0.585, -0.341, -0.460, 0.348, -0.059, 0.277, -0.400, 0.144, 0.421, 0.171, 0.338, -0.440, 0.209, -0.145, -0.615, 0.392, 0.241, 0.075, -0.326, 0.364, 0.746, 0.948, 0.128, -0.496, -0.194, -1.006, 0.001, -0.819, -0.066, -0.548, -1.047, -0.827, -0.270, -0.386, -0.833, 0.346, 0.323, 0.322, -0.146, 0.723, 0.829, -0.129, -5.000, -0.293, 0.244, -0.457, -5.000, -0.282, 0.186, -0.193, -0.284, -0.316, -0.316, 0.080, -0.227, 1.051, 1.191, 0.825, -5.000, -0.042, 0.224, 0.089, 0.579, 0.307, 0.630, 0.501, 0.209, 0.840, 1.120, 1.128, 0.123, 1.179, 1.305, 0.701, 1.324, 0.545, 1.204, 0.850, 0.368, 1.124, 0.967, 0.262, 0.493, 1.182, 1.093, 1.075, 0.906, 0.580, 0.914, 0.559, 1.051, -0.175, 0.738, 0.275, -0.003, 0.278, 0.735, 0.190, -0.437, 0.951, 0.628, 0.901, 0.588, 0.747, 0.389, -0.661, -5.000, -0.303, -0.039, -0.932, -5.000, 0.221, -0.162, -0.646, -0.229, -0.131, -0.602, 0.331, -0.189, 0.942, 0.787, 0.538, -5.000, 0.266, 0.258, 0.274, 0.627, 0.876, 0.631, 0.651, 0.633, 0.813, 0.989, 1.004, 0.096, 1.122, 0.860, 0.460, 1.337, 0.407, 0.811, 0.466, -0.031, 0.692, 0.258, 0.068, -0.178, 1.066, 0.460, 0.506, 0.624, 0.251, 0.200, -0.243, 0.921, 0.119, 0.158, -0.252, -0.454, 0.043, 0.095, -0.148, -0.340, 0.874, 0.164, 0.175, 0.478, 0.712, 0.465, 0.006, -5.000, -0.169, 0.656, -0.572, -5.000, 0.386, 0.452, -0.091, 0.418, -0.307, 0.032, -0.406, -0.088, 1.025, 0.877, 0.531, -5.000, -0.004, 0.767, 0.285, 0.533, 1.077, 0.944, 0.719, 0.916, 1.071, 1.272, 1.174, 0.701, 1.100, 0.833, 0.101, 1.265, 0.697, 0.751, 0.168, 0.220, 0.937, 0.517, -0.526, 0.215, 0.843, 0.012, -0.405, 1.069, 0.505, 0.436, -0.145, 1.047, 0.385, 0.225, -0.180, -0.516, -0.151, -0.350, -0.768, -0.359, 1.195, -0.400, -0.202, 0.512, 0.466, 0.648, 0.018, -5.000, -0.864, 0.387, -0.649, -5.000, -0.522, 0.084, -0.241, -0.167, -0.254, -0.166, -0.421, -0.451, 0.944, 1.194, 0.749, -5.000, -0.567, 0.402, -0.062, 0.494, 0.170, 0.729, 0.646, 0.617, 0.813, 1.156, 1.024, 0.305, 0.918, 1.027, 0.571, 1.065, 0.345, 0.749, 0.435, -0.146, 0.913, 0.577, 0.287, 0.053, 0.718, 0.757, 0.512, 0.660, 0.370, 0.506, -0.091, 0.646, 0.005, 0.026, 0.143, -0.303, 0.032, -0.155, -0.224, -0.568, 0.629, 0.054, 0.101, 0.239, -0.112, -0.107, -0.989, -5.000, -0.339, -0.664, -1.611, -5.000, -0.420, -0.557, -0.588, -0.363, -0.311, -0.305, 0.083, -0.208, 0.474, 0.058, -0.045, -5.000, -0.179, -0.578, -0.592, 0.039, -0.165, -0.511, -0.140, -0.323, 0.500, 0.275, 0.206, 0.050, 0.428, 0.598, 0.177, 0.812, 0.128, 0.359, 0.160, -0.327, 0.772, 0.649, 0.210, 0.539, 0.660, 0.788, 0.806, 0.544, 0.011, -0.137, -0.432, 0.043, -0.049, -0.282, -0.975, -0.480, -0.252, 0.503, 0.011, -0.101, -0.029, 0.112, 0.217, 0.130, 0.165, 0.177, -1.305, -5.000, -0.790, -0.867, -1.806, -5.000, -0.667, -1.119, -1.671, -0.880, -0.235, -0.813, 0.700, 0.366, 1.059, 0.791, 0.475, -5.000, 0.121, -0.167, -0.521, 0.687, -0.108, -0.457, -0.307, 0.132, 0.882, 0.448, -0.192, -0.097, 0.575, 0.269, -0.253, 0.863, 0.128, -0.115, 0.041, -0.206, 0.617, 0.222, 0.469, 0.361, 0.720, 0.594, 0.506, 0.288, -0.234, -0.446, -0.907, 0.447, -0.072, -0.435, -0.471, -0.489, -0.418, -0.538, -0.651, -0.616, 0.106, -0.139, -0.148, -0.105, -0.354, -0.499, -1.120, -5.000, -0.875, -1.099, -1.925, -5.000, -0.699, -1.355, -1.279, -0.919, -0.467, -0.981, -1.753, -0.682, 0.209, 0.108, -0.475, -5.000, -0.617, -0.734, -1.513, -0.669, -0.300, -0.679, -0.709, -0.343, 0.324, 0.430, -0.130, 0.045, -0.209, -0.596, -1.030, 0.027, -0.344, -0.463, -0.988, -1.158, 0.222, -0.398, -0.545, -0.492, 0.035, -0.572, -0.749, -0.137, -0.558, -0.717, -1.615, -0.153, -0.586, -1.025, -1.153, -1.214, -0.513, -1.047, -1.371, -0.805, -0.113, -0.807, -1.085, -0.556, 0.294, 0.062, -0.488, -5.000, -0.516, -0.572, -1.474, -5.000, -0.581, -0.497, -0.768, -0.640, -0.117, -0.208, -0.870, -0.009, 0.784, 1.059, 0.561, -5.000, -0.461, 0.039, -0.842, 0.072, -0.030, -0.004, -0.109, -0.262, 0.698, 0.724, 0.636, 0.104, 0.926, 1.170, 0.639, 0.847, 0.866, 0.853, 0.613, 0.006, 1.244, 1.236, 0.929, 0.834, 1.223, 1.493, 1.195, 0.766, 0.264, 0.355, -0.538, 0.458, 0.259, 0.107, -0.091, -0.441, -0.313, 0.133, -0.257, -0.041, 0.312, 0.539, -0.078, 0.047, -0.327, -0.210, -0.981, -5.000, -0.849, -0.811, -1.906, -5.000, -1.119, -0.778, -1.051, -0.973, -0.050, -0.224, 0.018, -0.297, -0.351, 0.188, -0.155, -5.000, -1.131, -0.328, -0.888, -0.490, -0.985, -1.104, -0.741, -1.061, 0.345, 0.248, 0.283, -0.049, -0.021, 0.312, 0.033, 0.369, -0.491, 0.130, -0.517, -1.074, -0.256, -0.489, -1.313, -0.975, 0.293, 0.229, 0.457, 0.101, -0.444, -0.556, -0.867, -0.693, -1.204, -1.159, -1.863, -1.817, 0.226, -0.442, -1.384, -0.998, 0.006, 0.130, 0.285, -0.333, 0.060, -0.308, -1.412, -5.000, -1.374, -0.804, -2.167, -5.000, -0.776, -0.714, -1.414, -1.105, -0.338, -0.628, 0.449, 0.186, 0.397, 0.425, 0.141, -5.000, -0.396, -0.765, -0.923, 0.171, -0.146, -0.046, -0.253, -0.030, 0.823, 0.141, -0.222, 0.087, 0.327, 0.119, -0.293, 0.491, -0.192, 0.145, -0.518, -0.620, 0.438, 0.029, 0.026, -0.289, 0.716, 0.148, 0.523, 0.273, -0.231, -0.704, -1.081, 0.163, -0.610, -0.395, -1.221, -1.094, -0.788, -0.916, -1.125, -1.270, 0.112, -0.223, 0.124, -0.032, -0.114, -0.373, -1.404, -5.000, -1.554, -0.115, -1.974, -5.000, -0.861, -1.153, -1.471, -0.722, -0.345, -0.757, -1.729, -0.865, 0.013, -0.017, -0.447, -5.000, -1.140, -0.692, -1.489, -1.112, -0.330, -0.502, -0.641, -0.451, 0.294, 0.243, 0.034, -0.087, -0.071, -0.156, -1.027, 0.392, -0.366, -0.287, -0.949, -1.268, 0.255, 0.099, -0.448, -0.318, 0.444, -0.312, -0.148, 0.065, -0.646, -0.707, -1.772, -0.256, -0.952, -0.953, -1.443, -1.962, -1.140, -1.146, -1.769, -1.448, 0.054, -0.688, -0.956, -1.125, -0.418, -0.984, -1.195, -5.000, -1.540, -1.520, -2.260, -5.000, -1.220, -1.642, -2.182, -1.684, -0.743, -1.134, -1.426, -0.707, -0.460, -0.009, -0.457, -5.000, -1.615, -1.041, -1.714, -1.264, -0.922, -1.247, -1.475, -0.920, -0.026, -0.169, -0.402, -0.015, -0.563, -0.485, -0.445, -0.225, -1.253, -0.864, -1.241, -1.342, -0.321, -0.337, -0.785, -0.876, -0.150, -0.309, 0.154, -0.284, -0.852, -0.892, -0.998, -0.405, -0.653, -1.224, -1.574, -1.129, -1.433, -1.878, -1.663, -1.502, -0.718, -0.910, -1.056, -0.720, -0.292, 0.005, -1.060, -5.000, -1.305, -1.097, -2.084, -5.000, -0.974, -1.233, -1.096, -1.081, -0.555, -0.167, -0.379, -0.405, 0.281, 0.476, 0.045, -5.000, -1.150, -0.636, -1.459, -0.648, -0.687, -0.749, -0.973, -0.937, 0.352, 0.387, 0.462, -0.109, 0.105, 0.235, -0.108, 0.650, -0.665, 0.102, -0.884, -1.040, -0.230, -0.469, -1.151, -0.806, 0.207, 0.120, 0.272, 0.162, -0.102, -0.119, -0.961, 0.154, -1.343, -0.712, -1.482, -1.806, -1.003, -0.660, -1.470, -1.974, -0.086, -0.184, 0.192, -0.371, -0.144, -0.208, -1.675, -5.000, -1.298, -0.993, -2.246, -5.000, -0.834, -0.847, -1.528, -1.231, -0.163, -0.209, 0.737, -0.157, 0.471, 0.543, 0.208, -5.000, -0.719, -0.500, -1.001, -0.028, -0.200, -0.255, -0.526, -0.559, 0.476, 0.420, 0.282, -0.260, -0.007, -0.199, -0.820, 0.245, -0.678, -0.426, -0.956, -1.065, -0.113, -0.436, -0.905, -0.744, 0.368, -0.241, -0.171, -0.199, -0.400, -0.440, -1.202, 0.241, -0.725, -0.948, -1.528, -1.176, -0.984, -1.063, -1.470, -1.451, 0.121, -0.197, 0.272, -0.035, -0.607, -0.752, -1.511, -5.000, -1.455, -0.998, -2.317, -5.000, -1.176, -1.599, -1.686, -1.584, -0.939, -1.201, -1.759, -1.032, -0.106, -0.173, -0.795, -5.000, -1.111, -0.685, -1.764, -1.218, -0.517, -1.005, -1.221, -0.951, 0.156, 0.363, 0.146, -0.389, -0.258, -0.265, -1.122, -0.391, -0.585, -0.136, -1.409, -1.195, -0.128, -0.881, -1.107, -0.559, -0.285, -0.618, -0.732, -0.154, -0.275, -0.101, -1.251, -0.585, -1.027, -0.370, -0.884, -1.318, -0.904, -1.168, -1.774, -1.485, 0.355, -0.786, -0.792, -0.432, -0.602, -0.850, -1.480, -5.000, -1.542, -1.326, -2.781, -5.000, -1.135, -1.398, -1.323, -1.508, -0.819, -0.870, -1.639, -0.719, 0.076, 0.084, -0.170, -5.000, -1.225, -1.463, -2.128, -1.368, -1.129, -1.069, -0.722, -1.177, 0.200, -0.049, 0.079, -0.288, -0.268, 0.026, -0.349, 0.043, -1.015, -0.409, -1.012, -1.527, -0.358, -0.412, -0.618, -0.808, -0.308, 0.142, 0.229, -0.308, -0.524, -0.902, -1.426, -0.711, -1.025, -0.690, -1.436, -1.325, -1.211, -1.190, -1.308, -1.165, -0.250, -0.541, -0.672, -0.745, 0.377, 0.568, -0.388, -5.000, -0.213, -0.212, -0.762, -5.000, -0.246, -0.123, -0.460, -0.364, -0.167, 0.180, -0.118, -0.043, 0.867, 0.968, 0.737, -5.000, -0.119, 0.072, -0.071, 0.138, 0.456, 0.552, 0.257, 0.191, 0.752, 0.930, 0.939, 0.235, 0.752, 0.975, 0.373, 0.874, 0.348, 0.928, 0.429, -0.151, 0.799, 0.657, -0.109, 0.212, 0.883, 0.864, 0.779, 0.611, 0.320, 0.638, 0.075, 0.261, -0.147, 0.464, -0.098, -0.375, 0.082, 0.443, -0.114, -0.195, 0.544, 0.430, 0.405, 0.240, 0.049, -0.222, -1.155, -5.000, -0.668, -0.888, -1.624, -5.000, -0.699, -1.079, -1.089, -0.683, -0.286, -0.859, -0.052, 0.179, 0.660, 0.369, 0.068, -5.000, -0.098, 0.018, -0.377, 0.170, 0.310, -0.072, 0.062, 0.164, 0.402, 0.573, 0.485, -0.021, 0.293, -0.044, -0.293, 0.567, -0.333, -0.121, -0.306, -0.762, 0.224, -0.283, -0.485, -0.312, 0.458, -0.096, -0.117, 0.034, 0.103, -0.288, -0.858, 0.328, -0.414, -0.527, -0.897, -0.547, -0.356, -0.420, -0.736, -0.497, 0.160, -0.225, -0.058, 0.038, 0.386, 0.155, -0.689, -5.000, -0.389, 0.233, -1.262, -5.000, -0.098, -0.251, -0.567, -0.431, -0.246, -0.448, -1.067, -0.706, 0.523, 0.521, 0.199, -5.000, -0.351, 0.198, -0.578, -0.139, 0.475, 0.321, 0.014, 0.253, 0.764, 0.871, 0.624, 0.377, 0.274, 0.098, -0.890, 0.473, 0.074, 0.027, -0.585, -0.568, 0.238, -0.078, -0.940, -0.165, 0.155, -0.452, -0.886, 0.415, 0.034, 0.128, -0.621, 0.494, -0.262, -0.200, -0.390, -0.919, -0.618, -0.790, -1.221, -0.586, 0.541, -0.364, -0.467, -0.088, -0.096, -0.122, -0.479, -5.000, -0.780, -0.086, -1.278, -5.000, -0.637, -0.151, -0.614, -0.377, -0.267, -0.352, -0.602, -0.456, 0.471, 0.578, 0.194, -5.000, -0.662, -0.118, -0.854, -0.301, -0.157, 0.044, 0.038, 0.030, 0.395, 0.716, 0.527, 0.149, 0.265, 0.359, -0.107, 0.303, -0.149, 0.229, -0.083, -0.368, 0.440, 0.021, -0.262, -0.248, 0.372, 0.330, 0.144, 0.197, -0.040, -0.058, -0.366, 0.065, -0.248, -0.308, -0.309, -0.487, -0.228, -0.542, -0.681, -0.807, 0.127, -0.355, -0.383, -0.206 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_32(struct _training *tptr) {
  struct _training tinf = {
    0.368, 11, 4.350, { 2.475, 0.334, 0.191 }, { 0.289, -0.899, -0.110 }, 1, 
    { -0.968, -2.007, -1.630, -0.757, -4.000, -4.000, 0.658, 1.541, 0.847, -4.000, -1.045, -4.000, 0.789, 0.576, 2.199, -2.421, 1.477, 0.201, 0.412, 2.027, 0.673, -0.798, 1.120, -0.310, 2.166, 1.891, 1.048, 2.595 }, 
    {{ 0.128, -0.231, -0.174, 0.074},{ 0.255, -0.202, -0.319, -0.024},{ 0.097, 0.235, -0.719, 0.042},{ 0.050, 0.088, -0.634, 0.156},{ 0.059, 0.099, -0.428, 0.078},{ 0.033, -0.042, -0.458, 0.187},{ 0.150, -0.155, -0.440, 0.122},{ 0.134, 0.066, -0.471, 0.035},{ 0.128, -0.026, -0.375, 0.059},{ 0.215, -0.164, -0.440, 0.055},{ 0.277, -0.080, -0.369, -0.100},{ 0.290, -0.128, -0.336, -0.105},{ 0.240, -0.132, -0.410, -0.003},{ 0.260, -0.119, -0.287, -0.090},{ 0.164, -0.169, -0.292, 0.059},{ 0.298, -0.197, -0.347, -0.075},{ 0.189, -0.088, -0.369, 0.022},{ 0.171, -0.216, -0.298, 0.074},{ 0.136, -0.160, -0.282, 0.080},{ 0.207, -0.022, -0.464, -0.001},{ 0.152, -0.137, -0.375, 0.089},{ 0.068, -0.055, -0.347, 0.124},{ 0.083, -0.101, -0.303, 0.116},{ 0.142, -0.155, -0.386, 0.112},{ 0.187, -0.164, -0.369, 0.061},{ 0.130, -0.221, -0.386, 0.152},{ 0.179, -0.298, -0.404, 0.138},{ 0.215, -0.106, -0.325, -0.020},{ 0.183, -0.093, -0.416, 0.048},{ 0.196, -0.261, -0.298, 0.066},{ 0.200, -0.178, -0.380, 0.057},{ 0.175, -0.212, -0.256, 0.050} }, 
    {{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}} }, 
    0.000, { 0.834, 0.954, -0.017, -5.000, 0.444, 0.699, -0.282, -5.000, 0.567, 1.002, 0.555, 0.329, 0.457, 0.661, 0.476, 0.504, 0.864, 1.033, 0.287, -5.000, 0.563, 0.469, -0.336, 0.036, -0.105, 0.438, 0.350, 0.040, 0.357, 0.529, 0.141, 0.370, 0.008, 0.397, -0.383, -0.047, -0.093, 0.860, -0.128, -1.063, -0.479, 0.225, 0.281, -0.799, 0.137, 0.621, 0.373, 0.286, 0.233, 0.989, 0.187, 0.348, 0.374, 1.170, 0.791, -0.630, 0.168, 1.083, 0.686, 0.172, 0.534, 1.098, 0.741, 0.263, 0.901, 1.063, 0.070, -5.000, 0.794, 0.793, -0.222, -5.000, 0.830, 1.040, 0.935, 0.443, 0.757, 0.773, 0.623, 0.590, 0.899, 1.032, 0.151, -5.000, 0.685, 0.479, -0.100, 0.295, 0.352, 0.459, 1.012, 0.032, 0.078, 0.146, -0.027, -0.022, 0.756, 1.356, 0.504, 0.675, 0.724, 1.189, 0.636, -0.209, 0.235, 0.548, 0.995, -0.073, 0.468, 0.735, 0.734, 0.542, 0.698, 1.295, 0.492, 0.690, 0.767, 1.029, 1.118, -0.267, 0.589, 1.203, 1.153, 0.344, 0.822, 1.206, 0.972, 0.475, 0.110, 0.402, -0.689, -5.000, 0.199, 0.607, -1.114, -5.000, 0.317, 0.996, 0.259, -0.194, -0.139, 0.208, -0.146, -0.270, -0.648, 0.065, -0.977, -5.000, -0.336, -0.097, -1.452, -0.369, -0.898, 0.550, 0.147, -0.739, -0.707, -0.609, -0.660, -1.479, -0.829, 0.283, -0.863, -0.620, -0.513, -0.245, -1.257, -1.283, -0.824, -0.106, -0.340, -1.129, -1.103, -0.023, -0.810, -0.506, -0.777, -0.045, -1.136, -0.485, -0.288, 0.218, -0.590, -1.511, -0.505, 0.210, -0.454, -1.209, -0.452, 0.189, -0.589, -1.151, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.390, 0.602, -0.125, -5.000, 0.243, 0.511, -0.800, -5.000, 0.299, 0.819, 0.430, -0.065, 0.562, 0.776, 0.427, 0.313, 0.636, 0.960, 0.370, -5.000, 0.353, 0.221, -0.498, -0.012, -0.135, 0.576, 0.177, -0.453, 0.273, 0.555, 0.302, 0.088, -0.460, 0.357, 0.037, -0.074, -0.183, 0.780, 0.313, -0.855, -0.695, 0.144, 0.115, -0.881, 0.012, 0.733, 0.557, 0.324, -0.138, 0.994, 0.124, 0.304, 0.064, 1.150, 0.845, -0.642, 0.041, 1.085, 0.464, -0.098, 0.580, 1.214, 0.812, 0.239, 1.021, 1.032, 0.176, -5.000, 0.585, 0.774, -0.398, -5.000, 0.802, 1.101, 0.795, 0.131, 0.814, 0.910, 0.575, 0.358, 0.979, 1.056, 0.311, -5.000, 0.473, 0.408, 0.094, 0.444, 0.457, 0.717, 0.701, -0.204, 0.196, 0.523, 0.435, 0.038, 0.554, 1.210, 0.470, 0.565, 0.522, 1.187, 0.723, 0.282, 0.251, 0.178, 0.617, -0.537, 0.599, 0.837, 0.787, 0.822, 0.440, 1.078, 0.596, 0.552, 0.618, 1.007, 0.905, 0.025, 0.362, 0.968, 0.903, -0.052, 0.636, 1.095, 0.788, 0.488, -0.344, -0.066, -1.249, -5.000, -0.948, 0.140, -1.581, -5.000, -0.348, 0.564, -0.402, -0.858, -0.822, -0.319, -0.340, -0.699, -1.384, -0.649, -1.464, -5.000, -1.176, -0.648, -1.920, -1.260, -1.390, -0.236, -0.624, -1.245, -1.428, -1.172, -0.465, -0.882, -0.945, -0.165, -1.187, -0.970, -1.198, -0.317, -1.175, -1.917, -1.654, -0.693, -0.972, -1.424, -1.032, 0.007, -0.427, -0.704, -1.718, -0.020, -0.812, -0.889, -1.088, -0.002, -0.630, -2.685, -0.650, 0.022, -0.626, -1.271, -0.695, 0.122, -0.465, -1.317, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.614, 0.874, 0.291, -5.000, 0.533, 0.945, -0.339, -5.000, 0.522, 0.783, 0.514, -0.104, 0.743, 1.014, 0.521, 0.507, 0.423, 0.701, 0.219, -5.000, 0.197, 0.197, -0.556, 0.140, 0.406, 0.388, 0.357, -0.575, 0.549, 0.544, -0.081, -0.035, 0.036, 0.813, 0.382, 0.334, 0.163, 0.811, 0.275, -0.690, 0.121, 0.272, 0.087, -0.599, 0.219, 0.994, 0.417, 0.547, -0.143, 0.593, -0.061, 0.284, 0.064, 0.749, 0.275, -0.569, 0.188, 0.637, 0.209, -0.392, 0.371, 0.964, 0.424, 0.333, 1.116, 1.296, 0.590, -5.000, 1.050, 1.101, 0.001, -5.000, 0.727, 1.172, 0.604, 0.322, 1.069, 1.166, 0.933, 0.890, 0.640, 0.810, -0.383, -5.000, 0.287, 0.581, -0.252, 0.383, -0.144, 0.346, 0.072, -0.685, 0.323, 0.551, 0.326, 0.090, 0.762, 1.226, 0.624, 0.729, 0.597, 1.145, 0.331, 0.134, 0.104, 0.635, 0.346, -0.356, 0.854, 1.116, 0.956, 0.970, 0.361, 1.207, 0.698, 0.877, 0.527, 1.154, 0.884, -0.255, 0.349, 1.095, 0.446, 0.104, 0.888, 1.117, 1.015, 0.696, 0.654, 0.914, 0.117, -5.000, 0.708, 0.927, -0.599, -5.000, 0.495, 0.860, 0.397, -0.105, 0.557, 0.756, 0.404, 0.307, 0.229, 0.726, -0.106, -5.000, 0.375, 0.738, -1.156, 0.153, 0.265, 0.544, 0.492, -0.279, 0.230, 0.665, 0.042, -0.066, -0.041, 0.915, 0.183, 0.014, -0.019, 0.769, -0.488, 0.088, -0.392, 0.202, 0.092, -0.496, -0.189, 0.599, 0.030, 0.063, 0.323, 1.055, 0.260, 0.276, 0.127, 0.839, -0.023, -0.374, -0.082, 0.290, 0.172, -0.728, 0.234, 0.778, 0.196, -0.426, 0.384, 0.911, -0.109, -5.000, -0.194, 0.098, -1.029, -5.000, -0.070, 0.738, 0.062, -0.510, 0.243, 0.768, 0.053, 0.287, -0.129, 0.566, -0.569, -5.000, -0.619, -0.396, -0.921, -0.400, -1.135, 0.084, -0.276, -0.923, -0.016, 0.288, -0.834, -0.228, -0.454, 0.397, -0.456, -0.027, -1.039, 0.241, -0.713, -1.623, -0.850, -0.257, -0.303, -1.024, -0.524, 0.433, -0.321, -0.558, -0.697, 0.262, -0.555, -0.361, -0.677, 0.327, 0.133, -1.312, -0.666, -0.141, -0.354, -1.240, -0.436, 0.345, -0.367, -0.644, 0.840, 1.119, 0.166, -5.000, 0.774, 1.024, -0.272, -5.000, 0.503, 0.968, 0.452, 0.064, 0.534, 0.833, 0.400, 0.291, 0.598, 0.733, -0.351, -5.000, 0.058, 0.019, -0.778, 0.066, -0.419, -0.003, 0.061, -0.453, 0.087, 0.217, -0.428, -0.216, 0.158, 1.050, 0.120, 0.304, 0.063, 0.907, 0.060, -0.782, -0.499, 0.223, 0.020, -0.510, 0.198, 0.760, 0.162, 0.491, -0.025, 0.879, -0.513, -0.048, -0.038, 0.816, 0.123, -0.975, -0.154, 0.650, 0.123, -0.302, 0.310, 0.858, 0.320, 0.175, 1.021, 1.139, 0.182, -5.000, 0.855, 1.195, -0.147, -5.000, 0.555, 1.037, 0.538, 0.098, 0.563, 0.835, 0.670, 0.413, 0.531, 0.884, -0.699, -5.000, 0.017, 0.183, -0.821, 0.061, -0.387, 0.112, 0.188, -0.613, -0.483, 0.217, -0.486, -0.551, 0.393, 1.182, -0.073, 0.184, 0.229, 1.023, 0.015, -0.762, -0.215, 0.435, 0.251, -0.775, -0.056, 0.808, 0.500, 0.574, 0.355, 1.250, 0.267, 0.536, 0.569, 1.058, 0.927, -0.342, 0.402, 0.995, 0.611, 0.156, 0.622, 1.151, 0.708, 0.426, 0.974, 1.226, -0.225, -5.000, 0.702, 1.090, -0.599, -5.000, 0.425, 1.191, 0.398, 0.133, 0.281, 0.800, 0.293, 0.246, 0.231, 0.812, -0.770, -5.000, 0.107, 0.240, -0.907, 0.102, -0.666, 0.411, -0.115, -0.535, -0.354, -0.228, -0.671, -0.601, 0.268, 1.079, -0.555, 0.020, 0.010, -0.036, -0.965, -0.870, -0.201, 0.395, 0.024, -0.403, -0.110, 0.407, -0.025, 0.364, 0.149, 1.036, -0.533, 0.014, -0.092, 0.032, -0.663, -1.121, -0.264, 0.413, -0.272, -0.542, 0.043, 0.573, -0.142, -0.147, 0.499, 1.043, 0.029, -5.000, 0.435, 1.113, -0.323, -5.000, 0.386, 1.118, 0.658, -0.222, 0.136, 0.747, 0.098, 0.254, 0.226, 0.733, -0.146, -5.000, 0.121, 0.547, -1.038, -0.127, -0.517, 0.577, 0.107, -0.488, -0.318, -0.144, -0.725, -0.233, 0.161, 0.868, -0.014, 0.134, -0.022, 0.439, -0.632, -1.014, -0.567, 0.132, -0.263, -0.923, -0.228, 0.251, -0.201, -0.387, 0.215, 0.781, -0.065, -0.035, -0.056, 0.700, 0.037, -0.970, -0.320, 0.490, -0.200, -0.938, -0.241, 0.325, -0.307, -0.683, 0.421, 0.376, -0.640, -5.000, 0.119, 0.180, -0.762, -5.000, 0.635, 0.835, 0.360, -0.028, 0.535, 0.629, 0.008, 0.438, 0.773, 0.797, -0.233, -5.000, 0.430, 0.219, -0.687, -0.243, -0.259, 0.121, 0.187, -0.348, 0.459, 0.528, -0.121, 0.324, 0.250, 0.394, -0.065, 0.128, 0.257, 0.667, 0.134, -1.104, 0.128, 0.164, 0.099, -0.765, 0.501, 0.495, 0.242, 0.103, 0.471, 0.914, -0.027, 0.557, 0.606, 1.185, 0.612, -0.681, 0.473, 1.092, 0.839, -0.076, 0.872, 1.250, 0.755, 0.227, 0.822, 0.596, -0.443, -5.000, 0.664, 0.383, -0.387, -5.000, 0.959, 0.717, 0.823, 0.154, 0.936, 0.749, 0.309, 0.657, 0.967, 0.932, -0.129, -5.000, 1.002, 0.180, -0.529, 0.272, 0.221, 0.397, 0.778, -0.253, 0.636, 0.315, -0.099, 0.238, 0.929, 1.233, 0.347, 0.798, 1.111, 1.133, 0.488, -0.945, 0.679, 0.808, 1.159, -0.113, 0.972, 0.995, 0.669, 0.669, 0.835, 1.158, 0.424, 0.819, 1.051, 1.048, 1.138, -0.718, 0.849, 1.156, 1.134, 0.333, 1.159, 1.307, 0.897, 0.516, -0.353, -0.536, -1.323, -5.000, 0.185, 0.061, -0.809, -5.000, 0.421, 0.401, 0.142, -0.271, 0.115, 0.036, -0.417, -0.478, -0.383, -0.039, -1.029, -5.000, -0.087, -0.022, -1.546, -0.331, -0.090, 0.035, -0.035, -0.689, -0.066, -0.276, -1.002, -0.609, -0.646, 0.046, -1.498, -0.550, -0.359, 0.040, -1.918, -1.552, -0.800, -0.798, -0.250, -1.284, -0.656, -0.041, -1.057, -0.720, -0.507, -0.293, -1.548, -0.564, -0.090, 0.547, -1.506, -1.180, -0.202, 0.007, -0.381, -1.312, 0.046, 0.079, -0.992, -1.273, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.078, -0.304, -1.578, -5.000, -0.041, -0.247, -1.205, -5.000, 0.164, 0.518, -0.125, -0.324, 0.415, 0.523, 0.018, 0.101, 0.544, 0.479, 0.037, -5.000, 0.369, -0.098, -0.749, -0.361, -0.323, 0.247, -0.045, -0.586, 0.458, 0.404, -0.167, -0.016, -0.462, -0.042, -0.503, -0.169, -0.097, 0.669, -0.069, -1.203, -0.310, -0.085, -0.140, -1.144, 0.121, 0.220, -0.157, -0.233, 0.011, 0.718, -0.155, 0.340, 0.350, 0.976, 0.543, -0.818, 0.248, 0.946, 0.325, -0.220, 0.731, 1.171, 0.463, 0.044, 0.513, -0.138, -0.859, -5.000, 0.257, -0.092, -1.440, -5.000, 0.669, 0.511, 0.251, -0.307, 0.586, 0.315, 0.191, 0.191, 0.718, 0.609, -0.382, -5.000, 0.409, -0.085, -0.313, -0.083, -0.013, -0.139, -0.032, -0.438, 0.379, 0.176, -0.372, -0.322, 0.395, 0.489, -0.133, 0.211, 0.482, 0.637, -0.427, -0.541, 0.113, 0.135, -0.156, -0.748, 0.397, 0.367, -0.246, 0.019, -0.071, 0.434, -0.466, -0.157, 0.233, 0.602, 0.165, -1.345, 0.008, 0.505, 0.053, -0.579, 0.363, 0.700, -0.116, -0.237, -0.747, -0.783, -1.203, -5.000, -0.379, -0.184, -2.373, -5.000, -0.794, 0.120, -0.584, -0.922, -0.450, -0.564, -0.262, -0.717, -0.651, -0.799, -1.215, -5.000, -0.480, -0.300, -1.117, -1.347, -1.155, -0.229, -0.254, -1.580, -0.472, -0.158, -0.763, -0.546, -1.335, -0.458, -1.731, -0.958, -1.046, -0.600, -1.235, -2.179, -0.963, -0.269, -0.364, -1.077, -1.392, -0.402, -1.381, -1.347, -1.584, -0.388, -1.694, -0.892, -1.151, -0.802, -0.573, -3.427, -0.442, -0.197, -0.989, -1.406, -0.760, -0.762, -0.963, -1.464, 0.555, 0.703, -0.475, -5.000, 0.465, 0.868, -0.469, -5.000, 0.243, 0.710, 0.427, 0.024, -0.163, 0.250, 0.053, 0.006, 0.401, 0.634, -0.199, -5.000, 0.001, 0.017, -1.230, -0.194, -0.267, -0.247, 0.161, -1.122, -0.157, 0.000, -0.318, -0.646, 0.064, 0.779, -0.082, -0.127, -0.583, 0.186, -0.783, -1.334, -1.549, -1.102, -0.116, -1.655, -0.881, -0.448, -0.557, -0.206, -0.084, 0.777, -0.629, -0.634, -0.432, 0.159, -0.531, -1.815, -0.701, 0.036, 0.297, -0.750, -0.212, 0.221, -0.343, -0.680, -0.109, -0.026, -1.244, -5.000, -0.055, 0.126, -2.031, -5.000, 0.315, 0.131, -0.213, -0.634, 0.471, 0.584, -0.130, 0.263, -0.032, -0.525, -0.997, -5.000, 0.148, 0.040, -0.665, -0.077, -0.491, 0.008, -0.796, -1.116, 0.543, -0.550, -0.996, -0.442, -0.357, -0.388, 0.061, -0.264, -0.354, 0.282, -0.442, -1.435, -0.019, -0.219, -0.134, -1.423, -0.021, -0.049, -0.413, -0.387, -0.618, -0.110, -0.624, -0.268, -0.357, 0.630, -0.132, -1.597, -0.061, -0.267, -0.728, -1.130, 0.275, 0.391, -0.161, -0.364, 0.581, 0.589, -0.575, -5.000, 0.602, 0.526, -0.673, -5.000, 0.378, 0.516, 0.223, -0.357, 0.877, 0.654, 0.564, 0.695, 0.247, 0.186, -0.959, -5.000, 0.100, 0.075, -1.016, -0.025, -0.591, -0.526, -0.972, -1.175, 0.303, 0.181, -0.819, -0.376, 0.646, 0.893, -0.032, 0.271, 0.679, 0.696, -0.113, -1.540, 0.101, 0.318, 0.229, -0.342, 0.562, 0.719, 0.028, 0.316, 0.196, 0.547, -0.302, 0.334, 0.059, 0.953, -0.442, -1.865, 0.216, 0.535, -0.657, -0.498, 0.659, 0.811, 0.580, -0.200, 0.303, 0.381, -0.892, -5.000, 0.557, 0.402, -0.442, -5.000, 0.365, 0.365, 0.338, -0.358, 0.606, 0.657, 0.104, 0.134, 0.381, 0.489, -0.336, -5.000, 0.594, 0.481, 0.251, 0.299, 0.055, 0.357, 0.355, -0.246, 0.357, 0.311, 0.189, 0.383, 0.208, 0.536, -0.245, -0.128, -0.041, 0.043, -1.016, -0.252, 0.099, -0.369, 0.008, -0.839, -0.217, 0.001, -0.616, -0.338, 0.037, 0.955, -0.331, 0.047, 0.069, 0.517, -0.665, -0.487, -0.039, -0.154, 0.126, -0.481, 0.277, 0.511, -0.554, -0.939, -0.493, 0.285, -1.190, -5.000, -0.648, -0.532, -2.051, -5.000, -0.242, 0.215, -0.268, -0.849, -0.104, 0.366, -0.728, 0.106, -0.304, 0.195, -1.328, -5.000, 0.194, -0.433, -5.000, -0.822, -1.723, 0.219, -0.176, -1.176, -0.170, -0.062, -0.927, -0.293, -0.716, -0.025, -1.168, -0.358, -0.847, -0.041, -0.673, -2.707, -0.810, -0.417, -0.128, -1.524, -0.692, -0.415, -0.898, -0.982, -0.518, -0.287, -1.066, -0.587, -0.617, 0.065, -0.932, -1.215, -0.935, -0.624, -0.917, -1.040, -0.491, -0.049, -0.819, -1.240, 0.684, 0.838, 0.076, -5.000, 0.612, 0.820, -0.986, -5.000, 0.419, 0.876, 0.315, 0.118, 0.220, 0.555, -0.084, 0.250, 0.256, 0.288, -1.112, -5.000, -0.169, -0.467, -0.929, -0.231, -0.552, -0.053, 0.040, -0.841, 0.007, -0.177, -1.086, -0.456, 0.154, 0.669, -0.140, 0.132, 0.004, 0.434, -0.787, -0.883, -0.548, -0.110, -0.336, -0.949, -0.001, 0.040, 0.244, 0.190, -0.267, 0.391, -0.729, -0.304, -0.193, 0.510, 0.069, -1.039, -0.504, 0.580, -0.035, -0.491, 0.129, 0.592, 0.060, -0.191, 0.720, 0.379, -0.871, -5.000, 0.658, 0.434, -1.168, -5.000, 0.219, 0.206, -0.102, -0.621, 0.419, 0.180, -0.191, 0.010, 0.545, 0.359, -1.401, -5.000, -0.044, -0.130, -1.243, -0.733, -0.498, -0.740, -0.585, -0.759, -0.233, -0.039, -0.930, -0.568, 0.122, 0.753, -0.771, -0.178, 0.034, 0.700, -0.638, -1.062, -0.343, -0.542, 0.164, -1.358, 0.173, 0.482, -0.486, -0.046, 0.342, 0.883, -0.422, 0.299, 0.365, 0.890, 0.195, -0.800, 0.456, 0.470, 0.296, -0.368, 0.526, 0.824, -0.026, 0.112, 0.577, 0.431, -1.172, -5.000, 0.529, 0.319, -1.328, -5.000, 0.463, 0.886, 0.024, -0.415, 0.269, 0.331, -0.207, -0.103, 0.142, 0.481, -1.043, -5.000, 0.139, -0.017, -1.212, -0.461, -0.844, -0.193, -0.299, -0.953, -0.442, -0.334, -0.918, -0.690, -0.174, 0.311, -1.156, -0.670, -0.634, -0.729, -2.137, -2.369, -0.622, -0.827, -0.413, -0.752, -0.563, -0.310, -1.415, -0.438, -0.392, 0.730, -1.425, -0.539, -0.449, -0.074, -1.151, -1.673, -0.085, -0.389, -0.612, -0.893, -0.256, -0.079, -0.803, -0.812, 0.105, 0.111, -1.013, -5.000, 0.081, 0.292, -1.323, -5.000, 0.056, 0.709, 0.265, -0.632, 0.045, 0.293, -0.615, -0.071, -0.009, 0.057, -0.727, -5.000, 0.065, -0.015, -0.892, -0.637, -0.282, 0.299, 0.184, -0.605, -0.284, -0.407, -1.212, -0.569, -0.130, -0.082, -0.717, -0.178, -0.629, -0.301, -2.041, -2.060, -0.855, -0.486, -0.618, -1.186, -0.750, -0.614, -0.978, -0.681, 0.017, 0.263, -0.926, -0.241, -0.006, 0.214, -0.656, -1.530, -0.573, 0.227, -0.020, -0.967, -0.366, -0.018, -0.955, -0.751, 0.295, 0.624, -0.239, -5.000, 0.238, 0.569, -0.356, -5.000, 0.335, 0.468, 0.439, -0.158, 0.138, 0.226, 0.181, 0.142, 0.104, 0.320, -0.348, -5.000, -0.253, -0.503, -0.491, -0.412, -0.567, -0.040, -0.068, -1.527, -0.002, 0.115, -0.290, -0.220, -0.738, 0.008, -0.832, -0.683, -0.760, 0.213, -0.036, -1.251, -1.038, -0.439, -0.011, -1.418, -0.728, -0.398, -0.363, -0.379, -0.684, 0.256, -0.554, -0.384, -0.569, 0.217, -0.192, -1.719, -0.749, 0.324, -0.101, -1.118, -0.239, 0.485, -0.225, -0.484, 0.848, 0.946, 0.139, -5.000, 0.855, 1.158, 0.187, -5.000, 0.948, 1.020, 1.129, 0.103, 0.746, 0.863, 0.942, 0.539, 0.475, 0.463, -0.624, -5.000, 0.192, 0.100, -0.864, 0.290, -0.099, 0.119, 0.467, -0.612, -0.360, 0.047, 0.023, -0.755, 0.429, 0.877, 0.357, 0.520, 0.762, 1.060, 0.650, -0.036, 0.437, 0.203, 0.931, -0.135, 0.379, 0.819, 0.610, 0.917, 0.249, 0.921, 0.642, 0.438, 0.589, 0.882, 0.932, -0.294, 0.190, 0.999, 1.094, -0.034, 0.641, 1.174, 0.926, 0.641, 0.089, 0.284, -0.828, -5.000, 0.367, 0.898, -1.061, -5.000, 0.145, 0.666, 0.342, -0.318, -0.455, -0.029, 0.136, -0.459, -0.476, 0.080, -1.210, -5.000, -0.340, -0.017, -0.929, -0.193, -1.172, 0.134, 0.078, -0.949, -0.540, -0.624, -0.581, -1.639, -0.810, 0.079, -0.772, -0.654, -0.377, 0.412, -0.425, -0.737, -1.193, -0.491, -0.102, -0.958, -0.862, -0.135, -0.461, -0.579, -0.939, 0.097, -0.712, -0.596, -0.840, 0.225, -0.704, -1.184, -0.609, 0.268, -0.200, -1.532, -0.523, 0.274, -0.639, -0.941, 0.443, 0.753, -0.438, -5.000, 0.299, 1.028, -0.804, -5.000, -0.112, 0.655, 0.330, -0.640, -0.310, 0.285, 0.184, -0.185, 0.114, 0.542, -0.487, -5.000, -0.340, 0.159, -0.927, -0.184, -1.174, -0.085, -0.382, -0.805, -0.167, -0.514, -0.704, -0.716, -0.501, 0.686, -0.340, -0.409, -0.448, 0.587, -0.545, -1.609, -0.970, -0.187, 0.305, -1.217, -0.397, -0.024, 0.016, -0.178, -0.533, 0.522, -0.805, -0.583, -0.567, 0.251, -0.110, -1.491, -1.084, 0.071, -0.378, -0.936, -0.472, 0.194, -0.399, -0.849, 0.092, 0.168, -0.434, -5.000, -0.046, 0.436, -0.972, -5.000, 0.336, 0.546, 0.436, -0.092, 0.043, 0.304, 0.303, 0.097, -0.115, -0.037, -0.232, -5.000, -0.477, -0.357, -0.559, 0.098, -0.972, -0.382, -0.306, -1.142, 0.386, 0.288, -0.300, -0.161, -1.171, 0.080, -0.047, -0.485, -1.193, 0.041, -0.320, -1.511, -1.270, -0.312, -0.143, -1.367, -0.606, 0.108, -0.274, -0.246, -0.999, 0.065, -0.945, -0.651, -0.578, 0.365, -0.329, -1.359, -0.932, 0.082, -0.396, -1.108, -0.298, 0.254, -0.131, -0.762, 1.035, 0.818, -0.031, -5.000, 0.375, 0.525, -0.110, -5.000, 0.974, 0.910, 0.669, 0.208, 0.715, 0.682, 0.738, 0.459, 0.694, 0.490, -0.259, -5.000, -0.267, -0.575, -0.206, 0.233, -0.142, 0.075, 0.241, -0.559, 0.295, -0.052, 0.362, -0.243, 0.612, 1.202, 0.645, 0.652, 0.511, 0.622, 0.466, -0.447, 0.234, 0.713, 0.495, 0.219, 0.532, 0.945, 0.499, 0.833, -0.156, 0.728, -0.095, 0.111, -0.065, 0.620, 0.220, -0.530, 0.046, 0.745, 0.342, -0.294, 0.462, 0.913, 0.459, 0.361, -0.414, 0.019, -1.161, -5.000, -0.454, 0.682, -1.168, -5.000, -0.504, 0.787, -0.247, -0.453, -0.982, -0.085, -0.209, -0.967, -0.742, -0.249, -2.496, -5.000, -1.893, -0.208, -0.742, -0.634, -1.605, -0.358, -0.316, -0.796, -0.855, -0.336, -0.713, -0.836, -1.366, -0.267, -1.012, -0.581, -1.026, 0.348, -0.651, -1.427, -0.959, -0.213, -0.064, -0.831, -0.808, -0.149, -0.472, -0.451, -1.313, -0.270, -1.087, -1.075, -1.334, -0.927, -1.378, -5.000, -1.416, 0.229, -1.205, -1.471, -0.771, 0.119, -0.847, -1.191, -0.156, -0.233, -1.259, -5.000, -0.479, 0.216, -1.018, -5.000, -1.048, 0.001, -0.873, -1.264, -1.555, -1.050, -0.894, -1.330, -0.455, -0.381, -1.923, -5.000, -1.041, -0.972, -1.506, -1.824, -2.329, -1.410, -1.084, -1.893, -1.163, -0.860, -1.424, -1.741, -1.216, -1.103, -1.180, -1.643, -2.399, -1.023, -1.564, -2.427, -2.156, -1.304, -1.534, -2.058, -1.877, -0.874, -1.379, -1.084, -1.706, -0.679, -1.711, -1.912, -2.935, -1.230, -0.813, -2.136, -2.421, -1.297, -1.592, -2.043, -1.543, -0.832, -1.245, -1.668, -0.042, 0.188, -0.633, -5.000, -0.441, 0.244, -0.940, -5.000, 0.242, 0.404, 0.087, -0.389, -0.079, 0.461, 0.089, -0.063, -0.229, -0.132, -0.808, -5.000, -1.259, -0.349, -1.562, -0.525, -0.230, -0.368, -0.648, -1.101, 0.096, 0.129, -1.423, -0.757, -1.220, 0.005, -0.781, -0.997, -1.249, 0.105, -1.350, -2.047, -0.939, -0.537, -1.112, -1.591, -0.707, 0.100, -0.319, -0.635, -0.932, -0.017, -1.162, -0.838, -0.809, 0.215, -1.257, -2.074, -0.762, -0.069, -0.533, -1.696, -0.439, 0.279, -0.704, -1.172, 0.493, 0.619, -0.422, -5.000, 0.058, 0.408, -0.734, -5.000, 0.246, 0.586, -0.286, -0.191, 0.260, 0.457, 0.576, 0.159, -0.141, -0.021, -1.066, -5.000, -0.769, -0.464, -0.683, -0.840, -0.642, -0.345, -0.466, -0.847, -0.191, -0.418, -0.430, -0.455, -0.403, 0.594, -0.442, -0.433, -0.994, 0.296, -0.475, -1.628, -0.645, -0.085, -0.344, -0.995, -0.299, 0.181, 0.135, -0.295, -0.161, 0.430, -0.534, -0.614, -0.681, 0.462, 0.059, -1.278, -0.427, 0.596, -0.461, -0.702, 0.198, 0.562, 0.207, -0.418, 0.247, 0.390, -0.490, -5.000, 0.297, 0.815, -1.532, -5.000, 0.064, 0.452, 0.098, -0.384, 0.258, 0.535, 0.141, -0.072, 0.155, 0.400, -0.844, -5.000, -0.327, 0.237, -0.698, -0.277, 0.047, 0.303, 0.043, -0.342, -0.095, 0.063, -0.533, -0.212, -0.220, 0.647, -0.106, -0.388, -0.211, 0.693, -0.653, -0.416, -0.345, 0.174, -0.085, -1.003, -0.213, 0.341, -0.356, -0.374, -0.087, 0.584, -0.288, -0.246, -0.744, 0.590, -0.395, -0.600, -0.318, 0.101, 0.002, -1.084, -0.159, 0.390, -0.382, -0.788, -0.093, -0.038, -0.984, -5.000, -0.905, -0.617, -1.689, -5.000, -0.771, -0.138, -0.870, -0.660, -0.661, -0.330, -0.431, -0.258, -0.469, -0.121, -1.578, -5.000, -0.650, -1.057, -0.802, -1.320, -0.886, -1.264, -1.195, -1.853, -0.666, -0.632, -2.067, -0.869, -1.256, -0.491, -0.765, -1.327, -1.581, -0.446, -1.171, -2.262, -1.571, -0.776, -0.785, -1.816, -1.015, -1.339, -0.972, -1.431, -1.106, -0.101, -1.555, -1.418, -1.275, -0.654, -0.765, -2.626, -1.370, -0.817, -0.839, -1.477, -0.851, -0.523, -1.058, -1.558, 0.698, 0.503, -0.282, -5.000, 0.037, -0.034, -0.906, -5.000, 0.390, 0.543, 0.005, -0.147, -0.074, 0.146, -0.271, -0.083, 0.760, 0.924, -0.193, -5.000, 0.057, 0.002, -0.983, -0.242, -0.113, 0.341, 0.069, -0.330, 0.136, 0.244, -0.544, -0.316, -0.605, 0.475, -0.597, -0.605, -1.165, -0.085, -0.878, -2.677, -1.160, -0.345, -0.478, -1.317, -0.718, -0.438, -0.666, -0.517, -0.379, 0.509, -1.029, -0.795, -0.707, -0.249, -0.864, -1.851, -0.304, 0.285, -0.294, -1.114, -0.431, 0.213, -0.275, -0.662, 0.906, 0.716, -0.190, -5.000, 0.416, 0.620, -1.036, -5.000, 0.498, 0.843, 0.026, 0.364, 0.114, 0.140, 0.265, 0.155, 0.497, 0.530, -0.868, -5.000, -0.308, -0.101, -0.808, -0.455, -0.255, 0.069, -0.545, -0.858, -0.627, 0.411, -0.579, -0.618, 0.174, 0.977, 0.288, -0.140, -0.408, 0.456, -1.410, -1.428, -0.279, -0.042, 0.182, -0.503, -0.429, -0.095, -0.281, -0.423, 0.260, 0.960, 0.033, -0.175, 0.202, 0.620, 0.194, -0.768, 0.347, 0.843, 0.451, -0.059, 0.378, 0.809, 0.325, -0.265, 0.569, 0.583, -0.490, -5.000, 0.369, 0.590, -0.904, -5.000, 0.360, 0.671, -0.068, -0.176, -0.224, 0.187, -0.119, -0.151, 0.096, 0.648, -0.795, -5.000, -0.244, -0.005, -1.223, -0.574, -0.460, 0.197, -0.166, -0.553, -0.500, -0.300, -0.434, -0.504, -0.536, 0.684, -0.357, -0.730, -0.646, 0.022, -0.893, -2.108, -0.499, -0.073, -0.188, -0.857, -0.729, -0.048, -0.801, -0.583, -0.085, 0.346, -0.775, -0.273, -0.803, 0.080, -0.616, -1.730, -0.078, 0.281, -0.385, -1.096, -0.219, 0.243, -0.642, -0.816, 0.745, 0.791, -0.377, -5.000, 0.603, 0.939, -0.813, -5.000, 0.448, 0.747, 0.360, -0.157, -0.195, 0.088, -0.379, 0.085, 0.360, 0.772, -0.124, -5.000, -0.115, 0.257, -0.808, -0.374, -0.172, 0.287, 0.357, -0.632, -0.274, -0.076, -1.075, -0.277, -0.216, 0.814, -0.349, -0.422, -0.593, 0.178, -0.635, -2.427, -0.673, -0.264, 0.156, -1.242, -0.995, -0.344, -0.793, -0.463, -0.191, 0.778, -0.575, -0.573, -0.669, 0.289, -0.202, -1.619, -0.302, 0.280, -0.375, -0.871, -0.563, 0.025, -0.726, -1.038, -0.076, 0.180, -0.676, -5.000, -0.290, -0.101, -1.569, -5.000, 0.286, 0.536, 0.141, -0.231, 0.356, 0.460, 0.204, 0.140, 0.102, 0.264, -0.590, -5.000, -0.181, -0.403, -0.880, -0.325, -0.626, -0.296, -0.132, -0.695, 0.245, 0.245, -0.398, 0.153, -0.271, 0.260, -0.528, 0.259, -0.369, 0.036, -0.694, -1.216, -0.721, -0.137, -0.433, -1.136, -0.189, 0.188, -0.633, -0.137, -0.252, 0.461, -0.397, 0.234, -0.224, 0.428, -0.213, -0.741, -0.175, 0.506, 0.015, -0.400, 0.157, 0.721, -0.077, -0.257, 0.749, 0.807, -0.417, -5.000, 0.702, 0.649, -1.010, -5.000, 1.001, 1.005, 0.903, 0.425, 0.986, 1.019, 0.716, 0.480, 0.795, 0.916, -0.350, -5.000, 0.607, 0.480, -0.614, 0.549, 0.374, 0.578, 0.720, 0.182, 0.349, 0.494, 0.187, 0.026, 0.607, 1.326, 0.094, 0.925, 0.932, 1.119, -0.394, -0.021, 0.444, 0.771, 0.666, -0.031, 0.725, 0.989, 0.354, 0.740, 0.563, 1.188, 0.502, 0.940, 0.914, 0.978, 0.683, 0.041, 0.848, 1.111, 0.920, 0.361, 0.933, 1.236, 0.703, 0.612, 0.082, 0.210, -1.295, -5.000, -0.055, 0.649, -1.458, -5.000, 0.508, 0.889, 0.201, -0.486, 0.162, 0.442, 0.043, -0.276, -0.365, 0.298, -1.274, -5.000, -0.326, 0.114, -1.617, 0.159, -0.557, -0.045, -0.110, -0.398, -0.139, -0.199, -0.549, -0.765, -0.900, 0.049, -1.062, -0.543, -0.276, 0.207, -1.241, -1.052, -0.892, -0.593, -0.410, -1.006, -0.921, -0.385, -1.110, -0.708, -0.643, 0.043, -0.691, -0.228, -0.371, 0.546, -0.719, -0.775, -0.235, 0.189, -0.393, -0.927, -0.304, 0.332, -1.020, -0.890, 0.358, 0.597, -0.768, -5.000, 0.164, 0.696, -1.141, -5.000, 0.348, 0.769, 0.285, -0.202, 0.207, 0.597, 0.158, -0.101, 0.181, 0.578, -0.749, -5.000, -0.229, 0.061, -1.334, -0.113, -0.519, 0.181, -0.510, -1.067, 0.058, 0.029, -0.419, -0.524, 0.016, 0.893, -0.572, 0.398, -0.214, 0.773, -1.538, -1.104, -0.394, -0.146, -0.068, -0.763, -0.111, 0.275, -0.404, 0.054, -0.233, 0.586, -0.677, -0.202, -0.241, 0.698, -0.717, -1.192, -0.183, 0.473, -0.434, -0.727, -0.139, 0.326, -0.592, -0.459, -0.337, -0.283, -0.659, -5.000, -0.305, 0.201, -1.783, -5.000, 0.324, 0.339, 0.143, -0.279, 0.343, 0.648, 0.099, 0.104, -0.059, -0.063, -0.565, -5.000, -0.445, -0.500, -2.208, -0.202, -0.255, -0.164, -0.314, -0.583, 0.680, 0.246, -0.006, 0.085, -0.529, 0.375, -0.493, -0.022, -0.324, 0.610, -0.962, -0.685, -0.515, -0.177, -0.526, -1.177, 0.082, 0.772, -0.103, 0.171, -0.369, 0.585, -0.679, 0.202, -0.063, 0.631, -0.308, -0.725, -0.196, 0.473, -0.212, -0.482, 0.353, 0.898, 0.057, 0.111, 0.798, 0.776, -0.248, -5.000, 0.382, 0.483, -0.761, -5.000, 0.977, 1.038, 0.699, 0.151, 0.940, 0.877, 0.711, 0.445, 0.819, 0.880, -0.149, -5.000, 0.338, 0.257, -0.786, 0.554, 0.336, 0.554, -0.027, -0.045, 0.676, 0.704, 0.395, 0.275, 0.624, 1.206, 0.248, 0.831, 0.899, 0.994, 0.101, 0.348, 0.568, 0.654, 0.299, 0.162, 0.811, 1.029, 0.412, 0.928, 0.367, 1.077, 0.342, 0.867, 0.729, 0.697, 0.332, -0.023, 0.602, 1.092, 0.570, -0.062, 0.868, 1.173, 0.418, 0.560, 0.363, 0.762, -0.752, -5.000, -0.555, 0.871, -1.723, -5.000, 0.555, 1.003, 0.149, -0.053, 0.387, 0.930, 0.109, -0.035, 0.189, 0.699, -0.753, -5.000, -0.181, 0.517, -1.135, 0.088, -0.020, 0.267, 0.008, -0.360, 0.391, 0.533, -0.019, -0.099, 0.041, 0.738, -0.290, 0.319, -0.093, 0.251, -0.759, -0.481, -0.249, 0.617, -0.189, -0.547, -0.001, 0.999, -0.408, 0.373, -0.233, 0.499, -0.398, 0.303, -0.214, 0.417, -0.336, -0.767, -0.043, 0.518, -0.481, -0.630, 0.119, 0.608, -0.591, -0.697, -0.216, -0.236, -1.700, -5.000, -0.779, -0.435, -2.393, -5.000, -0.793, -0.021, -1.095, -1.169, -0.829, -0.523, -1.019, -0.849, -0.676, -0.492, -1.533, -5.000, -1.290, -0.917, -2.407, -1.321, -1.373, -0.745, -1.119, -1.601, -0.826, -0.300, -1.545, -0.862, -1.248, -0.495, -0.831, -0.761, -1.833, -0.462, -1.623, -1.793, -1.848, -1.953, -1.592, -2.257, -1.129, -0.998, -1.554, -0.752, -1.150, -0.717, -1.606, -1.069, -1.672, -0.383, -1.407, -1.614, -1.513, -1.218, -1.262, -1.948, -0.931, -0.330, -1.573, -1.248, -0.026, 0.121, -0.842, -5.000, -0.450, 0.253, -1.397, -5.000, 0.243, 0.586, 0.261, -0.260, 0.445, 0.746, 0.084, 0.126, 0.176, 0.259, -1.143, -5.000, -0.458, -0.025, -1.155, 0.127, 0.082, -0.171, -0.304, -0.562, 0.686, 0.570, -0.244, 0.021, -0.241, 0.413, -0.292, 0.091, -0.545, 0.123, -1.615, -1.053, -0.447, 0.065, -0.409, -1.059, -0.195, 0.310, -0.695, -0.158, -0.270, 0.444, -0.457, -0.012, -0.422, 0.412, -1.338, -0.956, -0.225, 0.341, -0.350, -0.726, -0.027, 0.617, -0.650, -0.133, 0.716, 0.912, -0.096, -5.000, 0.493, 0.607, -0.981, -5.000, 0.671, 0.958, 0.219, 0.195, 0.970, 1.033, 0.792, 0.578, 0.607, 0.737, -0.505, -5.000, 0.308, 0.288, -0.840, 0.720, 0.190, 0.594, -0.171, -0.387, 0.796, 0.679, -0.044, 0.254, 0.685, 1.163, 0.430, 0.811, 0.275, 0.926, -0.511, -0.358, -0.139, 0.511, 0.069, -0.389, 0.414, 0.679, -0.125, 0.448, 0.243, 1.082, 0.271, 0.739, 0.183, 1.014, 0.339, -0.565, 0.170, 0.905, 0.166, -0.101, 0.655, 1.012, 0.470, 0.287, 0.325, 0.443, -0.903, -5.000, 0.385, 0.567, -1.029, -5.000, 0.384, 0.464, -0.046, -0.149, 0.641, 0.722, 0.163, 0.096, 0.489, 0.876, -0.544, -5.000, 0.570, 0.713, -0.733, 0.560, 0.319, 0.672, 0.468, -0.132, 0.603, 0.841, 0.100, 0.297, -0.090, 0.908, -0.923, -0.099, -0.129, 0.265, -1.382, -0.210, -0.030, -0.033, -0.241, -0.721, -0.339, -0.053, -1.180, -0.970, -0.044, 0.623, -0.216, 0.006, 0.069, 0.620, -0.304, -0.047, -0.016, 0.045, -0.246, -0.927, -0.096, 0.428, -0.895, -1.201, -0.140, 0.061, -0.612, -5.000, -0.532, -0.625, -1.613, -5.000, -0.399, 0.287, -0.247, -0.545, -0.173, 0.178, -0.248, 0.113, -0.240, 0.226, -1.124, -5.000, -0.682, -0.692, -0.959, -0.636, -0.660, -0.077, -0.704, -0.820, -0.177, -0.161, -1.129, -0.076, -0.620, -0.151, -0.673, -0.542, -1.224, -0.081, -1.203, -2.382, -1.326, -0.661, -0.650, -1.328, -0.760, -0.629, -1.199, -1.133, -0.760, 0.056, -1.312, -0.743, -0.982, -0.123, -1.201, -1.922, -0.920, -0.393, -0.994, -1.363, -0.712, -0.294, -1.062, -1.240, 0.675, 0.800, -0.070, -5.000, 0.259, 0.425, -0.923, -5.000, 0.520, 0.746, 0.212, 0.087, 0.608, 0.766, 0.165, 0.247, 0.576, 0.666, -0.138, -5.000, -0.069, -0.096, -1.382, -0.198, 0.242, 0.336, 0.208, -0.140, 0.480, 0.518, -0.309, -0.011, 0.215, 0.803, -0.378, 0.167, -0.323, 0.339, -0.903, -1.170, -0.645, -0.333, -0.372, -1.092, -0.023, 0.092, -0.454, -0.005, 0.230, 0.902, -0.340, 0.225, -0.016, 0.504, -0.492, -0.939, 0.116, 0.677, 0.075, -0.261, 0.188, 0.761, -0.079, -0.068, 1.024, 1.159, -0.054, -5.000, 0.713, 0.832, -0.924, -5.000, 0.828, 1.091, 0.393, 0.302, 0.851, 0.834, 0.400, 0.475, 0.953, 1.169, -0.223, -5.000, 0.570, 0.489, -0.659, 0.339, 0.415, 0.726, 0.445, 0.036, 0.497, 0.539, -0.135, 0.050, 0.590, 1.273, -0.005, 0.595, 0.251, 0.983, -0.785, -0.640, -0.051, 0.471, 0.408, -0.172, 0.378, 0.657, 0.019, 0.606, 0.546, 1.308, 0.268, 0.769, 0.593, 1.105, 0.435, -0.373, 0.805, 1.172, 0.737, 0.240, 0.594, 1.012, 0.472, 0.295, 0.637, 0.765, -0.640, -5.000, 0.473, 0.241, -1.739, -5.000, 0.719, 0.891, -0.113, 0.092, 0.277, 0.330, 0.020, 0.103, 0.502, 1.032, -0.624, -5.000, 0.361, 0.326, -1.275, 0.136, 0.112, 0.744, 0.071, -0.302, 0.184, -0.023, -0.340, 0.003, -0.053, 0.631, -1.239, -0.090, -0.330, 0.215, -1.832, -1.957, -0.322, -0.057, -0.204, -0.607, -0.475, -0.270, -1.108, -0.529, 0.060, 0.511, -0.537, -0.122, -0.101, 0.577, -0.983, -1.456, 0.169, 0.395, -0.276, -0.776, -0.156, 0.179, -0.930, -0.999, 0.322, 0.414, -0.679, -5.000, 0.215, 0.430, -1.129, -5.000, 0.206, 0.525, -0.059, -0.368, -0.243, 0.090, -0.761, -0.234, 0.192, 0.676, -0.745, -5.000, 0.015, -0.073, -1.341, -0.380, -0.242, 0.293, 0.122, -0.418, -0.252, -0.117, -0.664, -0.166, -0.294, 0.263, -0.470, -0.280, -0.426, -0.150, -1.449, -1.813, -0.981, -0.513, -0.143, -1.255, -0.689, -0.376, -1.424, -0.651, -0.586, 0.311, -0.605, -0.498, -0.466, 0.147, -0.914, -1.425, -0.299, 0.062, -0.488, -0.923, -0.699, -0.318, -1.236, -1.163 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_33(struct _training *tptr) {
  struct _training tinf = {
    0.286, 11, 4.350, { 2.553, 0.337, 0.110 }, { 0.674, -1.632, -1.606 }, 1, 
    { -0.711, 0.035, -1.809, -1.082, -4.000, -4.000, -1.269, -4.000, 2.445, -4.000, -4.000, -4.000, -1.772, 1.075, 1.576, 0.183, 2.201, 0.588, 1.938, 1.817, -4.000, -4.000, 1.642, -4.000, 2.695, -4.000, -4.000, 2.730 }, 
    {{ -0.192, -0.966, -0.836, 0.500},{ 0.111, -0.846, -0.501, 0.238},{ 0.135, -0.508, -0.403, 0.138},{ 0.188, -0.397, -0.444, 0.066},{ 0.280, -0.458, -0.479, -0.024},{ 0.280, -0.451, -0.403, -0.046},{ 0.272, -0.592, -0.444, 0.010},{ 0.331, -0.561, -0.523, -0.059},{ 0.330, -0.430, -0.659, -0.059},{ 0.278, -0.625, -0.642, 0.054},{ 0.259, -0.617, -0.600, 0.068},{ 0.239, -0.417, -0.650, 0.056},{ 0.205, -0.523, -0.451, 0.078},{ 0.242, -0.493, -0.358, 0.003},{ 0.257, -0.424, -0.530, 0.010},{ 0.204, -0.561, -0.339, 0.059},{ 0.248, -0.584, -0.538, 0.061},{ 0.243, -0.515, -0.584, 0.061},{ 0.316, -0.642, -0.625, 0.004},{ 0.308, -0.642, -0.659, 0.022},{ 0.288, -0.458, -0.625, -0.001},{ 0.257, -0.538, -0.577, 0.048},{ 0.227, -0.515, -0.676, 0.099},{ 0.284, -0.458, -0.667, 0.013},{ 0.205, -0.384, -0.501, 0.056},{ 0.235, -0.515, -0.315, 0.004},{ 0.267, -0.352, -0.444, -0.044},{ 0.325, -0.501, -0.600, -0.046},{ 0.282, -0.584, -0.711, 0.054},{ 0.271, -0.515, -0.693, 0.049},{ 0.249, -0.650, -0.667, 0.099},{ 0.248, -0.577, -0.577, 0.068} }, 
    {{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}} }, 
    0.000, { 0.637, 1.416, 0.403, -5.000, 0.354, 0.907, -0.333, -5.000, 0.705, 1.283, 0.582, 0.756, 0.161, 0.806, -0.389, 0.644, -0.062, 0.684, -0.537, -5.000, -0.071, -0.102, -1.433, -0.477, -0.722, 0.317, -0.340, -0.316, 0.451, -0.136, -2.118, -0.110, 0.371, 1.127, -0.011, 0.043, -0.148, 0.576, -1.571, -1.248, 0.131, 0.365, -0.417, -0.231, -0.273, -0.426, -0.495, -0.656, 0.469, 1.233, 0.077, 0.123, 0.433, 1.355, 0.046, -0.061, 0.689, 1.237, 0.881, 0.545, 0.187, 0.953, 0.418, -0.184, 1.389, 1.716, 0.913, -5.000, 1.323, 1.570, 0.687, -5.000, 1.139, 1.484, 1.296, 1.135, 1.026, 1.385, -0.508, 1.233, 0.899, 1.382, 0.477, -5.000, 1.094, 1.276, 0.054, 0.528, 0.791, 1.113, 1.086, 0.516, 1.104, 0.951, -0.783, 0.751, 1.397, 1.774, 1.513, 1.117, 1.286, 1.708, -0.439, 0.584, 0.993, 1.408, 1.097, 0.882, 1.238, 1.281, 1.221, 0.722, 1.222, 1.686, 0.875, 0.910, 1.313, 1.310, 0.794, 0.887, 1.352, 1.607, 1.469, 1.130, 1.175, 1.505, 1.199, 0.737, 0.278, 1.146, -0.102, -5.000, 0.402, 0.640, -0.890, -5.000, 0.325, 0.973, -0.063, 0.301, -0.069, 0.150, -1.368, -0.084, -0.193, 0.949, -0.389, -5.000, -0.330, 0.169, -1.184, -0.660, -0.257, 0.087, -0.354, -0.719, 0.025, -0.626, -2.051, -0.629, -0.291, 1.012, -0.566, -0.691, -0.120, -0.551, -1.427, -1.228, -0.512, -0.416, -0.622, -0.977, -0.443, -0.653, -0.784, -0.705, 0.147, 0.903, -0.661, -0.484, 0.215, 1.078, -1.092, -0.424, 0.537, 1.140, 0.702, 0.313, -0.040, 0.660, -0.876, -1.104, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.039, 1.108, 0.143, -5.000, -0.009, 0.395, -1.625, -5.000, 0.689, 1.285, 0.792, 0.676, 0.260, 1.009, -0.363, 0.819, -0.337, 0.739, 0.009, -5.000, -0.259, -0.352, -1.929, -0.419, 0.095, 1.002, 0.738, -0.182, 0.928, 0.157, -1.687, -0.117, -0.022, 1.306, 0.209, -0.098, -0.660, -0.008, -2.325, -1.842, -0.439, -0.166, -1.524, -0.619, -0.091, -0.710, -0.609, -0.989, 0.062, 1.199, -0.225, -0.313, -0.207, 1.338, -0.983, -0.704, 0.381, 0.484, -0.439, 0.647, -0.117, 0.854, 0.490, -0.528, 1.121, 1.594, 0.704, -5.000, 0.782, 0.972, 0.152, -5.000, 0.827, 1.505, 0.978, 0.637, 0.751, 1.131, 0.860, 1.027, 0.287, 0.640, -0.166, -5.000, 0.251, 0.912, -0.472, -0.227, 0.581, 1.356, 0.818, 0.373, 0.826, 0.810, -0.805, 0.730, 0.941, 1.665, 1.175, 0.658, 0.594, 1.528, -0.606, 0.329, 0.404, 0.656, 0.435, 0.363, 0.888, 0.905, 0.855, 0.401, 0.445, 1.368, 0.001, 0.145, 0.739, 1.409, -0.063, 0.447, 1.077, 1.143, 1.116, 0.844, 0.577, 1.185, 0.650, 0.449, -0.637, 0.616, -1.395, -5.000, -0.730, -0.661, -2.140, -5.000, -0.741, -0.364, -0.626, -1.115, -0.730, -0.315, -1.868, -0.668, -0.576, 0.869, -0.901, -5.000, -0.776, -0.418, -3.058, -3.015, -5.000, 0.167, -0.985, -5.000, -0.091, -0.439, -1.118, -0.485, -1.044, 0.080, -1.709, -1.077, -0.706, -0.201, -5.000, -2.223, -0.629, 0.030, -0.417, -0.647, -0.910, -0.512, -1.580, -0.933, -0.788, 0.013, -1.579, -0.748, -0.495, 0.167, -1.630, -1.773, -0.314, 0.528, 0.340, -0.057, -0.605, -0.003, -1.676, -2.070, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.620, 1.105, 0.167, -5.000, 0.201, 0.878, -0.581, -5.000, 0.427, 0.710, 0.312, 0.388, 0.223, 0.768, -0.639, 0.430, -0.409, 0.183, -1.019, -5.000, -0.238, 0.144, -1.842, -0.292, 0.408, 0.097, -0.344, -0.068, 0.632, 0.665, -2.057, -0.424, 0.337, 0.868, 0.245, 0.167, -0.417, 0.441, -3.189, -1.194, 0.167, 0.372, -0.691, -0.357, 0.244, 0.679, 0.013, -0.085, 0.266, 0.988, -0.204, 0.067, 0.279, 1.260, -0.615, -0.033, 0.591, 1.222, 0.845, 0.293, 0.408, 1.295, 0.493, -0.113, 1.105, 1.508, 0.677, -5.000, 0.925, 0.872, -0.157, -5.000, 0.770, 1.306, 0.718, 0.604, 0.806, 1.066, -0.380, 0.995, 0.503, 0.837, 0.020, -5.000, 0.900, 0.895, -1.306, 0.346, 0.271, 1.345, 0.722, 0.054, 1.148, 0.631, -0.676, 0.938, 1.231, 1.622, 1.394, 0.988, 0.461, 1.431, -5.000, 0.410, 0.547, 1.148, 0.430, 0.329, 0.957, 0.905, 0.920, 0.584, 0.984, 1.544, 0.778, 0.820, 0.857, 1.555, 0.387, 0.692, 1.029, 1.217, 0.789, 0.645, 1.001, 1.281, 0.906, 0.447, 0.599, 0.986, -0.083, -5.000, 0.295, 0.903, -0.972, -5.000, 0.289, 0.465, -0.419, 0.039, 0.196, 0.505, -0.470, 0.187, 0.166, 0.714, -0.326, -5.000, -0.048, 0.887, -1.037, 0.147, 0.568, 0.683, -0.417, -0.503, 0.667, 0.495, -1.636, 0.270, 0.341, 1.391, 0.074, -0.158, -0.044, 0.333, -1.867, -0.050, 0.065, 0.262, -0.385, -0.458, 0.010, -0.260, -0.307, 0.248, 0.431, 0.477, -0.383, -0.204, -0.186, 1.025, -0.280, 0.364, 0.475, 1.046, 0.647, -0.159, 0.176, 0.694, -0.686, -0.972, 0.479, 1.164, 0.180, -5.000, 0.087, 0.477, -5.000, -5.000, 0.206, 0.586, 0.009, -0.288, -0.100, 0.514, -0.449, 0.124, -0.063, 0.679, -0.483, -5.000, 0.079, -0.983, -0.839, -0.579, -0.082, 0.189, -0.201, -0.529, 0.657, 0.041, -0.780, 0.295, 0.399, 0.978, 0.087, 0.021, -0.265, 0.941, -0.829, -0.618, 0.294, 0.266, -0.461, -0.275, 0.354, -0.024, -0.015, 0.277, 0.300, 1.021, -0.467, 0.013, 0.164, 1.241, 0.065, -0.189, 0.210, 1.005, 0.494, -0.472, 0.337, 0.919, 0.289, -0.415, 0.208, 1.082, -0.166, -5.000, -0.118, 0.687, -0.588, -5.000, 0.133, 0.828, 0.159, 0.017, -0.419, 0.352, -0.725, 0.086, -0.315, 0.508, -0.681, -5.000, -0.380, 0.074, -1.099, -0.525, -0.483, 0.348, 0.078, -0.640, 0.360, 0.059, -1.056, -0.190, 0.115, 0.813, -0.495, -0.115, -0.357, 0.492, -1.761, -0.735, -0.224, 0.298, -0.474, -0.429, -0.319, -0.672, -0.487, -0.546, 0.032, 0.816, -0.700, -0.423, -0.112, 0.893, -0.528, -0.218, 0.024, 0.747, 0.373, 0.007, -0.180, 0.354, 0.199, -0.202, 0.820, 1.397, -0.002, -5.000, 0.694, 0.941, -0.519, -5.000, 0.428, 1.139, 0.670, 0.518, 0.173, 0.649, 0.108, 0.504, -0.267, 0.307, -0.899, -5.000, 0.214, 0.519, -1.086, -0.288, -0.342, -0.114, 0.292, -0.553, 0.362, -0.021, -0.593, -0.099, 0.796, 1.458, 0.847, 0.525, 0.746, 1.339, -5.000, -0.014, 0.311, 0.777, 0.519, 0.059, 0.715, 0.426, 0.633, 0.152, 0.576, 1.345, -0.101, 0.289, 0.589, 1.209, -0.048, 0.281, 0.584, 1.084, 1.036, 0.454, 0.578, 1.071, 0.374, 0.203, -0.433, 0.461, -1.182, -5.000, -0.431, 0.535, -1.389, -5.000, -0.010, 0.631, -0.488, -0.273, -0.489, -0.180, -0.990, -0.309, -0.914, 0.170, -0.975, -5.000, -0.598, -0.616, -1.469, -1.408, -0.819, 0.070, -1.016, -0.729, -0.364, -1.039, -1.458, -0.806, -0.641, -0.418, -1.923, -1.302, -0.545, -0.404, -1.748, -1.162, -0.867, -0.212, -0.745, -1.166, -1.591, -1.173, -1.388, -0.894, -0.510, 0.796, -1.368, -0.984, -0.637, -0.747, -2.084, -1.498, -0.581, -0.586, -1.490, -1.447, -1.094, -0.815, -1.879, -1.591, 0.517, 1.299, -0.107, -5.000, 0.501, 0.883, -0.587, -5.000, 0.496, 0.977, 0.446, 0.274, 0.083, 0.419, -0.386, -0.026, -0.056, 0.939, -0.248, -5.000, -0.312, 0.300, -1.023, -0.080, 0.029, 0.647, -0.030, -0.253, 0.604, 0.030, -0.663, -0.069, 0.425, 1.220, -0.217, 0.146, 0.312, 0.644, -1.673, -0.539, 0.248, 0.499, -0.757, -0.378, 0.155, -0.007, -0.234, 0.199, 0.343, 1.188, -0.410, -0.082, 0.391, 1.267, -0.451, -0.204, 0.376, 1.213, 0.425, -0.175, -0.097, 0.762, -0.126, -0.360, 0.117, 0.895, -0.948, -5.000, -0.421, 0.214, -1.082, -5.000, -0.223, 0.679, -0.629, 0.054, -0.365, -0.010, -1.408, -0.075, -1.365, -0.287, -1.641, -5.000, -1.312, -0.874, -1.292, -1.483, -1.666, -0.990, -1.135, -1.108, -0.430, -0.876, -2.208, -1.315, -0.160, 0.298, -1.214, -0.826, -1.109, -0.307, -2.935, -1.574, -1.132, -0.740, -0.808, -1.227, -0.732, -1.254, -1.086, -1.873, 0.239, 0.931, -0.445, -0.123, -0.183, 0.902, -0.754, -0.499, 0.642, 1.023, 0.374, 0.160, -0.084, 0.778, 0.137, -0.459, 0.899, 1.424, -0.118, -5.000, 0.333, 0.953, -0.661, -5.000, 0.504, 1.257, 0.791, 0.543, 0.707, 0.720, -0.344, 0.952, -0.325, 0.484, -0.567, -5.000, 0.414, 0.687, -1.058, -0.390, -0.539, -0.083, -0.664, -0.887, 0.214, -0.160, -1.896, -0.260, 0.852, 1.530, 0.393, 0.339, 0.193, 1.097, -5.000, -0.424, 0.241, 0.350, 0.222, 0.195, 0.593, -0.173, -0.433, -0.751, 0.844, 1.460, 0.475, 0.283, 0.833, 0.855, -0.211, 0.283, 0.915, 1.318, 0.937, 0.662, 0.747, 1.152, 0.381, 0.212, 0.120, 1.120, -0.970, -5.000, 0.248, 0.216, -1.496, -5.000, 0.036, 0.615, -0.715, -0.095, -0.292, -0.084, -2.259, -0.568, -1.480, 0.332, -1.762, -5.000, -0.344, -0.483, -1.191, -1.636, -1.023, -0.483, -1.070, -0.850, -0.745, -1.377, -1.423, -1.705, -0.647, 0.990, -1.414, -0.987, -0.601, -0.559, -2.350, -1.717, -0.572, -0.153, -1.266, -0.805, -0.683, -1.219, -2.590, -1.032, -0.054, 1.448, -2.117, -0.551, -0.025, 0.952, -1.973, -0.043, 0.396, 0.970, -0.214, 0.158, -0.269, 0.078, -2.102, -1.789, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.563, 0.526, -0.590, -5.000, -0.913, -0.185, -1.351, -5.000, -0.484, 0.581, -0.354, -0.297, -0.092, 0.480, -0.773, 0.378, -1.248, -0.806, -0.837, -5.000, -1.470, -0.071, -1.575, -0.942, -1.160, -0.502, -0.129, -0.809, -0.020, -1.020, -1.740, -0.584, -0.746, 0.598, -0.382, -0.774, -2.011, -0.601, -5.000, -2.648, -1.451, -0.698, -1.286, -2.629, -1.615, -1.024, -1.673, -2.013, 0.074, 0.992, -0.348, 0.104, -0.319, 1.168, -1.129, -0.622, 0.210, 1.148, -0.120, -0.439, -0.173, 0.708, 0.328, -0.562, 0.714, 1.226, -0.381, -5.000, 0.240, 0.877, -0.696, -5.000, 0.211, 0.934, 0.560, -0.266, 0.152, 0.649, -0.238, 0.422, -0.579, -0.010, -0.745, -5.000, -0.766, 0.288, -2.954, -1.254, 0.093, 0.404, -0.708, -0.754, 0.180, 0.230, -0.727, 0.138, 0.269, 1.016, 0.737, 0.142, -0.201, 1.076, -0.526, -0.401, -0.411, -0.003, 0.254, -1.070, 0.228, 0.350, -0.471, -0.524, -0.086, 0.769, -0.258, -0.050, 0.237, 0.989, -0.532, -0.037, 0.595, -0.112, 0.323, -0.212, -0.055, 0.616, -0.094, -0.008, -0.881, -0.022, -1.848, -5.000, -1.526, -1.611, -5.000, -5.000, -1.953, -0.774, -1.736, -1.250, -1.045, -0.786, -1.126, -1.155, -2.231, -0.356, -2.200, -5.000, -2.164, -1.619, -3.065, -2.815, -5.000, 0.573, -1.219, 0.624, -0.767, -0.737, -2.456, -2.893, -1.662, -0.859, -1.408, -2.209, -2.541, 0.743, -2.460, -2.861, -1.212, -5.000, -0.931, -1.923, -1.187, -1.309, -1.070, -2.372, -1.341, -0.238, -1.736, -1.602, -1.267, -0.953, -1.567, -5.000, -0.695, -1.246, -0.689, -0.997, -1.384, -0.652, -1.665, -1.983, -0.392, 0.616, -0.855, -5.000, -0.493, 0.380, -1.419, -5.000, -0.785, 0.140, -0.220, -0.282, -0.805, -0.217, -1.059, -0.534, -1.684, -0.085, -0.814, -5.000, -1.696, -1.438, -2.000, -1.149, -0.088, 0.604, -0.350, -0.352, -0.369, -1.546, -3.280, -1.114, -0.186, 0.900, -0.545, -0.428, -0.467, 0.949, -1.475, -1.063, -0.669, -0.046, -0.801, -0.762, -1.067, -2.990, -1.531, -0.791, -0.501, 0.658, -1.111, -1.025, -1.065, 0.813, -1.169, -1.141, -0.298, 0.826, 0.164, -0.243, -0.809, 0.105, -0.475, -1.064, -0.004, 0.504, -0.435, -5.000, -0.286, 0.643, -0.680, -5.000, -0.323, 0.333, -0.287, -0.698, -0.184, 0.227, -1.105, 0.015, -1.574, -0.410, -2.556, -5.000, -0.480, -0.606, -1.086, -1.459, -1.268, -0.490, -1.057, -1.294, -0.382, 0.706, -2.820, -1.449, -0.254, -0.232, -1.155, -0.473, -1.315, -0.542, -5.000, -1.318, -0.446, -0.081, -0.606, -1.554, -0.469, 0.684, -1.870, -1.123, 0.330, 1.017, -0.310, 0.239, 0.281, 1.229, -0.344, -0.368, 0.219, 0.727, 0.440, -0.164, 0.154, 0.998, -0.228, -0.331, 0.535, 1.002, -0.081, -5.000, 0.557, 0.423, -0.189, -5.000, 0.229, 1.192, 0.665, 0.013, 0.458, 0.728, -1.219, 0.657, -1.060, -0.671, -1.120, -5.000, 0.076, 0.350, -1.143, -0.868, -0.459, -0.392, -0.263, -0.854, 0.336, -0.415, -2.062, -0.230, 0.735, 1.266, 0.860, -0.120, -5.000, -5.000, -5.000, -5.000, 0.806, -5.000, 0.860, 0.780, 1.448, -5.000, 1.266, 1.353, 0.740, 1.344, 0.328, 0.586, 0.867, 1.240, -0.173, 0.144, 0.628, 0.870, 0.167, 0.139, 0.709, 0.613, 0.133, 0.077, -0.035, 0.506, -0.852, -5.000, 0.476, 0.422, 0.031, -5.000, -0.209, -0.094, -0.565, -0.559, -0.075, 0.184, -1.234, -0.010, -0.819, 0.224, -0.472, -5.000, 0.601, -0.022, -0.814, -5.000, 0.093, -0.344, -0.985, -1.112, 0.204, -0.255, -1.884, -0.373, 0.215, 1.091, 0.210, -0.210, 0.023, 0.455, -1.837, -0.053, -0.339, -0.461, -1.008, -1.048, 0.167, -0.749, -1.905, -0.596, 0.085, 0.419, -0.134, -0.471, 0.304, 0.717, -0.862, -0.137, 0.003, 0.271, -0.017, -0.725, -0.235, 0.627, -1.356, -1.125, -0.233, 0.312, -0.962, -5.000, -0.749, 0.678, 0.978, -5.000, -0.825, -0.372, -0.688, -1.280, -0.940, -0.421, -1.028, -0.293, -0.996, -0.145, -2.246, -5.000, -0.392, -1.285, -2.048, -1.155, -0.941, -1.260, -0.790, -1.329, -0.238, -0.594, -1.091, -0.944, -0.695, -0.805, -1.219, -1.000, -1.140, -0.738, -0.344, -1.207, -0.550, -0.587, -0.696, -1.011, -1.547, -1.184, -0.971, -1.760, -0.045, 0.427, -0.746, -0.345, 0.133, 0.526, -0.210, -1.033, -0.213, 0.030, -0.361, -0.912, -0.362, 0.094, -0.409, -1.049, 0.437, 1.345, 0.023, -5.000, 0.620, 1.183, -0.187, -5.000, 0.489, 1.159, 0.465, 0.503, 0.113, 0.680, -0.486, 0.561, -0.690, 0.158, -0.603, -5.000, -0.344, -0.092, -1.079, -0.058, -0.375, 0.125, 0.056, -0.675, 0.454, -0.383, -1.424, -0.407, 0.163, 0.773, 0.299, 0.512, 0.097, 0.370, -0.771, -0.710, 0.034, 0.560, 0.288, 0.081, 0.043, -0.614, -0.749, 0.091, 0.330, 1.198, -0.035, 0.237, 0.310, 1.301, -0.067, -0.029, 0.630, 1.332, 0.928, 0.489, 0.221, 0.557, 0.261, 0.200, 0.307, 0.918, -0.739, -5.000, 0.194, 0.283, -1.507, -5.000, 0.063, 0.995, 0.148, 0.105, -0.009, 0.367, -0.483, 0.322, -0.982, -1.081, -1.314, -5.000, -0.507, -0.257, -5.000, -1.217, -1.299, -0.408, -1.052, -1.111, -0.176, -0.839, -2.302, -0.431, -0.089, 1.203, 0.380, -0.098, -0.858, 0.581, -5.000, -1.097, -0.708, -0.544, 0.153, -0.370, -0.195, -0.370, -0.465, -0.780, 0.249, 0.870, -0.352, 0.249, 0.087, 0.969, -1.059, 0.027, 0.256, 0.280, 0.475, 0.024, 0.153, 0.426, -0.306, -0.278, -1.300, -0.445, -1.622, -5.000, -1.184, -0.808, -1.553, -5.000, -0.980, -0.104, -0.680, -1.296, -1.036, -0.910, -1.828, -0.531, -2.364, -0.723, -0.447, -5.000, -1.237, -1.293, -5.000, -1.391, -1.814, -0.005, -2.200, -1.387, -1.150, -1.463, -1.236, -1.428, -1.628, -1.513, -2.258, -1.608, -1.816, -5.000, -2.419, -5.000, -1.705, -1.132, -1.320, -2.023, -2.293, -2.679, -1.820, -2.435, -1.597, 0.013, -2.531, -2.125, -0.759, -1.883, -2.556, -1.550, -1.637, -1.968, -0.837, -1.326, -2.142, -2.042, -1.712, -1.782, 0.093, 0.988, -0.639, -5.000, 0.133, 0.629, -1.595, -5.000, 0.147, 0.645, -0.178, -0.087, -0.005, 0.093, -0.610, 0.127, -0.748, 0.111, -0.696, -5.000, -0.596, -0.877, -3.104, -1.128, -0.814, -0.173, -0.426, -0.671, 0.125, -0.391, -1.422, -0.522, -0.650, 0.560, -0.873, -0.689, -1.280, -0.641, -1.656, -1.384, -0.721, -0.480, -1.337, -0.874, -1.055, -1.469, -1.802, -1.303, -0.150, 0.654, -0.683, -0.308, -0.239, 0.903, -1.283, -0.968, -0.076, 0.764, 0.172, -0.617, -0.499, 0.017, -0.941, -0.969, 0.537, 1.287, -0.130, -5.000, 0.055, 0.961, -0.630, -5.000, 0.660, 1.141, 0.330, 0.747, 0.382, 0.644, -0.606, 0.640, -0.536, 0.013, -0.856, -5.000, -1.319, -0.558, -2.026, -1.093, -0.792, -0.156, -0.732, -1.074, 0.578, -0.563, -1.675, -0.391, 0.251, 1.049, 0.085, -0.172, -0.286, -0.042, -2.331, -1.282, -0.550, -0.476, -1.149, -0.999, -0.127, -0.985, -0.632, -1.022, 0.329, 0.912, -0.351, 0.001, -0.894, 0.551, -2.666, -1.466, 0.343, 1.022, 0.677, 0.232, 0.065, 0.656, 0.049, -0.302, 1.318, 1.695, 0.441, -5.000, 1.287, 1.656, 0.160, -5.000, 1.247, 1.621, 1.301, 1.176, 1.283, 1.424, 0.477, 1.382, 0.437, 1.018, -0.520, -5.000, 0.921, 1.216, -1.155, 0.629, 0.712, 1.075, 0.637, 0.469, 1.180, 0.710, -1.470, 0.672, 1.087, 1.593, 1.433, 1.046, 1.161, 1.732, 0.706, 0.722, 0.611, 1.140, 0.668, 0.790, 1.071, 0.741, 1.120, 0.278, 1.000, 1.503, 0.021, 0.782, 0.415, 1.072, -1.567, -0.080, 1.383, 1.495, 1.396, 1.125, 1.237, 1.403, 0.982, 0.814, 0.256, 1.302, -0.522, -5.000, 0.817, 1.212, -1.773, -5.000, 0.717, 1.339, 0.459, 0.495, 0.474, 0.599, -0.963, 0.274, -0.265, 0.910, -0.701, -5.000, 0.124, 0.881, -0.741, -0.315, 0.521, 0.969, -0.427, -0.513, 0.571, -0.050, -2.427, -0.385, -0.237, 1.277, -0.471, -0.363, -0.120, 0.499, -1.759, -0.164, -0.322, -0.010, -0.664, -0.788, -0.327, -0.331, -0.827, -0.275, 0.022, 0.735, -0.436, -0.391, -0.680, 0.584, -0.968, -1.337, 0.577, 1.364, 1.059, 0.573, -0.007, 0.874, -0.594, -0.961, 0.238, 1.026, -0.675, -5.000, -0.070, 0.840, -0.952, -5.000, 0.197, 0.815, -0.166, 0.174, -0.150, 0.232, -0.561, 0.067, -0.258, 0.554, -0.586, -5.000, -1.657, -0.001, -2.650, -0.847, -0.255, 0.343, -0.514, -0.836, 0.291, -0.488, -1.811, -0.359, -0.065, 0.736, -0.315, -0.257, -0.706, 0.443, -3.349, -1.131, -0.696, -0.823, -1.004, -0.772, -0.479, -1.141, -0.677, -0.914, -0.119, 0.716, -1.341, -0.610, -1.710, -0.371, -2.075, -1.117, 0.100, 0.976, 0.490, -0.155, -0.362, 0.575, -0.277, -0.837, -0.463, 0.871, -0.802, -5.000, -0.704, 0.046, -3.014, -5.000, -0.148, 0.407, -0.053, 0.150, 0.094, 0.580, -0.075, 0.686, -1.063, -0.004, -0.869, -5.000, -0.989, -0.866, -1.415, -1.357, -0.378, 0.167, 0.053, -0.403, 0.560, -0.898, -5.000, -0.625, -0.451, 0.782, -0.238, -0.247, -4.007, -5.000, -2.714, -2.885, -1.169, -2.584, -0.553, -1.007, -0.578, -1.395, -1.940, -1.555, -0.062, 0.766, -1.211, -0.674, -0.506, 1.027, -1.798, -1.345, 0.167, 0.755, 0.455, 0.182, -0.328, 0.253, -0.076, -1.018, 1.028, 1.552, 0.819, -5.000, 0.895, 1.217, 0.330, -5.000, 0.927, 1.431, 0.359, 0.608, 1.030, 1.326, 1.266, 1.278, 0.102, 0.876, -0.134, -5.000, 0.469, 0.757, -0.344, -0.067, 0.788, 1.298, 1.158, 0.241, 1.188, 1.142, -0.463, 1.054, 1.062, 1.645, 1.402, 0.666, -2.048, 1.027, -5.000, -1.943, 0.580, 0.860, 0.198, 0.460, 0.786, 0.520, 0.637, -0.327, 0.207, 1.176, -0.082, -0.000, 0.693, 1.392, -0.700, 0.323, 0.942, 1.493, 0.778, 0.801, 0.529, 0.897, 0.406, -0.126, -2.077, -0.687, -1.965, -5.000, -1.442, -0.788, -5.000, -5.000, -2.299, -5.000, -3.084, -1.519, -1.505, -1.672, -1.572, -1.870, -2.584, -0.526, -0.698, -5.000, -1.408, -5.000, -0.344, -5.000, -5.000, -5.000, -5.000, 0.167, -0.736, -5.000, -1.870, -2.685, -2.334, -0.774, -2.066, -2.400, -5.000, -0.874, -5.000, -2.484, -1.436, -1.070, -1.155, -1.862, -1.264, -1.665, -2.163, -2.936, -2.387, -5.000, -2.095, -2.626, -5.000, -0.942, -1.742, -3.038, -1.203, -5.000, -0.502, -1.608, -2.374, -1.408, -2.861, -2.258, -0.856, 0.287, -1.070, -5.000, -1.381, -0.177, -5.000, -5.000, -2.075, 0.167, -1.246, -0.459, -1.010, -0.571, -1.299, -0.131, -1.672, -0.352, -0.797, -5.000, -2.643, -1.435, -3.162, -1.635, -1.219, -0.323, -0.907, -1.923, -0.129, -0.809, -1.687, -0.993, -1.538, -0.167, -0.459, -1.130, -3.093, -5.000, -2.472, -3.494, -1.451, -0.931, -1.705, -1.302, -1.699, -3.097, -1.489, -1.710, -1.044, -0.217, -1.346, -1.590, -1.187, 0.749, -1.832, -1.794, -0.422, 0.524, 0.070, -0.813, -0.903, -0.124, -0.839, -1.424, 0.178, 0.890, -0.190, -5.000, -0.172, 0.470, -1.033, -5.000, 0.238, 0.430, -0.190, 0.165, 0.109, 1.038, -0.327, 0.561, -1.272, -0.625, -1.413, -5.000, -1.782, 0.100, -1.155, -1.030, -0.846, -1.859, 0.076, -0.931, 0.363, 0.221, -3.479, -0.706, -0.401, 0.396, -0.517, -0.641, -1.524, 0.160, -5.000, -2.070, -0.631, -0.526, -1.351, -0.972, -0.545, -0.315, -0.784, -1.354, -0.281, 0.373, -1.109, -0.379, -0.705, 0.561, -2.577, -1.135, -0.291, 0.502, 0.167, -0.555, -0.091, 0.688, -0.196, -1.105, 0.363, 0.969, -0.091, -5.000, 0.270, 0.780, -1.431, -5.000, -0.096, 0.656, -0.598, -0.567, 0.369, 0.425, -0.439, 0.426, 0.260, 0.934, -0.285, -5.000, -0.985, 0.224, -0.526, -0.072, -0.254, 0.512, -0.644, -0.201, 0.855, 0.767, -0.782, 0.573, -0.232, 1.132, 0.711, -0.588, -1.150, 0.755, 0.573, -0.567, -1.040, 0.408, -0.740, -1.093, -0.743, -0.774, -0.344, -1.933, 0.118, 0.999, -0.061, -0.095, -0.072, 1.013, -0.542, -0.201, 0.358, 0.783, 0.229, -0.287, 0.065, 0.381, 0.153, -0.493, -0.110, 0.424, -0.877, -5.000, -0.927, 0.182, -1.418, -5.000, -0.159, -0.231, -0.627, -0.775, -0.346, 0.094, -1.148, -0.276, -1.044, -0.171, -0.445, -5.000, -0.575, -0.169, -5.000, -1.233, 0.192, -0.475, -0.926, -0.944, 0.272, -0.066, -1.400, -0.717, 0.117, 1.169, 0.062, -0.323, -0.931, 0.379, -2.048, -1.103, -0.413, 0.020, -0.606, -0.425, -0.425, -0.794, -1.453, -0.701, -0.126, -0.680, -1.446, -0.694, -0.645, 0.254, -1.905, -0.503, -0.125, -0.173, -0.238, -0.435, -0.286, -0.056, -1.302, -1.027, -0.163, 0.360, -0.719, -5.000, -0.344, 0.013, -5.000, -5.000, -0.382, -0.299, -0.700, -0.756, -0.283, -0.328, -1.106, 0.092, -0.627, 0.080, -0.641, -5.000, -1.414, -0.963, -5.000, -1.987, -0.253, 0.493, -0.001, -1.660, -0.181, -0.916, -1.730, -0.594, -0.422, 0.342, -0.673, -0.489, -1.093, 0.450, -2.410, -1.225, -0.804, -0.498, -0.367, -0.796, -0.971, -1.792, -0.715, -1.416, -0.518, 0.232, -1.041, -0.639, -1.243, 0.380, -1.825, -1.150, -0.399, 0.313, -0.022, -0.938, -0.371, -0.013, -0.814, -1.158, 0.098, 1.035, -0.249, -5.000, -0.000, 0.766, -1.348, -5.000, 0.434, 0.919, 0.034, 0.351, -0.002, 0.518, -0.680, 0.416, 0.224, 0.493, -0.680, -5.000, -1.219, 0.013, -5.000, -5.000, 0.755, -5.000, -0.931, 0.013, -1.337, 0.512, -5.000, -0.078, -0.057, 0.901, -0.329, -0.649, -1.533, 0.179, -2.568, -2.488, -0.644, -0.660, -0.763, -1.527, -0.693, -1.120, -1.560, -1.743, -0.158, 0.649, -0.805, -0.455, -0.284, 0.953, -1.297, -0.777, -0.215, 0.804, 0.273, -0.514, -0.434, 0.066, -0.402, -0.890, -0.028, 0.802, -0.279, -5.000, 0.181, 0.490, -0.553, -5.000, -0.052, 0.701, -0.100, 0.092, -0.051, 0.476, -0.392, 0.299, -1.237, -0.559, -0.638, -5.000, -1.500, -0.427, -2.223, -1.465, -0.492, -0.145, -0.454, -2.318, -0.076, -0.581, -1.625, -0.914, -0.841, 0.869, -0.198, -0.722, -1.692, 0.285, -5.000, -2.290, -1.389, -0.301, -0.292, -1.489, -1.123, -0.782, -1.659, -1.921, -0.476, 0.485, -1.114, -0.633, 0.071, 0.831, -1.385, -0.530, -0.205, 0.474, 0.276, -0.242, -0.458, -0.255, -0.494, -1.129, -0.003, 0.863, -0.544, -5.000, 0.260, 0.695, -1.061, -5.000, 0.619, 1.166, 0.162, 0.151, -0.025, 0.137, -1.333, -0.000, -1.455, -0.249, -0.974, -5.000, -0.610, -0.091, -5.000, -1.446, -0.344, 0.167, -0.644, -0.899, 0.092, -0.329, -1.098, -0.754, -0.483, 0.540, -0.388, -0.946, -1.631, -1.011, -1.364, -1.647, -0.780, -1.093, -0.704, -0.762, -0.633, -0.793, -1.462, -1.577, -0.750, -0.606, -1.318, -1.147, -0.263, 0.431, -1.573, -1.381, -0.467, 0.388, 0.059, -0.465, -0.752, -0.198, -1.471, -2.199, -0.202, 0.641, -0.887, -5.000, -0.302, 0.434, -1.962, -5.000, -0.079, 0.718, 0.166, 0.145, -0.368, 0.030, -0.693, -0.020, -1.258, -0.073, -0.850, -5.000, -1.938, -0.657, -1.825, -1.487, -1.512, -0.194, -0.367, -1.089, 0.117, -0.896, -2.421, -0.351, -1.070, 0.284, -0.720, -0.921, -1.774, -0.703, -2.700, -1.963, -3.024, -1.672, -2.469, -2.539, -1.805, -2.452, -2.134, -1.570, -0.698, 0.227, -1.703, -0.932, -1.156, 0.259, -1.751, -1.288, -0.808, 0.465, 0.106, -0.987, -1.366, -0.635, -1.378, -1.478, 0.460, 1.384, 0.142, -5.000, -0.045, 0.858, -0.598, -5.000, 0.471, 0.975, 0.219, 0.383, 0.160, 0.644, -0.486, 0.297, -0.278, 0.460, -0.805, -5.000, -0.809, -0.309, -1.637, -0.391, -0.222, 0.042, -0.319, -0.689, 0.520, 0.154, -1.574, -0.144, 0.253, 0.977, -0.103, -0.076, -0.419, 0.443, -1.897, -1.181, -0.317, -0.170, -0.868, -0.706, -0.411, -0.528, -0.472, -0.859, 0.401, 0.907, -0.342, -0.086, 0.104, 0.849, -1.034, -0.372, 0.352, 0.642, 0.398, 0.036, -0.186, 0.458, 0.087, -0.537, 1.276, 1.664, 0.828, -5.000, 0.956, 1.421, 0.593, -5.000, 0.937, 1.504, 1.146, 0.953, 0.923, 1.238, 0.903, 1.138, 0.634, 1.125, -0.095, -5.000, 0.694, 1.092, -0.431, 0.500, 0.672, 0.945, 0.289, 0.402, 1.094, 0.887, -0.277, 0.734, 1.030, 1.645, 1.311, 0.818, 0.810, 1.542, -5.000, 0.439, 0.472, 1.102, 0.739, 0.429, 0.904, 0.858, 0.775, 0.137, 0.942, 1.442, 0.719, 0.738, 1.036, 1.084, 0.187, 0.671, 1.093, 1.303, 1.223, 0.752, 0.933, 1.229, 0.745, 0.602, -0.174, 0.836, -0.688, -5.000, -0.238, 0.445, -0.701, -5.000, -0.107, 0.539, -0.488, -0.374, -0.476, -0.019, -1.055, -0.473, -0.700, 0.323, -1.297, -5.000, -0.883, -0.040, -1.563, -0.948, -0.740, -0.043, -0.767, -1.543, 0.393, -0.364, -1.757, -0.779, -1.026, 0.918, -0.995, -1.099, -0.634, -0.197, -1.622, -1.175, -1.200, -0.604, -0.808, -0.787, -1.082, -1.028, -1.405, -1.452, -0.659, 0.966, -0.953, -1.061, -0.393, 0.852, -1.663, -0.695, -0.302, 0.254, 0.013, -0.569, -0.647, -0.263, -1.709, -1.646, 0.028, 0.940, -0.539, -5.000, -0.456, 0.443, -0.761, -5.000, -0.244, 0.393, -0.468, -0.437, -0.356, 0.002, -0.681, -0.388, -0.436, 0.511, -0.411, -5.000, -1.073, -0.266, -1.833, -0.776, -0.377, -0.205, -0.539, -0.937, 0.136, -0.278, -1.545, -0.364, -0.034, 0.647, -0.246, -0.156, -0.418, 0.734, -1.464, -0.648, -0.393, -0.450, -0.549, -0.450, -0.674, -0.475, -0.344, -0.686, -0.169, 0.734, -0.704, -0.519, -0.159, 0.961, -0.474, -0.497, 0.016, 0.948, 0.567, -0.216, -0.531, 0.223, -0.492, -0.857, 0.084, 1.109, -0.042, -5.000, 0.043, 0.674, -0.983, -5.000, 0.324, 0.672, 0.278, 0.429, 0.138, 0.804, -0.826, 0.349, -0.520, 0.373, -0.467, -5.000, -0.644, -0.125, -1.418, -0.174, 0.205, 0.431, -0.038, -0.337, 0.752, 0.110, -0.910, -0.122, 0.091, 1.005, -0.324, -0.130, -0.771, 0.109, -2.011, -1.638, -0.805, -0.738, -1.209, -0.749, -0.360, -0.458, -0.680, -0.931, 0.224, 1.030, -0.402, -0.254, 0.108, 1.218, -0.186, -0.673, 0.230, 0.167, 0.433, 0.118, -0.192, 0.557, 0.147, -0.521, 1.222, 1.630, 0.920, -5.000, 0.976, 1.036, 0.467, -5.000, 1.018, 1.521, 0.940, 0.768, 0.939, 1.318, 0.301, 1.273, 0.477, 1.088, -0.021, -5.000, 0.581, 0.953, -0.386, 0.611, 1.043, 1.259, 0.710, 0.364, 1.325, 1.351, -0.481, 1.095, 1.009, 1.685, 1.527, 1.009, 1.089, 1.655, -0.985, 0.863, 0.927, 0.896, 0.841, 0.665, 1.173, 1.226, 1.021, 0.717, 0.686, 1.397, 0.545, 0.706, 1.206, 1.325, 0.150, 0.837, 1.079, 1.405, 1.102, 0.710, 0.897, 1.292, 0.517, 0.565, -0.577, 0.879, -0.769, -5.000, -0.325, 0.373, -1.953, -5.000, -0.001, 0.195, -0.807, 0.188, -0.435, -0.166, -1.823, -0.542, -0.653, 0.573, -0.772, -5.000, -1.417, -0.056, -3.165, -1.224, -5.000, -5.000, 0.285, -5.000, -0.300, -0.621, -2.345, -0.990, -0.840, 0.712, -1.245, -1.069, -0.799, -0.254, -2.164, -2.368, -0.559, -0.465, -0.745, -0.998, -0.970, -0.962, -2.385, -1.416, -0.747, -0.344, -1.520, -1.023, -0.885, 0.397, -1.268, -1.089, -0.029, 0.315, 0.257, -0.300, -0.846, -0.204, -2.408, -1.871, 0.033, 0.858, -0.777, -5.000, -0.305, 0.500, -0.887, -5.000, -0.288, 0.728, -0.138, -0.505, -0.407, 0.225, -0.746, -0.200, -0.664, 0.207, -0.392, -5.000, -1.630, -0.894, -2.460, -1.192, -0.512, -0.220, -0.567, -1.070, 0.104, -0.548, -1.573, -0.382, -0.051, 0.915, 0.079, -0.261, -0.658, 0.864, -2.336, -0.869, -0.585, -0.496, -0.977, -0.738, -0.430, -0.838, -0.662, -0.761, -0.450, 0.473, -0.559, -0.862, -0.720, 0.565, -1.348, -1.204, -0.156, 0.860, 0.376, -0.642, -0.491, 0.158, -0.808, -0.879, 0.472, 1.084, 0.317, -5.000, 0.345, 1.068, -0.409, -5.000, 0.334, 0.705, 0.125, -0.056, 0.268, 0.746, -0.613, 0.403, 0.002, 0.661, -0.423, -5.000, -0.064, 0.704, -1.855, 0.028, 0.153, 0.339, 0.274, -0.495, 1.068, 0.978, -0.980, 0.183, 0.305, 0.885, 0.141, 0.175, -0.653, 0.543, -1.513, -0.930, -0.269, 0.112, -0.579, -0.435, -0.005, 0.415, -0.371, -0.479, 0.359, 0.943, -0.238, 0.018, 0.232, 1.293, -0.396, -0.087, 0.406, 0.634, 0.450, -0.067, 0.145, 1.242, 0.104, -0.431, 1.029, 1.521, 0.862, -5.000, 0.946, 1.270, 0.565, -5.000, 0.723, 1.207, 0.411, 0.269, 0.688, 1.235, 0.493, 0.943, 0.598, 1.025, -0.024, -5.000, 0.812, 1.148, -0.740, 0.336, 0.913, 1.280, 0.232, -0.108, 1.185, 1.004, -0.601, 0.812, 0.991, 1.658, 1.451, 0.595, 0.619, 1.368, -5.000, 0.336, 0.488, 0.947, 0.182, 0.272, 0.751, 0.416, 0.490, -0.066, 0.743, 1.556, 1.013, 0.707, 0.801, 1.578, 0.350, 0.590, 0.921, 1.219, 0.653, 0.200, 0.778, 1.187, 0.408, 0.155, 0.626, 1.124, 0.331, -5.000, 0.880, 1.028, 0.167, -5.000, 0.531, 0.576, 0.137, 0.542, 0.625, 0.844, -0.526, 0.614, 0.577, 0.987, 0.373, -5.000, 0.072, 0.812, -0.903, 0.399, 0.598, 0.326, -0.183, -0.466, 1.130, 0.941, -0.854, 0.703, 0.842, 1.725, 0.945, 0.641, 0.514, 1.292, -1.359, 0.207, 0.428, 0.485, -0.042, -0.303, 0.406, 0.365, 0.091, 0.294, 0.664, 0.727, 0.307, 0.217, 0.530, 1.199, -0.406, 0.597, 0.646, 0.644, 0.627, -0.600, 0.318, 0.784, -0.444, -1.072, 0.229, 0.967, -0.033, -5.000, -0.814, 0.350, -5.000, -5.000, -0.106, 0.201, -0.073, -0.524, 0.140, 0.353, -0.309, 0.237, -0.241, 0.345, 0.268, -5.000, -0.402, -0.608, -1.189, -0.803, -0.187, -0.883, -0.610, -0.953, 0.562, -0.005, -0.768, 0.025, -0.333, 0.939, 0.260, -0.152, -0.374, 0.913, -1.117, -0.783, -0.123, -0.189, -0.199, -0.577, -0.416, -0.793, -0.099, -1.133, -0.078, 0.549, -0.463, -0.151, -0.042, 0.986, -0.020, -0.564, -0.238, 0.183, -0.169, -0.943, -0.048, 0.499, 0.081, -1.026, 0.169, 1.143, -0.123, -5.000, -0.073, 0.739, -1.029, -5.000, 0.355, 0.835, 0.168, -0.007, -0.195, 0.524, -1.021, -0.121, -0.507, 0.534, -0.289, -5.000, -0.761, 0.254, -1.425, -0.598, -0.221, 0.242, -0.022, -0.712, 0.474, 0.110, -1.518, -0.292, 0.175, 0.913, -0.090, -0.343, -0.506, 0.242, -2.563, -1.476, -0.418, -0.039, -0.767, -0.701, -0.552, -0.667, -0.976, -1.125, -0.002, 0.868, -0.437, -0.356, -0.026, 0.973, -0.990, -0.478, 0.030, 0.704, 0.445, -0.191, -0.430, 0.289, -0.223, -0.744, 0.827, 1.472, 0.425, -5.000, 0.815, 1.073, -0.243, -5.000, 0.689, 1.233, 0.825, 0.616, 0.386, 1.010, -0.492, 0.674, 0.112, 0.528, -0.209, -5.000, 0.159, 0.683, -0.807, -0.028, 0.214, 0.528, -0.158, -0.259, 0.828, 0.254, -1.243, 0.188, 0.789, 1.545, 1.057, 0.360, 0.444, 1.290, -0.181, -0.740, 0.533, 0.637, 0.552, -0.011, 0.619, 0.401, 0.217, -0.477, 0.387, 1.163, 0.163, 0.140, 0.487, 1.266, -0.555, 0.309, 0.677, 1.085, 0.625, 0.199, 0.319, 0.785, -0.208, -0.055, 0.216, 1.120, -0.408, -5.000, 0.244, 0.930, -1.139, -5.000, 0.657, 1.016, 0.239, 0.195, 0.066, 0.439, -0.874, 0.022, -0.287, 0.630, -0.644, -5.000, -0.097, 0.308, -0.652, -0.285, 0.054, 0.411, -0.183, -0.547, 0.159, -0.278, -1.794, -0.369, -0.418, 0.799, -0.683, -0.849, -0.351, 0.134, -2.507, -1.142, -0.224, 0.184, -0.298, -0.446, -0.762, -1.254, -0.665, -1.136, -0.346, 0.042, -1.046, -0.602, 0.051, 0.683, -1.517, -0.834, -0.221, 0.130, -0.051, -0.694, -0.849, -0.230, -1.706, -2.004, -0.071, 0.848, -0.645, -5.000, -0.221, 0.508, -1.139, -5.000, -0.111, 0.545, -0.167, -0.401, -0.402, 0.113, -0.906, -0.452, -0.746, 0.480, -0.499, -5.000, -1.070, -0.892, -1.715, -1.167, -0.537, 0.063, -0.405, -1.043, 0.165, -0.400, -1.521, -0.340, -0.342, 0.838, -0.387, -0.606, -0.902, 0.113, -2.156, -1.866, -0.999, -0.815, -1.111, -1.305, -1.265, -1.278, -1.450, -1.160, -0.498, 0.401, -1.077, -0.905, -0.560, 0.382, -1.097, -1.280, -0.468, 0.152, -0.467, -1.182, -0.990, -0.475, -1.310, -1.259 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_34(struct _training *tptr) {
  struct _training tinf = {
    0.486, 11, 4.350, { 0.604, 0.217, 2.180 }, { 0.847, -1.182, -2.106 }, 0, 
    { -0.256, -0.788, -0.807, -0.830, -0.735, -4.000, -0.973, -4.000, 1.981, -0.069, -0.601, -4.000, -0.956, -0.278, 1.094, -0.402, 0.683, -4.000, 2.457, 1.021, 0.143, 0.074, 0.410, 0.904, 1.911, -0.233, 1.986, 2.218 }, 
    {{ 0.009, -0.170, 0.045, 0.091},{ 0.055, 0.131, -0.231, 0.007},{ 0.065, -0.016, -0.282, 0.165},{ 0.153, -0.160, -0.279, 0.187},{ 0.153, -0.071, -0.207, 0.074},{ 0.053, -0.114, -0.147, 0.162},{ 0.140, -0.219, -0.200, 0.188},{ 0.135, -0.012, -0.202, 0.039},{ 0.205, -0.241, -0.111, 0.072},{ 0.379, -0.279, -0.388, 0.070},{ 0.394, -0.210, -0.594, 0.112},{ 0.334, -0.308, -0.648, 0.266},{ 0.362, -0.519, -0.766, 0.373},{ 0.305, -0.359, -0.626, 0.314},{ 0.014, -0.326, -0.559, 0.503},{ 0.106, -0.274, -0.746, 0.477},{ 0.086, -0.036, -0.329, 0.190},{ 0.199, -0.069, -0.373, 0.129},{ 0.443, -0.086, -0.459, -0.142},{ 0.577, -0.061, -0.597, -0.357},{ 0.479, -0.227, -0.490, -0.059},{ 0.473, -0.138, -0.447, -0.153},{ 0.399, 0.134, -0.388, -0.389},{ 0.179, 0.103, -0.210, -0.128},{ 0.148, 0.038, -0.337, 0.072},{ 0.196, 0.060, -0.289, -0.038},{ 0.173, -0.086, -0.313, 0.134},{ 0.233, -0.111, -0.368, 0.121},{ 0.140, 0.124, -0.343, -0.000},{ 0.138, -0.026, -0.244, 0.077},{ 0.277, -0.163, -0.295, 0.062},{ 0.252, 0.025, -0.271, -0.089} }, 
    {{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 1.691, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 0.444, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 2.754, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 0.470, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}} }, 
    -0.355, { 0.203, 0.367, -0.997, -5.000, 0.097, 0.038, -1.544, -5.000, -0.133, 0.241, -0.300, -0.420, 0.574, 0.405, 0.307, -0.196, 0.538, 0.630, -0.449, -5.000, 0.199, -0.150, -1.532, -0.503, -0.221, 0.453, -0.084, -0.486, 0.459, 0.772, 0.497, -0.220, 0.176, 0.782, -0.036, 0.899, -0.006, 0.115, -0.922, -0.666, 0.133, 0.363, 0.127, -0.105, 0.280, 0.350, 0.098, 0.323, -0.643, -0.038, -1.140, -0.211, -0.884, -0.063, -1.954, -1.657, 0.169, 0.375, -0.010, -0.095, 0.435, 0.841, 0.513, -0.051, -0.056, -0.157, -1.621, -5.000, -0.008, -0.316, -2.331, -5.000, -0.425, -0.139, -0.358, -0.807, 0.847, -0.077, 0.196, -0.135, 0.806, 0.741, -0.259, -5.000, 0.602, -0.199, -1.456, -0.255, -0.062, 0.418, 0.204, -0.325, 0.613, 0.561, 0.315, -0.194, 0.283, 0.544, 0.034, 1.078, 0.488, -0.322, -0.501, -0.375, 0.563, 0.440, 0.752, -0.199, 0.627, 0.190, 0.663, 0.573, 0.021, 0.425, -0.684, 0.057, -0.015, -0.086, -1.628, -1.002, 0.373, 0.232, -0.108, -0.525, 0.984, 0.829, 0.789, 0.330, -1.294, -1.368, -1.934, -5.000, -1.386, -1.512, -2.564, -5.000, -1.457, -1.474, -1.843, -1.592, -1.108, -1.985, -1.854, -1.569, -0.627, -0.472, -1.342, -5.000, -1.070, -1.510, -2.249, -1.557, -0.944, -0.894, -1.504, -1.589, -0.393, -0.406, -1.176, -1.320, -0.844, -0.115, -1.524, -0.615, -1.337, -1.380, -1.855, -1.757, -0.710, -0.978, -1.085, -1.474, -0.860, -0.847, -1.238, -1.247, -1.308, -0.937, -1.810, -0.864, -1.856, -1.797, -2.904, -2.197, -1.434, -1.492, -1.926, -1.836, -0.528, -0.819, -1.326, -1.244, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.057, 0.111, -1.598, -5.000, -0.106, -0.222, -1.951, -5.000, -0.089, 0.488, -0.152, -0.383, 0.975, 0.621, 0.301, -0.284, 0.486, 0.520, -0.246, -5.000, -0.027, -0.510, -1.922, -0.815, -0.022, 0.661, 0.127, -0.438, 0.436, 0.766, 0.522, -0.394, 0.843, 1.114, 0.552, 1.198, 0.153, 0.297, -0.927, -0.495, -0.398, 0.332, -0.467, -0.753, 0.558, 0.836, 0.592, 0.538, -1.155, -0.156, -1.566, -0.249, -1.118, -0.213, -1.869, -1.743, 0.293, 0.296, -0.426, -0.348, 0.521, 1.038, 0.602, 0.024, -0.362, -0.464, -2.209, -5.000, -0.342, -0.325, -2.903, -5.000, -0.031, 0.266, -0.308, -0.507, 1.062, 0.539, 0.648, -0.183, 0.608, 0.336, -0.172, -5.000, 0.467, -0.091, -1.571, -0.189, 0.696, 0.731, 0.771, 0.030, 0.640, 0.574, 0.469, 0.054, 0.901, 0.911, 0.738, 1.210, 0.616, 0.205, -0.374, -0.032, 0.763, 0.631, 0.570, -0.413, 0.865, 0.784, 0.973, 0.731, -0.035, 0.381, -0.729, -0.047, -0.488, 0.142, -1.703, -0.985, 0.002, 0.316, -0.281, -0.746, 0.798, 1.073, 0.871, 0.383, -1.544, -1.937, -2.280, -5.000, -1.784, -2.511, -2.495, -5.000, -1.836, -1.862, -2.472, -2.001, -1.433, -2.292, -2.531, -2.284, -0.972, -1.338, -2.034, -5.000, -1.490, -1.861, -2.419, -2.022, -1.086, -0.652, -1.395, -1.945, -0.638, -0.981, -1.171, -1.566, -1.225, -1.351, -1.922, -0.518, -1.982, -2.019, -2.195, -1.973, -1.453, -1.491, -1.639, -2.044, -1.270, -1.214, -1.674, -1.723, -1.557, -1.474, -2.300, -1.667, -2.239, -2.048, -2.563, -2.593, -1.781, -2.620, -2.212, -2.126, -1.156, -1.316, -1.905, -1.693, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.160, 0.065, -0.912, -5.000, -0.397, 0.247, -1.684, -5.000, -0.264, 0.168, -0.206, -0.678, 0.614, 0.532, 0.274, -0.420, 0.091, 0.250, -0.424, -5.000, -0.584, -0.264, -1.879, -0.640, -0.491, 0.197, -0.400, -0.968, 0.128, 0.488, 0.216, -0.693, 0.733, 0.941, 0.226, 1.080, -0.556, 0.176, -0.891, -0.091, -0.199, 0.261, -0.220, -0.576, 0.345, 0.688, 0.345, 0.319, -0.700, -0.268, -1.312, -0.228, -1.977, -0.497, -2.242, -1.429, -0.955, -0.368, -1.011, -1.069, 0.100, 0.580, 0.165, -0.621, -0.149, -0.072, -1.778, -5.000, -0.327, -0.161, -2.216, -5.000, -0.090, 0.266, -0.366, -0.809, 0.930, 0.115, 0.140, -0.249, 0.554, 0.813, -0.127, -5.000, 0.290, 0.368, -1.763, -0.364, 0.091, 0.706, -0.008, -0.266, 0.474, 0.716, 0.527, -0.289, 0.618, 0.813, 0.184, 1.293, -0.020, 0.318, -0.478, -0.305, 0.165, 0.543, -0.030, -0.138, 0.519, 0.486, 0.665, 0.493, 0.245, 0.623, -0.348, 0.580, -0.521, 0.218, -1.544, -0.664, 0.110, 0.521, -0.281, -0.433, 0.867, 0.994, 0.737, 0.380, -0.505, -0.799, -1.493, -5.000, -0.767, -0.395, -2.638, -5.000, -0.337, -0.566, -0.646, -0.991, -0.047, -0.509, -0.562, -0.859, 0.243, 0.352, -0.582, -5.000, -0.293, 0.056, -2.346, -1.472, -0.542, -0.515, -0.388, -0.935, 0.001, 0.220, -0.087, -0.725, -0.167, 0.938, -0.838, 0.105, -0.797, -0.216, -1.547, -0.891, -0.572, -0.361, -1.009, -0.872, -0.173, -0.278, -0.586, -0.698, -0.068, 0.844, -0.697, -0.056, -1.154, -0.192, -1.980, -1.248, -0.641, -0.419, -0.985, -1.195, 0.356, 0.348, -0.327, -0.727, -0.366, -0.602, -1.795, -5.000, -0.969, -0.715, -2.268, -5.000, -1.026, -0.356, -1.029, -1.054, -0.054, -0.598, -0.772, -1.281, 0.070, 0.020, -0.561, -5.000, -0.655, -0.861, -2.199, -1.081, -0.930, -0.250, -0.811, -1.120, -0.244, 0.084, -0.319, -0.614, 0.016, 0.591, -0.333, 0.478, -0.873, -0.072, -1.532, -1.027, -0.635, -0.211, -0.886, -1.054, -0.036, 0.296, -0.255, -0.549, -0.564, -0.199, -1.237, -0.152, -1.476, -0.673, -2.778, -1.835, -1.065, -0.502, -1.317, -1.333, 0.064, 0.540, -0.068, -0.836, 0.684, 0.963, -0.245, -5.000, 0.934, 1.084, -0.887, -5.000, 0.645, 1.059, 0.573, 0.241, 1.136, 0.978, 0.925, 0.277, 0.977, 1.120, 0.490, -5.000, 0.741, 0.653, -0.803, 0.282, 0.790, 1.125, 0.717, 0.118, 1.025, 1.036, 1.007, 0.298, 1.044, 1.371, 0.741, 1.338, 0.833, 0.960, -0.376, 0.342, 0.720, 1.004, 0.372, 0.289, 0.923, 1.120, 0.720, 0.986, -0.088, 0.724, -0.875, 0.028, -0.403, 0.768, -1.560, -0.507, -0.028, 0.590, -0.057, -0.231, 0.636, 1.168, 0.522, 0.049, -0.024, -0.462, -1.148, -5.000, -0.018, -0.225, -1.815, -5.000, 0.172, 0.281, -0.158, -0.275, 0.563, -0.602, 0.525, 0.095, 0.450, 0.369, -0.367, -5.000, 0.488, -0.273, -1.322, -0.203, 0.375, 0.571, 0.589, -0.265, 0.695, 0.311, 0.274, -0.030, 0.147, 0.457, -0.084, 0.943, 0.217, -0.161, -1.615, -0.488, 0.140, 0.225, 0.054, -0.215, 0.280, -0.105, -0.087, 0.489, -0.198, -0.051, -0.743, -0.262, 0.041, 0.088, -1.447, -0.980, 0.533, 0.448, -0.321, -0.449, 0.802, 0.531, 0.311, 0.177, -0.591, -0.758, -2.180, -5.000, -0.806, -0.825, -2.158, -5.000, -0.335, -0.361, -0.712, -1.109, 0.065, -1.804, -1.621, -1.820, 0.487, 0.683, -0.230, -5.000, -0.168, -0.498, -2.358, -0.881, 0.260, 0.447, -0.454, -0.652, 0.193, 0.538, 0.247, 0.023, -0.215, 0.527, -0.866, 0.561, -0.516, -0.298, -2.734, -1.302, -0.292, 0.068, -0.723, -0.647, -0.113, 0.108, -0.334, -0.192, -0.221, 0.430, -1.131, 0.140, -0.676, -0.513, -2.241, -1.543, -0.391, -0.244, -1.326, -1.274, 0.396, 0.257, -0.341, -0.478, -0.577, -0.481, -1.358, -5.000, -1.063, -0.708, -1.803, -5.000, -0.584, -0.305, -1.275, -0.969, -0.211, -0.671, -1.367, -0.902, -0.245, -0.284, -0.638, -5.000, -0.563, -0.674, -1.377, -1.058, -1.033, -0.519, -0.958, -1.296, -0.501, -0.298, -0.494, -0.463, 0.013, 0.639, -0.469, 0.099, -0.721, -0.251, -1.284, -1.031, -0.487, -0.088, -0.849, -0.983, -0.109, -0.029, -0.665, -0.499, -0.189, 0.205, -0.781, -0.168, -0.909, -0.639, -2.275, -1.211, -0.508, -0.095, -1.132, -1.001, 0.127, 0.414, -0.078, -0.374, 0.638, 0.854, -0.304, -5.000, 0.799, 0.834, -0.955, -5.000, 0.460, 0.879, 0.450, 0.138, 1.215, 0.746, 0.782, 0.198, 1.022, 1.153, 0.479, -5.000, 0.756, 0.626, -1.141, 0.310, 0.536, 0.981, 0.469, -0.056, 0.817, 1.079, 0.842, 0.286, 0.833, 1.226, 0.533, 1.350, 0.809, 0.654, -0.649, 0.176, 0.805, 0.960, 0.691, 0.141, 0.999, 0.863, 0.373, 0.813, -0.356, 0.513, -1.136, 0.120, -0.258, 0.595, -1.256, -0.822, 0.645, 0.657, 0.473, 0.096, 1.080, 1.275, 0.769, 0.353, 0.637, 0.689, -1.442, -5.000, 0.669, 0.688, -1.469, -5.000, 0.180, 0.516, 0.257, -0.216, 1.392, 0.558, 0.848, 0.323, 1.231, 1.263, 0.502, -5.000, 1.098, 0.876, -1.161, 0.529, 0.650, 1.017, 0.588, 0.245, 1.101, 1.148, 0.771, 0.194, 0.897, 1.218, 0.694, 1.472, 0.999, 0.294, -0.732, 0.234, 0.757, 0.629, 0.971, 0.068, 1.088, 0.684, 0.854, 0.901, 0.505, 1.087, -0.061, 0.713, 0.532, 0.770, -1.113, -0.280, 0.807, 0.724, 0.539, -0.113, 1.322, 1.314, 1.223, 0.831, -0.700, -0.706, -1.618, -5.000, -0.083, -0.177, -1.847, -5.000, -0.221, -0.398, -0.875, -0.788, 0.270, -0.965, -1.459, -1.466, 0.538, 0.701, -0.259, -5.000, 0.588, 0.262, -1.810, -0.352, 0.342, 0.535, 0.184, -0.452, 0.470, 0.507, 0.032, -0.299, 0.231, 0.930, -0.082, 0.761, -0.036, -0.051, -1.073, -0.537, -0.125, 0.429, -0.114, -0.387, 0.084, -0.072, -0.523, -0.004, -0.465, 0.153, -0.773, 0.175, -0.399, -0.163, -2.008, -0.903, 0.059, -0.122, -0.874, -0.763, 0.653, 0.305, -0.307, -0.488, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.346, 0.550, -1.350, -5.000, 0.093, 0.441, -1.627, -5.000, -0.382, 0.569, -0.450, -0.289, 1.193, 0.883, 0.358, -0.227, 0.790, 0.959, 0.222, -5.000, 0.210, 0.144, -1.241, -0.335, 0.198, 0.757, 0.216, -0.261, 0.562, 1.002, 0.648, -0.179, 0.994, 1.278, 0.558, 1.327, 0.400, 0.493, -0.720, -0.053, -0.145, 0.380, -0.452, -0.339, 0.742, 1.007, 0.357, 0.672, -0.949, 0.221, -1.757, -0.231, -0.734, 0.084, -2.667, -1.515, 0.580, 0.702, 0.447, -0.069, 0.824, 1.105, 0.714, -0.068, -0.225, -0.203, -1.467, -5.000, -0.466, 0.146, -2.469, -5.000, -0.503, -0.094, -0.686, -0.845, 0.934, -0.055, -0.084, -0.620, 0.771, 0.808, 0.048, -5.000, 0.553, 0.457, -0.930, -0.159, 0.421, 0.625, 0.569, -0.183, 0.772, 0.672, 0.352, -0.150, 0.473, 0.616, 0.072, 1.026, 0.511, 0.544, -0.394, 0.150, 0.123, 0.054, 0.343, -0.558, 0.564, 0.227, 0.409, 0.380, 0.039, 0.383, -0.963, 0.061, -0.519, 0.434, -1.891, -0.944, -0.618, 0.139, -0.523, -1.123, 0.762, 0.959, 0.434, 0.206, -2.019, -1.740, -2.140, -5.000, -1.695, -1.745, -1.980, -5.000, -2.369, -1.956, -1.813, -1.974, -1.306, -1.368, -2.505, -2.172, -0.784, -0.903, -1.736, -5.000, -0.976, -1.449, -1.533, -1.619, -0.925, -1.205, -0.957, -1.475, -0.743, -1.187, -1.129, -1.216, -1.155, -0.929, -1.771, -0.664, -1.678, -1.501, -1.279, -1.868, -1.189, -1.143, -1.338, -1.107, -1.337, -1.217, -1.349, -1.244, -1.676, -1.102, -1.920, -1.178, -2.547, -1.811, -2.662, -2.335, -1.806, -2.423, -1.876, -1.956, -0.986, -0.974, -1.563, -1.535, -0.310, -0.366, -1.629, -5.000, -0.578, -0.112, -1.799, -5.000, -0.492, -0.103, -0.582, -0.836, 0.378, -0.102, -0.878, -0.991, 0.748, 0.824, 0.102, -5.000, -0.031, -0.196, -1.578, -0.280, -0.081, 0.238, 0.476, -0.491, 0.001, 0.131, -0.048, -0.727, 0.643, 0.980, 0.128, 0.953, -0.180, 0.173, -1.042, -0.821, -0.049, 0.419, 0.106, -0.426, 0.190, 0.600, -0.011, -0.005, -0.864, -0.609, -1.307, -0.635, -1.350, -0.948, -2.339, -1.771, -0.616, -0.833, -1.291, -1.265, -0.605, -0.118, -0.788, -0.953, 0.247, 0.499, -0.434, -5.000, 0.096, 0.635, -1.211, -5.000, -0.296, 0.249, -0.412, -0.501, 0.774, 0.806, 0.541, -0.405, 0.659, 0.786, 0.211, -5.000, 0.055, 0.637, -1.361, -0.153, -0.375, 0.327, -0.064, -0.718, 0.296, 0.614, 0.414, -0.513, 1.034, 1.236, 0.710, 1.335, -0.113, 0.603, -0.553, -0.183, -0.371, 0.222, -0.173, -0.475, 0.432, 0.781, 0.330, 0.419, -0.767, 0.268, -0.820, 0.050, -1.310, -0.101, -1.856, -1.200, -1.130, -0.468, -1.497, -0.979, 0.099, 0.789, 0.240, -0.618, 0.306, 0.627, -1.091, -5.000, 0.005, 0.747, -1.686, -5.000, -0.316, 0.348, -0.461, -0.779, 1.155, 0.584, 0.756, -0.300, 0.929, 1.298, 0.552, -5.000, 0.754, 0.981, -1.132, 0.345, 0.214, 0.785, -0.104, -0.448, 0.751, 1.128, 0.897, -0.098, 1.117, 1.322, 0.949, 1.489, 0.437, 0.758, -5.000, 0.405, 0.324, 0.809, 0.322, 0.081, 0.839, 1.086, 0.833, 0.597, 0.655, 1.168, 0.374, 0.993, -0.224, 0.963, -1.246, -0.023, -0.018, 0.750, -0.180, -0.547, 1.020, 1.193, 1.032, 0.554, 0.021, 0.041, -2.017, -5.000, -0.034, 0.301, -1.822, -5.000, -0.365, -0.129, -0.404, -0.763, 0.507, 0.172, -0.579, -1.040, 0.756, 1.006, -0.010, -5.000, 0.185, 0.602, -0.721, -0.505, -0.174, -0.170, 0.059, -0.958, 0.189, 0.785, 0.218, -0.713, 0.742, 1.284, -0.272, 0.748, -0.550, 0.397, -0.749, -0.387, -0.648, -0.216, -0.671, -0.514, -0.043, 0.312, -0.493, -0.378, 0.666, 1.095, 0.019, 0.724, -0.541, 0.492, -1.179, -0.526, -0.251, 0.027, -0.678, -0.786, 0.535, 0.859, 0.014, -0.443, -0.359, -0.269, -1.166, -5.000, -1.531, -0.307, -2.048, -5.000, -1.402, -0.376, -1.033, -1.269, -0.127, -0.199, -0.620, -1.202, 0.162, 0.692, -0.270, -5.000, -0.265, -0.650, -1.216, -0.875, -0.770, -0.357, -0.575, -1.233, -0.302, 0.130, -0.415, -0.785, -0.266, 0.639, -0.413, 0.433, -1.012, -0.009, -1.367, -1.089, -0.914, -0.436, -1.036, -1.285, -0.423, 0.347, -0.491, -0.721, -0.228, 0.147, -1.029, -0.259, -1.288, -0.187, -1.211, -1.422, -1.004, -0.390, -1.517, -1.378, 0.214, 0.683, 0.189, -0.882, 0.568, 0.844, -0.604, -5.000, 0.446, 0.871, -0.862, -5.000, 0.281, 0.668, 0.150, -0.095, 1.143, 0.954, 0.623, 0.165, 0.805, 1.011, 0.488, -5.000, 0.189, 0.269, -1.160, -0.199, 0.148, 0.762, 0.286, -0.319, 0.588, 0.875, 0.712, -0.187, 0.993, 1.305, 0.828, 1.203, 0.386, 0.431, -0.547, 0.317, 0.294, 0.633, 0.102, -0.155, 0.638, 0.873, 0.546, 0.805, -0.296, 0.477, -0.432, 0.051, -0.706, 0.212, -1.331, -0.619, -0.541, 0.048, -0.356, -0.755, 0.219, 0.729, 0.250, -0.300, 0.445, 0.535, -1.044, -5.000, 0.532, 0.627, -1.947, -5.000, 0.461, 0.403, 0.059, -0.257, 1.249, 0.213, 0.416, 0.092, 0.825, 0.914, 0.255, -5.000, 0.619, 0.395, -0.822, 0.216, 0.171, 0.658, 0.419, -0.349, 0.477, 0.848, 0.557, -0.079, 0.953, 1.179, 0.593, 1.424, 0.321, 0.733, -0.883, 0.481, 0.430, 0.599, 0.332, -0.186, 0.783, 0.821, 0.626, 0.863, 0.531, 0.967, -0.304, 0.525, 0.469, 0.972, -1.125, -0.161, 0.538, 0.819, 0.145, -0.060, 0.970, 1.141, 0.932, 0.576, 0.040, 0.095, -1.358, -5.000, 0.073, 0.561, -1.480, -5.000, 0.118, 0.436, -0.213, -0.032, 0.815, -0.446, -0.593, -0.803, 0.860, 1.168, 0.250, -5.000, 0.653, 0.594, -1.258, 0.028, 0.518, 0.831, 0.293, -0.116, 0.588, 0.965, 0.564, 0.140, 0.372, 1.098, -0.085, 0.922, -0.121, 0.458, -0.927, -0.363, -0.271, 0.467, -0.246, -0.450, 0.042, 0.376, -0.284, 0.182, 0.216, 0.967, -0.439, 0.525, -0.266, 0.435, -1.476, -0.789, 0.198, 0.569, -0.450, -0.277, 0.687, 0.980, 0.150, 0.177, -0.367, -0.344, -1.555, -5.000, -0.745, 0.053, -1.572, -5.000, -1.119, -0.061, -1.254, -1.081, -0.083, -0.260, -0.838, -0.905, -0.294, 0.062, -0.652, -5.000, -0.478, -0.232, -1.248, -0.588, -1.171, -0.583, -1.026, -1.447, -0.637, -0.334, -0.643, -0.911, -0.180, 0.838, -0.277, -0.050, -0.848, -0.336, -1.567, -0.882, -0.965, -0.238, -0.934, -1.080, -0.755, -0.039, -0.759, -0.731, 0.005, 0.819, -0.305, 0.088, -0.569, 0.279, -1.350, -0.929, -0.697, 0.264, -0.908, -0.761, 0.180, 0.669, 0.088, -0.263, 0.302, 0.442, -0.579, -5.000, 0.680, 0.717, -0.907, -5.000, 0.482, 0.531, 0.055, -0.178, 1.014, 0.130, 0.831, 0.183, 0.705, 0.965, 0.012, -5.000, 0.595, 0.153, -1.132, 0.327, 0.380, 0.825, 0.297, -0.064, 0.824, 0.973, 0.678, 0.207, 0.342, 0.862, 0.053, 1.150, 0.454, 0.407, -0.758, 0.037, 0.750, 0.788, 0.504, 0.159, 0.590, 0.345, 0.104, 0.655, -0.332, -0.007, -1.307, -0.461, -0.296, 0.243, -1.351, -0.990, 0.327, 0.090, -0.180, -0.244, 0.797, 0.876, 0.178, -0.043, 0.691, 0.698, -0.834, -5.000, 0.861, 0.959, -1.405, -5.000, 0.779, 0.766, 0.241, 0.465, 1.381, 0.355, 0.845, 0.528, 1.250, 1.325, 0.715, -5.000, 1.240, 0.832, -0.954, 0.787, 1.075, 1.301, 0.968, 0.542, 1.295, 1.121, 1.004, 0.414, 0.828, 1.125, 0.731, 1.495, 1.108, 0.845, -0.167, 0.739, 0.905, 0.965, 1.090, 0.524, 1.197, 0.967, 1.087, 1.223, 0.202, 0.846, -0.382, 0.434, 0.404, 0.792, -0.984, -0.411, 0.875, 0.632, 0.157, 0.006, 1.276, 1.322, 0.999, 0.921, -0.322, -0.416, -2.075, -5.000, 0.357, 0.206, -2.092, -5.000, -0.104, -0.063, -1.173, -1.182, 0.414, -0.921, -1.577, -1.085, 0.834, 0.971, -0.280, -5.000, 0.819, 0.453, -1.355, 0.179, 0.709, 0.823, 0.251, -0.616, 0.820, 0.617, 0.146, -0.077, 0.148, 1.047, -0.202, 0.732, 0.122, 0.644, -0.806, -0.022, 0.306, 0.438, -0.150, -0.388, 0.328, 0.267, -0.343, 0.220, -0.546, 0.157, -0.973, 0.033, -0.406, 0.287, -1.228, -0.405, 0.236, -0.220, -1.049, -0.860, 0.670, 0.540, -0.478, -0.319, 0.826, 0.964, -0.446, -5.000, 0.748, 0.949, -0.371, -5.000, 0.462, 0.653, 0.080, -0.371, 1.015, -0.064, 0.295, -0.181, 1.357, 1.472, 0.950, -5.000, 1.115, 1.000, -0.927, 1.022, 0.250, 0.761, 0.242, -0.401, 0.906, 0.478, 0.499, -0.193, 1.318, 1.586, 1.159, 1.598, 1.323, 1.464, 0.781, 0.897, 1.470, 1.537, 1.340, 1.010, 1.383, 1.374, 1.212, 1.326, 0.426, 0.932, -0.072, 0.485, 0.124, 0.815, -1.380, -0.716, 0.905, 0.914, 0.226, 0.024, 1.367, 1.410, 0.877, 0.669, -0.019, 0.151, -1.269, -5.000, -0.133, 0.254, -1.643, -5.000, -0.574, 0.182, -0.506, -0.758, 0.798, 0.320, 0.409, -0.173, 0.512, 0.676, -0.118, -5.000, 0.020, 0.130, -1.320, -0.013, -0.316, 0.503, -0.043, -0.634, 0.632, 0.868, 0.530, -0.123, 0.266, 0.846, -0.006, 0.884, 0.002, 0.338, -1.009, -0.320, -0.333, -0.020, -0.646, -0.645, 0.237, 0.584, 0.081, 0.274, -1.023, -0.417, -1.507, -0.613, -1.163, 0.090, -2.226, -1.745, -0.047, 0.094, -0.620, -0.754, 0.268, 0.870, 0.245, -0.440, -0.428, -0.480, -1.782, -5.000, -0.507, -0.604, -1.971, -5.000, 0.007, 0.069, -0.574, -0.556, 1.156, -0.271, 0.677, -0.193, 0.521, 0.502, -0.184, -5.000, 0.288, -0.193, -2.008, -0.208, 0.689, 0.555, 0.583, -0.223, 0.964, 0.478, 0.476, 0.070, 0.642, 0.942, 0.549, 1.275, 0.441, 0.155, -0.955, -0.095, 0.615, 0.598, 0.475, -0.069, 0.877, 0.491, 0.861, 0.842, -0.272, 0.208, -0.516, -0.014, -0.659, -0.182, -1.966, -1.188, 0.036, 0.199, -0.589, -0.805, 0.849, 0.860, 0.473, 0.523, -1.371, -1.372, -2.201, -5.000, -0.993, -2.110, -2.640, -5.000, -0.763, -1.436, -1.634, -1.686, -0.146, -1.663, -2.500, -2.077, -0.179, -0.003, -0.700, -5.000, -0.249, -1.149, -1.750, -0.957, -0.469, -0.939, -0.378, -0.485, 0.282, -0.108, -0.632, -1.088, -0.389, 0.183, -0.711, 0.293, -1.247, -0.872, -1.193, -1.373, -0.533, -0.544, -1.029, -0.861, -0.439, -0.667, -0.883, -0.495, -1.025, -0.973, -1.551, -0.887, -1.651, -2.032, -1.924, -2.748, -1.268, -1.098, -1.592, -1.484, -0.181, -0.595, -1.042, -1.276, -0.160, -0.474, -1.846, -5.000, -0.535, -0.319, -2.022, -5.000, -0.510, -0.139, -1.169, -0.841, 0.272, -0.698, -1.076, -1.211, 0.676, 0.720, 0.149, -5.000, 0.062, -0.259, -1.439, -0.303, -0.517, 0.269, -0.273, -0.997, 0.013, -0.090, -0.296, -0.650, 0.107, 0.561, -0.111, 0.650, -0.456, -0.085, -0.868, -0.781, -0.314, 0.194, -0.683, -0.740, 0.146, 0.400, -0.091, -0.062, -1.018, -0.808, -1.515, -0.744, -1.592, -0.935, -1.816, -1.841, -1.188, -1.275, -1.260, -1.318, -0.256, 0.053, -0.683, -0.874, 0.180, 0.459, -0.813, -5.000, -0.160, 0.517, -1.473, -5.000, -0.131, 0.242, -0.366, -0.432, 0.697, 0.220, 0.306, -0.226, 0.419, 0.412, -0.228, -5.000, -0.258, -0.155, -1.243, 0.051, -0.136, 0.133, -0.558, -0.828, 0.700, 0.633, 0.339, -0.431, 0.421, 0.890, -0.043, 1.164, -0.169, 0.253, -1.034, -0.023, -0.279, 0.286, -0.364, -0.331, 0.255, 0.405, 0.086, 0.526, -0.705, -0.056, -1.081, -0.344, -1.597, -0.167, -3.320, -1.477, -0.672, -0.364, -0.843, -0.734, 0.263, 0.764, 0.103, -0.274, 0.107, 0.075, -1.722, -5.000, -0.030, 0.228, -1.626, -5.000, 0.046, 0.160, -0.759, -0.422, 1.075, -0.164, 0.697, -0.012, 0.869, 0.993, 0.060, -5.000, 0.704, 0.460, -1.302, 0.258, 0.338, 0.587, -0.274, -0.549, 0.816, 0.696, 0.604, -0.048, 0.832, 0.917, 0.430, 1.333, 0.279, 0.566, -0.212, 0.422, 0.226, 0.481, -0.175, 0.038, 0.497, 0.520, 0.617, 0.774, 0.215, 0.692, -0.406, 0.257, -0.379, 0.197, -1.174, -0.655, -0.045, 0.341, -0.662, -0.656, 0.900, 1.029, 0.725, 0.536, -0.395, -0.413, -1.461, -5.000, -0.127, -0.704, -1.709, -5.000, 0.039, -0.163, -0.669, -0.497, 0.422, -0.700, -0.650, -0.859, 0.543, 0.687, -0.490, -5.000, 0.220, 0.278, -1.366, -0.500, 0.008, -0.113, -0.309, -1.039, 0.631, 0.420, 0.053, -0.425, 0.378, 1.325, -0.100, 0.762, -0.372, 0.363, -0.622, -0.057, -0.311, 0.026, -0.804, -0.484, 0.063, 0.081, -0.523, 0.055, 0.123, 0.249, -0.596, 0.226, -0.811, -0.224, -1.464, -0.646, -0.132, -0.318, -0.889, -0.880, 0.517, 0.595, -0.436, -0.423, -0.415, -0.343, -1.329, -5.000, -0.867, -0.234, -2.674, -5.000, -0.573, -0.505, -0.768, -0.838, 0.114, -0.533, -0.595, -1.093, 0.041, 0.564, -0.477, -5.000, -0.513, -0.319, -1.449, -0.841, -0.551, -0.193, -0.915, -0.852, -0.088, -0.108, -0.400, -0.724, -0.179, 0.427, -0.476, 0.574, -0.600, 0.032, -0.872, -0.571, -0.497, -0.361, -0.916, -0.807, -0.189, -0.062, -0.366, -0.311, -0.693, -0.383, -1.117, -0.569, -1.295, -0.743, -1.616, -1.406, -0.838, -0.592, -1.337, -1.121, 0.014, 0.238, -0.333, -0.638, 0.567, 0.777, -0.569, -5.000, 0.589, 0.625, -0.814, -5.000, 0.290, 0.499, 0.219, -0.256, 1.011, 0.640, 0.947, 0.240, 0.884, 1.152, 0.193, -5.000, 0.603, 0.431, -0.782, 0.349, 0.372, 0.725, 0.263, -0.189, 0.735, 0.822, 0.530, 0.362, 0.641, 1.193, 0.346, 1.251, 0.256, 0.488, -0.841, -0.095, 0.335, 0.593, 0.092, -0.116, 0.460, 0.649, 0.154, 0.688, -0.323, 0.405, -0.679, -0.142, -1.219, 0.171, -1.608, -1.263, -0.566, -0.263, -0.742, -0.842, 0.329, 0.752, -0.028, -0.201, 0.203, 0.124, -1.396, -5.000, 0.659, 0.559, -1.177, -5.000, 0.440, 0.310, -0.314, 0.155, 1.246, -0.408, 0.696, 0.353, 0.921, 0.781, 0.044, -5.000, 0.625, -0.332, -0.939, 0.164, 0.454, 0.718, 0.498, 0.035, 1.011, 0.523, 0.561, -0.031, 0.626, 0.934, 0.360, 1.295, 0.419, 0.549, -0.148, 0.224, 0.478, 0.416, 0.445, -0.076, 0.709, 0.615, 0.345, 0.858, 0.070, 0.334, -0.872, 0.009, -0.154, 0.399, -1.028, -0.635, 0.320, 0.368, -0.486, -0.557, 0.946, 0.935, 0.344, 0.319, -0.272, -0.144, -1.528, -5.000, 0.188, 0.051, -1.392, -5.000, 0.093, -0.127, -0.730, -0.310, 0.599, -0.607, -0.538, -0.568, 0.557, 0.860, -0.081, -5.000, 0.611, 0.233, -1.218, 0.023, 0.442, 0.425, 0.064, -0.193, 0.902, 0.623, 0.532, 0.257, 0.204, 0.869, -0.145, 0.853, -0.133, 0.325, -0.666, -0.242, -0.017, 0.366, -0.180, -0.374, 0.155, 0.088, -0.295, 0.180, -0.194, 0.072, -1.027, -0.022, -0.473, 0.098, -1.249, -0.974, 0.023, 0.020, -0.800, -0.564, 0.650, 0.529, -0.171, -0.099, 0.232, 0.208, -1.178, -5.000, 0.157, 0.509, -1.136, -5.000, -0.414, 0.049, -0.423, -0.608, 0.848, 0.101, -0.246, -0.858, 0.981, 1.136, 0.500, -5.000, 0.566, 0.528, -0.761, 0.300, -0.256, 0.196, -0.255, -0.851, 0.667, 0.669, 0.503, -0.347, 0.534, 1.127, 0.306, 1.029, 0.058, 0.682, -0.393, -0.145, 0.356, 0.710, 0.261, -0.242, 0.421, 0.700, 0.325, 0.445, -0.268, 0.135, -0.875, -0.162, -0.760, 0.032, -1.315, -1.058, -0.244, -0.054, -0.657, -0.741, 0.550, 0.835, 0.234, -0.069, -0.191, -0.282, -0.785, -5.000, -0.008, -0.385, -1.623, -5.000, -0.129, 0.092, -0.232, -0.666, 0.363, -0.171, 0.150, -0.467, 0.050, 0.153, -0.649, -5.000, -0.090, -0.494, -1.657, -0.314, 0.157, 0.130, -0.380, -0.436, 0.460, 0.733, 0.227, -0.092, -0.204, 0.121, -0.320, 0.460, -0.169, -0.468, -0.988, -0.576, 0.098, 0.087, -0.089, -0.330, 0.085, 0.079, -0.407, 0.020, -0.841, -0.661, -1.436, -0.531, -0.925, -0.602, -2.184, -1.434, -0.179, -0.628, -0.429, -0.387, 0.192, 0.328, -0.225, -0.420, 0.169, 0.079, -1.625, -5.000, 0.317, 0.075, -2.230, -5.000, 0.268, -0.020, -0.462, -0.484, 0.919, 0.101, 0.688, 0.099, 0.878, 0.836, -0.058, -5.000, 0.736, 0.386, -1.129, 0.283, 0.453, 0.741, 0.365, -0.124, 0.919, 0.757, 0.272, 0.066, 0.268, 0.638, 0.120, 1.215, 0.632, 0.091, -0.666, -0.032, 0.425, 0.187, 0.542, -0.092, 0.727, 0.364, 0.451, 0.698, -0.074, 0.457, -1.017, 0.245, -0.069, 0.186, -1.184, -0.517, 0.212, 0.118, -0.332, -0.511, 0.963, 0.987, 0.629, 0.551, -0.902, -1.394, -2.413, -5.000, -0.975, -1.192, -2.580, -5.000, -0.580, -1.059, -1.839, -1.484, -0.616, -1.642, -2.102, -1.612, -0.174, -0.187, -1.020, -5.000, -0.035, -0.461, -2.251, -0.815, -0.124, -0.312, -1.325, -1.060, 0.194, -0.339, -0.725, -0.799, -0.814, -0.309, -1.071, -0.265, -0.980, -0.713, -1.737, -1.056, -0.660, -0.580, -1.009, -0.712, -0.459, -0.501, -0.952, -0.667, -1.145, -0.464, -1.415, -1.045, -0.885, -1.029, -2.083, -1.215, -0.689, -1.286, -1.784, -1.493, -0.352, -0.799, -1.250, -0.970, -0.047, -0.136, -1.215, -5.000, -0.002, -0.229, -1.671, -5.000, -0.218, -0.496, -0.689, -0.578, -0.088, -0.290, -0.318, -0.673, 0.768, 0.785, 0.148, -5.000, 0.719, 0.144, -1.530, 0.308, -0.165, 0.210, -0.362, -0.817, 0.569, 0.440, -0.042, -0.212, 0.124, 0.447, -0.091, 0.901, 0.185, 0.296, -0.268, -0.400, 0.336, 0.490, 0.150, -0.053, 0.337, 0.147, -0.298, 0.105, -0.417, -0.059, -1.045, -0.330, -0.619, -0.248, -1.355, -1.178, -0.153, -0.314, -0.842, -0.562, 0.149, 0.346, -0.264, -0.493, -0.528, -0.372, -1.775, -5.000, -0.704, -0.543, -1.859, -5.000, -0.626, -0.325, -0.596, -0.972, 0.114, -0.004, -0.070, -0.468, -0.349, -0.143, -0.885, -5.000, -0.601, -0.820, -1.937, -0.920, -0.681, -0.282, -0.919, -0.925, 0.084, 0.267, -0.160, -0.621, -0.225, 0.039, -0.857, 0.117, -0.647, -0.403, -1.361, -0.945, -1.068, -0.692, -1.508, -1.334, -0.246, -0.025, -0.236, -0.373, -1.126, -0.972, -1.750, -1.108, -1.546, -0.832, -2.557, -2.133, -1.425, 0.241, -1.499, -0.806, -0.223, 0.258, -0.286, -0.342, -0.311, -0.513, -1.792, -5.000, -0.447, -0.461, -2.262, -5.000, -0.249, -0.212, -1.037, -0.904, 0.884, -0.290, 0.258, -0.542, 0.680, 0.407, -0.447, -5.000, 0.400, -0.083, -1.465, -0.292, 0.605, 0.321, 0.310, -0.419, 0.862, 0.374, 0.254, 0.030, 0.462, 0.578, 0.295, 1.085, 0.659, 0.201, -0.460, -0.023, 0.458, 0.106, 0.328, -0.673, 0.711, 0.572, 0.714, 0.609, -0.173, 0.189, -0.859, -0.185, -0.316, 0.105, -1.771, -0.928, -0.271, -0.063, -1.398, -1.073, 0.720, 0.779, 0.497, 0.347, -1.818, -2.262, -3.444, -5.000, -2.375, -2.559, -2.902, -5.000, -1.538, -2.170, -1.952, -1.933, -1.839, -2.721, -2.660, -2.273, -1.070, -1.587, -1.609, -5.000, -1.363, -1.997, -2.302, -1.708, -1.601, -0.980, -1.410, -2.408, -0.641, -1.000, -1.559, -1.375, -0.790, -0.922, -2.097, -1.022, -1.687, -1.951, -1.741, -2.110, -1.302, -1.386, -1.665, -1.736, -1.180, -1.208, -1.372, -1.900, -1.528, -1.853, -1.790, -1.063, -2.251, -3.053, -2.605, -2.593, -2.141, -2.357, -2.325, -2.618, -1.564, -1.241, -1.859, -1.913, -0.773, -1.107, -2.466, -5.000, -1.230, -1.212, -2.116, -5.000, -1.049, -0.923, -1.718, -2.055, -0.713, -1.264, -1.867, -1.857, -0.095, -0.279, -1.063, -5.000, -0.751, -1.113, -2.096, -1.353, -0.910, -0.507, -0.865, -1.629, -0.310, -0.104, -0.769, -0.891, -0.273, -0.485, -1.043, 0.020, -0.740, -0.745, -1.385, -1.484, -1.001, -0.982, -1.439, -1.524, -0.488, -0.584, -1.101, -1.105, -1.316, -1.217, -2.070, -1.048, -1.675, -1.482, -2.781, -2.546, -1.655, -1.894, -1.744, -2.133, -0.893, -0.698, -1.196, -1.226, -0.093, 0.076, -1.075, -5.000, -0.355, 0.064, -2.135, -5.000, -0.220, 0.168, -0.059, -0.535, 0.399, 0.580, 0.324, -0.148, 0.282, 0.621, -0.448, -5.000, -0.248, -0.200, -1.620, -0.436, -0.380, -0.170, -0.486, -1.140, 0.538, 0.602, 0.166, -0.696, 0.337, 0.611, -0.178, 0.910, -0.639, 0.217, -1.750, -0.619, -0.539, -0.052, -0.736, -0.996, 0.266, 0.469, -0.018, 0.057, -1.056, -0.469, -1.494, -0.503, -1.652, -0.758, -2.757, -2.095, -1.094, -0.469, -1.090, -0.882, -0.042, 0.706, -0.103, -0.696, -0.294, -0.067, -1.922, -5.000, -0.384, -0.481, -2.497, -5.000, -0.428, -0.223, -0.945, -0.921, 0.809, -0.033, 0.280, -0.158, 0.543, 0.798, -0.129, -5.000, 0.613, 0.225, -1.787, -0.104, 0.028, 0.363, -0.343, -0.617, 0.563, 0.558, 0.369, -0.129, 0.211, 0.689, 0.161, 1.053, -0.038, 0.146, -1.010, -0.034, -0.147, 0.386, -0.091, -0.318, 0.306, 0.224, 0.174, 0.353, -0.092, 0.459, -0.693, 0.283, -0.549, 0.255, -1.850, -1.022, -0.278, -0.007, -0.753, -0.815, 0.613, 0.811, 0.385, 0.186, -0.704, -1.030, -1.970, -5.000, -0.775, -0.582, -2.787, -5.000, -0.233, -0.741, -1.020, -1.181, -0.316, -1.157, -1.231, -1.367, -0.120, -0.066, -1.154, -5.000, -0.415, -0.153, -1.950, -1.237, -0.220, -0.412, -0.930, -1.512, 0.194, 0.233, -0.401, -0.898, -0.463, 0.599, -1.121, -0.169, -0.939, -0.691, -1.495, -1.034, -0.933, -0.660, -1.289, -1.240, -0.390, -0.721, -1.109, -0.624, -0.284, -0.090, -1.132, -0.145, -1.229, -0.579, -2.695, -1.380, -0.942, -0.911, -1.729, -1.448, -0.005, -0.050, -0.913, -1.077, -0.674, -0.853, -1.613, -5.000, -0.443, -0.481, -1.937, -5.000, -0.883, -0.535, -1.212, -1.097, -0.359, -1.039, -0.989, -1.282, -0.124, 0.023, -0.772, -5.000, -0.421, -0.709, -1.643, -0.767, -0.806, -0.418, -0.833, -1.336, -0.068, -0.061, -0.231, -0.544, -0.487, -0.127, -0.933, 0.343, -1.096, -0.442, -1.574, -1.141, -0.683, -0.611, -1.337, -1.107, -0.405, -0.423, -0.601, -0.692, -0.947, -0.805, -1.408, -0.614, -1.399, -1.239, -2.359, -2.141, -1.352, -1.213, -1.740, -1.335, -0.231, -0.111, -0.745, -0.970, 0.507, 0.951, -0.382, -5.000, 0.683, 0.810, -1.031, -5.000, 0.449, 0.677, 0.179, -0.025, 0.793, 0.854, 0.877, 0.185, 0.935, 1.117, 0.625, -5.000, 0.610, 0.309, -1.454, 0.419, 0.334, 0.749, 0.431, -0.233, 0.970, 1.070, 0.894, 0.343, 0.677, 1.188, 0.711, 1.181, 0.378, 0.716, -0.271, 0.071, 0.449, 0.870, 0.147, 0.002, 0.572, 0.931, 0.502, 0.656, -0.204, 0.585, -0.693, 0.049, -0.559, 0.406, -1.485, -0.968, -0.350, -0.002, -0.240, -0.570, 0.309, 0.893, 0.332, -0.070, 0.572, 0.550, -0.968, -5.000, 0.876, 0.619, -1.616, -5.000, 0.721, 0.672, 0.220, 0.153, 1.145, 0.288, 0.825, 0.476, 1.078, 1.105, 0.598, -5.000, 1.122, 0.503, -0.896, 0.835, 0.835, 0.966, 0.726, 0.232, 1.060, 1.032, 0.878, 0.339, 0.878, 1.176, 0.684, 1.368, 0.850, 0.732, -0.307, 0.622, 0.702, 0.791, 0.644, 0.219, 1.034, 0.977, 0.795, 0.991, 0.441, 0.902, -0.260, 0.357, 0.459, 0.854, -1.071, -0.065, 0.622, 0.853, 0.102, -0.276, 1.038, 1.194, 0.797, 0.741, -0.257, -0.202, -1.478, -5.000, 0.004, 0.052, -1.713, -5.000, 0.047, -0.177, -1.049, -0.269, 0.310, -1.014, -1.083, -0.685, 0.643, 0.981, 0.109, -5.000, 0.676, 0.381, -1.379, 0.070, 0.668, 0.603, 0.244, -0.117, 0.837, 0.722, 0.611, 0.519, -0.075, 0.519, -0.323, 0.637, -0.052, -0.073, -0.874, -0.322, -0.133, 0.259, -0.405, -0.264, 0.158, -0.024, -0.464, 0.130, -0.291, 0.073, -0.732, 0.025, -0.359, 0.073, -1.727, -0.774, 0.117, 0.016, -0.980, -0.517, 0.533, 0.554, -0.208, -0.136, -0.184, 0.074, -1.158, -5.000, -0.195, 0.116, -1.441, -5.000, -0.485, -0.186, -0.789, -0.889, 0.098, -0.337, -0.773, -0.786, 0.490, 0.906, 0.057, -5.000, 0.184, 0.058, -1.258, -0.210, -0.516, -0.079, -0.607, -0.985, 0.263, 0.519, 0.248, -0.184, 0.075, 0.753, -0.016, 0.551, -0.158, 0.166, -0.486, -0.562, -0.046, 0.337, -0.158, -0.508, -0.018, 0.201, -0.039, -0.124, -0.507, 0.021, -0.766, -0.430, -0.602, -0.205, -1.558, -1.275, -0.594, -0.546, -1.114, -0.767, -0.118, 0.399, -0.301, -0.500 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_35(struct _training *tptr) {
  struct _training tinf = {
    0.328, 11, 4.350, { 2.470, 0.327, 0.202 }, { 0.529, -0.256, -1.787 }, 0, 
    { -0.051, -1.286, -1.053, -1.080, -4.000, -0.526, -0.281, -4.000, 1.094, -0.673, -0.883, -4.000, -0.436, 0.266, 1.154, -0.581, 0.846, -0.478, 0.232, 1.045, -0.243, 0.560, 0.292, 0.049, 1.395, 1.235, -4.000, 1.659 }, 
    {{ -0.054, -0.188, -0.353, 0.248},{ 0.163, -0.245, -0.552, 0.128},{ 0.075, -0.157, -0.289, 0.109},{ 0.176, -0.178, -0.349, 0.030},{ 0.138, -0.184, -0.299, 0.059},{ 0.037, -0.163, -0.346, 0.164},{ 0.042, -0.133, -0.216, 0.107},{ 0.034, -0.084, -0.286, 0.119},{ 0.017, -0.210, -0.139, 0.130},{ 0.024, -0.051, -0.127, 0.057},{ 0.228, -0.175, -0.357, -0.032},{ 0.336, -0.458, -0.612, 0.003},{ 0.248, -0.331, -0.766, 0.111},{ 0.207, -0.314, -0.847, 0.166},{ 0.133, -0.574, -0.847, 0.300},{ 0.018, -0.454, -0.823, 0.360},{ -0.080, -0.310, -0.454, 0.325},{ -0.020, -0.191, -0.289, 0.205},{ 0.174, -0.175, -0.252, -0.004},{ 0.281, -0.051, -0.387, -0.155},{ 0.358, -0.317, -0.512, -0.107},{ 0.314, -0.200, -0.478, -0.100},{ 0.246, -0.016, -0.491, -0.085},{ 0.183, -0.035, -0.361, -0.037},{ 0.179, 0.067, -0.160, -0.171},{ 0.155, 0.135, -0.282, -0.126},{ 0.122, -0.087, -0.296, 0.035},{ 0.081, 0.017, -0.175, -0.015},{ 0.094, -0.037, -0.262, 0.031},{ 0.104, -0.157, -0.279, 0.077},{ 0.070, -0.032, -0.145, 0.009},{ 0.129, 0.045, -0.210, -0.070} }, 
    {{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, 0.631, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 1.047, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 0.939, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, 1.169, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 1.305, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 0.774, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 1.113, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 1.395, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 1.382}} }, 
    -0.084, { 0.562, 0.975, 0.035, -5.000, 0.252, 0.806, -1.377, -5.000, 0.307, 0.908, 0.314, 0.188, 0.544, 0.768, 0.096, 0.461, 0.451, 0.775, -0.299, -5.000, 0.041, 0.364, -1.844, -0.010, -0.505, 0.244, 0.020, -0.184, 0.415, 0.512, -0.457, -0.032, -0.057, 0.530, -0.710, -0.134, -0.319, 0.207, -1.247, -1.184, -0.849, 0.032, -0.445, -1.143, -0.575, 0.127, -0.421, -0.285, 0.209, 0.897, -0.339, 0.131, 0.220, 0.887, -0.978, -0.650, 0.398, 0.926, 0.567, 0.141, 0.293, 0.714, 0.273, 0.112, 0.836, 1.171, 0.586, -5.000, 0.703, 1.087, -1.059, -5.000, 0.761, 1.235, 1.166, 0.562, 1.024, 1.146, 0.627, 0.918, 0.597, 0.992, -0.201, -5.000, 0.517, 0.611, -1.466, 0.474, -0.082, 0.675, 0.509, 0.030, 0.487, 0.472, -0.762, -0.085, 0.809, 1.323, 0.556, 0.836, 0.674, 1.206, -0.142, -0.002, 0.117, 1.153, 0.837, -0.051, 0.595, 1.026, 0.478, 0.638, 0.820, 1.319, 0.463, 0.776, 0.917, 1.243, -0.166, 0.024, 0.900, 1.299, 0.910, 0.536, 0.959, 1.222, 0.686, 0.742, 0.352, 0.741, 0.082, -5.000, 0.515, 0.749, -1.111, -5.000, 0.622, 1.144, 0.632, 0.452, 0.224, 0.460, -0.395, 0.307, 0.082, 0.531, -0.564, -5.000, 0.093, 0.308, -2.053, -0.200, 0.068, 0.536, 0.202, -0.094, 0.037, 0.125, -1.548, -0.492, -0.562, 0.187, -1.483, -0.616, -0.317, 0.199, -1.486, -1.310, -0.458, 0.189, -0.367, -0.708, -0.621, -0.020, -1.090, -0.705, 0.106, 0.662, -1.113, -0.087, 0.183, 0.892, -1.427, -0.961, 0.448, 0.920, 0.118, 0.145, 0.348, 0.563, -0.333, -0.446, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.116, 0.639, -0.008, -5.000, 0.038, 0.719, -1.334, -5.000, 0.191, 0.842, 0.473, 0.103, 0.579, 0.770, 0.201, 0.607, 0.098, 0.524, -0.250, -5.000, -0.351, 0.010, -2.376, -0.168, -0.426, 0.584, 0.437, -0.142, 0.416, 0.501, -0.471, -0.064, -0.047, 0.649, -0.233, -0.106, -0.527, 0.133, -1.989, -1.300, -0.953, 0.006, -0.619, -1.504, -0.187, 0.379, -0.240, 0.011, -0.041, 0.811, -0.182, 0.142, -0.003, 0.946, -1.226, -1.059, 0.438, 1.150, 0.583, 0.099, 0.345, 0.761, 0.183, 0.125, 0.721, 1.120, 0.729, -5.000, 0.570, 1.087, -0.477, -5.000, 0.762, 1.196, 0.951, 0.146, 1.056, 1.197, 0.707, 0.965, 0.623, 0.914, -0.242, -5.000, 0.447, 0.324, -0.658, 0.785, 0.287, 0.877, 0.782, 0.037, 0.752, 0.513, -0.615, 0.264, 1.111, 1.410, 1.193, 1.114, 0.822, 1.178, -0.117, 0.196, 0.359, 1.179, 0.934, 0.156, 0.528, 0.952, 0.755, 1.017, 0.466, 1.117, 0.319, 0.556, 0.713, 1.197, -0.665, 0.019, 1.014, 1.262, 0.855, 0.665, 0.681, 1.020, 0.628, 0.737, -0.690, -0.350, -1.033, -5.000, -0.786, -0.898, -2.929, -5.000, -0.630, 0.133, -0.674, -0.927, -0.570, -0.897, -1.227, -0.652, -0.953, -1.472, -1.609, -5.000, -0.823, -1.160, -5.000, -1.696, -0.912, 0.464, 0.028, -0.912, -0.479, -1.700, -1.040, -0.880, -1.543, -0.515, -2.613, -2.208, -1.145, -0.484, -2.386, -1.919, -1.631, -0.843, -1.187, -1.697, -1.715, -1.798, -2.276, -2.156, -1.438, -0.495, -2.014, -1.307, -1.264, -1.382, -1.252, -2.260, -1.126, -0.635, -1.287, -1.014, -1.436, -1.831, -1.889, -1.719, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.241, 0.752, 0.266, -5.000, 0.171, 0.725, -1.049, -5.000, 0.475, 0.867, 0.596, 0.112, 0.474, 0.724, 0.052, 0.360, 0.370, 0.806, 0.027, -5.000, -0.023, 0.620, -1.706, 0.104, 0.093, 0.649, 0.505, -0.009, 0.702, 0.413, -0.457, 0.022, 0.219, 0.861, 0.102, 0.466, -0.524, 0.505, -0.932, -0.971, -0.253, 0.344, 0.160, -0.613, -0.096, 0.493, -0.032, -0.078, 0.133, 0.874, -0.069, 0.224, -0.017, 0.938, -0.827, -0.862, 0.450, 0.888, 0.540, 0.063, 0.136, 0.736, 0.136, 0.001, 0.775, 1.246, 0.882, -5.000, 0.806, 1.145, -1.476, -5.000, 0.805, 1.094, 0.789, 0.510, 1.055, 1.166, 0.567, 0.989, 0.773, 1.198, -0.103, -5.000, 0.760, 0.884, -1.367, 0.556, 0.181, 0.902, 0.534, 0.551, 0.981, 0.575, -0.450, 0.557, 0.799, 1.376, 0.709, 0.915, 0.687, 1.230, 0.099, 0.125, 0.483, 1.083, 0.387, 0.086, 0.566, 0.908, 0.518, 0.729, 0.737, 1.325, 0.802, 0.935, 0.777, 1.426, -0.235, 0.005, 0.858, 1.202, 0.803, 0.529, 0.861, 1.145, 0.506, 0.677, 0.576, 0.917, 0.455, -5.000, 0.762, 0.984, -0.783, -5.000, 0.619, 0.721, 0.661, 0.408, 0.699, 0.855, 0.130, 0.762, 0.427, 0.733, -0.086, -5.000, 0.296, 0.511, -5.000, 0.408, 0.565, 0.964, 0.711, 0.451, 0.739, 0.589, -0.257, 0.289, 0.256, 1.135, -0.142, 0.122, -0.373, 0.638, -0.428, -0.192, 0.040, 0.577, 0.300, -0.259, -0.004, 0.532, -0.502, 0.152, 0.444, 1.290, 0.396, 0.503, 0.003, 1.064, -0.827, 0.085, 0.452, 0.569, 0.416, 0.065, 0.383, 0.817, -0.214, -0.176, 0.082, 0.467, -0.053, -5.000, -0.052, 0.149, -1.882, -5.000, -0.007, 0.617, 0.340, -0.239, 0.113, 0.481, -0.257, 0.166, 0.033, 0.503, -0.185, -5.000, -0.281, -0.133, -2.459, -0.106, -0.296, 0.549, 0.210, -0.058, 0.395, 0.278, -0.095, 0.122, -0.030, 0.648, -0.472, -0.013, -0.684, 0.320, -1.171, -1.371, -0.296, 0.396, -0.165, -0.425, 0.048, 0.449, 0.051, -0.217, -0.098, 0.563, -0.289, 0.105, -0.424, 0.683, -0.429, -0.920, -0.002, 0.614, 0.237, -0.382, 0.195, 0.603, 0.111, -0.306, 0.578, 0.988, 0.288, -5.000, 0.439, 1.065, -0.738, -5.000, 0.639, 1.144, 0.665, 0.370, 0.541, 0.828, 0.150, 0.436, 0.432, 0.849, -0.302, -5.000, 0.057, 0.494, -1.661, 0.226, 0.094, 0.743, 0.560, -0.038, 0.482, 0.400, -0.480, -0.236, 0.231, 0.710, -0.064, 0.242, -0.340, 0.419, -0.967, -1.152, -0.509, 0.062, -0.103, -0.711, -0.194, 0.252, -0.362, 0.026, 0.194, 0.911, -0.298, 0.196, 0.149, 0.933, -1.043, -0.654, 0.333, 0.953, 0.415, 0.091, 0.291, 0.729, 0.034, 0.014, 0.714, 1.024, 0.569, -5.000, 0.678, 1.053, -0.812, -5.000, 0.819, 1.144, 0.881, 0.507, 0.818, 0.945, 0.487, 0.697, 0.292, 0.724, -0.296, -5.000, 0.163, 0.310, -1.355, 0.240, -0.038, 0.539, 0.455, -0.160, 0.195, -0.007, -1.131, -0.414, 0.706, 1.253, 0.478, 0.720, 0.391, 0.925, -0.702, -0.497, -0.008, 0.838, 0.682, 0.043, 0.264, 0.672, 0.246, 0.563, 0.743, 1.359, 0.448, 0.739, 0.748, 1.305, -0.485, -0.121, 0.827, 1.254, 0.816, 0.374, 0.741, 0.942, 0.182, 0.560, 0.350, 0.879, -0.297, -5.000, 0.435, 0.634, -0.868, -5.000, 0.357, 1.015, 0.202, 0.052, 0.217, 0.466, -0.470, -0.065, -0.099, 0.637, -0.857, -5.000, -0.039, 0.149, -1.408, -0.066, -0.384, 0.524, -0.195, -0.185, -0.031, -0.119, -1.066, -0.670, -0.307, 0.235, -1.614, -0.495, -0.278, -0.063, -1.809, -1.318, -0.536, 0.145, -0.366, -0.453, -0.480, -0.042, -1.016, -0.425, -0.039, 0.740, -0.890, -0.140, 0.056, 0.355, -1.941, -1.242, -0.104, 0.447, -0.360, -0.519, -0.023, 0.274, -0.575, -0.372, 0.439, 1.034, 0.156, -5.000, 0.517, 0.824, -0.560, -5.000, 0.509, 1.190, 0.559, 0.266, 0.356, 0.641, -0.281, 0.144, 0.251, 0.889, -0.180, -5.000, 0.198, 0.642, -2.210, 0.544, 0.107, 0.883, 0.287, 0.117, 0.426, 0.350, -0.650, 0.034, 0.255, 0.821, -0.438, 0.123, 0.009, 0.486, -0.944, -1.115, -0.093, 0.587, -0.188, -0.357, -0.008, 0.338, -0.425, 0.022, 0.237, 1.004, -0.307, 0.237, 0.192, 0.904, -0.871, -0.945, 0.253, 0.909, 0.141, -0.252, 0.287, 0.644, -0.066, -0.206, 0.178, 0.607, -0.240, -5.000, 0.018, 0.656, -1.190, -5.000, 0.151, 0.743, 0.360, 0.183, 0.442, 0.588, -0.171, 0.450, 0.142, 0.533, -0.720, -5.000, -0.007, 0.280, -1.835, -0.087, -0.405, 0.027, -0.216, -0.502, 0.062, 0.083, -0.672, -0.327, -0.093, 0.412, -0.606, -0.083, -0.484, 0.053, -1.554, -1.311, -0.984, 0.065, -0.485, -1.167, -0.518, 0.185, -0.366, -0.377, 0.354, 0.937, -0.344, 0.365, 0.264, 1.045, -1.193, -0.623, 0.483, 1.065, 0.790, 0.362, 0.449, 0.922, 0.508, 0.366, 0.728, 1.036, 0.426, -5.000, 0.519, 0.923, -0.926, -5.000, 0.404, 0.968, 1.109, 0.411, 0.825, 0.906, 0.265, 0.753, 0.601, 0.745, -0.290, -5.000, 0.600, 0.149, -0.877, 0.311, -0.217, 0.163, 0.258, -0.107, 0.383, 0.230, -1.154, -0.237, 0.976, 1.414, 0.751, 0.939, 0.770, 1.042, -0.551, 0.225, 0.263, 1.082, 0.946, 0.125, 0.828, 1.110, 0.447, 0.672, 0.890, 1.367, 0.495, 0.882, 0.912, 1.215, 0.065, 0.040, 0.922, 1.248, 0.936, 0.468, 1.010, 1.281, 0.520, 0.689, -0.002, 0.301, -0.310, -5.000, -0.117, 0.385, -5.000, -5.000, 0.478, 0.721, 0.125, -0.200, 0.095, 0.076, -1.241, -0.300, -0.156, 0.081, -1.055, -5.000, -0.432, -0.371, -1.537, -0.304, -0.367, -0.529, -0.412, -0.481, -0.468, -0.728, -1.568, -1.047, -0.749, -0.790, -2.189, -1.487, -1.017, -0.876, -2.552, -1.954, -1.259, -0.433, -0.829, -1.154, -1.124, -0.619, -1.793, -1.289, -0.133, 0.247, -1.251, -0.284, -0.114, 0.425, -1.562, -1.280, 0.138, 0.399, -0.240, -0.151, 0.023, 0.291, -0.714, -0.799, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.190, 0.427, -0.274, -5.000, -0.226, 0.418, -1.661, -5.000, -0.292, 0.592, 0.036, -0.258, 0.187, 0.375, -0.386, 0.267, 0.146, 0.506, -0.405, -5.000, -0.198, -0.019, -1.579, -0.479, -0.574, 0.010, -0.013, -0.134, -0.083, 0.145, -0.564, -0.249, -0.132, 0.319, 0.019, -0.265, -0.578, -0.160, -1.543, -1.887, -1.330, -0.496, -0.678, -1.498, -0.365, 0.085, -1.072, -0.578, 0.015, 0.822, -0.276, -0.001, -0.220, 1.014, -0.770, -1.490, 0.383, 1.104, 0.379, 0.057, 0.149, 0.751, -0.078, -0.274, 0.357, 0.720, 0.452, -5.000, 0.178, 0.640, -1.090, -5.000, 0.725, 1.067, 0.789, 0.082, 0.553, 0.675, 0.066, 0.465, 0.328, 0.605, 0.019, -5.000, 0.465, 0.419, -0.917, -0.032, 0.240, 0.393, 0.372, -0.042, 0.352, -0.027, -0.829, -0.255, 0.551, 0.986, 0.397, 0.356, 0.125, 0.425, 0.270, -0.424, -0.017, 0.449, 0.295, -0.633, 0.089, 0.556, 0.050, 0.213, 0.060, 0.579, -0.462, -0.179, 0.386, 0.790, -0.960, -0.604, 0.524, 0.926, 0.621, 0.217, 0.104, 0.330, -0.183, -0.037, -1.309, -1.732, -1.461, -5.000, -1.578, -1.096, -0.866, -5.000, -1.570, -0.612, -1.169, -1.420, -1.333, -2.134, -1.408, -1.807, -1.588, -1.024, -0.645, -5.000, -2.001, -1.524, -1.266, -1.928, -0.365, -0.229, -0.728, -1.071, -2.500, -1.092, -2.146, -2.036, -1.749, -1.148, -2.256, -2.748, -1.469, -1.234, -1.453, -2.601, -1.927, -2.134, -0.544, -1.713, -2.791, -1.023, -1.711, -2.047, -1.367, -2.178, -1.575, -1.763, -1.321, -0.131, -1.036, -3.051, -0.689, -0.869, -2.365, -1.035, -1.766, -1.504, -1.959, -2.574, 0.204, 0.755, 0.099, -5.000, 0.188, 0.860, -1.333, -5.000, 0.428, 1.063, 0.511, 0.141, -0.151, 0.397, -0.370, -0.020, 0.282, 0.721, 0.163, -5.000, -0.425, -0.061, -1.264, -0.324, 0.136, 0.842, 0.565, 0.253, 0.271, 0.019, -0.518, -0.308, -0.506, 0.379, -0.426, -0.764, -0.671, 0.172, -0.912, -2.177, -0.853, 0.076, -0.360, -1.609, -1.032, -0.333, -1.164, -0.654, -0.081, 0.967, -0.274, -0.151, 0.041, 0.982, -0.698, -1.433, 0.035, 0.707, 0.483, -0.594, -0.179, 0.307, -0.270, -0.257, -0.168, 0.260, -0.662, -5.000, -0.381, 0.337, -1.380, -5.000, 0.248, 0.431, -0.032, -0.429, 0.035, 0.365, -0.631, -0.296, -0.268, 0.245, -1.328, -5.000, -0.474, -0.638, -0.999, -0.064, -0.484, -0.288, -0.189, -0.405, -0.337, -0.089, -1.092, -1.382, -0.181, 0.547, 0.130, 0.266, -0.163, -0.286, -0.566, -1.414, -0.463, 0.259, -0.554, -0.556, -0.363, -0.183, -0.477, -0.095, -0.285, 0.427, -0.204, 0.055, -0.218, 0.429, -0.748, -0.397, 0.159, 0.906, 0.274, 0.077, -0.303, 0.455, -0.446, -0.356, 0.525, 0.933, 0.630, -5.000, 0.358, 0.864, -0.912, -5.000, 0.769, 0.860, 0.509, 0.312, 0.867, 0.792, -0.094, 0.716, 0.225, 0.740, -0.081, -5.000, 0.175, 0.058, -0.031, -0.080, 0.011, 0.019, 0.221, 0.012, 0.181, -0.900, -1.704, -1.176, 0.534, 1.096, 0.606, 0.744, 0.315, 0.898, -0.306, -0.999, 0.441, 0.377, -0.261, -0.011, 0.569, 0.963, 0.365, 0.792, 0.577, 1.124, 0.497, 0.856, 0.627, 1.097, -0.971, 0.048, 0.765, 1.024, 0.536, 0.231, 0.548, 0.956, 0.343, 0.418, 0.526, 0.553, 0.042, -5.000, 0.568, 0.578, -5.000, -5.000, 0.348, 0.485, 0.323, -0.050, 0.625, 0.449, -0.442, 0.337, -0.208, 0.343, -0.557, -5.000, -0.465, 0.295, 0.133, -0.347, 0.208, -0.306, 0.181, 0.168, 0.059, -0.447, -0.949, -0.522, 0.281, 0.754, -0.555, -0.257, -0.484, 0.242, -1.130, -0.412, -0.233, -0.197, -0.029, -0.252, -0.200, 0.404, -0.877, -0.321, 0.520, 1.172, 0.104, 0.468, 0.276, 0.631, -1.693, 0.126, 0.205, 0.333, 0.055, -0.217, 0.292, 0.466, -0.500, -0.458, -0.299, 0.207, -0.143, -5.000, -0.343, -0.084, -5.000, -5.000, -0.064, 0.199, 0.199, -0.509, -0.056, 0.209, -0.867, -0.174, -0.477, -0.327, -0.404, -5.000, -0.195, -0.882, -1.543, -0.378, -0.266, 0.695, -0.173, -0.627, 0.085, -0.146, -1.543, -0.156, -0.295, 0.234, -0.942, -0.119, -0.518, 0.088, -0.912, -1.764, -0.644, 0.099, -0.397, -0.756, -0.402, -0.075, -0.146, -0.227, -0.269, 0.718, -0.726, -0.125, -0.409, 0.370, -0.081, -1.231, -0.250, 0.417, -0.051, -0.247, 0.098, 0.148, -0.229, -0.278, 0.339, 0.844, 0.001, -5.000, 0.333, 0.974, -0.832, -5.000, 0.649, 1.139, 0.649, 0.552, 0.204, 0.464, -0.360, 0.109, 0.051, 0.356, -0.754, -5.000, -0.148, 0.209, -1.975, 0.043, -0.156, 0.531, 0.143, -0.429, 0.103, -0.138, -1.251, -0.654, 0.167, 0.762, -0.234, 0.180, -0.352, 0.117, -1.643, -1.250, -0.849, 0.082, -0.406, -0.912, -0.351, 0.332, -0.482, -0.290, 0.018, 0.758, -0.548, 0.058, 0.116, 0.798, -1.813, -0.831, 0.247, 1.016, 0.321, -0.132, 0.088, 0.529, -0.255, -0.059, 0.325, 0.527, 0.115, -5.000, 0.095, 0.477, -0.825, -5.000, 0.262, 0.696, 0.505, 0.169, 0.322, 0.546, -0.174, 0.098, -0.045, 0.558, -0.882, -5.000, -0.148, -0.252, -1.855, -0.526, -1.247, -0.239, -0.551, -0.715, -0.682, -0.620, -1.713, -1.216, 0.488, 1.019, 0.076, 0.418, 0.294, 0.702, -0.573, -0.722, -0.192, 0.238, 0.572, -0.660, -0.039, 0.494, 0.016, 0.199, 0.635, 1.026, 0.204, 0.478, 0.356, 0.939, -0.322, -0.872, 0.472, 0.983, 0.489, -0.032, 0.380, 0.569, -0.325, 0.136, -0.016, 0.334, -1.286, -5.000, -0.296, -0.363, -1.177, -5.000, -0.335, 0.513, -0.404, -0.281, -0.649, -0.507, -1.208, -0.671, -0.702, 0.180, -1.571, -5.000, -0.818, -0.500, -2.231, -1.055, -0.812, 0.350, -0.499, -0.981, -0.886, -0.794, -1.579, -1.466, -0.819, -0.267, -2.217, -1.156, -1.278, -0.585, -2.479, -2.372, -1.789, -1.125, -0.364, -1.247, -1.238, -1.012, -1.249, -1.020, -0.546, 0.118, -1.676, -0.732, -0.663, 0.230, -2.340, -1.933, -0.533, 0.032, -1.024, -0.775, -0.631, -0.365, -1.279, -1.188, -0.277, 0.249, -0.696, -5.000, -0.379, 0.191, -1.590, -5.000, -0.354, 0.637, -0.218, -0.371, -0.446, -0.104, -0.998, -0.775, -0.454, 0.385, -0.796, -5.000, -0.314, -0.356, -2.699, -0.693, -0.796, 0.366, -0.224, -0.644, -0.653, -0.218, -1.204, -1.046, -0.487, 0.151, -1.261, -0.403, -0.978, -0.252, -2.232, -1.999, -1.068, -0.226, -0.640, -0.922, -0.643, -0.363, -0.904, -0.768, -0.129, 0.577, -1.089, -0.308, -0.680, 0.436, -1.591, -1.614, -0.207, 0.531, -0.173, -0.563, -0.253, 0.100, -0.537, -0.722, -0.034, 0.564, -0.321, -5.000, -0.163, 0.468, -1.007, -5.000, 0.070, 0.543, 0.233, 0.030, 0.151, 0.322, -0.331, 0.212, 0.056, 0.475, -0.410, -5.000, -0.516, -0.197, -1.837, -0.268, -0.523, -0.495, -0.169, -0.531, 0.087, 0.319, -0.645, -0.467, -0.574, -0.373, -0.741, -0.412, -1.329, -0.689, -2.089, -1.990, -1.405, -0.452, -0.703, -1.480, -1.183, -0.561, -1.030, -1.036, -0.176, 0.471, -0.870, -0.084, -0.400, 0.505, -1.337, -1.346, 0.127, 0.406, 0.234, -0.168, 0.035, 0.518, -0.057, -0.134, 0.588, 0.887, 0.269, -5.000, 0.254, 0.897, -1.139, -5.000, 0.512, 1.039, 1.062, 0.601, 0.828, 1.072, 0.428, 0.807, 0.599, 0.848, -0.811, -5.000, 0.381, 0.476, -1.994, 0.149, -0.157, 0.475, 0.528, 0.322, 0.485, 0.456, -0.874, -0.148, 0.433, 0.792, 0.452, 0.617, 0.375, 0.855, -0.772, -0.513, -0.104, 0.505, 0.333, -0.386, 0.366, 0.651, 0.071, 0.478, 0.469, 1.081, 0.250, 0.552, 0.672, 1.222, -0.519, -0.155, 0.762, 1.127, 0.733, 0.363, 0.994, 1.235, 0.432, 0.633, -0.432, 0.125, -1.012, -5.000, -0.261, 0.281, -1.090, -5.000, 0.213, 0.592, -0.090, -0.252, -0.445, -0.320, -0.859, -0.469, -0.787, 0.356, -1.188, -5.000, -0.498, 0.209, -0.688, -0.300, -0.869, 0.721, -0.127, -1.294, -0.798, -0.463, -1.885, -1.140, -0.924, 0.153, -1.141, -0.776, -1.258, -0.717, -1.593, -1.750, -1.162, 0.126, -0.699, -1.184, -0.940, -0.383, -1.318, -1.031, -0.830, 0.356, -0.624, -0.648, -0.911, 0.671, -1.058, -1.269, -0.212, 0.355, -0.146, -0.436, -0.274, 0.095, -0.663, -0.976, 0.087, 0.565, -0.468, -5.000, -0.047, 0.451, -1.504, -5.000, 0.083, 0.557, -0.045, -0.453, -0.191, 0.091, -0.462, -0.361, 0.118, 0.535, -0.493, -5.000, -0.625, -0.295, -2.190, -0.427, -0.063, 0.505, -0.400, -0.204, 0.100, 0.240, -0.913, -0.432, -0.528, 0.289, -1.198, -0.401, -0.996, 0.158, -2.252, -2.288, -1.357, -0.290, -0.327, -1.380, -0.732, -0.127, -0.535, -0.662, -0.263, 0.708, -0.991, -0.212, -0.528, 0.851, -0.962, -1.257, 0.093, 0.687, 0.186, -0.424, 0.026, 0.559, -0.212, -0.388, -0.447, 0.240, -0.314, -5.000, -0.908, 0.271, -1.742, -5.000, -0.377, 0.317, -0.195, -0.456, -0.243, 0.242, -0.403, 0.172, -0.260, 0.354, -0.694, -5.000, -0.789, 0.050, -1.901, -0.866, -0.152, 0.146, -0.176, -0.452, 0.165, 0.241, -0.510, -0.803, -1.265, -0.140, -1.713, -1.534, -2.369, -1.389, -1.502, -2.929, -1.917, -0.766, -1.261, -2.035, -1.415, -0.580, -1.190, -1.433, -1.006, -0.061, -1.176, -1.095, -1.116, 0.379, -2.017, -1.743, -0.412, 0.321, -0.396, -0.825, -0.676, 0.102, -0.834, -1.142, 0.159, 0.598, 0.347, -5.000, -0.328, 0.292, -0.770, -5.000, 0.477, 0.854, 0.373, 0.007, 0.797, 0.945, 0.522, 0.882, 0.095, 0.188, -0.169, -5.000, -0.380, -0.357, -0.757, -0.182, 0.186, 0.347, 0.117, -0.150, 0.211, -0.224, -0.808, -0.018, 0.482, 0.877, 0.526, 0.578, -1.054, 0.673, 0.176, -1.194, -0.840, 0.342, -0.162, -0.297, -0.140, 0.263, -0.148, 0.239, 0.029, 0.642, 0.030, 0.137, 0.270, 0.854, -0.839, -1.027, 0.557, 1.018, 0.683, 0.025, 0.229, 0.627, 0.252, 0.094, -1.140, -1.240, -0.712, -5.000, -2.018, -0.999, -5.000, -5.000, -0.755, -0.537, -1.237, -0.822, -0.801, -0.850, -1.476, -0.810, -1.040, -0.834, -1.664, -5.000, -1.417, -0.621, -0.594, -1.927, -1.575, -5.000, 0.058, -0.635, -0.856, -1.476, -0.817, -0.983, -1.114, -0.902, -1.220, -1.468, -3.319, -0.817, -2.060, -2.563, -2.104, -0.518, 0.273, -1.275, -1.528, -1.645, -2.212, -1.817, -1.635, -1.162, -1.902, -1.186, -1.810, -0.927, -0.693, -2.372, -2.198, -1.559, -2.130, -1.328, -1.225, -1.123, -1.420, -1.374, -1.078, -0.381, -1.249, -5.000, -1.461, -0.804, -1.747, -5.000, -1.058, -0.167, -2.068, -0.944, -1.530, -0.740, -1.277, -1.383, -1.094, -0.402, -1.417, -5.000, -2.283, -0.951, -3.427, -2.457, -0.507, -0.249, -1.200, -1.882, -0.779, -0.572, -1.071, -1.654, -1.381, -1.147, -1.595, -1.746, -2.517, -1.273, -1.755, -3.188, -2.049, -1.959, -2.001, -2.434, -1.849, -1.248, -1.318, -1.891, -1.450, -0.364, -2.101, -1.672, -2.020, -0.420, -1.729, -2.331, -1.101, -0.512, -0.828, -1.621, -1.303, -1.012, -1.692, -2.035, -0.665, -0.142, -0.551, -5.000, -0.946, -0.038, -1.790, -5.000, -0.624, -0.005, -0.490, -0.506, -0.360, -0.079, -0.506, -0.126, -0.400, 0.127, -1.096, -5.000, -1.464, -0.258, -1.397, -0.808, -0.139, 0.251, -0.249, -0.507, -0.323, 0.111, -0.546, -0.750, -1.313, -0.995, -1.380, -1.162, -2.413, -0.772, -0.983, -3.336, -1.739, -0.869, -1.051, -2.397, -1.814, -0.732, -1.695, -1.276, -1.054, -0.088, -1.212, -0.721, -1.299, 0.301, -2.056, -1.734, -0.512, 0.255, -0.299, -0.615, -0.569, 0.206, -0.735, -0.859, 0.210, 0.755, 0.195, -5.000, -0.071, 0.960, -1.011, -5.000, 0.029, 0.590, 0.129, -0.082, 0.497, 0.825, -0.133, 0.575, 0.355, 0.863, -0.702, -5.000, -0.135, 0.314, -0.520, -0.124, 0.145, 0.436, -0.317, 0.002, 0.133, 0.281, -0.796, -0.019, -0.279, 0.818, -0.128, -0.017, -0.691, 0.333, -0.712, -1.543, -1.105, -0.069, -0.674, -1.159, -0.674, 0.066, -0.311, -0.586, -0.086, 0.703, -0.460, 0.100, -0.044, 0.998, -1.585, -1.013, -0.092, 0.956, 0.183, 0.121, 0.251, 0.737, -0.099, 0.102, -0.039, 0.276, -0.397, -5.000, -0.346, 0.655, -1.729, -5.000, 0.077, 0.148, 0.093, -0.312, 0.170, 0.316, -0.375, 0.194, -0.240, 0.220, -0.627, -5.000, -0.475, -0.055, -0.216, -0.258, -0.080, -0.111, -0.042, -0.349, -0.235, 0.209, -1.133, -0.244, -0.271, 0.578, -0.850, -0.699, -0.677, 0.008, -0.635, -1.203, -0.701, 0.211, -0.716, -0.911, -0.298, -0.639, -1.115, -0.547, -0.386, 0.729, -0.626, -0.454, -1.115, 0.482, -1.938, -0.462, -0.314, -0.128, -0.252, -0.479, -0.209, 0.251, -0.838, -0.668, -0.788, -0.338, -0.849, -5.000, -1.468, -0.761, -2.353, -5.000, -0.967, -0.211, -1.150, -0.917, -0.630, -0.119, -0.842, -0.435, -0.692, -0.124, -1.056, -5.000, -1.685, -1.720, -1.700, -1.859, -0.474, -0.594, -0.323, -0.834, -0.669, -0.213, -1.266, -0.922, -1.009, -0.339, -1.425, -0.967, -1.475, -0.886, -0.942, -1.961, -1.985, -0.987, -1.034, -1.612, -1.257, -0.734, -0.963, -1.134, -0.865, 0.192, -1.316, -1.027, -1.342, 0.122, -2.921, -1.866, -1.030, -0.204, -0.857, -1.107, -0.621, -0.093, -0.739, -1.031, -0.119, 0.308, -0.611, -5.000, -0.444, 0.408, -1.238, -5.000, -0.092, 0.408, -0.261, -0.202, -0.117, 0.104, -0.196, -0.110, -0.293, 0.498, -0.594, -5.000, -1.064, -0.226, -3.556, -0.836, -0.295, 0.573, -0.099, -0.586, -0.155, 0.130, -0.581, -0.552, -0.948, 0.067, -0.741, -1.093, -1.779, -0.460, -2.134, -1.991, -1.538, -1.086, -1.225, -1.737, -1.442, -0.438, -1.425, -0.951, -0.754, 0.339, -1.124, -0.731, -0.916, 0.173, -1.662, -1.890, -0.488, 0.182, -0.269, -0.736, -0.480, 0.149, -0.609, -0.717, 0.377, 0.618, -0.062, -5.000, 0.177, 0.679, -0.735, -5.000, 0.248, 0.645, 0.183, 0.205, 0.434, 0.641, 0.311, 0.490, 0.065, 0.537, -1.316, -5.000, -0.238, -0.258, -2.079, -0.734, -0.706, -0.209, -0.283, -0.274, -0.204, 0.080, -0.663, -0.791, 0.010, 0.786, 0.011, -0.133, -0.896, 0.333, -1.138, -1.495, -0.614, 0.357, 0.033, -1.200, -1.242, 0.014, -1.159, -0.706, -0.019, 0.768, -0.512, 0.077, -0.159, 0.771, -0.456, -0.912, 0.176, 0.428, 0.520, -0.289, -0.048, 0.526, -0.196, -0.187, -0.257, 0.326, -0.787, -5.000, -0.235, -0.085, -1.713, -5.000, -0.182, 0.567, -0.568, -0.341, -0.303, -0.096, -0.507, -0.189, -0.358, 0.334, -1.095, -5.000, -0.463, -0.163, -1.882, -0.509, -0.667, -0.141, -0.388, -0.460, -0.494, -0.282, -1.186, -0.500, -0.988, -0.396, -1.879, -0.916, -1.408, -0.523, -2.001, -2.265, -0.616, -0.406, -0.672, -1.034, -1.191, -0.412, -0.934, -0.961, -0.807, 0.042, -1.321, -0.915, -0.998, -0.050, -1.435, -1.773, -0.747, -0.347, -0.933, -0.875, -0.569, -0.223, -1.017, -1.146, -0.234, 0.358, -0.427, -5.000, -0.184, 0.558, -1.194, -5.000, -0.016, 0.532, 0.048, -0.127, -0.323, 0.064, -0.408, -0.315, -0.078, 0.480, -0.457, -5.000, -0.539, 0.081, -1.632, -0.293, -0.034, 0.570, 0.235, 0.033, -0.112, 0.171, -0.493, -0.581, -0.531, 0.303, -0.763, -0.505, -1.375, -0.385, -1.361, -2.364, -1.488, -0.416, -0.555, -1.214, -0.879, -0.435, -0.938, -0.779, -0.602, 0.583, -0.856, -0.644, -0.735, 0.657, -0.590, -1.761, -0.399, 0.098, -0.261, -0.785, -0.507, -0.023, -0.676, -1.020, 0.087, 0.623, -0.194, -5.000, -0.163, 0.554, -1.393, -5.000, 0.138, 0.507, 0.389, -0.066, 0.347, 0.578, -0.099, 0.316, 0.017, 0.553, -0.371, -5.000, -0.481, -0.002, -2.280, -0.229, -0.288, -0.005, -0.191, -0.467, 0.321, 0.401, -0.421, -0.090, -0.296, 0.201, -0.869, -0.321, -0.830, -0.066, -1.491, -1.793, -1.128, -0.180, -0.550, -1.240, -0.769, -0.220, -0.711, -0.542, 0.031, 0.578, -0.469, 0.116, -0.104, 0.692, -1.173, -0.841, 0.323, 0.544, 0.453, -0.202, 0.229, 0.649, 0.238, 0.013, 0.853, 1.156, 0.667, -5.000, 0.701, 1.117, -0.690, -5.000, 0.886, 1.260, 1.170, 0.679, 1.129, 1.195, 0.689, 1.081, 0.709, 0.933, -0.230, -5.000, 0.753, 0.561, -1.230, 0.447, 0.039, 0.528, 0.576, 0.202, 0.673, 0.669, -0.752, 0.019, 0.771, 1.345, 0.643, 0.934, 0.564, 1.110, -0.229, -0.264, 0.304, 1.057, 0.722, 0.355, 0.683, 0.971, 0.483, 0.636, 0.772, 1.303, 0.511, 0.952, 0.946, 1.330, 0.004, 0.232, 1.022, 1.326, 0.848, 0.672, 1.137, 1.282, 0.867, 0.898, -0.231, 0.474, -0.615, -5.000, 0.130, 0.624, -1.819, -5.000, -0.079, 0.648, -0.290, -0.295, -0.372, -0.075, -0.950, -0.215, -0.435, 0.294, -1.233, -5.000, 0.033, 0.483, -1.445, -0.307, -0.440, 0.242, -0.149, -0.628, -0.247, -0.392, -1.657, -0.776, -1.181, -0.294, -1.285, -1.526, -1.419, 0.203, -2.070, -1.409, -0.933, 0.011, -0.873, -1.227, -0.796, -0.254, -1.530, -1.089, -0.445, 0.457, -0.726, -0.474, -0.249, 0.880, -1.738, -0.971, -0.037, 0.483, -0.193, -0.562, 0.001, 0.382, -0.466, -0.664, 0.235, 0.690, -0.277, -5.000, 0.020, 0.781, -1.186, -5.000, 0.223, 0.848, 0.255, -0.134, -0.001, 0.436, -0.295, -0.113, 0.062, 0.599, -0.380, -5.000, -0.300, 0.389, -1.799, -0.156, -0.132, 0.635, 0.140, -0.488, 0.463, 0.428, -0.583, -0.272, -0.072, 0.505, -0.698, -0.111, -0.840, 0.347, -1.449, -1.730, -0.809, 0.248, -0.093, -0.906, -0.405, 0.144, -0.594, -0.436, 0.037, 0.800, -0.472, 0.064, -0.174, 1.082, -0.791, -0.794, 0.334, 0.958, 0.375, -0.059, 0.216, 0.625, -0.043, -0.233, -0.036, 0.537, -0.156, -5.000, -0.152, 0.651, -1.283, -5.000, 0.185, 0.599, 0.086, -0.247, 0.361, 0.663, 0.058, 0.385, 0.072, 0.498, -0.506, -5.000, -0.275, 0.192, -2.704, -0.150, -0.279, 0.595, 0.068, -0.269, 0.656, 0.543, -0.565, -0.295, -0.398, 0.346, -0.854, -0.547, -0.929, 0.259, -1.916, -1.624, -1.219, -0.313, -0.674, -1.584, -0.558, 0.018, -0.853, -0.542, -0.218, 0.620, -0.523, -0.081, -0.107, 0.952, -1.105, -0.994, 0.073, 0.651, 0.292, -0.270, 0.013, 0.578, -0.085, -0.229, 0.825, 1.227, 0.903, -5.000, 0.673, 1.037, -0.399, -5.000, 0.903, 1.352, 0.930, 0.416, 1.161, 1.245, 0.718, 1.176, 0.785, 0.919, 0.291, -5.000, 0.769, 0.436, -0.886, 0.786, 0.619, 1.167, 0.544, 0.362, 0.927, 0.573, -0.194, 0.553, 1.155, 1.409, 1.128, 1.184, 0.916, 1.167, -0.201, 0.240, 0.453, 1.186, 0.745, 0.089, 0.579, 1.140, 0.568, 1.042, 0.780, 1.253, 0.701, 0.905, 0.980, 1.242, -0.102, 0.262, 1.028, 1.275, 0.969, 0.640, 0.965, 1.129, 0.651, 0.796, -0.760, -0.659, -0.855, -5.000, -0.642, -0.535, -1.713, -5.000, -0.530, -0.159, -1.128, -0.557, -0.700, -0.511, -1.167, -0.709, -0.539, -0.379, -1.431, -5.000, -0.470, -0.428, -0.639, -1.044, -1.011, -0.882, -0.365, -1.318, -0.356, -1.226, -1.021, -0.714, -1.294, -1.043, -1.381, -1.375, -1.938, -0.772, -2.187, -1.805, -1.602, -0.769, -0.790, -1.701, -1.265, -1.766, -1.380, -1.847, -1.362, -0.400, -1.220, -0.582, -0.842, -1.420, -0.889, -1.661, -0.631, -0.999, -0.980, -1.524, -0.904, -0.094, -1.642, -1.135, -0.487, 0.142, -0.836, -5.000, -0.731, -0.300, -2.326, -5.000, -0.669, 0.108, -0.849, -0.898, -0.917, -0.361, -1.321, -0.916, -0.642, 0.066, -1.156, -5.000, -1.100, -0.650, -2.170, -1.590, -0.530, -0.062, -0.796, -0.694, -0.494, -0.629, -1.336, -1.233, -0.947, -0.287, -1.253, -1.025, -1.799, -0.400, -2.586, -2.131, -1.613, -1.362, -1.635, -2.534, -1.082, -0.856, -1.086, -1.310, -0.800, 0.015, -0.874, -0.784, -1.242, 0.189, -1.804, -1.644, -0.694, -0.089, -0.505, -0.962, -0.916, -0.496, -0.979, -1.140, 0.135, 0.648, 0.113, -5.000, -0.037, 0.651, -1.197, -5.000, 0.332, 0.638, 0.287, 0.050, 0.606, 0.728, 0.016, 0.357, 0.485, 0.937, 0.117, -5.000, 0.281, 0.548, -3.361, 0.270, 0.139, 0.565, 0.498, -0.045, 0.762, 0.725, -0.265, 0.149, -0.129, 0.562, -0.199, 0.212, -0.661, 0.374, -0.577, -1.598, -0.582, 0.270, -0.122, -0.962, -0.386, 0.303, -0.338, -0.174, 0.047, 0.832, -0.157, 0.314, -0.029, 0.940, -1.065, -0.749, 0.288, 0.845, 0.363, 0.113, 0.046, 0.776, -0.020, -0.098, 0.719, 1.203, 0.885, -5.000, 0.784, 1.100, -0.460, -5.000, 0.680, 0.920, 0.601, 0.332, 1.087, 1.100, 0.537, 1.034, 0.921, 1.275, 0.263, -5.000, 1.088, 0.805, -0.772, 0.761, 0.393, 0.886, 0.359, 0.143, 1.154, 0.967, -0.147, 0.632, 0.514, 1.177, 0.658, 0.855, 0.339, 0.962, -5.000, -0.594, 0.027, 1.119, 0.175, -0.256, 0.242, 0.965, 0.018, 0.455, 0.569, 1.313, 0.645, 0.998, 0.624, 1.410, -0.215, 0.013, 0.786, 1.237, 0.600, 0.428, 0.800, 1.160, 0.334, 0.597, 0.366, 0.771, 0.154, -5.000, 0.585, 0.886, -1.140, -5.000, 0.394, 0.656, 0.339, 0.100, 0.438, 0.805, -0.123, 0.501, 0.289, 0.834, -0.540, -5.000, 0.363, 0.624, -1.071, 0.454, -0.042, 0.529, -0.008, 0.102, 0.397, 0.453, -0.638, 0.088, -0.200, 1.071, -0.304, -0.329, -1.046, 0.537, -0.781, -0.527, -0.660, 0.202, -0.457, -0.531, -0.471, 0.016, -0.826, -0.352, 0.199, 1.242, 0.046, 0.331, -0.261, 1.029, -0.474, -0.058, 0.030, 0.357, -0.044, -0.241, 0.067, 0.635, -0.379, -0.501, -0.191, 0.416, -0.452, -5.000, -0.262, 0.033, -1.441, -5.000, -0.105, 0.376, -0.138, -0.361, 0.039, 0.398, -0.290, 0.054, -0.276, 0.505, -0.462, -5.000, -0.322, 0.017, -1.814, -0.353, -0.403, 0.443, -0.125, -0.216, 0.301, 0.295, -0.590, -0.082, -0.264, 0.471, -0.488, -0.232, -0.990, 0.402, -1.367, -1.526, -0.778, 0.108, -0.269, -0.838, -0.387, -0.079, -0.380, -0.436, -0.326, 0.668, -0.654, 0.010, -0.592, 0.655, -0.898, -1.207, -0.143, 0.383, -0.132, -0.577, -0.082, 0.372, -0.273, -0.551, 0.446, 0.874, 0.172, -5.000, 0.128, 0.746, -0.994, -5.000, 0.306, 0.747, 0.330, 0.072, 0.491, 0.776, 0.008, 0.349, 0.337, 0.827, -0.221, -5.000, -0.102, 0.364, -1.893, 0.035, 0.099, 0.700, 0.121, 0.021, 0.492, 0.590, -0.208, -0.113, -0.179, 0.573, -0.526, -0.133, -0.839, -0.086, -1.613, -2.063, -1.284, -0.449, -0.595, -1.026, -0.630, 0.020, -0.642, -0.516, -0.031, 0.859, -0.434, 0.061, -0.091, 0.808, -1.130, -0.824, 0.144, 0.636, 0.158, -0.247, 0.090, 0.641, -0.013, -0.113, 0.701, 1.070, 0.539, -5.000, 0.541, 0.896, -0.806, -5.000, 0.665, 0.952, 0.772, 0.356, 0.922, 1.010, 0.574, 0.816, 0.618, 0.986, -0.414, -5.000, 0.442, 0.478, -1.297, 0.465, -0.112, 0.483, 0.375, 0.015, 0.403, 0.254, -0.652, -0.168, 0.576, 1.151, 0.323, 0.613, -0.103, 0.778, -0.473, -0.843, -0.481, 0.736, 0.405, -0.335, 0.137, 0.735, 0.034, 0.357, 0.565, 1.274, 0.353, 0.723, 0.574, 1.280, -0.181, -0.310, 0.684, 1.086, 0.706, 0.342, 0.741, 0.960, 0.295, 0.432, 0.303, 0.810, -0.201, -5.000, 0.345, 0.570, -1.701, -5.000, 0.180, 0.755, -0.077, 0.003, 0.146, 0.295, -0.451, 0.247, 0.125, 0.705, -0.494, -5.000, 0.077, 0.294, -1.690, -0.283, 0.016, 0.314, 0.005, 0.106, 0.112, 0.046, -0.739, -0.072, -0.612, 0.255, -0.979, -0.436, -0.753, -0.238, -1.110, -1.715, -0.654, -0.081, -0.445, -0.920, -0.468, -0.305, -1.077, -0.536, -0.222, 0.511, -1.043, -0.213, -0.395, 0.452, -1.102, -1.404, -0.315, 0.215, -0.474, -0.583, -0.159, 0.117, -0.658, -0.615, -0.022, 0.522, -0.394, -5.000, 0.004, 0.593, -1.102, -5.000, 0.166, 0.780, 0.187, -0.083, -0.019, 0.323, -0.387, -0.157, -0.001, 0.708, -0.297, -5.000, -0.189, 0.237, -1.237, -0.123, -0.121, 0.662, 0.330, -0.101, 0.264, 0.385, -0.430, -0.182, -0.415, 0.341, -0.860, -0.349, -0.797, -0.016, -1.029, -1.819, -0.811, -0.028, -0.389, -0.961, -0.707, -0.273, -0.751, -0.463, -0.322, 0.568, -0.703, -0.339, -0.342, 0.694, -0.655, -1.101, -0.238, 0.389, -0.209, -0.718, -0.481, 0.059, -0.683, -0.852 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_36(struct _training *tptr) {
  struct _training tinf = {
    0.514, 11, 4.350, { 0.601, 0.143, 2.255 }, { 0.975, -0.320, -4.000 }, 0, 
    { 0.111, -0.167, -0.130, 0.163, 0.035, 0.013, -0.055, -0.425, 0.476, -0.078, -0.076, -4.000, -0.571, -0.098, -0.628, 0.249, -0.350, -0.771, 1.107, -0.318, -0.844, -1.333, 0.201, 0.522, -0.743, -0.970, -4.000, 0.484 }, 
    {{ -0.281, -1.053, 0.240, 0.498},{ 0.325, -0.604, 0.080, 0.007},{ 0.076, -0.081, -0.185, 0.166},{ 0.241, -0.089, -0.196, 0.005},{ 0.170, 0.051, -0.161, -0.087},{ 0.151, -0.194, -0.106, 0.122},{ 0.095, -0.324, -0.155, 0.296},{ 0.439, -0.343, -0.306, 0.033},{ 0.569, -0.487, -0.629, 0.126},{ 0.684, -0.670, -0.774, 0.098},{ 0.561, -0.429, -1.026, 0.257},{ 0.536, -0.611, -0.963, 0.355},{ 0.245, -0.761, -0.913, 0.651},{ 0.182, -0.587, -0.799, 0.615},{ -0.020, -0.385, -0.475, 0.563},{ 0.184, -0.199, -0.475, 0.328},{ 0.354, -0.027, -0.423, -0.032},{ 0.483, -0.252, -0.402, -0.037},{ 0.600, -0.400, -0.542, -0.032},{ 0.423, -0.196, -0.408, 0.015},{ 0.195, -0.017, -0.295, 0.070},{ 0.189, 0.058, -0.242, -0.045},{ 0.197, 0.148, -0.220, -0.195},{ 0.096, 0.091, -0.143, -0.062},{ 0.154, 0.014, -0.288, 0.080},{ 0.087, 0.122, -0.223, -0.018},{ 0.070, 0.008, -0.173, 0.083},{ 0.107, -0.056, -0.146, 0.083},{ 0.053, 0.073, -0.220, 0.072},{ 0.118, -0.072, -0.220, 0.145},{ 0.152, -0.056, -0.196, 0.078},{ 0.172, -0.012, -0.173, -0.007} }, 
    {{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 0.668, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 0.660, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 0.840, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 0.724, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 1.388, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 1.513, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 0.955, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 0.788, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 2.288},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}} }, 
    -0.126, { 0.621, 0.467, -0.196, -5.000, 0.133, -0.396, -1.238, -5.000, 0.195, 0.412, -0.200, -0.065, 0.460, 0.672, -0.083, 0.465, 0.758, 0.808, 0.080, -5.000, 0.592, 0.171, -0.502, -0.059, -0.046, 0.494, -0.026, -0.024, 0.628, 1.111, 0.243, 0.510, 0.209, 0.631, -0.004, 0.490, 0.350, 0.407, -0.405, -0.471, -0.718, 0.409, 0.083, -0.669, -0.065, 0.257, 0.110, 0.029, 0.164, 0.380, -0.228, 0.267, -0.427, -0.300, -0.792, -0.274, 0.578, 0.712, 0.290, 0.243, 0.674, 0.504, 0.363, 0.254, 0.636, 0.226, -0.102, -5.000, 0.350, -0.596, -1.174, -5.000, 0.143, 0.275, -0.374, 0.098, 0.831, 0.589, 0.365, 0.875, 0.779, 0.695, 0.108, -5.000, 0.755, -0.102, -0.412, -0.146, 0.014, 0.266, 0.375, 0.130, 0.925, 0.963, 0.515, 0.490, 0.909, 0.946, 0.426, 1.046, 0.671, 0.157, 0.265, 0.016, 0.354, 0.133, 0.554, -0.133, 0.515, -0.043, 0.470, 0.711, 0.106, 0.710, -0.210, 0.667, -0.677, -1.156, -1.127, -0.587, 0.571, 0.034, 0.634, 0.160, 0.958, 0.425, 0.582, 0.800, 0.314, 0.303, -0.186, -5.000, 0.009, -0.726, -1.737, -5.000, -0.467, -0.265, -1.377, -0.765, 0.057, -0.115, -0.318, 0.005, -0.029, 0.384, -0.561, -5.000, -0.304, -0.921, -1.433, -0.687, -0.078, 0.112, -0.197, -0.048, 0.530, 0.819, -0.513, 0.165, 0.061, 0.728, -0.018, 0.526, -0.612, -0.568, -1.266, -1.116, -0.778, -0.243, -0.441, -0.848, -0.250, 0.112, -0.508, -0.021, -0.248, 0.371, -0.614, 0.076, -1.179, -0.919, -2.293, -1.057, -0.336, -0.718, -1.172, -0.796, 0.341, -0.050, -0.586, -0.387, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.186, 0.079, -0.652, -5.000, -0.628, -0.675, -1.858, -5.000, -0.456, -0.320, -1.055, -0.470, 0.746, 0.672, -0.105, 0.272, 0.465, 0.444, -0.202, -5.000, 0.159, -0.206, -1.070, -0.430, -0.264, 0.293, -0.429, -0.034, 0.476, 1.191, 0.244, 0.441, 0.156, 0.760, 0.108, 0.680, 0.321, 0.357, -0.447, -0.448, -0.233, 0.336, -0.282, -0.506, 0.587, 0.605, 0.313, 0.478, -0.453, 0.202, -0.556, 0.133, -0.886, -0.928, -1.325, -0.693, 0.332, 0.265, -0.139, 0.125, 0.732, 0.443, 0.248, 0.208, -0.192, -0.362, -0.740, -5.000, -0.794, -1.067, -2.437, -5.000, -0.167, -0.143, -0.913, -0.718, 0.597, 0.201, -0.545, 0.065, 0.491, 0.300, -0.065, -5.000, 0.260, -0.448, -0.970, -0.370, -0.055, 0.002, -0.233, -0.221, 0.554, 0.764, 0.272, 0.328, 0.533, 0.754, 0.328, 1.012, 0.352, -0.125, -0.586, -0.084, 0.276, -0.003, -0.132, -0.053, 0.484, 0.226, 0.420, 0.824, -0.522, 0.164, -0.874, -0.072, -1.662, -1.625, -1.820, -1.624, -0.210, -0.579, -0.371, -0.484, 0.524, 0.018, -0.296, 0.191, -1.202, -1.348, -1.538, -5.000, -2.307, -2.448, -2.679, -5.000, -1.614, -2.554, -2.083, -1.472, -1.029, -1.341, -1.506, -1.421, -0.819, -0.679, -1.518, -5.000, -1.274, -1.717, -2.052, -1.405, -0.876, -1.073, -1.505, -0.889, -0.268, -0.313, -1.325, -0.293, -0.810, -0.061, -0.809, -0.316, -1.450, -1.987, -2.043, -1.960, -1.447, -1.420, -1.318, -1.089, -0.516, -1.202, -0.910, -0.507, -1.388, -0.945, -1.748, -0.921, -2.852, -2.165, -2.324, -2.375, -1.354, -2.249, -2.424, -1.890, -0.675, -0.940, -1.439, -1.323, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.171, 0.102, -0.600, -5.000, -0.607, -0.472, -1.944, -5.000, -0.565, -0.280, -1.014, -0.815, 0.444, 0.392, -0.631, -0.446, 0.211, 0.274, 0.023, -5.000, 0.051, -0.348, -1.223, -0.487, -0.732, -0.100, -0.486, -0.600, 0.266, 0.849, 0.115, -0.037, 0.102, 0.621, 0.193, 0.543, -0.109, 0.456, -0.391, -0.319, -0.109, 0.325, -0.071, -0.416, 0.487, 0.779, 0.522, 0.287, -0.601, -0.139, -0.983, -0.182, -1.755, -1.001, -1.469, -1.120, -0.400, -0.271, -0.307, -0.607, 0.103, 0.163, -0.098, -0.377, 0.235, -0.070, 0.143, -5.000, -0.342, -0.986, -2.364, -5.000, -0.156, 0.379, -1.036, -0.343, 1.089, 0.228, 0.235, 0.359, 0.720, 0.801, 0.036, -5.000, 0.357, -0.123, -0.838, -0.515, -0.246, 0.245, -0.546, -0.431, 0.637, 1.052, 0.589, 0.522, 0.605, 0.949, 0.536, 0.891, 0.104, 0.176, -0.559, -0.577, 0.143, 0.409, -0.121, -0.341, 0.742, 0.521, 0.614, 0.595, -0.183, 0.624, -0.222, 0.473, -1.029, -0.940, -1.571, -1.417, 0.052, 0.512, 0.084, -0.175, 0.775, 0.142, 0.224, 0.210, -0.601, -0.879, -0.607, -5.000, -1.421, -0.655, -2.427, -5.000, -1.444, -1.212, -2.392, -1.699, 0.164, -1.025, -0.839, -1.075, 0.056, 0.097, -0.662, -5.000, -0.576, -1.082, -1.739, -1.461, -0.611, -0.531, -0.919, -0.988, -0.083, 0.685, -0.536, -0.138, 0.494, 0.666, 0.388, 0.412, -0.794, -0.691, -1.376, -1.227, -0.717, -0.569, -0.626, -1.118, -0.248, -0.096, -0.456, -0.140, -0.461, 0.525, -0.583, -0.209, -1.649, -0.847, -2.092, -0.887, -0.593, -0.991, -1.344, -1.247, -0.203, -0.413, -0.750, -0.782, -0.406, -0.098, -0.578, -5.000, -0.586, -0.520, -2.312, -5.000, -0.740, -0.044, -0.826, -0.692, 0.059, 0.030, -0.508, -0.458, -0.119, 0.245, -0.432, -5.000, -0.338, -0.372, -1.024, -0.362, -0.691, -0.161, -0.693, -0.763, 0.075, 0.741, 0.229, -0.094, -0.252, 0.383, -0.085, 0.243, -0.879, -0.025, -0.766, -1.307, -0.543, -0.143, -0.554, -1.009, -0.164, 0.276, -0.080, -0.296, -0.655, -0.163, -0.619, -0.247, -1.323, -0.671, -1.389, -1.350, -0.771, -0.722, -1.038, -1.149, -0.156, -0.216, -0.058, -0.714, 0.864, 0.700, 0.253, -5.000, 0.782, 0.355, -0.975, -5.000, 0.513, 0.644, 0.194, 0.196, 0.710, 0.769, 0.378, 0.751, 0.862, 0.921, 0.366, -5.000, 0.783, 0.424, -0.152, 0.511, 0.053, 0.206, 0.068, -0.191, 1.064, 1.149, 0.447, 0.418, 0.576, 1.000, 0.529, 0.791, 0.467, 0.769, 0.209, -0.322, 0.347, 0.923, 0.629, 0.098, 0.393, 0.875, 0.627, 0.528, 0.217, 0.426, -0.371, 0.267, -0.503, -0.567, -1.055, -0.709, 0.490, 0.228, 0.006, 0.133, 0.683, 0.600, 0.360, 0.227, 0.952, 0.365, 0.315, -5.000, 0.792, 0.081, -1.293, -5.000, 0.608, 0.486, -0.311, 0.491, 0.914, 0.633, 0.676, 1.106, 0.814, 0.728, 0.073, -5.000, 0.711, 0.070, -0.448, 0.295, 0.437, 0.508, 0.185, 0.433, 0.977, 0.973, 0.188, 0.339, 0.914, 0.722, 0.182, 0.883, 0.469, 0.187, -0.259, -0.335, 0.526, 0.310, 0.224, -0.160, 0.467, 0.047, -0.050, 0.521, 0.221, 0.532, -0.155, 0.599, -0.564, -1.139, -1.141, -0.882, 0.702, 0.097, 0.070, 0.046, 0.832, 0.486, 0.020, 0.590, 0.760, 0.354, -0.256, -5.000, -0.116, -0.709, -1.718, -5.000, -0.687, -0.684, -1.591, -0.645, 0.461, -0.140, -0.457, -0.212, 0.914, 1.171, 0.400, -5.000, 0.631, -0.017, -1.152, -0.082, 0.532, 0.557, 0.018, 0.383, 0.703, 1.051, -0.030, 0.465, 0.602, 0.708, 0.295, 0.820, -0.227, 0.116, -0.930, -0.865, 0.090, 0.595, 0.044, -0.009, 0.512, 0.533, 0.253, 0.618, 0.176, 0.155, -0.793, 0.101, -0.720, -0.860, -1.794, -0.974, 0.055, -0.513, -0.986, -0.339, 0.320, -0.095, -0.483, -0.022, 0.445, 0.373, -0.555, -5.000, -0.190, -0.486, -1.338, -5.000, -0.190, 0.150, -1.207, -0.689, 0.406, 0.433, -0.425, 0.055, 0.536, 0.818, 0.123, -5.000, 0.066, -0.010, -0.968, -0.356, 0.404, 0.560, -0.072, 0.228, 0.948, 1.290, 0.453, 0.893, 0.565, 1.037, 0.419, 0.852, -0.286, 0.166, -0.684, -1.144, -0.074, 0.384, -0.319, -0.309, 0.363, 0.636, 0.000, 0.343, 0.303, 0.900, 0.162, 0.568, -0.445, -0.465, -1.142, -0.949, 0.142, 0.046, -0.624, -0.491, 0.298, 0.496, 0.086, 0.160, 0.503, 0.667, -0.217, -5.000, 0.343, 0.412, -0.710, -5.000, 0.043, 0.753, 0.069, -0.156, 0.506, 0.801, 0.337, 0.358, 0.668, 0.968, 0.169, -5.000, 0.761, 0.730, -0.058, 0.222, -0.257, 0.566, 0.134, -0.323, 0.702, 1.155, 0.669, 0.399, 0.397, 0.926, 0.059, 0.641, 0.355, 0.896, -0.048, -0.001, -0.189, 0.808, 0.458, -0.166, 0.473, 0.754, 0.310, 0.372, 0.141, 0.687, -0.540, 0.328, -0.180, 0.489, -0.523, -0.359, 0.661, 0.941, 0.410, 0.222, 0.753, 0.926, 0.487, 0.501, 0.939, 0.849, 0.224, -5.000, 0.793, 0.175, -0.917, -5.000, 0.269, 0.698, 0.382, 0.252, 0.972, 1.033, 0.917, 0.884, 1.085, 1.168, 0.182, -5.000, 1.075, 0.639, 0.170, 0.504, 0.430, 0.973, 0.906, 0.505, 1.083, 1.336, 1.023, 0.831, 1.088, 1.307, 0.675, 1.324, 0.914, 0.723, 0.400, 0.151, 0.804, 0.956, 1.072, 0.392, 0.789, 0.814, 0.861, 0.962, 0.472, 0.949, -0.210, 0.747, -0.502, -0.306, -0.796, -0.644, 0.818, 0.744, 0.864, 0.500, 1.092, 0.876, 0.864, 0.746, 0.185, 0.520, -0.246, -5.000, 0.167, -0.081, -1.361, -5.000, -0.668, -0.259, -1.187, -1.093, 0.004, -0.190, -0.302, -0.216, 0.360, 0.752, -0.318, -5.000, 0.208, -0.137, -1.119, -0.246, -0.461, 0.413, 0.052, -0.103, 0.501, 0.904, -0.425, 0.286, 0.245, 0.599, -0.506, 0.456, -0.272, -0.092, -1.049, -1.211, -0.511, 0.210, -0.296, -0.535, -0.201, 0.137, -0.261, 0.003, -0.333, 0.499, -1.102, -0.298, -1.057, -0.822, -1.562, -0.855, -0.132, -0.517, -1.155, -0.806, 0.395, 0.075, -0.296, -0.387, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.230, 0.595, -0.774, -5.000, 0.218, 0.228, -1.395, -5.000, -0.191, 0.283, -0.689, -0.716, 0.652, 0.766, 0.110, 0.187, 0.517, 0.919, 0.005, -5.000, 0.537, 0.569, -0.352, -0.110, -0.147, 0.521, -0.028, -0.345, 0.670, 1.265, 0.519, 0.402, 0.337, 0.933, -0.024, 0.717, 0.312, 0.736, -0.106, -0.368, 0.226, 0.805, 0.202, 0.010, 0.569, 0.750, 0.425, 0.408, -0.160, 0.557, -0.844, 0.173, -0.622, 0.272, -0.801, -0.757, 0.633, 0.836, 0.304, 0.096, 0.882, 0.973, 0.611, 0.422, -0.323, -0.177, -0.779, -5.000, -0.503, -0.353, -1.752, -5.000, -0.122, 0.204, -0.950, -0.363, 0.630, 0.250, -0.099, -0.216, 0.644, 0.761, -0.163, -5.000, 0.676, 0.179, -0.541, -0.000, 0.350, 0.523, 0.303, 0.176, 0.675, 0.922, 0.584, 0.316, 0.478, 0.859, 0.083, 0.807, 0.317, 0.361, -0.613, -0.121, 0.237, 0.464, -0.006, -0.144, 0.237, 0.113, -0.005, 0.454, -0.784, 0.359, -1.185, -0.267, -1.377, -0.995, -1.590, -1.281, 0.078, -0.162, -0.234, -0.655, 0.380, 0.291, -0.194, 0.043, -0.631, -0.333, -1.119, -5.000, -1.256, -0.699, -1.800, -5.000, -1.758, -1.032, -2.022, -1.499, -0.933, -1.109, -1.053, -1.127, -0.179, 0.475, -0.985, -5.000, -0.406, -0.606, -1.356, -0.749, -0.560, -0.103, -0.730, -0.555, -0.184, 0.249, -0.769, -0.152, -0.418, 0.002, -0.563, 0.163, -0.908, -0.513, -1.529, -1.756, -1.004, -0.208, -0.640, -0.743, -0.452, -0.545, -0.737, -0.350, -0.936, -0.781, -1.936, -1.069, -1.940, -1.338, -1.940, -1.417, -1.393, -1.368, -1.873, -1.480, -0.859, -0.991, -1.548, -1.125, 0.033, 0.166, -0.856, -5.000, -0.255, 0.119, -1.424, -5.000, -0.614, -0.170, -1.159, -1.035, 0.216, 0.114, -0.719, -0.527, 0.432, 0.841, -0.085, -5.000, 0.280, 0.438, -0.451, 0.026, -0.423, 0.356, -0.404, -0.375, 0.267, 1.135, -0.004, -0.139, 0.048, 0.837, -0.241, 0.458, -0.270, 0.123, -0.788, -1.089, -0.377, -0.256, -0.430, -0.461, -0.010, 0.192, -0.153, 0.562, -0.274, 0.471, -0.742, -0.317, -0.627, -0.135, -1.113, -1.204, -0.048, 0.047, -0.632, -0.355, -0.032, 0.093, -0.253, -0.084, -0.225, -0.141, -0.764, -5.000, -0.195, 0.044, -0.851, -5.000, -0.492, -0.114, -0.351, -0.725, 0.339, 0.426, -0.151, -0.175, 0.183, 0.448, -0.100, -5.000, 0.372, 0.158, -0.518, -0.163, -0.746, -0.229, -0.308, -0.951, 0.368, 0.918, 0.344, -0.130, -0.322, 0.588, 0.261, 0.293, -0.227, 0.583, -0.247, -0.525, -0.367, 0.286, 0.056, -0.547, 0.256, 0.769, 0.320, 0.404, -0.928, -0.457, -1.480, -0.736, -1.216, -1.181, -1.098, -1.233, -0.596, -0.222, -0.618, -0.745, 0.116, 0.371, -0.133, -0.546, 0.085, 0.076, -0.250, -5.000, -0.088, -0.106, -1.368, -5.000, -0.247, 0.618, -0.685, -0.492, 0.988, 0.168, 0.270, 0.204, 0.731, 0.952, -0.175, -5.000, 0.605, 0.385, -0.395, -0.072, -0.011, 0.547, -0.154, -0.237, 0.665, 1.126, 0.716, 0.529, 0.437, 0.896, 0.319, 0.716, 0.089, 0.496, -0.048, -0.577, 0.134, 0.710, 0.174, -0.256, 0.725, 0.668, 0.659, 0.628, -0.142, 0.667, -0.457, 0.276, -0.883, -0.349, -0.823, -0.883, 0.167, 0.604, -0.034, -0.156, 0.764, 0.297, 0.332, 0.148, -0.145, 0.014, -0.257, -5.000, -0.690, -0.245, -1.057, -5.000, -1.369, -0.912, -1.591, -1.715, 0.625, -0.503, -0.145, -0.805, 0.380, 0.644, -0.236, -5.000, 0.116, 0.034, -0.904, -0.954, -0.255, 0.013, -0.145, -0.597, 0.230, 0.842, 0.158, 0.090, 0.545, 1.112, 0.548, 0.541, -0.498, 0.015, -0.925, -0.852, -0.491, 0.024, -0.362, -0.822, 0.074, 0.393, 0.023, 0.008, -0.082, 0.806, -0.786, -0.278, -0.592, -0.152, -1.039, -0.577, -0.221, -0.672, -0.550, -1.158, 0.224, 0.012, 0.007, -0.356, -0.295, 0.219, -0.590, -5.000, 0.000, -0.125, -0.317, -5.000, -0.560, 0.147, -0.429, -0.792, 0.179, 0.282, 0.195, -0.405, -0.069, 0.463, -0.081, -5.000, 0.039, 0.033, -0.709, 0.112, -0.634, 0.198, -0.533, -1.168, 0.059, 0.819, 0.140, -0.211, -0.291, 0.450, -0.002, 0.093, -0.759, 0.013, -1.145, -1.132, -0.532, -0.093, -0.696, -1.121, -0.136, 0.258, -0.025, -0.111, -0.908, 0.114, -0.555, -0.556, -1.265, -0.585, -0.745, -1.251, -0.816, -0.516, -1.054, -1.115, -0.290, 0.215, 0.037, -0.595, 0.896, 0.804, 0.260, -5.000, 0.902, 0.550, -0.364, -5.000, 0.461, 0.602, 0.073, -0.001, 0.722, 0.840, 0.504, 0.821, 0.587, 0.839, 0.155, -5.000, 0.588, 0.391, -0.380, 0.629, -0.197, 0.167, -0.107, -0.426, 0.787, 0.776, 0.061, 0.357, 0.475, 0.986, 0.594, 0.759, 0.240, 0.985, 0.308, 0.020, 0.445, 0.886, 0.475, 0.261, 0.436, 0.799, 0.668, 0.679, 0.063, 0.043, -0.636, 0.289, -0.800, -0.611, -0.825, -0.639, 0.251, 0.021, -0.343, 0.044, 0.541, 0.492, 0.209, 0.199, 1.079, 0.999, 0.688, -5.000, 1.110, 0.706, -0.058, -5.000, 0.801, 1.055, 0.621, 0.755, 1.071, 1.238, 1.165, 1.218, 1.219, 1.311, 0.269, -5.000, 1.126, 0.771, 0.402, 0.838, 0.860, 1.149, 0.933, 0.621, 1.230, 1.372, 1.077, 0.789, 1.073, 1.305, 0.653, 1.182, 0.688, 0.974, 0.473, 0.085, 0.819, 0.992, 0.781, 0.523, 0.909, 0.990, 0.866, 0.983, 0.543, 1.045, -0.004, 0.666, -0.331, -0.176, -0.726, -0.225, 0.893, 0.826, 0.634, 0.420, 1.071, 1.018, 0.738, 0.726, 0.694, 0.459, -0.134, -5.000, 0.353, -0.036, -1.334, -5.000, -0.316, -0.182, -1.293, -0.700, 0.643, 0.290, 0.077, 0.134, 1.103, 1.326, 0.453, -5.000, 1.014, 0.572, -0.269, 0.392, 0.730, 1.008, 0.488, 0.391, 0.871, 1.269, 0.456, 0.815, 0.145, 0.423, -0.130, 0.321, -0.409, 0.139, -0.486, -0.871, -0.081, 0.628, 0.151, 0.031, 0.207, 0.341, 0.109, 0.185, -0.010, 0.201, -0.864, -0.035, -0.534, -0.275, -1.098, -0.805, 0.338, 0.166, -0.636, -0.202, 0.317, 0.322, -0.128, -0.340, -0.080, 0.096, -0.763, -5.000, -0.107, -0.338, -1.215, -5.000, -0.431, 0.170, -0.946, -0.841, 0.101, 0.321, -0.463, -0.267, 0.501, 0.936, 0.033, -5.000, 0.341, 0.041, -0.325, -0.030, 0.298, 0.657, 0.072, -0.000, 0.770, 1.255, 0.450, 0.432, 0.250, 0.875, -0.027, 0.488, -0.317, 0.228, -0.850, -0.733, -0.260, 0.536, -0.222, -0.558, 0.251, 0.595, 0.099, 0.168, 0.111, 0.666, -0.642, 0.033, -0.564, -0.342, -1.247, -0.899, 0.079, 0.305, -0.803, -0.597, 0.108, 0.429, -0.093, -0.242, 0.400, 0.748, -0.068, -5.000, 0.576, 0.479, -0.907, -5.000, 0.335, 0.583, 0.282, -0.103, 0.680, 0.828, 0.438, 0.434, 0.386, 0.717, 0.169, -5.000, 0.307, 0.118, -0.741, 0.603, -0.378, -0.031, -0.174, -0.286, 0.845, 1.015, 0.477, 0.333, 0.240, 0.740, -0.051, 0.760, 0.041, 0.400, -0.223, -0.277, -0.091, 0.464, 0.358, -0.293, 0.283, 0.496, 0.103, 0.327, -0.122, 0.041, -0.765, 0.172, -0.553, -0.264, -0.736, -0.167, 0.348, 0.442, 0.067, -0.127, 0.385, 0.532, 0.028, 0.152, 0.882, 0.763, 0.159, -5.000, 0.739, 0.326, -0.779, -5.000, 0.752, 0.829, 0.743, 0.664, 1.170, 1.119, 1.198, 1.101, 0.858, 0.854, 0.082, -5.000, 0.616, 0.420, -0.089, 0.740, 0.555, 0.690, 0.913, 0.245, 1.096, 1.227, 0.888, 0.674, 0.936, 1.248, 0.568, 1.384, 0.827, 0.785, 0.672, 0.541, 0.862, 0.797, 1.059, 0.660, 1.024, 0.908, 0.934, 1.281, 0.173, 0.667, -0.339, 0.545, -0.937, -0.405, -1.171, -0.716, 0.769, 0.335, 0.506, 0.458, 1.129, 0.914, 0.687, 0.940, 0.373, 0.649, -0.491, -5.000, 0.322, 0.135, -1.050, -5.000, 0.000, 0.386, -0.758, -0.176, 0.510, 0.185, 0.419, 0.470, 0.060, 0.668, -0.616, -5.000, 0.160, -0.420, -0.877, 0.118, 0.409, 0.463, 0.274, -0.096, 0.996, 0.770, -0.249, 0.460, -0.134, 0.395, -0.338, 0.356, -0.209, -0.067, -0.653, -0.545, -0.022, 0.102, 0.031, -0.510, -0.154, 0.135, -0.416, 0.177, -0.775, 0.479, -0.822, -0.051, -0.731, -0.521, -1.400, -0.472, 0.713, -0.169, -0.718, -0.358, 0.572, 0.017, -0.477, -0.271, 0.796, 0.935, 0.221, -5.000, 0.555, 0.684, -0.397, -5.000, 0.355, 0.615, 0.044, -0.108, 0.672, 0.690, 0.561, 0.482, 1.024, 1.306, 0.626, -5.000, 0.776, 0.693, 0.244, 1.012, 0.198, 0.678, 0.252, -0.095, 0.885, 1.050, 0.753, 0.621, 0.741, 1.145, 0.262, 1.060, 0.616, 0.929, 0.342, -0.034, 0.910, 1.009, 1.000, 0.678, 0.642, 0.769, 0.640, 0.973, 0.275, 0.951, -0.072, 0.567, 0.085, 0.459, -0.047, -0.273, 0.884, 0.552, 0.167, 0.412, 0.836, 0.702, 0.369, 0.552, -0.050, 0.292, -0.694, -5.000, -0.144, -0.023, -1.247, -5.000, -0.355, -0.307, -0.525, -0.532, 0.335, 0.393, 0.014, -0.014, 0.012, 0.281, -0.243, -5.000, 0.008, -0.217, -0.862, 0.030, -0.506, -0.311, -0.435, -0.699, 0.445, 0.721, 0.111, -0.019, -0.032, 0.523, -0.218, 0.559, -0.290, 0.349, -0.909, -0.712, -0.325, -0.059, -0.208, -0.520, 0.233, 0.305, -0.077, 0.288, -1.093, -0.318, -1.282, -0.589, -0.399, 0.180, -0.876, -0.300, -0.016, -0.272, -0.585, -0.523, 0.079, 0.101, -0.443, -0.324, -0.165, -0.017, -0.412, -5.000, -0.307, -0.114, -1.495, -5.000, 0.356, 0.538, 0.100, 0.250, 0.868, 0.542, 0.669, 0.540, 0.471, 0.653, -0.264, -5.000, 0.482, 0.111, -0.505, 0.333, 0.350, 0.439, 0.296, 0.229, 0.900, 0.898, 0.734, 0.665, 0.611, 0.923, 0.227, 1.111, 0.311, 0.366, -0.262, 0.250, 0.552, 0.638, 0.457, 0.355, 0.723, 0.679, 0.544, 1.157, -0.681, 0.029, -1.535, -0.122, -1.460, -0.931, -1.697, -1.010, 0.190, -0.186, -0.334, -0.297, 0.569, 0.390, -0.291, 0.284, -0.551, -0.142, -1.285, -5.000, -1.131, -0.672, -1.961, -5.000, -1.368, -0.992, -1.639, -1.487, -0.557, -0.659, -0.947, -0.496, -0.326, 0.497, -0.915, -5.000, -0.291, -0.332, -1.296, -0.344, -0.704, -0.095, -0.428, -0.520, 0.114, 0.631, -0.189, 0.091, -0.321, 0.411, -0.644, 0.515, -0.830, -0.214, -1.329, -0.964, -0.411, 0.072, -0.539, -0.467, -0.054, 0.079, -0.346, 0.137, -1.351, -0.269, -1.523, -0.848, -1.752, -0.966, -1.843, -1.457, -1.007, -1.604, -1.840, -1.218, -0.542, -0.567, -1.129, -0.969, -0.026, -0.114, -0.939, -5.000, -0.564, -0.171, -1.239, -5.000, -0.916, -0.642, -1.243, -0.849, -0.380, -0.537, -1.034, -0.562, 0.081, 0.332, -0.542, -5.000, -0.064, -0.101, -1.241, -0.541, -0.583, -0.464, -0.627, -0.906, 0.147, 0.438, -0.131, -0.334, -0.430, 0.180, -0.539, -0.049, -1.570, -0.286, -1.312, -1.356, -0.772, -0.689, -0.619, -0.889, -0.584, -0.435, -0.737, -0.287, -0.939, -0.385, -1.109, -1.197, -0.994, -0.416, -1.233, -0.807, -0.697, -0.850, -1.314, -0.878, -0.709, -0.686, -1.203, -0.911, -0.139, 0.178, -0.849, -5.000, -0.090, -0.053, -0.991, -5.000, -0.310, -0.401, -0.388, -0.655, 0.407, 0.422, -0.036, 0.019, 0.487, 0.701, -0.259, -5.000, 0.107, 0.176, -0.771, -0.131, -0.641, -0.350, -0.482, -0.865, 0.581, 0.884, 0.492, -0.024, -0.060, 0.594, 0.167, 0.559, -0.412, 0.389, -0.279, -0.381, -0.422, -0.100, -0.272, -0.679, 0.404, 0.632, 0.228, 0.492, -0.783, -0.101, -1.442, -0.358, -1.541, -0.885, -1.393, -1.453, -0.582, -0.565, -0.902, -0.715, 0.122, 0.469, -0.239, -0.100, 0.105, 0.116, -0.262, -5.000, -0.035, -0.146, -1.640, -5.000, -0.148, 0.634, -0.600, -0.311, 0.832, 0.351, 0.619, 0.522, 0.695, 0.884, -0.371, -5.000, 0.580, 0.343, -0.525, 0.319, 0.031, 0.446, -0.173, -0.236, 0.857, 1.115, 0.868, 0.627, 0.483, 0.908, -0.023, 0.948, 0.012, 0.513, -0.172, -0.030, 0.139, 0.494, 0.005, -0.106, 0.701, 0.705, 0.586, 0.888, -0.375, 0.605, -0.672, 0.259, -1.513, -0.702, -1.656, -0.958, -0.055, 0.215, -0.440, -0.478, 0.673, 0.292, -0.004, 0.464, -0.466, -0.133, -1.186, -5.000, -0.830, -0.037, -1.770, -5.000, -1.375, -0.961, -1.424, -1.598, 0.407, -0.317, -0.118, -0.795, 0.269, 0.800, -0.467, -5.000, 0.065, -0.034, -1.257, -0.435, -0.226, -0.047, -0.045, -0.485, 0.298, 0.980, 0.226, 0.271, 0.376, 1.110, 0.098, 0.622, -0.243, 0.389, -0.925, -0.228, -0.191, 0.099, -0.380, -0.587, 0.232, 0.508, 0.060, 0.380, -0.135, 1.065, -0.423, -0.098, -0.751, 0.072, -1.403, -0.133, -0.318, -0.546, -0.755, -0.689, 0.142, 0.484, -0.430, -0.375, -0.399, -0.069, -1.006, -5.000, -0.935, -0.879, -1.512, -5.000, -0.735, -0.389, -0.968, -0.928, 0.008, -0.206, -0.311, -0.502, 0.113, 0.282, -0.602, -5.000, -0.333, -0.373, -1.007, 0.301, -1.213, -0.575, -0.554, -0.982, 0.284, 0.623, 0.159, -0.140, -0.389, 0.333, -0.440, 0.113, -0.896, 0.102, -0.695, -0.796, -0.728, -0.365, -0.794, -1.000, -0.121, 0.137, -0.039, -0.046, -1.046, -0.195, -1.110, -0.625, -0.983, -0.548, -1.286, -0.746, -0.996, -1.018, -1.314, -1.094, -0.079, -0.103, -0.295, -0.401, 0.733, 0.594, -0.134, -5.000, 0.481, -0.013, -1.353, -5.000, 0.144, 0.197, -0.247, -0.004, 0.574, 0.517, 0.499, 0.595, 0.591, 0.548, -0.278, -5.000, 0.097, -0.464, -0.980, 0.169, -0.611, -0.218, -0.664, -0.597, 0.814, 0.926, 0.122, 0.069, 0.444, 0.907, 0.118, 0.773, 0.364, 0.459, -0.148, -0.223, 0.010, 0.402, 0.400, 0.053, 0.336, 0.788, 0.205, 0.514, -0.050, 0.248, -1.044, 0.159, -0.778, -0.689, -1.319, -0.467, 0.126, -0.255, -0.618, -0.123, 0.499, 0.512, -0.134, 0.192, 0.723, 0.418, 0.015, -5.000, 0.765, 0.303, -0.889, -5.000, 0.393, 0.427, -0.283, 0.405, 0.824, 0.540, 0.933, 0.999, 0.742, 0.794, -0.467, -5.000, 0.596, -0.165, -0.796, 0.497, 0.417, 0.432, 0.109, 0.093, 1.109, 0.869, 0.324, 0.459, 0.689, 0.951, 0.068, 1.003, 0.412, 0.392, 0.083, -0.083, 0.580, 0.374, 0.254, 0.274, 0.735, 0.466, 0.122, 0.738, -0.142, 0.340, -0.663, 0.350, -1.305, -0.878, -1.795, -1.074, 0.386, -0.123, -0.373, -0.083, 0.821, 0.500, -0.035, 0.447, 0.345, -0.039, -0.586, -5.000, 0.117, -0.300, -1.681, -5.000, -0.830, -0.635, -1.307, -0.810, 0.392, -0.367, 0.218, 0.095, 0.570, 0.912, -0.355, -5.000, 0.647, 0.083, -0.727, 0.498, 0.426, 0.398, -0.086, 0.428, 0.918, 1.064, 0.470, 0.834, 0.175, 0.671, -0.392, 0.746, -0.481, 0.056, -0.782, -0.779, -0.154, 0.293, -0.206, -0.143, 0.259, 0.453, -0.119, 0.410, -0.198, 0.543, -0.818, 0.056, -0.751, -0.159, -1.002, -0.755, 0.199, -0.429, -1.007, -0.371, 0.311, 0.138, -0.245, 0.053, 0.752, 0.560, -0.156, -5.000, 0.524, 0.132, -0.456, -5.000, 0.016, -0.095, -0.634, -0.289, 0.547, 0.265, 0.086, 0.414, 0.948, 1.136, 0.408, -5.000, 0.801, 0.307, 0.063, 0.930, 0.135, 0.104, 0.101, -0.216, 0.922, 0.932, 0.311, 0.647, 0.513, 0.973, 0.157, 0.775, 0.083, 0.588, -0.084, -0.569, 0.583, 0.493, 0.314, 0.254, 0.303, 0.525, 0.173, 0.623, -0.024, 0.442, -0.425, 0.210, -0.360, -0.323, -0.579, -0.264, 0.136, -0.316, -0.840, -0.248, 0.229, 0.205, 0.021, 0.077, -0.384, -0.364, -0.878, -5.000, -0.177, -0.623, -1.754, -5.000, -0.288, -0.210, -0.520, -0.522, -0.014, 0.202, -0.553, -0.144, -0.033, -0.070, -0.466, -5.000, 0.257, -0.014, -0.555, 0.011, -0.310, -0.052, -0.155, -0.871, 0.402, 0.642, -0.079, -0.047, -0.291, -0.053, -0.768, -0.235, -0.189, 0.022, -0.577, -0.850, -0.485, 0.167, 0.009, -0.645, -0.504, -0.137, -0.439, -0.460, -0.643, -0.407, -1.034, -0.478, -0.716, -0.770, -1.106, -1.013, 0.204, -0.014, -0.121, -0.340, 0.072, -0.129, -0.403, -0.430, 0.364, 0.266, -0.151, -5.000, 0.450, -0.203, -1.296, -5.000, 0.378, 0.514, 0.377, 0.331, 0.833, 0.891, 0.582, 0.667, 0.551, 0.678, -0.532, -5.000, 0.612, 0.262, -0.407, 0.117, 0.136, 0.604, 0.502, 0.023, 0.835, 0.923, -0.120, -0.265, 0.634, 0.844, 0.269, 0.961, 0.601, 0.672, 0.027, -0.155, 0.203, 0.584, 0.792, 0.312, 0.550, 0.673, 0.588, 0.669, -0.431, 0.189, -0.883, 0.287, -0.531, -0.523, -1.092, -0.924, 0.450, 0.250, 0.525, 0.226, 0.729, 0.595, 0.288, 0.514, -0.345, -0.488, -0.790, -5.000, -0.377, -0.620, -1.538, -5.000, -1.042, -0.593, -1.610, -1.060, -0.449, -0.698, -0.964, -0.815, -0.103, 0.004, -0.928, -5.000, -0.378, -0.565, -1.424, -0.624, -0.280, 0.060, -0.370, -0.291, 0.012, 0.236, -1.153, -0.274, -0.843, -0.979, -0.846, -0.709, -0.575, -0.541, -1.254, -1.151, -0.539, -0.450, -0.775, -1.253, -0.742, -0.637, -0.913, -0.876, -1.090, -0.200, -1.005, -0.939, -1.424, -1.099, -1.444, -1.248, -0.350, -0.901, -1.321, -1.072, -0.608, -0.802, -1.377, -1.106, 0.003, 0.137, -0.702, -5.000, 0.151, -0.027, -1.058, -5.000, -0.059, 0.377, -0.618, -0.341, -0.001, 0.025, -0.638, -0.507, 0.397, 0.744, 0.129, -5.000, 0.447, 0.363, -0.271, 0.360, 0.062, 0.515, 0.162, -0.282, 0.439, 0.742, 0.197, 0.046, 0.048, 0.410, -0.512, 0.127, 0.065, 0.433, -0.234, -0.763, 0.079, 0.317, 0.332, -0.127, -0.293, -0.030, -0.284, -0.239, -0.358, 0.243, -0.696, -0.170, -0.472, 0.023, -0.548, -0.862, 0.383, 0.145, -0.248, -0.405, 0.026, 0.073, -0.257, -0.386, -1.013, -0.484, -1.470, -5.000, -1.237, -1.135, -2.390, -5.000, -1.205, -1.167, -1.582, -1.178, -0.296, -0.467, -1.212, -0.993, -0.768, -0.478, -1.198, -5.000, -0.740, -0.910, -1.346, -0.706, -1.041, -0.602, -0.910, -0.808, -0.007, 0.195, -0.676, -0.575, -0.503, -0.343, -1.184, -0.495, -0.896, -0.451, -1.327, -0.937, -0.565, -0.661, -0.905, -0.999, -0.710, -0.370, -0.839, -0.590, -1.035, -0.724, -2.089, -0.823, -1.322, -1.002, -1.695, -1.225, -0.270, -0.564, -0.713, -0.531, -0.385, -0.817, -1.155, -0.921, -0.516, -0.709, -0.968, -5.000, -1.085, -1.250, -2.237, -5.000, 0.056, 0.206, -0.318, -0.217, 0.079, -0.239, -0.715, -0.106, 0.150, -0.051, -0.548, -5.000, -0.190, -0.691, -1.246, -0.502, -0.589, -0.184, -0.483, -0.406, 0.139, 0.207, -0.635, -0.314, 0.115, 0.092, -0.883, 0.513, -0.251, -0.297, -1.027, -0.686, -0.131, -0.141, -0.438, -0.417, 0.141, -0.110, -0.495, 0.326, -1.235, -0.077, -1.501, -0.677, -1.693, -1.725, -2.222, -1.650, -0.329, -0.603, -0.771, -0.671, -0.303, -0.448, -0.654, -0.274, -1.176, -0.558, -1.614, -5.000, -1.731, -1.788, -2.351, -5.000, -1.866, -1.664, -2.607, -1.981, -1.002, -1.247, -1.860, -1.589, -0.380, 0.070, -1.244, -5.000, -0.814, -0.837, -1.883, -1.225, -0.733, -0.416, -1.145, -0.562, -0.462, 0.139, -1.062, -0.457, -0.491, -0.473, -1.338, -0.377, -1.349, -1.039, -1.730, -1.846, -0.540, -0.501, -1.061, -1.070, -0.780, -0.669, -1.417, -0.955, -1.358, -1.150, -2.106, -0.982, -1.946, -1.967, -2.334, -2.064, -1.562, -1.881, -1.925, -1.651, -0.846, -1.235, -1.878, -1.526, -0.352, -0.500, -1.312, -5.000, -0.918, -0.968, -2.044, -5.000, -1.074, -0.762, -1.827, -1.046, -0.793, -0.748, -1.816, -1.339, -0.151, 0.250, -0.557, -5.000, -0.296, -0.348, -1.012, -0.662, -0.613, -0.308, -0.649, -0.336, -0.146, 0.517, -0.733, -0.686, -0.581, -0.541, -1.255, -0.303, -1.066, -0.689, -1.341, -1.513, -1.285, -1.159, -0.823, -1.327, -1.078, -0.791, -1.278, -0.877, -0.943, -0.620, -1.366, -1.152, -1.203, -1.133, -1.548, -1.785, -0.823, -0.940, -1.147, -0.949, -0.982, -1.087, -1.561, -1.173, -0.257, 0.078, -0.815, -5.000, -0.233, -0.143, -1.717, -5.000, -0.353, -0.186, -0.273, -0.466, 0.479, 0.724, -0.131, 0.079, 0.417, 0.757, -0.001, -5.000, 0.496, 0.425, -0.840, 0.173, -0.437, 0.040, -0.178, -0.773, 0.735, 1.065, 0.251, 0.218, 0.030, 0.628, -0.015, 0.387, -0.180, 0.774, -0.216, -0.264, -0.050, 0.388, -0.029, -0.429, 0.275, 0.912, 0.336, 0.478, -0.724, 0.133, -0.876, -0.291, -1.383, -0.296, -1.399, -0.846, -0.242, -0.041, -0.366, -0.602, 0.190, 0.380, 0.048, -0.178, -0.319, -0.340, -0.492, -5.000, -0.584, -0.817, -1.919, -5.000, -0.461, 0.603, -1.006, -0.496, 0.694, 0.021, -0.027, 0.187, 0.359, 0.489, -0.572, -5.000, 0.482, 0.131, -0.886, -0.109, -0.162, 0.522, -0.215, -0.469, 0.506, 0.886, 0.253, 0.246, -0.112, 0.231, -0.587, 0.278, -0.353, 0.048, -0.754, -0.953, -0.089, 0.302, -0.462, -0.376, 0.077, 0.096, -0.283, 0.044, -0.605, 0.129, -0.876, -0.075, -1.462, -0.625, -1.542, -1.131, -0.097, 0.452, -0.140, -0.555, 0.249, -0.050, -0.273, -0.179, -0.762, -0.699, -0.862, -5.000, -0.874, -0.095, -1.797, -5.000, -1.339, -0.903, -1.715, -1.537, -0.126, -0.774, -0.747, -1.077, -0.001, 0.405, -1.036, -5.000, -0.046, -0.063, -1.441, -0.737, -0.239, -0.059, -0.238, -0.369, 0.119, 0.856, -0.469, -0.001, -0.358, 0.543, -0.911, -0.377, -1.112, -0.449, -1.880, -1.171, -0.633, -0.524, -0.974, -1.240, -0.630, -0.358, -1.058, -0.899, -0.623, 0.097, -1.320, -0.590, -1.285, -0.290, -1.683, -0.862, -0.766, -1.052, -1.161, -1.249, -0.622, -0.366, -1.162, -1.047, -0.502, 0.029, -0.709, -5.000, -0.379, -0.160, -1.359, -5.000, -0.736, 0.093, -0.624, -0.897, -0.169, -0.203, -0.357, -0.637, 0.049, 0.438, -0.707, -5.000, -0.150, -0.041, -0.848, 0.284, -0.873, -0.051, -0.541, -1.018, 0.260, 0.762, 0.043, -0.185, -0.694, -0.103, -0.976, -0.233, -0.850, 0.125, -0.438, -1.269, -0.543, -0.017, -0.574, -0.774, -0.472, -0.061, -0.539, -0.488, -1.153, -0.257, -1.220, -0.457, -1.354, -0.160, -1.181, -1.012, -0.770, -0.598, -1.309, -0.797, -0.358, -0.279, -0.643, -0.874, 0.579, 0.625, -0.007, -5.000, 0.761, 0.330, -0.968, -5.000, 0.287, 0.539, 0.053, 0.245, 0.677, 0.910, 0.306, 0.621, 0.700, 0.873, 0.075, -5.000, 0.665, 0.356, -0.231, 0.649, 0.158, 0.174, -0.148, -0.019, 1.071, 1.165, 0.361, 0.315, 0.314, 0.887, 0.091, 0.507, 0.139, 0.871, 0.125, -0.428, 0.060, 0.757, 0.400, -0.261, 0.274, 0.814, 0.395, 0.344, -0.015, 0.482, -0.741, 0.206, -0.457, -0.473, -0.912, -0.601, 0.375, 0.300, -0.023, 0.051, 0.493, 0.578, 0.145, 0.248, 0.455, 0.447, -0.181, -5.000, 0.658, 0.062, -1.240, -5.000, 0.347, 0.684, -0.143, 0.227, 0.680, 0.722, 0.494, 0.716, 0.717, 0.826, -0.189, -5.000, 0.765, 0.451, -0.108, 0.571, 0.597, 0.662, 0.304, 0.349, 0.925, 1.048, 0.073, 0.241, 0.415, 0.659, -0.369, 0.394, 0.208, 0.422, -0.088, -0.357, 0.284, 0.537, 0.164, -0.226, 0.422, 0.463, -0.061, 0.286, -0.175, 0.288, -1.109, 0.169, -0.769, -1.007, -1.169, -0.888, 0.490, 0.335, 0.198, -0.119, 0.448, 0.303, -0.114, 0.150, 0.001, -0.404, -0.511, -5.000, -0.004, -0.822, -1.683, -5.000, -0.887, -0.631, -1.732, -0.804, 0.108, -0.749, -0.554, -0.395, 0.566, 0.982, -0.461, -5.000, 0.835, 0.383, -0.831, 0.285, 0.569, 0.875, 0.292, 0.645, 0.682, 1.148, 0.072, 0.583, -0.193, 0.206, -1.088, 0.225, -0.320, -0.097, -0.947, -1.115, 0.027, 0.274, -0.309, -0.143, 0.034, 0.111, -0.372, -0.092, -0.329, -0.174, -0.767, -0.190, -0.887, -0.391, -1.547, -1.004, -0.023, -0.343, -1.044, -0.506, -0.107, -0.223, -0.613, -0.436, 0.071, 0.014, -0.830, -5.000, 0.101, -0.305, -1.349, -5.000, -0.034, -0.009, -0.510, -0.257, 0.015, -0.161, -0.723, -0.217, 0.433, 0.804, -0.127, -5.000, 0.696, 0.422, -0.051, 0.492, 0.232, 0.466, 0.177, 0.068, 0.614, 0.854, 0.152, 0.278, -0.049, 0.201, -0.418, -0.068, -0.275, 0.298, -0.468, -0.578, 0.177, 0.426, 0.169, 0.008, -0.109, 0.161, -0.335, -0.099, -0.400, 0.010, -0.865, -0.258, -0.314, -0.330, -0.503, -0.531, 0.097, -0.131, -0.679, -0.380, -0.181, -0.171, -0.693, -0.503 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_37(struct _training *tptr) {
  struct _training tinf = {
    0.214, 11, 4.350, { 2.662, 0.218, 0.119 }, { 0.635, -1.007, -1.668 }, 1, 
    { -1.486, -4.000, 0.715, 1.594, -4.000, -4.000, 1.232, 0.834, -4.000, -0.643, 2.300, -4.000, 2.014, 0.670, 0.007, 2.078, 1.928, 2.374, 0.141, 1.818, 2.435, -4.000, 2.425, -4.000, 2.087, -4.000, 2.492, 2.374 }, 
    {{ 0.183, -1.063, -0.638, 0.101},{ 0.390, -1.699, -0.952, -0.091},{ 0.173, 0.748, -0.677, -0.444},{ 0.296, 0.689, -1.123, -0.563},{ 0.348, 0.498, -1.063, -0.534},{ 0.336, 0.247, -0.761, -0.402},{ 0.320, -0.258, -0.805, -0.180},{ 0.241, -0.025, -0.761, -0.128},{ 0.300, -0.182, -0.564, -0.207},{ 0.344, -0.370, -1.006, -0.167},{ 0.210, -0.564, -1.006, 0.055},{ 0.312, -0.805, -1.257, -0.021},{ 0.348, -1.188, -0.564, -0.116},{ 0.344, -0.677, -0.952, -0.116},{ 0.300, -0.805, -0.564, -0.085},{ 0.228, -0.638, -0.600, -0.004},{ 0.232, -0.341, -0.529, -0.073},{ 0.223, -0.430, -0.761, -0.010},{ 0.214, -0.341, -0.638, -0.033},{ 0.201, -0.341, -0.761, 0.001},{ 0.173, -0.430, -1.006, 0.076},{ 0.228, -0.900, -0.462, 0.007},{ 0.249, -0.495, -0.761, -0.033},{ 0.154, -0.341, -0.900, 0.070},{ 0.245, -0.805, -0.564, -0.010},{ 0.091, -0.370, -0.900, 0.140},{ 0.096, -0.761, -0.529, 0.145},{ 0.091, -0.495, -0.900, 0.159},{ 0.135, -0.430, -0.851, 0.101},{ 0.060, -0.564, -0.529, 0.154},{ 0.164, -0.285, -0.952, 0.055},{ 0.106, -0.638, -0.529, 0.121} }, 
    {{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}
   },{{ 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000},
   { 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000, 0.000}} }, 
    0.000, { 0.321, 1.172, 0.867, -5.000, -0.078, 0.676, -0.058, -5.000, 0.057, 0.468, 0.337, -0.221, -0.193, 0.102, -1.042, 0.470, -0.737, -0.262, -1.063, -5.000, -1.600, 0.513, -1.458, -0.022, -0.237, 0.443, 0.300, -0.232, 0.357, -0.017, -1.356, -0.156, -0.392, 0.829, -0.664, -0.698, -0.664, 0.501, -0.711, -1.746, -0.105, 0.518, -0.030, -0.181, -0.648, -0.715, -1.159, -0.827, 0.470, 1.065, 0.215, 0.277, 0.592, 1.273, 1.127, -0.429, 0.899, 1.242, 0.698, 0.495, 0.551, 0.712, -0.067, -0.020, 1.311, 1.564, 1.615, -5.000, 1.357, 1.136, 0.938, -5.000, 1.426, 1.437, 1.221, 0.961, 1.089, 1.222, 0.162, 1.368, -0.005, 0.398, -0.789, -5.000, -0.257, 0.744, -0.061, 0.857, 0.431, 0.715, 0.300, 0.785, 0.961, 0.723, -0.900, 0.254, 1.012, 1.071, 0.824, 0.495, 0.680, 1.274, 1.070, 0.566, 1.072, 1.151, 1.043, 0.685, 0.644, 0.294, 0.151, 0.486, 1.144, 1.598, 1.189, 1.064, 1.252, 1.474, 1.187, 0.753, 1.381, 1.513, 1.344, 1.157, 1.156, 0.963, 0.103, 0.690, 0.835, 1.515, 1.111, -5.000, 0.751, 1.366, 0.486, -5.000, 0.834, 1.442, 1.164, 0.797, 0.649, 0.928, -0.299, 1.177, -0.236, 0.275, -0.378, -5.000, -0.773, 0.930, -1.670, 0.266, 0.038, 0.900, 0.204, 0.493, 0.998, 0.338, -0.895, 0.231, -0.178, 0.706, -0.720, -0.765, -0.671, 0.655, -0.415, -0.758, 0.156, 0.373, 0.036, 0.054, -0.456, 0.109, -1.149, -0.709, 0.795, 1.293, 0.361, 0.665, 1.150, 1.696, 1.332, 0.603, 1.320, 1.729, 1.425, 1.337, 0.950, 1.054, -0.316, 0.488, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.146, 0.944, 0.874, -5.000, -0.678, 0.703, -0.269, -5.000, -0.939, 0.648, 0.166, -0.881, 0.060, 0.754, -0.192, 1.115, -0.766, -0.147, 0.042, -5.000, -2.667, 0.581, -5.000, -0.749, -1.045, -0.112, 0.427, -0.517, 0.764, 0.735, -5.000, -0.225, -1.234, 0.581, 0.148, -0.811, -2.376, 0.839, -1.400, -2.705, -1.924, 0.521, -0.069, -1.832, -1.074, -1.347, -1.529, -1.702, -0.249, 0.951, 0.267, -0.197, -0.406, 1.373, 0.969, -0.555, 0.725, 1.500, 1.083, 0.715, 0.194, 0.625, -0.496, -0.835, 0.690, 1.238, 1.345, -5.000, 1.099, 1.220, 0.143, -5.000, 1.184, 1.210, 0.948, 0.391, 0.795, 1.164, 0.240, 1.200, -0.161, 0.338, 0.096, -5.000, -0.977, 0.624, -5.000, 0.831, 0.176, 0.869, 0.427, 0.240, 0.835, 0.659, -1.210, -0.023, 0.571, 1.274, 1.274, 0.581, 0.022, 1.482, 0.869, -0.578, 0.668, 1.029, 0.715, -0.025, 0.070, 0.218, -5.000, -0.650, 0.352, 1.187, 1.291, 0.466, 0.549, 1.370, 1.006, -0.186, 1.213, 1.380, 1.078, 0.920, 0.767, 0.842, -0.517, 0.032, -0.892, -0.038, 0.146, -5.000, -0.230, 0.046, -0.895, -5.000, 0.127, -0.517, -0.430, -0.379, -1.056, 0.336, -0.368, -0.148, -0.826, -1.251, -1.077, -5.000, -5.000, -5.000, -5.000, -1.210, -0.230, -0.740, 0.263, -1.434, -0.025, 0.022, -5.000, -1.353, -1.077, -0.112, -0.489, -1.048, -0.635, -0.597, -0.284, -1.053, -1.077, 1.274, 0.521, -1.146, -0.780, -0.805, 0.022, -2.853, 0.091, 0.608, 0.252, -0.165, 0.107, 1.418, 1.274, -0.161, -0.335, 1.135, 1.023, 0.481, -0.480, 0.198, -0.363, -0.420, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.313, 1.099, 0.660, -5.000, -0.373, 0.809, -0.262, -5.000, 0.048, 0.592, 0.272, 0.049, -0.204, 0.214, -1.159, 0.629, -0.659, 0.338, -2.110, -5.000, -1.411, 0.633, -5.000, -1.077, 0.004, 0.822, -0.207, -0.384, 0.617, 0.912, -1.964, -0.125, -0.199, 1.051, 0.176, -0.470, -1.065, 0.554, 0.096, -1.251, -0.185, -0.130, 0.464, -1.652, -0.567, -1.365, -1.817, -0.805, 0.337, 1.098, 0.497, 0.342, 0.681, 1.391, 0.956, -0.355, 0.777, 1.019, 0.453, 0.016, 0.329, 0.680, -0.671, -0.113, 0.505, 1.266, 1.133, -5.000, 1.028, 0.869, -0.034, -5.000, 0.908, 0.795, 0.336, -0.053, 0.317, 0.622, -0.566, 0.705, -0.489, 0.521, -5.000, -5.000, -1.168, 0.409, -5.000, -0.784, 0.668, 0.581, -0.866, -1.053, 0.511, 0.322, -2.003, 0.022, 0.483, 0.869, 0.833, 0.143, -0.172, 1.029, -5.000, -0.923, 0.486, 0.263, 0.751, -1.271, 0.131, -0.977, -0.430, 0.278, 0.511, 1.404, 0.815, 0.692, 0.804, 1.234, 1.157, -0.335, 0.786, 0.764, -0.010, 0.473, 0.824, 0.696, 0.118, 0.126, 0.446, 0.788, 0.792, -5.000, 0.625, 0.793, -0.545, -5.000, 0.490, 0.511, -0.335, -0.363, -0.016, 0.280, -0.777, 0.498, -1.498, 0.122, -5.000, -5.000, -0.558, 0.778, -5.000, -0.112, 0.399, -0.301, -0.635, 0.399, 0.581, 0.753, 0.135, 0.170, -0.268, 0.392, -0.301, -1.365, -1.643, 0.427, -1.210, -1.189, -0.010, -0.558, -0.558, -0.393, -0.466, -1.670, -0.762, -1.764, 0.430, 1.567, 0.401, 0.453, 0.451, 0.436, 0.022, 0.245, 0.783, 0.568, 0.225, 0.216, 0.644, 0.894, -0.207, -0.080, -0.034, 0.882, 0.508, -5.000, -0.756, -0.062, -1.135, -5.000, -0.262, -0.876, -0.352, -0.369, -0.291, 0.120, -1.365, -0.032, -0.784, 0.058, -1.588, -5.000, -1.794, -0.301, -0.475, -0.986, -0.578, 0.392, 0.687, -0.199, 0.696, -0.137, -1.839, -0.448, -0.404, 0.962, -1.904, -2.052, -1.281, -0.517, -5.000, -1.974, 0.012, -0.080, -0.172, -1.434, -0.747, -0.143, -2.237, -2.212, -0.064, 0.597, -0.004, -0.270, 0.027, 0.771, 0.340, -1.374, 0.376, 0.481, -0.079, -0.218, 0.067, 0.402, -0.805, -0.621, -0.089, 0.872, 0.573, -5.000, 0.105, 0.458, -0.547, -5.000, -0.248, 0.146, -0.153, -0.619, -0.657, -0.473, -1.844, -0.153, -0.887, 0.155, -1.756, -5.000, -1.100, 0.122, -1.168, -0.558, -0.790, -0.481, -0.266, -0.899, -0.113, -0.923, -1.721, -0.639, -1.031, 0.127, -0.230, -0.879, -1.141, 0.163, -0.360, -2.527, -1.780, -0.653, -0.563, -0.977, -1.256, -0.767, -1.875, -1.448, 0.014, 0.863, -0.101, -0.204, 0.151, 0.698, 0.886, -0.272, 0.469, 1.139, 0.455, 0.145, 0.032, 0.321, -0.698, -0.331, 0.503, 1.165, 0.822, -5.000, 0.789, 0.883, 0.464, -5.000, 0.649, 0.654, 0.327, 0.032, -0.016, 0.216, -1.228, 0.432, -0.951, 0.445, -1.595, -5.000, -0.866, 0.107, -1.588, 0.102, -0.374, 0.070, -0.091, -0.460, -0.047, -0.904, -2.439, -0.188, -0.614, -0.597, -0.112, -5.000, -0.489, 0.233, -5.000, -0.368, -0.407, -0.635, -0.635, -0.430, -0.603, -0.597, -5.000, -1.089, 0.443, 1.188, 0.484, 0.588, 0.538, 1.051, 0.652, -0.028, 0.965, 1.332, 0.486, 0.383, 0.539, 0.505, -1.766, -0.099, -0.685, 0.092, -0.491, -5.000, -0.192, 0.115, -1.861, -5.000, -0.430, -0.053, -1.559, -0.709, -1.302, -0.335, -1.893, -0.550, -2.550, -0.589, -5.000, -5.000, -0.143, -5.000, -1.365, -0.750, -1.417, -5.000, -2.110, -0.842, -1.070, -2.021, -5.000, -1.553, -1.704, -1.782, -2.288, -2.028, -1.588, -0.061, -5.000, -1.883, -0.885, -0.430, -1.770, -1.028, -2.873, -2.101, -2.143, -2.407, -0.698, -0.196, -2.143, -1.486, 0.715, 0.492, -0.866, -1.758, -1.011, 0.176, -0.616, -1.065, -1.293, -1.080, -2.288, -1.665, 0.342, 1.221, 0.752, -5.000, 0.452, 0.825, -0.050, -5.000, 0.264, 0.365, 0.034, -0.080, -0.181, 0.035, -0.922, 0.408, -0.190, 0.284, -0.220, -5.000, -0.662, 0.233, -1.210, 0.130, -0.247, 0.332, 0.077, -0.050, 0.734, -0.130, -1.466, -0.024, -0.206, 0.787, -0.444, -0.768, -0.384, 0.869, 0.300, -1.216, 0.297, 0.813, 0.633, -0.642, -0.325, -1.261, -1.059, -0.516, 0.595, 1.270, 0.555, 0.378, 1.011, 1.259, 1.245, -0.069, 1.225, 1.377, 0.959, 0.671, 0.615, 0.759, -0.132, 0.072, -0.717, 0.057, -0.775, -5.000, -1.337, 0.074, -2.214, -5.000, -0.649, -1.758, -0.264, -1.354, -1.339, -1.159, -3.354, -1.013, -2.033, -0.915, -2.323, -5.000, -1.210, -1.231, -5.000, -0.836, -1.278, -1.310, -0.466, -2.309, -0.930, -1.391, -2.021, -1.089, -1.166, -0.391, -1.466, -2.172, -0.977, 0.122, -1.696, -1.422, -0.679, -1.817, -0.689, -0.517, -2.121, -0.830, -2.266, -1.638, -0.188, 0.571, -1.110, -0.194, 0.044, 1.365, 0.789, -1.008, 0.383, 1.218, 0.789, 0.315, 0.303, 0.572, 0.253, -0.487, 0.370, 1.126, 0.962, -5.000, 0.002, 0.427, 0.442, -5.000, 0.409, 0.427, 0.655, 0.581, 0.267, 0.723, -0.503, 0.311, -1.047, -0.805, -2.389, -5.000, -0.384, -0.384, -1.168, -0.252, -5.000, 0.581, -0.430, -5.000, -0.143, -0.158, -5.000, -0.697, -0.805, -1.290, -1.670, -2.003, -0.597, 0.358, -5.000, 0.263, 0.581, 1.562, -5.000, -0.284, -0.018, -5.000, -1.770, -1.316, 0.160, 0.374, -0.616, -0.141, 0.554, 1.051, 0.233, -0.430, 0.628, 0.869, 1.408, 0.417, 0.134, 0.527, -2.960, -0.430, -0.941, 0.176, -0.436, -5.000, -0.013, -0.047, -0.597, -5.000, -0.266, -5.000, -1.400, -0.707, -1.018, -2.127, -2.617, -0.764, -1.476, -5.000, -5.000, -5.000, -5.000, 0.096, -5.000, -0.846, -0.740, 0.263, -5.000, -0.475, -0.702, 0.135, -5.000, -0.740, -1.974, -1.108, -1.319, -3.132, -5.000, -5.000, -1.817, -2.003, -5.000, -5.000, -0.597, -5.000, -1.625, -5.000, -1.077, -5.000, -0.542, 0.122, -1.065, -1.093, 0.330, 0.687, -0.112, -1.271, 0.245, 0.512, 0.176, 0.096, -0.668, -0.083, -2.309, -1.037, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -1.286, -0.165, -0.946, -5.000, -2.900, -1.365, -0.647, -5.000, -1.400, -0.635, -0.211, -1.875, -1.482, -0.273, -5.000, -0.230, -2.498, -5.000, -0.013, -5.000, -5.000, -5.000, -5.000, -1.721, -1.434, -5.000, -0.335, -1.616, -1.316, -0.400, -5.000, -0.391, -1.146, -0.284, -5.000, -5.000, -1.805, -5.000, -0.430, -1.108, -1.210, -5.000, -5.000, -1.630, -2.350, -5.000, -5.000, -3.365, -0.986, -1.138, -1.482, -1.061, -1.634, 0.250, -0.671, -1.539, -0.355, -0.517, -5.000, -0.475, -1.094, -0.503, -1.290, -1.942, 0.655, 1.187, 1.092, -5.000, 0.122, 0.135, 0.022, -5.000, 0.358, 0.956, 0.969, -0.489, 0.897, 0.715, 0.869, 1.120, -1.138, 0.263, -5.000, -5.000, -0.475, 1.169, 0.358, 0.135, 0.464, 1.274, -0.112, -0.866, 0.107, 0.245, -5.000, -1.168, -1.365, 0.022, -5.000, 0.751, -5.000, 0.581, -0.335, -0.230, -0.740, 0.715, 0.581, -1.077, -0.805, 0.668, -5.000, -5.000, -0.005, 1.205, 0.677, -0.275, 0.699, 0.918, 0.869, -0.923, 0.869, 1.179, 1.080, 0.624, 0.002, 0.159, -2.075, -0.492, -1.112, -0.172, -5.000, -5.000, -0.517, -5.000, -0.671, -5.000, -5.000, -5.000, -5.000, -0.805, -5.000, -1.168, -5.000, -1.417, -2.160, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.866, -5.000, -5.000, -5.000, -1.271, -0.284, -5.000, -0.671, -2.176, -0.112, -1.028, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, 0.869, 0.987, -5.000, -5.000, -0.740, -5.000, -0.904, -0.493, -5.000, -1.770, -0.854, 0.581, 0.263, -5.000, -5.000, -0.805, -0.230, 1.274, -5.000, -0.517, -0.762, -5.000, -2.003, -0.066, 1.144, 0.615, -5.000, -0.299, 0.652, -1.498, -5.000, -0.084, 0.225, -0.805, -0.588, -0.805, -0.400, -0.866, 0.065, -1.337, -0.335, -0.201, -5.000, -2.724, -0.384, -5.000, -1.376, -5.000, -0.172, 0.176, -5.000, -0.002, -0.895, -0.301, -1.434, -1.944, 0.828, -1.400, -2.892, -5.000, -5.000, -5.000, -2.554, -2.266, -5.000, -5.000, -2.607, -2.075, -5.000, -1.290, -1.948, 0.004, 0.935, -0.102, -0.474, -0.254, 0.760, -0.545, -1.471, 0.309, 1.080, 0.942, 0.629, -0.138, 0.379, -1.011, -0.430, -0.476, 0.764, -0.310, -5.000, -1.872, 0.869, -5.000, -5.000, -0.230, -0.773, 0.148, -0.820, -1.077, -0.245, -5.000, -0.052, -2.075, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -1.365, -0.230, 0.764, 1.631, -5.000, 0.233, -0.284, -5.000, -1.089, -1.657, -0.977, -5.000, -0.647, -5.000, -0.597, -5.000, -5.000, -1.964, -5.000, 0.464, -1.559, -1.893, -0.671, -0.172, -1.210, -0.653, 0.822, -5.000, -1.011, -0.762, 0.358, -5.000, -1.529, -0.006, 0.427, 0.938, -0.284, 0.307, 0.111, -5.000, -0.501, 0.671, 1.187, 1.335, -5.000, 0.464, 0.501, -0.517, -5.000, 0.540, 0.987, -5.000, 0.135, 0.176, 0.557, -1.365, 0.732, -2.058, 0.764, -0.143, -5.000, -0.597, -5.000, -0.517, -1.210, -1.028, 0.263, -0.335, -0.977, -0.291, 0.058, -0.025, -1.514, -1.210, -0.112, -5.000, -1.077, 0.581, 1.339, 0.176, -0.430, -5.000, 1.274, 0.764, -5.000, -0.257, 1.380, 0.176, -1.328, 0.593, 1.605, -5.000, 0.200, 1.157, 0.668, 0.869, -5.000, 0.480, 1.421, 0.668, 1.165, 0.828, -0.368, -0.310, 0.287, 0.417, 0.176, 0.077, -5.000, -5.000, 0.764, -5.000, -5.000, 0.755, 0.581, 0.333, -0.112, -0.505, 0.613, -1.883, 0.540, 0.176, 0.309, -0.866, -5.000, -0.112, 0.176, -5.000, -1.077, -5.000, -5.000, -0.805, -0.047, 0.253, 1.012, -5.000, -0.571, -1.210, -5.000, -0.384, -5.000, 0.358, 0.581, -0.517, -0.671, -0.047, -0.430, -5.000, -5.000, 0.276, -0.112, -5.000, -0.977, 0.469, 0.668, -0.475, -0.475, -0.740, 0.764, 0.581, 0.294, 0.509, -0.172, -0.047, 0.319, 0.689, 0.533, -0.805, 0.151, -0.412, 0.263, 0.227, -5.000, -5.000, -1.328, 0.358, -5.000, -0.417, -0.080, 0.374, -0.687, -0.885, -1.529, -2.127, 0.139, -0.284, -0.112, 0.022, -5.000, -0.430, 0.233, -5.000, -1.643, -5.000, -5.000, -5.000, -0.489, 0.300, -5.000, -5.000, -0.613, -5.000, -0.430, -5.000, -5.000, -0.597, 0.022, 0.869, -5.000, -0.707, -5.000, 0.022, -5.000, -1.146, -5.000, -0.069, -1.008, -0.234, 0.456, -0.132, -0.988, -1.003, 1.043, 0.956, -1.872, 0.581, 0.404, 0.557, -0.102, 0.125, 0.387, -0.605, -0.539, 0.235, 1.265, 0.839, -5.000, 0.430, 1.039, -0.826, -5.000, 0.437, 0.934, 0.329, 0.136, -0.609, -0.078, -1.904, 0.461, -1.102, -0.795, -1.498, -5.000, -1.241, 0.646, -5.000, -0.698, -1.328, 0.818, -0.161, -0.729, -0.070, -1.657, -1.758, -0.946, -0.284, 0.358, -0.284, -0.528, -0.826, 1.185, 0.744, -1.670, -0.711, 0.022, -1.721, -1.450, -0.963, -0.740, -1.310, -1.225, 0.226, 1.128, 0.427, 0.046, 0.383, 1.594, 1.157, -0.013, 0.904, 1.360, 1.157, 1.023, 0.365, 0.387, -1.014, 0.135, 0.236, 0.603, 0.649, -5.000, 0.135, 0.521, -0.335, -5.000, -0.453, 0.392, -0.707, -0.184, -0.575, -1.388, -2.363, 0.362, -1.091, -1.077, -5.000, -5.000, -1.365, -0.230, -1.077, -0.994, -1.365, 0.022, -1.028, -1.588, -0.597, -0.877, -1.607, -1.318, -2.207, -5.000, -0.923, -1.210, -0.335, 0.122, 0.358, -1.365, -5.000, -0.335, 0.022, -5.000, -0.805, -5.000, -5.000, -1.661, 0.314, 0.926, -0.284, -0.317, 0.250, 1.151, 0.869, -0.006, 0.914, 0.646, 1.051, -0.257, 0.002, 0.022, -1.754, -0.664, -1.205, -0.317, -0.857, -5.000, 0.245, -0.384, -5.000, -5.000, -5.000, -1.251, -0.201, -0.826, -0.832, -0.846, -0.874, -1.345, -5.000, -5.000, -2.336, -5.000, -5.000, -5.000, -5.000, -1.924, -5.000, -1.028, 0.176, -5.000, -1.162, -1.904, -2.510, -2.170, -2.316, -1.168, -5.000, -2.288, 0.233, -0.923, -5.000, -5.000, -5.000, -5.000, -0.335, -1.003, -2.230, -5.000, -1.696, -2.581, -1.489, -0.695, -2.597, -2.093, -5.000, 0.804, -5.000, -0.724, -5.000, -0.335, -0.301, -1.904, -1.810, -2.869, -2.728, -2.161, -0.608, 0.571, 0.034, -5.000, -0.522, 0.327, -1.382, -5.000, -0.410, -0.642, -0.707, -0.773, -0.909, -0.602, -1.802, -0.180, -1.257, -0.242, -0.857, -5.000, -1.202, -0.517, -0.904, -0.436, -5.000, -0.143, -0.301, -0.460, -0.141, -1.730, -3.269, -1.221, -1.238, 1.077, -0.686, -1.394, -3.114, 0.263, -0.112, -1.100, -2.302, -0.284, 0.042, -2.252, -1.477, -2.266, -2.439, -2.789, -0.490, 0.442, -0.410, -0.533, -0.273, 0.854, 0.096, -0.396, 0.589, 1.123, 0.869, 0.105, -0.240, -0.012, -0.934, -0.759, -0.393, 0.679, 0.030, -5.000, -1.791, -0.616, -1.964, -5.000, -0.375, 0.442, -0.314, -0.428, -0.612, -0.449, -2.227, -0.298, -2.775, -0.895, -2.176, -5.000, -3.305, 0.022, -1.770, -1.996, -1.231, -0.517, -1.168, -0.207, -0.573, -0.820, -1.954, -1.956, -0.742, 0.289, -1.231, -0.973, -1.822, 0.176, -0.368, -2.705, -0.952, -0.430, -1.045, -1.258, -1.496, -0.415, -1.670, -1.272, -0.251, 0.401, -0.517, -0.304, -0.833, 0.819, -0.400, -1.063, 0.524, 0.546, 0.701, -0.255, -0.298, 0.624, -0.362, -0.860, 0.581, 1.246, 1.135, -5.000, 0.509, 1.537, -0.172, -5.000, 1.253, 1.343, -5.000, 0.695, 0.488, 0.152, -0.597, 0.738, -0.453, -0.266, -0.959, -5.000, 0.358, -5.000, 0.581, -0.284, -5.000, 0.096, -0.047, -5.000, 0.233, 0.022, -5.000, -1.278, 0.233, 1.110, -0.597, -0.192, -0.773, 1.012, -5.000, -0.977, -0.230, -5.000, 0.263, -0.475, 0.051, 0.764, -0.475, -0.805, 0.345, 1.157, -0.964, 0.365, 0.869, 1.314, 0.427, -0.266, 0.682, 1.070, 0.581, 0.445, 0.489, 0.358, -0.647, -0.087, -0.203, 0.319, -0.343, -5.000, -0.161, 1.214, -0.335, -5.000, 0.581, 0.828, 0.204, -0.866, -0.230, -0.923, -1.011, 0.366, -1.924, -5.000, -1.904, -5.000, -0.718, 0.715, -5.000, -1.093, -5.000, 0.263, 0.122, -0.671, -0.132, -0.112, -1.251, -0.866, -1.621, -1.964, -0.877, -2.408, -5.000, -0.230, -5.000, -5.000, -0.597, -1.123, -1.365, -1.643, -2.769, -5.000, -1.138, -2.168, -0.514, 0.176, -0.099, -0.651, -1.616, 0.409, 0.409, -0.069, 0.309, 1.274, 0.448, 0.399, -0.078, 0.191, -1.679, -0.977, -0.619, 0.233, -0.746, -5.000, -1.547, 0.325, -1.529, -5.000, -1.456, -0.489, -0.805, -0.726, -1.453, -0.950, -0.937, -0.762, -1.609, -0.087, -0.846, -5.000, -1.746, -5.000, -0.080, -1.202, -5.000, -0.230, -1.168, -1.861, -1.616, -0.923, -1.434, -0.483, -3.589, -0.355, -1.100, -1.701, -1.217, 0.122, -5.000, -2.597, -1.519, -5.000, -0.671, -1.588, -5.000, -5.000, -1.417, -2.259, -0.951, 0.046, -1.533, -1.606, -1.659, 0.427, -0.582, -0.917, -0.252, 0.501, 0.602, 0.061, -0.688, -0.398, -1.788, -1.177, -0.992, 0.011, -0.204, -5.000, -3.104, -1.011, -5.000, -5.000, -1.224, -0.597, -0.866, -1.425, -0.796, -1.290, -0.545, 0.581, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.937, -1.168, -5.000, -5.000, 0.085, -0.312, -0.923, -0.335, -1.529, -1.588, -1.251, -5.000, -2.252, -1.177, -5.000, -0.977, -5.000, -5.000, 0.070, 0.486, -1.616, -2.087, -0.635, -5.000, -3.274, -0.998, 0.002, -0.335, -0.697, -1.077, -0.091, 0.427, -0.486, -1.670, 0.869, 1.092, -1.065, -0.337, 0.546, -0.430, -1.924, 0.668, 1.290, 1.662, -5.000, 0.869, 0.926, 0.176, -5.000, 1.464, 1.029, 1.274, 1.027, 0.998, 1.392, 0.427, 1.372, -0.172, -5.000, 0.096, -5.000, 0.070, 0.668, -0.430, 0.135, 0.987, 1.051, -5.000, -5.000, 0.869, 0.668, 0.581, 0.298, 0.200, 1.408, 1.274, -0.635, -0.153, 1.103, -5.000, -5.000, 0.204, 1.051, 0.715, 0.442, -0.161, 0.176, -5.000, -1.794, 0.052, 1.126, 0.795, 0.634, 0.482, 1.339, -0.230, 0.227, 0.800, 1.370, 1.194, 0.869, 0.305, 0.905, -0.207, -0.092, -0.298, 0.795, -0.836, -5.000, -1.290, 0.501, -5.000, -5.000, -1.168, 0.176, -0.172, -0.006, 0.135, -5.000, -5.000, 0.325, -5.000, -5.000, -5.000, -5.000, -0.635, 0.869, -5.000, -0.301, -5.000, -5.000, -5.000, -5.000, -0.047, -5.000, -0.430, -0.805, -0.040, 0.263, -1.588, -5.000, -5.000, 0.022, -0.430, -5.000, -1.643, -5.000, 0.176, -0.230, -5.000, 0.096, -5.000, -2.281, -0.145, 0.869, -0.335, -0.230, 0.540, 1.205, 0.358, -1.123, 0.804, 0.022, 1.274, 0.176, 0.006, -0.112, -5.000, -1.754, -1.452, 0.248, -2.252, -5.000, -2.974, -0.805, -5.000, -5.000, -2.266, -5.000, -1.721, -0.934, -1.638, -5.000, -5.000, -0.877, -5.000, -5.000, -0.558, -5.000, -5.000, -5.000, -5.000, -2.667, -5.000, 0.176, -0.112, -0.517, -1.861, -0.153, -0.284, -1.466, -1.210, -0.923, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.475, -5.000, -5.000, -5.000, -5.000, -0.671, -3.063, -1.335, -0.707, -5.000, -1.153, -1.569, -0.172, -0.773, -5.000, -0.404, -0.310, 0.464, -1.954, -1.046, -0.475, -2.451, -1.386, -0.270, 0.798, 0.066, -5.000, -1.421, -0.496, -2.176, -5.000, -0.308, 0.338, 0.335, -0.642, -1.090, -0.384, -0.445, 0.523, -2.597, 0.263, -5.000, -5.000, -5.000, -0.172, 0.358, -5.000, -1.817, -0.740, -0.430, 0.096, -0.475, 0.815, -0.923, -1.637, -1.384, 0.233, -1.100, -5.000, -1.828, 0.581, 0.263, -1.251, -1.822, -0.453, -0.335, -0.846, -1.443, -5.000, -0.558, -1.424, -0.547, 1.204, -0.956, -0.442, -0.707, 0.581, -5.000, -0.713, -0.318, 0.826, 0.607, -0.781, -0.627, -0.041, -0.393, -1.286, 0.442, 1.157, 0.956, -5.000, 0.081, 0.926, 0.022, -5.000, 0.325, 1.092, -0.475, 0.833, 0.115, 0.815, 0.022, 1.036, -5.000, 1.051, -0.923, -5.000, -5.000, 0.869, -5.000, -1.365, -0.977, -5.000, 0.869, 0.501, -0.192, 0.974, -5.000, -0.597, -0.475, -0.230, 0.409, 0.521, -1.529, 0.869, 0.358, -0.069, -0.689, -0.284, -5.000, -5.000, -0.923, -5.000, 0.646, -0.407, -0.294, 0.798, 0.204, 0.306, -2.003, 1.274, 0.501, -0.545, 0.604, 1.444, 0.969, -0.460, 0.490, 0.042, -0.061, -0.517, 0.239, 1.067, 0.176, -5.000, -0.013, 1.214, -0.172, -5.000, -0.671, -0.923, 0.533, 0.218, -0.566, 0.096, -0.866, 0.358, -1.053, -0.112, 0.294, -5.000, -0.517, 0.176, -5.000, -1.168, 0.070, 0.176, 0.358, 0.464, -0.671, 0.715, -0.597, -0.112, -0.242, -5.000, -1.328, -0.230, -1.251, -0.517, -0.430, -5.000, 0.122, 0.263, -5.000, -5.000, -0.475, 0.358, 0.022, -1.271, -0.032, 0.442, 0.107, -0.101, -0.335, 0.233, -5.000, -5.000, 0.609, 0.715, 0.176, 0.414, 0.167, -0.384, -5.000, -0.206, -0.820, 0.470, -0.219, -5.000, -5.000, -1.210, -5.000, -5.000, -0.378, 0.294, -1.746, -1.014, -0.626, 0.143, -2.058, -0.164, -1.498, -0.923, -5.000, -5.000, -5.000, -0.866, -5.000, -0.306, -1.794, -5.000, -5.000, -5.000, -0.503, -5.000, -0.047, -2.677, -1.826, -5.000, -0.866, -1.868, -5.000, 0.233, 0.501, -5.000, -0.686, -0.866, -0.153, -2.586, -1.372, -5.000, -5.000, -2.309, -0.944, 0.559, -0.327, -1.285, -1.861, 0.197, -0.230, -2.576, -0.355, 0.886, -0.112, -0.773, -0.370, 0.249, -0.773, -0.944, -0.729, 0.532, 0.150, -5.000, -1.680, -0.335, -0.642, -5.000, -0.642, 0.210, -0.500, -0.944, -1.153, -0.567, -1.588, -0.129, -1.168, -1.466, -1.794, -5.000, -2.981, -1.168, -1.123, -1.625, -1.616, -5.000, -1.028, -5.000, -0.335, -0.517, -0.754, -1.192, -1.214, -0.112, -0.306, -2.202, -2.207, 0.210, -1.168, -2.786, -2.127, -0.483, -1.839, -1.298, -1.248, -1.616, -2.191, -2.656, -0.988, 0.486, -0.757, -0.826, -0.892, -0.377, 0.668, -1.420, 0.047, 0.828, 0.536, 0.311, -0.624, -0.351, -1.061, -1.221, -0.791, 0.077, 0.250, -5.000, -0.805, 0.233, 0.263, -5.000, 0.633, 0.176, -1.251, 0.333, -0.273, -0.172, -0.230, -1.097, -2.402, -5.000, -5.000, -5.000, -0.571, -5.000, -5.000, -1.400, -5.000, -5.000, -5.000, -1.210, -0.977, -1.271, -5.000, -1.434, -0.245, -0.335, -0.597, -5.000, -5.000, -0.230, -5.000, -0.230, -5.000, -5.000, 0.427, -5.000, -2.439, -5.000, -1.290, -5.000, -0.791, 0.006, -1.944, -0.789, 0.051, 0.233, 0.122, -0.335, 1.019, 0.828, 0.815, 0.358, -0.190, -0.740, -1.238, -1.453, -1.220, -2.191, -0.647, -5.000, -1.643, 0.464, -5.000, -5.000, -0.006, -5.000, -0.740, -0.207, -1.442, -5.000, -2.521, -1.168, -2.183, -1.210, -1.271, -5.000, -5.000, -0.112, -0.384, -0.571, -1.400, -5.000, -5.000, -1.251, -2.336, -0.866, -5.000, -2.861, -1.623, -1.210, -1.077, -1.347, -5.000, 0.358, -0.740, -5.000, -0.230, 0.668, -0.430, -0.866, -0.849, -5.000, -2.191, -1.938, -1.588, -0.368, -0.977, -5.000, -1.365, -5.000, 0.581, -0.578, -0.977, 0.176, -0.489, -0.301, -1.300, -2.281, -0.915, -1.754, -1.444, -0.270, -0.984, -5.000, -2.226, -0.061, -0.836, -5.000, -1.770, -0.851, -2.151, -0.782, -1.374, -1.271, -1.504, -0.507, -1.804, -0.245, -1.616, -5.000, -1.632, -0.245, -0.805, -1.132, -5.000, -1.770, -5.000, -5.000, -1.396, -1.290, -5.000, -2.198, -2.189, -2.003, -0.923, -2.054, -3.685, -0.453, -5.000, -5.000, -2.191, -1.514, -0.517, -1.929, -2.543, -2.309, -2.031, -2.569, -1.173, 0.202, -1.889, -1.600, -1.392, 0.210, -0.335, -1.724, -0.597, 0.442, 0.007, -0.618, -1.105, -0.308, -1.716, -1.463, 0.346, 1.203, 0.779, -5.000, -0.237, 0.600, -0.349, -5.000, 0.095, 0.619, 0.286, -0.136, -0.265, -0.039, -1.211, 0.461, -1.075, -0.161, -1.358, -5.000, -1.624, 0.454, -2.607, -0.101, -0.502, 0.517, 0.176, 0.043, 0.373, -0.078, -1.047, -0.251, -0.229, 0.546, -0.240, -0.659, -0.623, 0.601, 0.289, -1.061, -0.707, 0.546, -0.144, -0.843, -0.621, -0.322, -1.508, -1.127, 0.412, 0.999, 0.359, 0.293, 0.288, 1.185, 1.014, -0.340, 0.974, 1.218, 1.049, 0.456, 0.483, 0.866, 0.124, -0.084, 1.252, 1.584, 1.454, -5.000, 1.070, 1.426, 0.994, -5.000, 1.505, 1.412, 1.257, 1.006, 1.238, 1.366, 0.634, 1.455, -0.013, 0.039, -0.358, -5.000, -0.826, 0.336, -0.571, 0.758, 0.633, 1.562, 1.120, 0.655, 1.092, 0.367, -2.031, 0.238, 0.589, 1.027, 0.358, -0.172, 0.399, 1.505, 1.065, -0.187, 0.643, 1.597, 1.274, 0.646, 0.532, 0.521, -5.000, 0.307, 1.061, 1.382, 1.030, 0.899, 1.301, 1.553, 1.025, 0.819, 1.321, 1.666, 1.364, 1.164, 1.174, 1.109, -0.387, 0.471, 0.124, 1.243, 0.552, -5.000, 0.536, 1.316, 0.300, -5.000, 0.744, 0.847, 0.604, 0.275, -0.085, 0.464, -1.117, 0.763, -0.710, -0.257, -1.721, -5.000, -0.639, 0.427, -1.251, 0.158, -0.075, 0.646, 0.434, 0.129, 0.649, -0.538, -5.000, -0.066, -1.036, -0.640, -1.173, -1.391, -1.219, 0.907, -1.138, -1.824, -0.977, -0.430, -0.230, -0.526, -1.434, -0.172, -1.241, -1.098, 0.213, 0.764, -0.283, -0.105, 0.437, 1.557, 0.693, 0.034, 1.079, 1.568, 1.436, 0.764, 0.223, 0.415, -1.070, -0.240, 0.123, 0.900, 0.166, -5.000, -0.571, 0.572, -0.325, -5.000, -0.134, -0.156, -0.081, -0.548, -0.345, 0.094, -1.220, 0.098, -0.856, 0.468, -1.084, -5.000, -1.195, -0.230, -5.000, -0.332, -2.207, 0.358, 0.250, -0.923, 0.554, -0.124, -5.000, -0.430, -1.003, 0.132, -0.506, -1.130, -1.576, -0.018, -0.597, -1.762, -0.973, -0.483, -0.671, -1.677, -1.719, -1.549, -0.789, -2.141, 0.090, 0.911, -0.095, -0.260, 0.213, 1.386, 0.945, -0.227, 1.072, 1.621, 1.373, 1.011, 0.133, 0.684, -0.681, -0.356, 0.293, 1.068, 0.944, -5.000, -0.425, 0.808, -0.700, -5.000, -0.575, 0.741, 0.951, -0.435, -0.027, 0.847, -0.307, 0.979, -0.671, -0.689, -0.087, -5.000, -2.638, -0.895, -0.407, -0.532, 0.129, 0.581, 0.804, 0.512, 0.795, 0.176, -1.365, -0.031, -0.535, -0.080, -0.407, -0.326, -0.355, 0.771, 0.325, -1.657, -2.330, 0.800, 0.399, -1.003, -0.597, 0.063, -1.077, -1.017, 0.342, 1.134, 0.706, 0.578, 0.011, 1.487, 1.274, -0.322, 0.907, 1.466, 1.403, 0.854, 0.577, 0.894, 0.250, -0.036, 1.238, 1.604, 1.741, -5.000, 1.164, 0.963, 1.165, -5.000, 1.329, 1.597, 1.230, 1.160, 1.241, 1.274, 0.755, 1.527, 0.648, 0.751, 0.245, -5.000, -0.335, 0.969, 0.869, 0.929, 0.998, 1.247, 0.987, 1.120, 1.274, 0.869, -0.112, 0.626, 0.802, 0.655, 1.482, 0.979, 0.826, 1.451, 0.938, 0.343, 0.724, 0.715, 1.205, 0.486, 0.643, 1.023, -0.805, -0.181, 1.060, 1.587, 1.368, 1.230, 1.290, 1.659, 1.403, 0.451, 1.552, 1.677, 1.041, 1.178, 1.201, 1.262, -0.312, 0.651, 0.717, 1.372, 1.176, -5.000, 1.440, 1.672, 0.294, -5.000, 0.661, 1.103, 1.332, 0.938, 0.838, 1.239, -0.112, 0.958, -0.257, 0.546, 0.218, -5.000, -5.000, 1.169, -1.028, 0.735, 0.581, 1.457, 0.521, 0.176, 1.114, -0.047, -1.434, 0.480, -0.895, 0.263, -1.365, -0.374, -0.112, 0.969, -0.335, -1.123, 0.392, -0.112, -0.230, -1.434, -0.689, 0.869, -0.597, -0.099, 0.913, 1.698, 1.070, 1.188, 1.063, 1.617, 1.520, 0.490, 1.442, 1.722, 0.964, 1.383, 1.215, 1.096, -0.297, 0.318, -0.423, 0.698, 0.032, -5.000, -1.263, -0.966, -1.670, -5.000, -0.517, 0.036, -5.000, -1.268, -0.593, -0.156, -1.328, 0.048, -1.347, -5.000, -0.950, -5.000, -0.999, 0.245, -5.000, -0.527, -0.805, -0.069, -0.597, -0.384, 0.233, -0.517, -1.365, -0.488, -1.717, -1.670, -1.146, -1.379, -5.000, -1.466, -0.558, -1.490, -2.021, -1.904, -0.153, -2.093, -3.316, -1.189, -1.670, -3.194, -0.343, 0.533, -0.083, -0.104, -0.364, 0.568, 0.330, -1.097, 0.220, 0.855, 0.210, -0.205, -0.025, 0.087, -0.760, -0.594, 0.787, 1.398, 1.305, -5.000, 0.663, 1.264, 0.830, -5.000, 0.789, 1.071, 0.662, 0.597, 0.372, 1.008, -0.503, 1.037, -0.097, 0.833, 0.427, -5.000, -0.460, 1.205, 0.646, 0.739, -0.384, 1.388, 0.070, 0.358, 0.961, 0.949, -0.006, 0.422, 0.237, 1.274, 0.943, 0.538, -0.196, 1.399, -0.923, -1.498, 0.145, 0.395, 0.448, 0.304, 0.006, 0.176, -0.545, -0.513, 0.853, 1.420, 1.231, 1.020, 0.885, 1.341, 1.274, 0.122, 1.158, 1.268, 1.138, 0.853, 1.054, 1.293, 0.252, 0.568, 1.164, 1.628, 1.622, -5.000, 1.576, 1.523, 0.214, -5.000, 1.123, 1.141, 1.033, 0.433, 0.973, 1.254, 0.189, 1.241, 0.920, 0.932, 0.744, -5.000, -0.013, 1.234, -5.000, 0.922, 0.176, 1.194, 0.135, 0.869, 1.283, 1.175, -0.384, 0.715, 0.994, 1.131, 1.131, 1.245, 1.205, 1.649, 1.274, 0.521, 0.826, 1.457, 0.668, 0.784, 0.804, 0.480, -5.000, 0.274, 1.294, 1.712, 1.390, 1.553, 1.394, 1.684, 1.491, 0.545, 1.255, 1.434, 0.903, 0.991, 1.358, 1.324, 0.345, 1.047, 0.694, 1.076, 1.039, -5.000, 1.076, 1.070, -0.143, -5.000, 0.884, 0.650, 0.167, 0.187, 0.509, 0.505, -0.412, 0.963, 0.566, 0.176, 0.399, -5.000, 0.245, 0.987, -5.000, 0.946, -5.000, -0.230, 0.315, 0.022, 0.719, 0.381, -5.000, 1.208, 0.562, 1.274, 0.427, 0.233, 0.680, 0.646, -0.597, 0.624, 0.070, 0.358, 0.218, -0.061, 0.817, -0.153, -0.384, 0.254, 1.205, 1.654, 1.380, 1.288, 0.884, 1.457, 1.100, 0.626, 0.960, 1.242, 0.657, 0.401, 1.075, 1.025, 0.399, 0.752, 0.375, 1.192, 0.910, -5.000, 0.395, 0.430, -0.805, -5.000, 0.460, 0.393, -0.047, -0.203, 0.225, 0.557, -0.238, 0.890, -0.343, 0.922, -1.365, -5.000, -1.450, 0.680, -5.000, 0.203, -0.597, 0.319, 0.176, -0.230, 1.009, -0.161, -1.400, -0.010, -0.527, 0.042, 0.135, -0.145, -0.909, 0.668, 0.176, -0.245, -0.693, 0.115, -0.061, -1.141, -0.709, -0.407, -0.153, -0.912, 0.392, 1.328, 0.729, 0.675, 0.707, 1.352, 1.046, -0.168, 0.761, 0.885, 0.801, 0.326, 0.581, 1.006, 0.124, 0.035, 0.373, 1.244, 0.924, -5.000, 0.061, 1.002, 0.134, -5.000, 0.134, 0.507, 0.454, -0.215, -0.383, 0.278, -1.525, 0.309, -0.383, 0.405, -0.391, -5.000, -1.323, 0.604, -0.529, -0.073, 0.032, 0.548, 0.605, -0.068, 0.435, 0.138, -1.171, -0.115, -0.196, 0.481, -0.347, -0.793, -0.504, 1.058, -0.505, -1.470, -0.361, 0.340, 0.056, -0.634, -0.477, -0.265, -1.696, -1.039, 0.435, 1.248, 0.335, 0.289, 0.656, 1.307, 1.152, -0.033, 1.075, 1.400, 1.178, 0.902, 0.513, 0.870, -0.516, -0.037, 0.714, 1.426, 1.301, -5.000, 0.914, 1.160, 0.273, -5.000, 0.795, 0.910, 0.927, 0.389, 0.280, 0.853, -0.584, 0.857, -0.817, 0.169, -0.301, -5.000, 0.137, 0.652, -0.805, -0.211, 0.117, 0.653, 0.597, 0.449, 0.278, -0.321, -1.569, -0.040, 0.146, 0.006, -0.261, -0.732, 0.301, 1.260, -0.517, -2.350, 0.668, 0.893, 0.833, 0.208, -0.434, -0.306, -1.498, -0.916, 0.699, 1.274, 0.564, 0.510, 1.032, 1.247, 1.084, 0.154, 1.108, 1.245, 0.852, 0.448, 0.604, 0.573, -1.070, -0.020, -0.330, 0.513, 0.185, -5.000, 0.388, 0.753, -0.466, -5.000, 0.081, -0.558, 0.109, -0.522, -0.584, -0.597, -2.350, -0.157, -1.718, -0.931, -1.893, -5.000, -1.514, 0.557, -1.616, -0.319, -2.336, -5.000, -0.773, -0.826, -0.274, -0.671, -3.421, -0.786, -1.255, -0.610, -2.295, -2.224, -2.075, 0.668, -2.058, -1.588, -1.177, -0.866, -0.158, -1.482, -1.959, -0.586, -1.415, -2.279, -0.365, 0.346, -1.561, -0.839, 0.114, 0.622, 0.227, -0.719, 0.102, 0.381, -0.056, -0.222, -1.155, -0.794, -1.628, -1.642, -0.152, 0.868, 0.314, -5.000, -0.669, 0.472, -0.686, -5.000, -0.374, 0.139, -0.083, -0.770, -0.722, -0.369, -1.675, -0.106, -0.872, 0.065, -0.546, -5.000, -1.654, -0.272, -1.817, -0.626, -1.148, -0.298, -0.419, -1.490, 0.084, -0.669, -2.291, -0.542, -1.309, -0.029, -1.028, -1.294, -2.748, 0.176, -0.939, -1.933, -1.652, 0.116, -0.689, -1.713, -1.564, -1.365, -2.284, -1.987, -0.080, 0.831, -0.230, -0.597, -0.130, 0.932, 0.831, -0.649, 0.342, 0.929, 0.741, 0.058, -0.204, 0.218, -0.876, -0.681 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

void initialize_metagenome_38(struct _training *tptr) {
  struct _training tinf = {
    0.694, 11, 4.350, { 0.542, 0.083, 2.375 }, { 1.311, -0.951, -2.291 }, 0, 
    { -0.216, -0.561, -0.504, -0.910, -4.000, 0.447, -1.198, -0.836, 0.514, 0.601, -1.183, -4.000, -1.082, -0.381, -0.880, 0.585, -0.456, -0.647, 0.915, 0.106, -1.142, 0.610, 0.683, 2.745, 1.363, -1.519, 3.280, 1.864 }, 
    {{ -0.765, -0.298, 0.333, 0.200},{ -0.360, 0.205, 0.057, -0.426},{ -0.197, 0.089, -0.163, 0.270},{ 0.049, 0.019, -0.169, 0.230},{ -0.098, 0.003, -0.054, 0.189},{ -0.072, -0.050, -0.028, 0.217},{ 0.094, -0.102, -0.136, 0.343},{ 0.016, -0.028, -0.042, 0.130},{ -0.098, 0.006, -0.005, 0.087},{ 0.139, -0.137, -0.045, 0.217},{ -0.057, 0.044, 0.001, -0.050},{ 0.009, -0.022, -0.028, 0.097},{ 0.148, -0.077, -0.031, 0.075},{ 0.009, 0.016, -0.008, -0.029},{ -0.113, 0.001, 0.009, 0.081},{ 0.068, -0.058, -0.090, 0.225},{ -0.025, 0.007, -0.018, 0.049},{ 0.068, -0.066, -0.009, 0.090},{ 0.157, -0.077, -0.080, 0.160},{ 0.059, 0.054, -0.093, 0.016},{ 0.078, -0.031, -0.023, 0.039},{ 0.127, -0.056, -0.115, 0.211},{ 0.029, -0.015, -0.017, 0.042},{ -0.029, -0.077, 0.032, 0.115},{ 0.174, -0.110, -0.169, 0.336},{ -0.079, 0.026, -0.036, 0.090},{ -0.043, -0.054, 0.001, 0.148},{ 0.163, -0.105, -0.054, 0.157},{ 0.068, 0.016, -0.070, 0.046},{ 0.012, -0.031, -0.026, 0.109},{ 0.039, -0.134, -0.006, 0.230},{ -0.005, 0.042, -0.009, -0.076} }, 
    {{{ -4.000, -4.000, -4.000, -4.000, -4.000, 0.518, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, 1.314, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}
   },{{ -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000},
   { -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000, -4.000}} }, 
    -0.332, { -0.168, 0.066, -1.144, -5.000, -1.016, -1.887, -1.285, -5.000, -1.296, -1.260, -2.195, -1.483, -0.672, -0.971, 0.470, -0.164, 0.294, 0.179, -0.560, -5.000, -1.340, -0.973, -1.155, -1.254, -0.612, -0.249, -1.721, -0.133, 1.073, 0.572, 1.017, 0.237, 0.866, 0.495, 0.259, 0.925, -0.267, 0.021, 0.196, -2.242, -0.404, 0.169, -0.409, -1.056, 0.513, -1.271, -0.100, 0.311, -0.672, -0.146, -0.826, -0.297, -2.653, -1.576, -1.662, -0.886, -0.267, -0.359, -1.015, -0.790, 0.801, 0.155, 0.311, 0.203, -0.832, -1.025, -1.300, -5.000, -1.278, -2.087, -2.187, -5.000, -0.802, -1.428, -2.586, -0.887, 0.876, -1.439, 0.915, 0.467, 0.850, 0.180, -0.196, -5.000, -0.235, -0.344, 0.355, 0.040, 0.602, 0.243, -0.022, 0.024, 1.139, 0.822, 0.856, 0.841, 0.804, -0.294, -1.307, 1.262, 0.351, -1.452, -0.508, -0.320, 0.544, -0.136, -0.075, -0.033, -0.384, 0.139, 0.386, -0.267, -2.618, -1.898, -2.039, 0.038, -1.621, -2.527, -1.643, -0.282, 0.131, -1.705, -2.091, -0.672, 1.425, -2.377, -1.406, 1.048, -0.752, -0.619, -1.917, -5.000, -1.464, -2.245, -3.544, -5.000, -0.189, -1.393, -2.597, -0.771, -0.084, -1.295, -2.314, -0.539, 0.267, -0.015, -0.410, -5.000, -0.375, -1.332, -1.092, 0.291, -0.133, -0.325, -1.323, -0.663, 1.162, 0.792, 0.537, 0.455, 0.735, -0.647, -1.556, 1.013, 0.041, -1.577, -1.265, -0.781, 0.330, -0.061, -0.863, -0.587, 1.185, -0.509, -0.624, 0.518, -0.991, -2.436, -3.053, 0.426, -2.079, -2.839, -2.275, -1.569, -1.548, -2.535, -2.886, -2.119, 0.272, -2.049, -2.174, -0.638, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -1.466, -0.775, -2.369, -5.000, -2.354, -2.665, -3.308, -5.000, -2.384, -1.648, -2.568, -2.385, 0.171, -0.844, -0.289, -1.222, -0.734, -0.217, -0.713, -5.000, -2.639, -2.253, -2.662, -2.969, -2.185, -0.696, -2.224, -0.713, 0.426, -0.048, 0.488, -1.203, -0.133, -0.644, -1.771, 0.021, -1.889, -2.119, -1.232, -2.915, -1.893, -1.671, -2.033, -2.220, -0.215, -0.241, 0.184, -0.672, -0.850, -1.702, -2.513, -0.861, -2.726, -3.249, -3.681, -3.843, -1.020, -0.722, -1.074, -1.323, -0.826, -0.339, -0.928, -0.790, -1.221, -1.371, -2.147, -5.000, -3.100, -3.105, -3.496, -5.000, -1.263, -2.223, -3.571, -2.691, -0.153, -1.208, -0.562, -0.983, -0.037, 0.075, -0.647, -5.000, -1.638, -1.153, -1.293, -1.422, -0.066, -0.742, -1.565, -0.528, 0.592, 0.302, 0.088, -0.182, -0.466, -0.545, -1.873, 0.767, -2.486, -2.250, -2.630, -2.464, -0.791, -1.239, -1.893, -1.166, 0.740, -2.279, -0.975, 0.354, -1.426, -2.124, -2.251, -0.637, -3.676, -2.872, -3.284, -2.285, -2.307, -2.979, -3.407, -2.913, -1.925, -2.591, -2.064, -1.775, -1.546, -2.009, -2.472, -5.000, -4.039, -3.299, -2.562, -5.000, -1.183, -3.513, -3.875, -2.371, -1.445, -1.864, -4.257, -2.009, -0.377, -0.457, -1.803, -5.000, -2.275, -2.782, -2.989, -2.286, -0.404, -0.570, -2.169, -2.642, 0.872, 0.374, -0.354, -0.375, -0.286, -0.838, -2.068, 0.226, -1.777, -2.713, -2.877, -2.562, -0.566, -1.303, -2.457, -1.963, -0.089, -0.957, -1.597, -0.928, 0.609, -1.588, -1.464, -5.000, -5.000, -0.490, -0.826, -5.000, -0.672, -2.767, -3.093, -5.000, -0.084, -0.752, -5.000, -0.826, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -1.937, -0.644, -1.406, -5.000, -2.033, -1.762, -1.519, -5.000, -2.991, -1.460, -4.037, -2.606, -0.133, -1.445, -0.490, -5.000, -0.400, 0.055, -1.232, -5.000, -1.895, -1.981, -1.491, -2.051, -3.059, -1.244, -2.333, -5.000, 0.203, 0.714, -0.585, -0.519, 0.449, 0.021, 0.309, 0.623, -1.068, -1.165, -0.767, -1.372, -1.810, -1.086, -1.237, -1.710, -0.347, -0.752, 0.614, 0.036, -5.000, -1.232, -1.483, -1.483, -3.693, -1.991, -2.099, -1.971, -1.937, -2.855, -2.316, -2.927, -0.133, -1.519, -1.020, -0.886, -1.183, -0.940, -2.131, -5.000, -2.272, -2.811, -2.623, -5.000, -1.889, -2.065, -3.141, -3.617, -0.548, -1.430, -0.020, -0.230, -0.186, 0.084, -0.672, -5.000, -1.995, -1.670, -1.342, -2.154, -1.261, -0.822, -1.893, -2.562, 0.218, -0.516, -0.392, -0.087, -0.384, -0.133, -1.065, 0.366, -1.829, -2.257, -1.504, -2.477, -0.958, -0.633, -1.759, -2.081, 0.692, -1.216, 0.488, -0.453, -0.672, -2.124, -1.901, 0.155, -1.078, -2.797, -2.765, -5.000, -1.884, -1.844, -3.053, -2.404, 0.426, -1.382, -0.939, -2.242, -1.988, -1.779, -2.748, -5.000, -3.933, -3.922, -3.500, -5.000, -4.260, -3.453, -3.975, -4.224, -0.623, -2.775, -2.642, -0.853, -1.041, -1.820, -2.298, -5.000, -2.924, -3.028, -3.103, -3.596, -2.452, -2.537, -3.230, -3.790, -0.452, -1.497, -1.959, -1.351, -0.457, -0.839, -2.279, -0.392, -2.246, -2.616, -2.550, -2.559, -1.307, -1.433, -1.810, -2.102, -0.182, -1.716, -1.636, -1.727, -1.851, -2.180, -4.783, -0.456, -3.096, -3.623, -3.567, -4.066, -3.300, -3.216, -3.730, -3.662, -0.202, -2.252, -2.252, -2.170, -1.255, -1.483, -5.000, -5.000, -3.676, -3.903, -2.860, -5.000, -3.178, -3.818, -2.974, -3.787, -5.000, -0.790, -0.713, -1.301, -0.895, -1.158, -0.212, -5.000, -3.020, -2.631, -1.680, -2.977, -2.572, -2.037, -2.300, -2.125, -1.537, -0.020, -1.771, 0.075, -0.866, -0.713, -0.878, -0.210, -2.322, -2.230, -2.511, -2.426, -2.550, -2.045, -2.429, -3.190, -1.416, -0.854, -0.202, -1.625, -5.000, -1.483, -5.000, -5.000, -3.055, -2.320, -3.422, -3.684, -3.608, -3.136, -3.938, -3.303, -5.000, -1.344, -1.067, -2.518, -0.097, 0.370, -0.771, -5.000, -0.287, -0.307, -1.876, -5.000, -0.327, -0.861, -0.782, -0.384, -0.202, -0.097, -5.000, -5.000, 0.570, 0.676, -0.084, -5.000, -0.421, 0.172, 0.418, 0.391, 0.331, -0.403, -0.741, -5.000, 0.078, 0.617, 0.573, 0.581, 1.024, 1.120, -0.012, 1.237, 0.121, 0.513, 0.904, -0.539, 0.554, 1.097, 0.671, 0.434, 0.049, 1.120, 0.859, 0.626, -0.033, -0.790, -0.826, -5.000, -0.534, -0.240, -0.059, -0.384, -0.523, -1.059, -0.404, -2.248, -0.960, -0.097, 0.522, 0.108, -1.003, -2.302, -2.369, -5.000, -1.166, -2.530, -2.642, -5.000, -5.000, -1.429, -2.758, -1.232, -1.278, -2.166, 0.501, 0.560, -0.028, -1.357, -2.106, -5.000, -0.484, -1.106, -0.250, -0.087, -0.196, -1.248, -1.815, -1.278, 0.519, -0.494, -0.922, -0.479, 0.021, -1.421, -2.283, 0.581, 0.021, -2.277, -1.311, -1.426, 0.684, -1.186, -1.255, -0.332, 0.446, -2.209, -1.538, 0.203, -1.537, -2.767, -3.125, 0.139, -0.767, -1.845, -1.510, -5.000, -5.000, -1.648, -1.155, -0.490, -0.033, -3.070, -1.793, -0.327, -0.384, -1.519, -2.158, -5.000, -0.339, -2.553, -2.207, -5.000, -0.456, -1.376, -2.386, 0.155, 0.090, -1.066, -2.364, -1.519, -0.023, 0.356, -0.482, -5.000, -0.164, -0.517, -0.441, -0.036, -0.752, -0.841, -1.678, -1.293, 0.191, 0.671, 0.134, 0.203, 0.366, 0.278, -1.601, 1.120, 0.041, -0.630, -0.672, -0.741, 0.651, 0.796, -0.479, -0.127, 0.587, 0.972, 0.506, 0.665, -5.000, -1.445, -2.857, 0.609, -1.555, -2.404, -2.767, -1.247, -0.840, -1.590, -2.112, -1.166, -0.611, -0.458, -1.138, -0.928, 0.203, -5.000, -5.000, -5.000, 0.108, -0.506, -0.630, -5.000, -0.490, -1.771, -1.247, 0.139, 0.309, -1.232, 0.155, -0.585, 0.469, 0.714, 0.478, -5.000, -0.696, -0.553, -0.730, 0.203, -1.232, 0.230, -0.995, -1.483, -0.059, 0.255, 0.391, -0.267, 0.070, 0.714, -0.470, 0.452, -1.164, -1.198, -0.291, -1.379, 0.405, 0.454, -0.307, -0.543, -0.585, 1.105, 1.008, -0.029, -0.133, 0.175, -0.991, 0.203, -0.529, -1.637, -1.020, -1.406, 0.003, -1.089, -1.575, -1.461, -0.878, -0.985, 0.026, 0.440, 0.389, 0.742, -0.373, -5.000, -0.324, -0.638, -0.384, -5.000, -0.902, -0.666, -1.150, -1.554, 0.021, -0.634, 1.203, 0.595, 0.771, 1.202, 0.623, -5.000, -0.334, 0.133, 0.121, -0.314, -0.956, -0.322, -0.904, -0.327, 0.797, 1.073, 1.381, -0.037, 1.491, 1.592, 1.178, 1.675, 1.013, 1.178, 1.070, 0.654, 1.061, 1.334, 0.925, 0.305, 1.615, 1.385, 1.531, 1.362, 0.118, 0.133, -0.752, 0.609, -0.012, -0.374, -0.070, -0.510, -0.644, -0.284, -0.751, -0.592, 1.287, 0.528, 0.660, 0.288, 0.041, -0.307, -0.143, -5.000, -0.503, -0.960, -0.836, -5.000, 0.560, -0.124, -1.054, -0.356, 1.463, -1.213, 1.131, 0.823, 1.249, 0.910, 0.780, -5.000, 0.691, 0.981, 1.408, 1.009, 1.224, 1.025, 0.781, 0.537, 1.234, 1.434, 1.476, 1.229, 1.556, 1.075, 0.491, 1.747, 1.405, -0.367, 0.587, 1.042, 1.429, 1.277, 1.177, 1.038, 1.559, 1.120, 1.039, 0.540, -1.531, -1.704, -1.691, 0.434, -0.373, -2.015, -1.438, 0.068, -0.072, -0.283, -0.596, -0.247, 1.704, -1.059, -0.493, 1.526, 0.100, 0.622, 0.130, -5.000, -0.585, -0.148, -1.308, -5.000, -0.180, -0.533, -1.635, -1.406, -0.672, -0.800, -0.616, 0.293, 1.146, 1.211, 1.277, -5.000, 0.577, 0.197, 0.803, 1.137, 0.438, -0.195, -1.003, -0.779, 1.494, 1.186, 0.957, 0.634, 1.081, 0.617, -0.325, 1.365, 0.509, -0.014, 0.313, 0.110, 0.921, 0.882, 0.259, 0.301, 1.273, 0.202, 0.152, 0.875, -1.078, -1.183, -2.221, 0.478, 0.064, -1.096, -0.063, -1.278, -0.539, -0.849, -1.364, -0.611, 0.883, -1.154, -0.259, 0.540, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -5.000, -0.540, 0.830, -0.284, -5.000, -1.792, -0.974, -1.408, -5.000, -1.716, -1.031, -2.029, -2.860, 0.813, -0.246, 0.781, -0.129, -0.936, 0.310, 0.257, -5.000, -1.755, -0.761, -0.730, -2.100, -1.486, -0.491, -1.319, -1.680, -0.674, -0.255, 1.005, -0.768, -0.189, 0.698, 0.036, 0.637, -1.674, -0.386, 0.007, -1.666, -1.821, -0.583, -0.643, -2.009, -0.413, 0.350, 0.861, -1.143, -0.975, 0.116, -0.485, 0.142, -2.752, -1.794, -2.316, -2.316, -0.826, -0.004, -0.201, -0.689, 0.386, 0.184, 0.792, 0.051, -0.571, 0.186, -0.586, -5.000, -2.277, -1.457, -1.980, -5.000, -0.218, -0.935, -2.648, -2.116, -0.064, -0.951, 0.373, -0.524, 0.493, 1.011, 0.469, -5.000, -1.020, 0.276, 0.047, -0.935, 0.291, 0.531, -0.541, -0.481, 0.614, 1.143, 0.997, 0.276, 0.872, 0.907, -0.038, 1.499, -0.669, -0.219, -0.614, -1.259, 0.080, 0.450, -0.316, -0.595, 1.535, -1.095, 0.305, 0.907, -0.644, -1.252, -1.864, 0.160, -1.732, -1.942, -2.297, -2.206, -2.052, -1.369, -1.914, -1.935, 0.346, -1.349, -0.305, -0.416, -0.100, 0.682, -0.370, -5.000, -2.474, -1.476, -1.347, -5.000, -2.195, -2.125, -3.410, -3.941, -0.109, -0.760, -1.317, -0.884, 0.665, 1.445, 0.819, -5.000, -0.565, -0.209, -0.368, -0.548, -0.222, 0.599, -1.311, -1.812, 0.700, 1.372, 0.823, 0.054, 1.137, 1.438, 0.428, 1.503, 0.053, 0.481, 0.106, -0.878, 0.246, 0.802, -0.494, -0.517, 1.124, 0.965, 0.590, 0.820, -0.356, -0.931, -1.688, 0.404, -2.733, -1.796, -2.191, -2.738, -2.014, -2.501, -3.014, -2.496, 0.698, -0.691, -0.548, -0.756, -0.401, -0.186, -1.169, -5.000, -2.613, -1.853, -3.095, -5.000, -1.777, -1.731, -2.520, -3.109, -0.059, -0.365, -0.346, -0.591, 0.558, 1.381, 0.876, -5.000, -2.123, -1.379, -1.434, -1.756, -2.393, -1.249, -2.424, -2.958, 0.334, 0.400, 0.622, -0.631, 0.464, 1.367, 1.050, 1.105, -0.991, 0.267, 0.481, -1.925, -0.736, 0.112, -0.742, -1.478, 0.347, 0.985, 1.205, 0.153, -0.960, 0.007, -0.023, 0.381, -1.296, -1.658, -1.648, -1.957, -1.418, -1.340, -1.823, -2.211, -0.247, -0.309, 0.520, -1.236, -0.904, 0.307, -0.267, -5.000, -1.986, -0.873, -1.216, -5.000, -2.126, -1.921, -3.494, -3.022, 0.064, -0.836, -0.015, -0.672, 0.312, 1.064, 0.760, -5.000, -1.602, -0.075, -0.412, -1.147, -1.902, -0.471, -1.968, -0.826, 0.243, 0.667, 0.699, -0.990, 0.834, 1.475, 1.094, 1.337, -0.946, 0.430, 0.264, -0.784, -0.230, 0.382, -0.002, -1.012, 0.415, 0.928, 1.301, 0.047, -0.428, 0.068, -0.149, -0.059, -3.748, -1.841, -0.657, -1.540, -4.690, -2.881, -2.653, -2.794, -0.291, -0.202, 0.112, -1.257, -0.913, -0.638, -1.292, -5.000, -1.808, -1.440, -2.230, -5.000, -3.293, -1.012, -2.344, -1.928, -0.523, -1.982, 0.095, -0.861, 0.481, 0.924, 0.362, -5.000, -0.919, 0.379, 0.419, -0.544, -0.091, 0.300, -0.477, -0.879, 0.346, 0.975, 0.953, 0.135, 0.959, 0.918, 0.409, 1.490, 0.197, -0.407, 0.120, -1.199, 0.207, 0.570, -0.073, -0.795, 1.407, -0.199, 1.043, 0.658, -1.287, -1.572, -1.448, -0.003, -1.239, -2.276, -1.899, -1.684, -0.640, -0.915, -1.430, -2.456, 0.021, -1.389, -0.117, -0.387, -1.385, -1.337, -1.699, -5.000, -2.670, -2.462, -2.101, -5.000, -3.094, -2.876, -2.722, -4.275, -0.560, -2.030, -2.280, -1.239, -0.589, -0.354, -0.445, -5.000, -1.562, -1.014, -0.911, -1.707, -1.210, -1.243, -1.752, -2.924, 0.030, 0.444, 0.342, -0.963, 0.631, 0.319, -0.977, 0.939, -0.838, -1.425, -1.057, -1.625, -0.201, -0.374, -0.514, -1.211, 0.348, -0.401, -0.907, -0.919, -0.414, -1.604, -2.447, -0.093, -1.793, -2.331, -2.142, -1.933, -2.923, -2.007, -2.062, -3.108, -0.003, -0.988, -1.340, -2.002, -0.922, -0.180, -0.456, -5.000, -2.853, -2.325, -5.000, -5.000, -2.814, -2.577, -3.213, -3.549, -5.000, -0.939, -1.096, -0.861, -0.036, 0.907, 0.431, -5.000, -1.661, -1.502, -1.226, -0.826, -1.549, -2.109, -1.598, -2.110, -0.271, -0.848, -0.615, -1.059, -0.519, 0.758, 0.217, 0.192, -2.264, -0.706, -0.553, -1.391, -1.255, -0.823, -1.031, -2.086, -0.666, 0.623, 1.072, -0.816, -0.585, -0.406, -0.362, -0.084, -3.283, -1.542, -0.656, -1.743, -3.549, -1.754, -1.765, -2.615, -0.230, -0.009, 0.309, -1.139, -0.088, 1.076, 0.300, -5.000, -0.534, 0.261, 0.426, -5.000, -0.366, 0.171, -1.035, -1.561, -0.173, -0.539, 0.463, 0.426, 0.656, 1.421, 1.130, -5.000, -0.299, 0.770, 0.483, 0.107, -1.201, -1.096, -1.543, -1.059, 0.642, 0.958, 1.128, -0.776, 1.120, 1.424, 1.191, 1.300, 0.059, 0.855, 0.902, -0.466, 0.576, 1.101, 0.596, 0.131, 0.969, 1.108, 1.518, 0.965, -0.084, 0.179, -0.267, 0.783, -0.562, -0.023, -0.400, -0.384, -5.000, -0.347, -0.696, -1.925, -5.000, 0.259, 0.512, 0.337, 0.167, -0.201, -0.317, -5.000, 0.006, -0.963, -1.025, -5.000, 0.021, -0.253, -1.775, -0.202, -0.059, -1.724, 0.560, 0.668, 1.191, 1.396, 1.089, -5.000, -0.060, 1.067, 1.318, 0.788, 0.944, 1.113, 0.498, -0.103, 1.068, 1.454, 1.509, 0.756, 1.649, 1.494, 1.048, 1.748, 1.451, 0.756, 0.990, 1.192, 1.079, 1.248, 0.947, 0.466, 1.666, 0.282, 1.295, 1.604, 0.568, -0.574, -1.251, 1.212, 0.325, -0.733, -0.688, -0.384, 0.108, 0.379, -0.032, -0.672, 1.051, -0.545, 0.507, 0.807, 0.052, -0.131, -0.384, -5.000, -0.232, -1.187, -0.974, -5.000, -0.861, -0.519, -5.000, -0.347, -0.212, -1.549, -1.642, -0.895, 1.066, 1.114, 0.881, -5.000, 0.636, 0.526, 0.941, 0.921, 0.077, 0.184, -1.104, -1.292, 1.340, 1.324, 0.361, 0.585, 1.614, 1.396, 0.669, 1.719, 1.016, 0.605, 0.962, 0.663, 1.556, 1.518, 0.962, 1.024, 1.549, 1.328, 1.160, 1.361, -0.224, -0.515, -0.767, 1.382, 0.452, -1.065, -0.451, -0.133, -0.356, -0.262, -0.630, -0.227, 1.355, 0.530, 0.918, 1.257, -0.630, 0.714, -0.267, -5.000, -2.005, -0.804, -5.000, -5.000, -2.485, -1.426, -2.016, -3.125, 0.832, 0.021, 0.671, -1.232, -1.049, 0.282, -0.259, -5.000, -1.105, -0.536, -0.252, -0.851, -1.336, -0.221, -0.989, -1.443, -1.331, 0.455, 0.749, -0.764, -1.132, 0.270, -0.237, 0.051, -1.316, -0.740, -0.304, -1.120, -0.035, 0.785, 0.584, -0.435, -0.218, 0.793, 1.067, -0.001, 0.272, 0.701, 0.133, 1.453, -1.450, -0.605, -0.044, -0.713, -0.740, 0.139, -0.267, -1.165, 0.935, 0.840, 1.289, 0.942, 0.784, 1.208, 0.559, -5.000, -0.031, -0.086, -0.009, -5.000, 0.139, -0.076, -0.732, -1.613, 0.118, -0.190, 0.965, 0.992, 1.212, 1.455, 1.166, -5.000, 0.186, 0.894, 0.861, 0.497, 0.234, 0.745, 0.150, -0.241, 1.199, 1.584, 1.564, 0.668, 1.638, 1.667, 1.563, 1.734, 0.860, 1.491, 1.410, 0.960, 1.499, 1.588, 1.477, 1.331, 1.697, 1.559, 1.643, 1.651, 1.120, 0.426, 0.164, 0.596, -0.202, -0.164, -0.384, -0.133, -0.267, 0.540, -0.152, -0.157, 1.177, 0.832, 0.103, 1.211, 0.183, -0.659, -0.463, -5.000, -0.195, -1.444, -1.829, -5.000, 0.955, -0.810, -1.603, -0.384, 1.462, -1.686, 1.108, 1.189, 1.432, 0.801, 0.541, -5.000, 0.798, 1.010, 1.290, 1.349, 1.526, 1.054, 0.612, 1.085, 1.497, 1.425, 1.434, 1.403, 1.641, 1.482, 1.397, 1.756, 1.392, 0.879, 1.390, 1.336, 1.611, 1.624, 1.544, 1.505, 1.484, 0.426, -5.000, 0.426, -1.960, -1.610, -1.861, -0.421, -0.960, -2.138, -1.948, 0.164, -0.133, -0.093, -0.635, -0.059, 1.713, -0.729, -0.185, 1.666, 0.224, -0.145, -1.442, -5.000, -0.554, -1.254, -2.012, -5.000, -0.928, -2.239, -2.206, -1.020, -1.588, -1.434, -2.024, -1.351, 1.188, 0.908, 0.393, -5.000, 0.635, 0.092, 0.279, 1.372, -0.593, -1.428, -2.151, -1.012, 1.458, 0.888, 0.408, 0.119, 1.153, 0.228, -0.685, 1.438, 0.752, -0.486, 0.108, 0.731, 1.293, 0.757, 0.031, 0.457, 1.380, 0.399, 0.138, 0.962, -1.464, -2.172, -2.487, 0.131, -1.323, -2.594, -1.759, -5.000, 0.139, -1.953, -2.308, -0.490, 0.944, -1.785, -1.201, 0.466, 0.179, 1.048, 0.175, -5.000, -0.693, 0.021, -0.091, -5.000, -0.895, -1.278, -1.118, -0.868, -1.445, -0.267, 0.130, -0.523, 1.524, 1.680, 1.459, -5.000, -0.304, 1.340, 1.038, 1.122, -0.774, 0.021, -0.665, -1.545, 1.163, 1.091, 0.992, -0.156, 1.746, 1.759, 1.689, 1.735, 1.597, 1.621, 1.713, 1.195, 1.724, 1.715, 1.556, 1.488, 1.752, 1.718, 1.711, 1.698, -5.000, 1.215, 0.021, 0.915, 0.843, 0.884, 1.149, -0.347, 0.957, 0.655, 0.782, -0.151, 1.542, 1.023, 1.502, 1.376, 0.093, 0.535, 0.162, -5.000, -1.548, -0.097, -0.880, -5.000, -1.234, 0.027, -0.999, -1.494, 0.287, 0.319, 0.523, 0.052, 0.565, 0.996, 0.661, -5.000, -1.187, 0.081, -0.040, -1.160, -0.211, 0.569, -0.596, -1.158, 0.533, 1.014, 0.678, -0.498, 1.188, 1.396, 0.916, 1.593, -0.690, 0.045, -0.173, -0.557, 0.122, 0.375, -0.522, -0.632, 1.335, 0.628, 0.781, 1.015, 0.509, -0.099, -0.347, 0.705, -1.001, -1.992, -2.139, -2.450, 0.021, -0.161, -0.623, 0.045, 0.678, -0.153, 0.063, 0.288, -0.912, -0.583, -1.199, -5.000, -2.654, -2.026, -2.975, -5.000, -0.568, -1.028, -2.415, -2.261, -0.419, -1.870, 0.411, -0.099, 0.409, 0.211, -0.397, -5.000, -0.553, -0.262, 0.161, -0.371, 0.660, 0.239, -0.759, 0.063, 0.938, 1.002, 0.830, 0.769, 1.242, 0.741, -0.013, 1.632, -0.040, -0.835, -0.470, -0.132, 0.472, 0.398, -0.302, 0.141, 1.623, -1.174, 0.493, 1.459, -0.982, -2.047, -2.141, -0.079, -2.366, -2.641, -3.300, -1.472, -2.158, -1.870, -2.371, -1.981, 0.315, -1.708, -1.117, -0.058, -0.366, 0.013, -1.332, -5.000, -1.775, -1.957, -1.847, -5.000, -1.301, -1.873, -2.814, -2.418, -0.802, -1.065, -2.045, -0.800, 0.715, 1.247, 0.685, -5.000, -0.167, -0.053, 0.305, 0.119, -0.286, 0.239, -1.565, -1.348, 0.978, 1.418, 1.193, 0.540, 1.229, 0.886, -0.195, 1.469, 0.459, -0.140, 0.052, -0.358, 0.310, 0.705, -0.528, -0.234, 1.234, 0.737, 0.640, 1.079, -0.975, -2.347, -2.814, 0.290, -1.851, -1.433, -1.135, -1.244, -1.298, -2.725, -3.192, -2.136, 0.070, -1.258, -0.875, -0.040, -0.878, -0.909, -2.119, -5.000, -3.767, -2.267, -2.865, -5.000, -3.059, -2.473, -2.270, -3.431, -0.384, -1.055, -1.359, -0.439, 0.281, 1.001, 0.579, -5.000, -2.158, -0.921, -1.215, -1.948, -2.127, -1.510, -2.566, -2.310, 0.057, 0.225, -0.166, -0.882, 0.497, 1.086, 0.749, 1.020, -0.258, 0.209, 0.173, -0.490, -0.301, 0.207, -0.777, -1.193, 0.396, 1.026, 0.964, 0.066, -0.202, -0.113, -1.621, -0.168, -1.595, -1.499, -1.095, -2.153, -1.672, -1.985, -2.149, -2.053, -0.585, -0.813, -0.356, -1.037, -0.384, 0.804, -0.387, -5.000, -1.754, -0.524, -1.107, -5.000, -2.359, -1.276, -2.351, -2.706, 0.321, 0.128, -0.055, -0.237, 0.630, 1.210, 0.912, -5.000, -1.016, 0.114, -0.102, -0.793, -1.323, -0.221, -1.771, 0.203, 0.714, 1.052, 1.173, -0.819, 1.359, 1.607, 1.322, 1.540, -0.223, 0.893, 0.453, -0.009, 0.086, 0.469, 0.138, -0.553, 1.025, 1.300, 1.534, 0.852, -0.280, -0.202, -0.955, 0.111, -2.098, -1.226, -1.906, -2.802, -2.468, -1.960, -1.754, -2.428, 0.463, 0.123, 0.450, -0.403, -1.321, -0.496, -0.909, -5.000, -2.061, -1.350, -2.357, -5.000, -0.977, -0.680, -2.579, -2.676, -0.718, -1.433, 0.179, -0.129, 0.749, 1.254, 0.807, -5.000, -0.457, 0.697, 0.672, -0.283, 0.103, 0.756, -0.325, -0.680, 0.657, 1.369, 1.309, 0.594, 1.456, 1.427, 0.911, 1.679, 0.359, 0.178, 0.587, -0.418, 0.470, 0.869, 0.187, -0.285, 1.687, 0.850, 1.465, 1.476, -0.177, -0.785, -1.336, 0.594, -0.866, -2.259, -1.656, -2.195, -1.082, -0.748, -1.456, -1.385, 1.106, -1.571, 0.286, 0.642, -0.706, -0.328, -1.052, -5.000, -2.748, -2.125, -1.828, -5.000, -2.018, -2.487, -2.614, -3.182, -0.366, -1.294, -1.141, -0.502, 0.259, 0.952, 0.598, -5.000, -0.685, -0.514, -0.310, -0.881, -0.608, -0.239, -0.733, -2.128, 0.683, 1.079, 1.091, -0.119, 0.992, 1.065, -0.018, 1.104, -0.029, -0.104, -0.177, -0.631, 0.355, 0.379, -0.256, -0.529, 0.984, 0.612, 0.557, 0.550, -0.287, -0.871, -1.255, 0.560, -1.624, -1.220, -1.250, -1.624, -1.355, -1.313, -1.527, -2.293, 0.868, 0.056, 0.533, 0.096, -0.950, -0.327, -0.868, -5.000, -2.552, -3.167, -3.336, -5.000, -2.592, -2.759, -2.855, -3.342, -0.473, -0.567, -0.401, -0.483, -0.130, 0.935, 0.380, -5.000, -1.954, -1.416, -1.175, -1.536, -2.169, -1.743, -2.200, -2.318, -0.313, -0.301, 0.002, -1.059, -0.058, 1.137, 0.472, 0.579, -1.461, -0.143, -0.392, -1.314, -1.001, -0.660, -0.956, -1.835, 0.118, 0.963, 1.339, 0.102, -0.180, -0.152, -1.007, 0.203, -2.501, -1.176, -0.854, -1.986, -2.102, -1.727, -1.562, -2.154, -0.334, 0.356, 0.811, -0.469, 0.684, 1.055, 0.388, -5.000, -0.428, 0.574, -0.224, -5.000, 0.287, 0.021, -0.686, -1.278, -0.267, 0.070, 0.391, -0.384, 1.359, 1.656, 1.480, -5.000, 0.378, 1.219, 1.039, 0.696, -0.172, -0.123, -1.132, -1.588, 1.043, 1.380, 1.391, 0.066, 1.482, 1.642, 1.452, 1.627, 0.421, 1.427, 1.348, 0.422, 1.242, 1.509, 1.338, 0.834, 1.386, 1.527, 1.636, 1.296, 0.560, 0.948, 0.402, 0.714, -0.384, 0.021, 0.309, 0.155, 0.426, -0.534, -0.497, -0.913, 0.643, 0.663, 0.731, 0.634, -0.985, -1.227, -0.366, -5.000, -0.473, -1.210, -2.906, -5.000, 0.203, -1.020, -2.119, -1.114, -0.456, -2.353, 0.155, 0.501, 1.121, 0.929, 0.390, -5.000, 0.345, 0.705, 1.182, 0.831, 1.023, 0.752, -0.567, 0.326, 1.161, 1.391, 1.269, 1.102, 1.605, 1.071, 0.283, 1.706, 1.237, 0.215, 0.840, 0.708, 1.099, 0.997, 0.598, 0.527, 1.604, 0.196, 0.996, 1.531, -0.421, -1.292, -1.081, 0.689, -0.490, -1.624, -1.199, -1.365, 0.560, -0.467, -0.469, -1.743, 0.108, -1.208, -0.623, 0.855, -0.100, 0.067, -0.333, -5.000, 0.034, -0.660, -1.317, -5.000, 0.118, -2.367, -2.602, -2.582, -0.400, -2.471, -0.863, -0.490, 0.923, 1.061, 0.868, -5.000, 1.046, 0.612, 1.075, 1.251, -0.260, -0.328, -2.184, -1.328, 1.449, 0.985, 0.633, 0.588, 1.485, 1.162, 0.227, 1.680, 1.050, 0.554, 0.817, 0.443, 1.449, 1.401, 0.748, 0.775, 1.503, 1.258, 1.181, 1.360, -1.013, -2.085, -1.991, 0.787, -0.439, -1.476, -1.489, -0.861, -0.384, -1.096, -1.721, -1.028, 0.998, -0.238, 0.375, 0.919, 0.532, 0.634, -1.365, -5.000, -0.412, -0.481, -1.278, -5.000, -0.585, -0.726, -1.033, -2.464, -0.235, -0.861, -0.101, -0.752, 1.169, 1.477, 1.366, -5.000, -0.592, 0.533, 0.524, 0.860, -1.779, -0.689, -1.379, -1.567, 1.021, 0.433, 0.540, -0.213, 1.357, 1.631, 1.310, 1.474, 0.399, 0.805, 1.160, -0.143, 0.894, 1.126, 0.715, -0.032, 1.217, 1.448, 1.539, 1.195, -0.020, 0.293, -0.658, 0.370, -0.593, -0.621, -0.006, -1.049, -0.363, -0.991, -1.186, -1.180, 0.190, -0.147, 0.850, 0.449, -0.267, 0.121, -1.066, -5.000, -0.700, -0.922, -2.176, -5.000, -0.059, -5.000, -1.714, -0.991, 0.021, -0.439, 0.064, -0.133, 0.544, 0.187, -0.980, -5.000, -0.767, -0.895, -0.077, -0.048, 0.366, -0.490, -1.247, -0.084, 0.783, 0.458, 0.372, 0.272, -0.133, 0.668, -0.202, 0.255, -5.000, -0.175, 0.244, -0.267, 0.055, 0.372, 0.289, 0.155, 1.120, -2.459, -1.899, -0.267, -5.000, -0.168, -0.928, -0.267, -5.000, -0.567, -0.802, -0.133, -5.000, 0.090, -0.713, -0.826, 0.000, 0.078, -1.278, -0.585, -1.490, -1.812, -2.146, -5.000, -1.495, -3.148, -2.659, -5.000, -0.059, -1.907, -2.518, -0.515, 0.426, -2.112, -0.297, 0.287, -0.246, -1.281, -1.528, -5.000, -0.874, -1.224, -0.993, 0.000, 0.064, -1.534, -1.908, 0.093, 0.513, -0.444, -0.751, -0.049, 0.399, -1.106, -2.058, 0.925, 0.280, -2.843, -0.523, -0.917, 0.628, -0.883, -0.633, 0.618, 0.783, -1.406, -0.470, 0.309, -0.721, -3.657, -2.016, 0.049, -0.133, -2.830, -3.556, -5.000, -1.278, -1.763, -2.533, -0.726, 0.139, -1.761, -1.861, 0.413, -1.971, -2.413, -2.119, -5.000, -1.386, -2.485, -2.505, -5.000, -1.078, -1.971, -3.655, -1.948, -0.267, -3.867, -3.102, -1.365, -0.275, -1.547, -1.524, -5.000, -0.700, -1.514, -1.907, -0.334, -0.352, -1.967, -2.680, -1.208, 0.832, -0.861, -2.003, -0.630, -0.826, -1.441, -2.483, -0.012, -1.020, -2.379, -1.923, -1.035, -0.005, -1.171, -1.399, -1.265, 0.881, -0.988, -1.385, -0.876, -5.000, -5.000, -4.382, 0.078, -0.033, -2.809, -3.191, -5.000, -1.183, -3.428, -2.693, -1.308, 0.272, -2.444, -2.887, -1.278, 0.783, 0.325, -0.672, -5.000, -0.384, -0.655, -0.074, -5.000, 0.896, -0.790, -1.445, -1.078, 0.203, -0.752, 0.203, -0.384, -0.506, 0.362, 0.327, -5.000, -0.439, 0.462, 0.220, -0.267, 0.469, -0.397, -0.648, -0.752, 0.832, 1.184, 0.937, 0.203, 0.965, 1.154, 0.164, 1.120, 0.657, 0.401, 0.924, -0.078, 0.989, 1.067, 0.171, 0.386, 0.783, 0.161, 0.136, 0.728, -5.000, -0.267, -2.119, 0.491, 0.560, -0.623, -0.917, -5.000, -0.307, -0.406, -1.089, -1.621, 0.532, -0.133, 0.232, 0.339, -1.096, -0.833, -1.487, -5.000, -3.742, -2.439, -2.855, -5.000, -1.733, -0.978, -2.192, -1.684, -0.307, -0.777, -0.151, -0.960, -0.428, 0.126, 0.203, -5.000, -2.346, -1.691, -1.968, -3.300, -2.377, -0.941, -3.193, -1.078, 0.689, 0.986, -0.133, -1.548, 0.309, 0.272, 0.108, 0.203, -2.594, -0.928, -1.595, -2.290, -1.884, -1.359, -1.696, -2.056, 0.108, -0.133, -0.477, 0.131, -5.000, -5.000, -0.895, -1.621, -2.109, -3.672, -3.304, -3.728, -5.000, 0.021, -1.049, -5.000, 0.714, -0.960, -0.133, -1.365, -2.653, -1.914, -2.228, -5.000, -2.678, -2.477, -3.252, -5.000, -1.222, -2.763, -3.515, -3.862, -0.844, -2.268, 0.021, -1.089, -0.901, -1.309, -1.670, -5.000, -1.711, -1.654, -2.122, -1.448, -0.602, -1.579, -2.506, -1.397, 0.547, -0.723, -0.751, -0.192, -0.602, -1.454, -2.282, 0.158, -1.760, -2.564, -1.803, -2.057, -0.718, -1.534, -2.526, -1.355, 0.737, -2.063, -1.372, 0.248, -1.379, -2.349, -2.825, -0.719, -1.817, -3.007, -3.047, -2.216, -1.884, -2.592, -3.208, -2.655, -0.861, -1.697, -2.163, -1.532, -1.642, -1.597, -2.499, -5.000, -2.780, -3.468, -2.935, -5.000, -2.464, -3.003, -4.473, -5.000, -0.630, -2.209, -2.795, -2.676, -0.500, -0.665, -1.681, -5.000, -1.870, -2.520, -2.150, -2.258, -0.741, -1.259, -2.657, -1.445, 0.880, 0.722, -0.279, 0.021, -0.802, -1.247, -2.178, 0.664, -1.278, -2.066, -1.803, -2.063, -0.269, -1.042, -2.336, -1.719, 0.955, -0.946, -1.302, -0.409, -1.020, -3.307, -3.887, -1.278, -5.000, -2.599, -2.819, -5.000, -3.763, -3.084, -4.125, -3.363, -0.327, -1.963, -3.072, -1.210, -1.743, -0.873, -3.178, -5.000, -2.622, -3.062, -4.424, -5.000, -5.000, -2.653, -3.243, -3.520, -0.490, -5.000, -5.000, -1.232, -1.040, -0.693, -1.555, -5.000, -2.716, -1.941, -2.758, -3.162, -1.078, -1.994, -3.293, -2.099, -1.078, 0.576, -1.278, -0.412, -0.585, 0.203, -5.000, 0.896, -2.256, -2.481, -1.096, -1.483, -0.347, -0.316, -1.391, -0.858, -0.752, 0.262, 0.000, -0.291, -0.585, -5.000, -1.464, -5.000, -2.991, -2.359, -3.917, -2.298, -2.138, -2.983, -2.671, -3.078, -0.752, -1.653, -1.007, -1.519, -1.193, -0.998, -1.920, -5.000, -3.024, -3.107, -2.436, -5.000, -5.000, -1.259, -5.000, -2.676, -0.539, -1.555, 0.078, -0.202, -0.282, 0.372, -1.851, -5.000, -2.582, -2.828, -2.016, -2.249, -2.772, -1.003, -2.733, -0.672, 0.255, 0.469, 0.469, -0.539, 0.801, 0.522, 0.458, 0.513, -1.355, -0.510, -0.412, -1.588, -1.817, -1.267, -2.184, -1.661, -0.133, 0.650, 0.415, 0.171, -1.232, -0.384, -1.255, -0.160, -3.693, -1.943, -3.342, -3.693, -2.802, -2.569, -3.262, -3.237, -0.585, -0.490, -0.368, -1.044, -2.073, -1.913, -2.601, -5.000, -3.155, -3.210, -3.579, -5.000, -1.563, -2.701, -2.719, -2.103, -1.078, -1.645, -0.384, -0.518, -0.765, -0.761, -1.094, -5.000, -1.739, -1.625, -1.460, -2.246, -1.789, -1.351, -2.190, -1.959, -0.065, -0.346, -1.052, -0.165, -0.210, -0.697, -1.233, 0.765, -2.235, -1.837, -0.752, -2.563, -1.217, -0.837, -1.864, -1.793, 0.919, -0.600, -0.184, 0.311, -2.099, -1.495, -2.407, 0.121, -1.642, -2.235, -2.578, -1.761, -2.188, -1.523, -2.017, -2.176, 0.589, -1.086, -0.787, -1.471, -1.237, -2.214, -3.142, -5.000, -3.005, -2.919, -2.632, -5.000, -2.562, -3.156, -3.441, -2.879, -0.726, -1.994, -2.507, -2.050, -1.191, -0.969, -1.405, -5.000, -2.011, -2.133, -2.256, -2.231, -1.711, -1.872, -2.525, -2.531, 0.250, 0.402, -0.354, -0.291, -0.326, -0.793, -1.986, 0.223, -1.314, -2.535, -2.109, -2.485, -0.948, -1.215, -1.492, -1.886, 0.323, -0.557, -0.970, -1.090, -1.121, -2.169, -2.480, -0.184, -2.225, -2.711, -3.139, -3.361, -2.259, -2.861, -3.050, -2.772, -0.585, -1.656, -1.705, -1.469, -1.059, -1.105, -5.000, -5.000, -2.599, -3.651, -4.799, -5.000, -3.027, -3.767, -3.065, -2.962, 0.309, -2.079, -1.642, -0.850, -0.397, -0.334, -1.244, -5.000, -2.630, -2.450, -1.922, -2.681, -2.557, -1.695, -2.725, -3.346, -0.470, -0.267, 0.108, -2.158, -0.187, -0.068, -1.293, -0.185, -2.174, -1.970, -1.228, -2.072, -2.506, -1.793, -2.199, -2.485, 0.451, 0.093, 0.618, -0.690, -5.000, -2.037, -1.834, -1.386, -2.736, -2.342, -2.392, -5.000, -3.337, -2.457, -2.914, -3.219, -0.412, -1.067, -0.583, -1.170, -0.826, 0.896, -0.133, -5.000, 0.203, -0.873, 0.108, -5.000, -0.585, -0.202, -0.267, -5.000, -5.000, 1.120, 1.813, -0.267, 1.313, 1.626, 1.268, -5.000, 0.214, 0.672, 1.021, 0.634, 0.714, 0.203, -0.238, 0.203, 1.269, 1.426, 1.365, 0.619, 1.240, 1.352, 0.990, 1.554, 0.896, 1.083, 1.262, 0.244, 1.284, 1.335, 0.885, 0.877, 1.476, 1.552, 1.521, 1.389, -1.078, 0.378, -0.490, 0.255, -1.232, -0.532, 0.042, -0.202, -0.267, -0.502, -0.570, -1.255, 0.560, -0.585, 0.629, 0.309, -0.625, -1.889, -2.230, -5.000, -1.653, -2.315, -2.253, -5.000, -0.180, -1.988, -2.261, -1.588, 0.155, -2.432, -0.033, 0.064, 0.422, -0.115, -1.063, -5.000, -0.389, -0.380, 0.040, -0.150, 0.497, -0.699, -1.313, -0.078, 0.495, 0.248, -0.400, 0.361, 0.678, -0.672, -1.703, 1.253, -0.392, -1.253, -0.585, -1.078, 0.402, -0.210, -0.464, -0.392, 1.035, -0.991, -0.191, 0.589, -1.158, -1.711, -2.195, -1.278, -5.000, -2.548, -2.037, -1.255, -5.000, -1.086, -2.086, -0.356, 0.560, -1.702, -0.940, -0.195, -0.960, -0.842, -1.743, -5.000, -0.515, -1.676, -2.548, -5.000, -0.529, -1.705, -2.310, -1.798, 0.474, -2.101, -1.892, -0.854, 0.603, 0.909, 0.379, -5.000, 0.744, 0.639, 0.725, 0.936, 0.210, -0.388, -1.821, -0.700, 0.949, 0.647, 0.387, 0.746, 0.581, 0.295, -1.390, 1.104, 0.061, -0.572, -0.567, -0.928, 0.565, 0.560, -0.400, -0.330, 0.831, -0.042, 0.179, 0.221, -1.605, -1.752, -1.812, 0.259, -0.975, -2.150, -2.047, -1.653, -0.428, -1.517, -2.303, -1.102, 0.650, -1.012, -0.475, -0.204, -0.826, 0.868, -0.630, -5.000, -1.464, -0.471, -1.145, -5.000, -1.049, -0.878, -1.020, -1.798, -5.000, -0.802, -1.714, 0.331, 0.986, 1.358, 1.104, -5.000, -0.544, 0.531, 0.561, 0.181, -1.132, -0.165, -1.343, -0.986, 1.073, 0.989, 0.474, 0.752, 0.867, 1.328, 0.652, 1.255, -0.550, -0.241, 0.628, -0.960, 0.731, 0.532, -0.019, -0.697, 1.120, 1.137, 1.282, 1.022, 0.272, -0.392, -0.861, 0.126, -0.500, -1.428, -1.149, -1.020, -0.942, -1.438, -1.312, -1.466, 0.070, -0.852, -0.139, -0.168 } 
  };
  memcpy(tptr, &tinf, sizeof(struct _training));
}

